@@ -3,14 +3,8 @@ import BroadcastMessagesBase from './components/base.vue';
 
 export default () => {
   const el = document.querySelector('#js-broadcast-messages');
-  const {
-    page,
-    targetAccessLevelOptions,
-    messagesPath,
-    previewPath,
-    messagesCount,
-    messages,
-  } = el.dataset;
+  const { page, targetAccessLevelOptions, messagesPath, previewPath, messagesCount, messages } =
+    el.dataset;
 
   return new Vue({
     el,
