@@ -12,9 +12,7 @@ export const initAdminOrganizationsIndex = () => {
   const {
     dataset: { appData },
   } = el;
-  const { newOrganizationUrl, organizationsEmptyStateSvgPath } = convertObjectPropsToCamelCase(
-    JSON.parse(appData),
-  );
+  const { newOrganizationUrl } = convertObjectPropsToCamelCase(JSON.parse(appData));
 
   const apolloProvider = new VueApollo({
     defaultClient: createDefaultClient(),
@@ -26,7 +24,6 @@ export const initAdminOrganizationsIndex = () => {
     apolloProvider,
     provide: {
       newOrganizationUrl,
-      organizationsEmptyStateSvgPath,
     },
     render(createElement) {
       return createElement(App);
