@@ -65,3 +65,10 @@ export const TOKENS = [
     ],
   },
 ];
+
+export const SOLO_OWNED_ORGANIZATIONS_REQUESTED_COUNT = 10;
+
+export const SOLO_OWNED_ORGANIZATIONS_EMPTY = {
+  count: 0,
+  nodes: [],
+};
