@@ -1,6 +1,7 @@
 import { createAlert } from '~/alert';
 import { __ } from '~/locale';
 import { validateAdditionalProperties } from '~/tracking/utils';
+import * as Sentry from '~/sentry/sentry_browser_wrapper';
 import axios from './lib/utils/axios_utils';
 import { joinPaths } from './lib/utils/url_utility';
 
@@ -75,7 +76,6 @@ const Api = {
   releaseLinkPath: '/api/:version/projects/:id/releases/:tag_name/assets/links/:link_id',
   mergeRequestsPipeline: '/api/:version/projects/:id/merge_requests/:merge_request_iid/pipelines',
   adminStatisticsPath: '/api/:version/application/statistics',
-  pipelineJobsPath: '/api/:version/projects/:id/pipelines/:pipeline_id/jobs',
   pipelineSinglePath: '/api/:version/projects/:id/pipelines/:pipeline_id',
   pipelinesPath: '/api/:version/projects/:id/pipelines/',
   createPipelinePath: '/api/:version/projects/:id/pipeline',
@@ -727,11 +727,9 @@ const Api = {
       .replace(':id', encodeURIComponent(id))
       .replace(':merge_request_iid', mergeRequestId);
 
-    const params = {};
-
-    if (gon.features.asyncMergeRequestPipelineCreation) {
-      params.async = true;
-    }
+    const params = {
+      async: true,
+    };
 
     return axios.post(url, params);
   },
@@ -799,14 +797,6 @@ const Api = {
     return axios.get(url);
   },
 
-  pipelineJobs(projectId, pipelineId, params) {
-    const url = Api.buildUrl(this.pipelineJobsPath)
-      .replace(':id', encodeURIComponent(projectId))
-      .replace(':pipeline_id', encodeURIComponent(pipelineId));
-
-    return axios.get(url, { params });
-  },
-
   // Return all pipelines for a project or filter by query params
   pipelines(id, options = {}) {
     const url = Api.buildUrl(this.pipelinesPath).replace(':id', encodeURIComponent(id));
@@ -962,11 +952,15 @@ const Api = {
 
     const { data = {} } = { ...window.gl?.snowplowStandardContext };
     const { project_id, namespace_id } = data;
-    return axios.post(
-      url,
-      { event, project_id, namespace_id, additional_properties: additionalProperties },
-      { headers },
-    );
+    return axios
+      .post(
+        url,
+        { event, project_id, namespace_id, additional_properties: additionalProperties },
+        { headers },
+      )
+      .catch((error) => {
+        Sentry.captureException(error);
+      });
   },
 
   buildUrl(url) {
