@@ -4,22 +4,20 @@ import initCollapseSidebarOnWindowResize from './collapse_sidebar_on_window_resi
 import initCopyToClipboard from './copy_to_clipboard';
 import installGlEmojiElement from './gl_emoji';
 import initCopyAsGFM from './markdown/copy_as_gfm';
-import './quick_submit';
+import { initQuickSubmit } from './quick_submit';
 import { initToastMessages } from './toasts';
 import { initGlobalAlerts } from './global_alerts';
 import './shortcuts';
 import './toggler_behavior';
 import './preview_markdown';
+import './find_and_replace';
 
 installGlEmojiElement();
-
 initCopyAsGFM();
 initCopyToClipboard();
-
 initCollapseSidebarOnWindowResize();
-
+initQuickSubmit();
 initToastMessages();
-
 initGlobalAlerts();
 
 window.requestIdleCallback(
