@@ -3,6 +3,7 @@ import highlightCurrentUser from './highlight_current_user';
 import { renderKroki } from './render_kroki';
 import renderMath from './render_math';
 import renderSandboxedMermaid from './render_sandboxed_mermaid';
+import { renderGlql } from './render_glql';
 import { renderJSONTable } from './render_json_table';
 
 function initPopovers(elements) {
@@ -20,12 +21,13 @@ export function renderGFM(element) {
     return;
   }
 
-  const [highlightEls, krokiEls, mathEls, mermaidEls, tableEls, userEls, popoverEls] = [
+  const [highlightEls, krokiEls, mathEls, mermaidEls, tableEls, glqlEls, userEls, popoverEls] = [
     '.js-syntax-highlight',
     '.js-render-kroki[hidden]',
     '.js-render-math',
     '.js-render-mermaid',
     '[data-canonical-lang="json"][data-lang-params="table"]',
+    '[data-canonical-lang="glql"]',
     '.gfm-project_member',
     '.gfm-issue, .gfm-work_item, .gfm-merge_request, .gfm-epic, .gfm-milestone',
   ].map((selector) => Array.from(element.querySelectorAll(selector)));
@@ -37,4 +39,6 @@ export function renderGFM(element) {
   renderJSONTable(tableEls.map((e) => e.parentNode));
   highlightCurrentUser(userEls);
   initPopovers(popoverEls);
+
+  if (gon?.features?.glqlIntegration) renderGlql(glqlEls.map((e) => e.parentNode));
 }
