@@ -2,7 +2,6 @@ import PortalVue from 'portal-vue';
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import BoardApp from '~/boards/components/board_app.vue';
-import '~/boards/filters/due_date_filters';
 import { TYPE_ISSUE, WORKSPACE_GROUP, WORKSPACE_PROJECT } from '~/issues/constants';
 import {
   navigationType,
@@ -36,6 +35,17 @@ defaultClient.cache.policies.addTypePolicies({
       };
     },
   },
+  BoardEpicConnection: {
+    merge(existing = { nodes: [] }, incoming, { args }) {
+      if (!args.after) {
+        return incoming;
+      }
+      return {
+        ...incoming,
+        nodes: [...existing.nodes, ...incoming.nodes],
+      };
+    },
+  },
   Board: {
     fields: {
       epics: {
@@ -55,7 +65,7 @@ function mountBoardApp(el) {
     groupId,
     fullPath,
     rootPath,
-    hasScopedLabelsFeature,
+    wiHasScopedLabelsFeature,
     wiGroupPath,
     wiCanAdminLabel,
   } = el.dataset;
@@ -123,11 +133,12 @@ function mountBoardApp(el) {
       multipleIssueBoardsAvailable: parseBoolean(el.dataset.multipleBoardsAvailable),
       scopedIssueBoardFeatureEnabled: parseBoolean(el.dataset.scopedIssueBoardFeatureEnabled),
       allowSubEpics: false,
-      hasScopedLabelsFeature: parseBoolean(hasScopedLabelsFeature),
+      hasScopedLabelsFeature: parseBoolean(wiHasScopedLabelsFeature),
       hasIterationsFeature: parseBoolean(el.dataset.iterationFeatureAvailable),
       hasIssueWeightsFeature: parseBoolean(el.dataset.weightFeatureAvailable),
       hasIssuableHealthStatusFeature: parseBoolean(el.dataset.healthStatusFeatureAvailable),
       hasSubepicsFeature: parseBoolean(el.dataset.subEpicsFeatureAvailable),
+      hasLinkedItemsEpicsFeature: parseBoolean(el.dataset.hasLinkedItemsEpicsFeature),
     },
     render: (createComponent) => createComponent(BoardApp),
   });
