@@ -1,5 +1,6 @@
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
+import { parseBoolean } from '~/lib/utils/common_utils';
 import PipelineHeader from './header/pipeline_header.vue';
 
 Vue.use(VueApollo);
@@ -11,7 +12,16 @@ export const createPipelineHeaderApp = (elSelector, apolloProvider, graphqlResou
     return;
   }
 
-  const { fullPath, pipelineIid, pipelinesPath } = el.dataset;
+  const {
+    fullPath,
+    pipelineIid,
+    pipelinesPath,
+    identityVerificationPath,
+    identityVerificationRequired,
+    mergeTrainsAvailable,
+    canReadMergeTrain,
+    mergeTrainsPath,
+  } = el.dataset;
 
   // eslint-disable-next-line no-new
   new Vue({
@@ -25,6 +35,11 @@ export const createPipelineHeaderApp = (elSelector, apolloProvider, graphqlResou
         pipelinesPath,
       },
       pipelineIid,
+      identityVerificationPath,
+      identityVerificationRequired: parseBoolean(identityVerificationRequired),
+      mergeTrainsAvailable: parseBoolean(mergeTrainsAvailable),
+      canReadMergeTrain: parseBoolean(canReadMergeTrain),
+      mergeTrainsPath,
     },
     render(createElement) {
       return createElement(PipelineHeader);
