@@ -12,7 +12,16 @@ export default class PipelinesStore {
     this.state.isRunningMergeRequestPipeline = false;
   }
 
-  storePipelines(pipelines = []) {
+  storePipelines(pipelines = [], isUsingAsyncPipelineCreation) {
+    if (isUsingAsyncPipelineCreation && pipelines.length) {
+      const firstPipelineFromTable = this.state.pipelines[0];
+      const firstPipelineFromRequest = pipelines[0];
+
+      if (firstPipelineFromTable?.created_at !== firstPipelineFromRequest?.created_at) {
+        this.toggleIsRunningPipeline(false);
+      }
+    }
+
     this.state.pipelines = pipelines;
   }
 
