@@ -1,4 +1,5 @@
 import Vue from 'vue';
+import { GlToast } from '@gitlab/ui';
 
 import { createAppOptions } from '~/ci/pipeline_editor/options';
 
@@ -9,6 +10,8 @@ export const initPipelineEditor = (selector = '#js-pipeline-editor') => {
     return null;
   }
 
+  Vue.use(GlToast);
+
   const options = createAppOptions(el);
 
   return new Vue(options);
