@@ -103,10 +103,6 @@ export const I18N_CONTACT_ADMIN_TO_REGISTER = s__(
   'Runners|To register new runners, contact your administrator.',
 );
 
-// No runners found
-export const I18N_NO_RESULTS = s__('Runners|No results found');
-export const I18N_EDIT_YOUR_SEARCH = s__('Runners|Edit your search and try again');
-
 // Runner details
 
 export const JOBS_ROUTE_PATH = '/jobs'; // vue-router route path
@@ -200,6 +196,7 @@ export const LINUX_PLATFORM = 'linux';
 export const MACOS_PLATFORM = 'osx';
 export const WINDOWS_PLATFORM = 'windows';
 export const GOOGLE_CLOUD_PLATFORM = 'google_cloud';
+export const GOOGLE_KUBERNETES_ENGINE = 'gke';
 
 // Stages for the google cloud setup
 export const GOOGLE_CLOUD_SETUP_START = 'google_cloud_setup_start';
