@@ -19,13 +19,8 @@ export const initGroupRunners = (selector = '#js-group-runners') => {
     return null;
   }
 
-  const {
-    allowRegistrationToken,
-    registrationToken,
-    newRunnerPath,
-    groupId,
-    groupFullPath,
-  } = el.dataset;
+  const { allowRegistrationToken, registrationToken, newRunnerPath, groupId, groupFullPath } =
+    el.dataset;
 
   const { cacheConfig, typeDefs, localMutations } = createLocalState();
 
