@@ -1,5 +1,7 @@
 import Vue from 'vue';
+import VueApollo from 'vue-apollo';
 import { convertObjectPropsToCamelCase } from '~/lib/utils/common_utils';
+import { defaultClient } from '~/graphql_shared/issuable_client';
 import TriggersList from './components/triggers_list.vue';
 
 const parseJsonArray = (triggers) => {
@@ -10,6 +12,10 @@ const parseJsonArray = (triggers) => {
   }
 };
 
+const apolloProvider = new VueApollo({
+  defaultClient,
+});
+
 export default (containerId = 'js-ci-pipeline-triggers-list') => {
   const containerEl = document.getElementById(containerId);
 
@@ -17,17 +23,18 @@ export default (containerId = 'js-ci-pipeline-triggers-list') => {
     return null;
   }
 
-  const triggers = parseJsonArray(containerEl.dataset.triggers);
+  const initTriggers = parseJsonArray(containerEl.dataset.triggers);
 
   return new Vue({
     el: containerEl,
+    apolloProvider,
     components: {
       TriggersList,
     },
     render(h) {
       return h(TriggersList, {
         props: {
-          triggers,
+          initTriggers,
         },
       });
     },
