@@ -1,4 +1,5 @@
 import { Mark } from '@tiptap/core';
+import { Fragment } from '@tiptap/pm/model';
 import Code from '@tiptap/extension-code';
 import { EXTENSION_PRIORITY_LOWER } from '../constants';
 
@@ -12,6 +13,18 @@ export default Code.extend({
    */
   priority: EXTENSION_PRIORITY_LOWER,
 
+  parseHTML() {
+    return [
+      {
+        tag: 'code',
+        preserveWhitespace: true,
+        getContent(element, schema) {
+          return Fragment.from(schema.text(element.textContent));
+        },
+      },
+    ];
+  },
+
   addKeyboardShortcuts() {
     return {
       ArrowRight: () => {
