@@ -1,4 +1,6 @@
 import Paragraph from '@tiptap/extension-paragraph';
+import { VueNodeViewRenderer } from '@tiptap/vue-2';
+import ParagraphWrapper from '../components/wrappers/paragraph.vue';
 
 export default Paragraph.extend({
   addOptions() {
@@ -20,4 +22,8 @@ export default Paragraph.extend({
       },
     };
   },
+
+  addNodeView() {
+    return VueNodeViewRenderer(ParagraphWrapper);
+  },
 });
