@@ -1,6 +1,7 @@
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import createDefaultClient from '~/lib/graphql';
+import { parseBoolean } from '~/lib/utils/common_utils';
 import ShowDeployment from './components/show_deployment.vue';
 
 Vue.use(VueApollo);
@@ -11,7 +12,14 @@ export const initializeShowDeployment = (selector = 'js-deployment-details') =>
     const apolloProvider = new VueApollo({
       defaultClient: createDefaultClient(),
     });
-    const { projectPath, deploymentIid, environmentName, graphqlEtagKey } = el.dataset;
+    const {
+      projectPath,
+      deploymentIid,
+      environmentName,
+      graphqlEtagKey,
+      protectedEnvironmentsAvailable,
+      protectedEnvironmentsSettingsPath,
+    } = el.dataset;
 
     return new Vue({
       el,
@@ -21,6 +29,8 @@ export const initializeShowDeployment = (selector = 'js-deployment-details') =>
         deploymentIid,
         environmentName,
         graphqlEtagKey,
+        protectedEnvironmentsAvailable: parseBoolean(protectedEnvironmentsAvailable),
+        protectedEnvironmentsSettingsPath,
       },
       render(h) {
         return h(ShowDeployment);
