@@ -8,14 +8,8 @@ import createRouter from './router';
 
 export default () => {
   const el = document.querySelector('.js-design-management');
-  const {
-    issueIid,
-    projectPath,
-    issuePath,
-    registerPath,
-    signInPath,
-    newCommentTemplatePaths,
-  } = el.dataset;
+  const { issueIid, projectPath, issuePath, registerPath, signInPath, newCommentTemplatePaths } =
+    el.dataset;
   const router = createRouter(issuePath);
 
   apolloProvider.clients.defaultClient.cache.writeQuery({
