@@ -9,56 +9,56 @@ export const ENVIRONMENT_DETAILS_TABLE_FIELDS = [
     label: __('Status'),
     columnClass: 'gl-w-2/20',
     tdClass: '!gl-align-middle',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'id',
     label: __('ID'),
     columnClass: 'gl-w-1/20',
     tdClass: '!gl-align-middle',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'triggerer',
     label: __('Triggerer'),
     columnClass: 'gl-w-2/20',
     tdClass: '!gl-align-middle',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'commit',
     label: __('Commit'),
     columnClass: 'gl-w-4/20',
     tdClass: '!gl-align-middle',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'job',
     label: __('Job'),
     columnClass: 'gl-w-3/20',
     tdClass: '!gl-align-middle',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'created',
     label: __('Created'),
     columnClass: 'gl-w-2/20',
     tdClass: '!gl-align-middle gl-whitespace-nowrap',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
-    key: 'deployed',
-    label: __('Deployed'),
+    key: 'finished',
+    label: __('Finished'),
     columnClass: 'gl-w-2/20',
     tdClass: '!gl-align-middle gl-whitespace-nowrap',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
   {
     key: 'actions',
     label: __('Actions'),
     columnClass: 'gl-w-3/20',
     tdClass: '!gl-align-middle gl-whitespace-nowrap',
-    thClass: 'gl-border-t-none!',
+    thClass: '!gl-border-t-0',
   },
 ];
 
@@ -74,3 +74,17 @@ export const translations = {
 
 export const environmentsLearnMorePath = helpPagePath('ci/environments/index');
 export const environmentsHelpPagePath = helpPagePath('ci/yaml/index', { anchor: 'environment' });
+
+export const DEPLOYMENTS_SORT_OPTIONS = [
+  {
+    value: 'createdAt',
+    text: s__('Environment|Created on'),
+  },
+  {
+    value: 'finishedAt',
+    text: s__('Environment|Finished on'),
+  },
+];
+
+export const DIRECTION_DESCENDING = 'DESC';
+export const DIRECTION_ASCENDING = 'ASC';
