@@ -17,7 +17,7 @@ import {
 } from '~/work_items/constants';
 import AjaxCache from './lib/utils/ajax_cache';
 import { spriteIcon } from './lib/utils/common_utils';
-import { parsePikadayDate } from './lib/utils/datetime_utility';
+import { newDate } from './lib/utils/datetime_utility';
 import { unicodeLetters } from './lib/utils/regexp';
 import { renderVueComponentForLegacyJS } from './render_vue_component_for_legacy_js';
 
@@ -220,7 +220,7 @@ class GfmAutoComplete {
           tpl += ' <small class="params"><%- params.join(" ") %></small>';
         }
         if (value.warning && value.icon && value.icon === 'confidential') {
-          tpl += `<small class="description gl-display-flex gl-align-items-center">${spriteIcon(
+          tpl += `<small class="description gl-flex gl-items-center">${spriteIcon(
             'eye-slash',
             's16 gl-mr-2',
           )}<em><%- warning %></em></small>`;
@@ -498,6 +498,7 @@ class GfmAutoComplete {
       alias: ISSUES_ALIAS,
       searchKey: 'search',
       maxLen: 100,
+      delay: DEFAULT_DEBOUNCE_AND_THROTTLE_MS,
       displayTpl(value) {
         let tmpl = GfmAutoComplete.Loading.template;
         if (value.title != null) {
@@ -553,7 +554,7 @@ class GfmAutoComplete {
               return m;
             }
 
-            const dueDate = m.due_date ? parsePikadayDate(m.due_date) : null;
+            const dueDate = m.due_date ? newDate(m.due_date) : null;
             const expired = dueDate ? Date.now() > dueDate.getTime() : false;
 
             return {
@@ -1016,6 +1017,11 @@ class GfmAutoComplete {
     GfmAutoComplete.glEmojiTag = Emoji.glEmojiTag;
   }
 
+  updateDataSources(newDataSources) {
+    this.dataSources = { ...this.dataSources, ...newDataSources };
+    this.clearCache();
+  }
+
   clearCache() {
     this.cachedData = {};
   }
@@ -1084,7 +1090,7 @@ GfmAutoComplete.atTypeMap = {
   '[[': 'wikis',
 };
 
-GfmAutoComplete.typesWithBackendFiltering = ['vulnerabilities', 'members'];
+GfmAutoComplete.typesWithBackendFiltering = ['vulnerabilities', 'members', 'issues'];
 
 GfmAutoComplete.isTypeWithBackendFiltering = (type) =>
   GfmAutoComplete.typesWithBackendFiltering.includes(GfmAutoComplete.atTypeMap[type]);
