@@ -11,8 +11,12 @@ import {
   WIDGET_TYPE_NOTES,
   WIDGET_TYPE_AWARD_EMOJI,
   WIDGET_TYPE_HIERARCHY,
+  WIDGET_TYPE_DESIGNS,
 } from '~/work_items/constants';
+
+import isExpandedHierarchyTreeChildQuery from '~/work_items/graphql/client/is_expanded_hierarchy_tree_child.query.graphql';
 import activeBoardItemQuery from 'ee_else_ce/boards/graphql/client/active_board_item.query.graphql';
+import activeDiscussionQuery from '~/work_items/components/design_management/graphql/client/active_design_discussion.query.graphql';
 import { updateNewWorkItemCache, workItemBulkEdit } from '~/work_items/graphql/resolvers';
 
 export const config = {
@@ -37,6 +41,8 @@ export const config = {
           epicBoardList: {
             keyArgs: ['id'],
           },
+          isExpandedHierarchyTreeChild: (_, { variables, toReference }) =>
+            toReference({ __typename: 'LocalWorkItemChildIsExpanded', id: variables.id }),
         },
       },
       Project: {
@@ -137,7 +143,11 @@ export const config = {
                 }
 
                 // we want to concat next page of children work items within Hierarchy widget to the existing ones
-                if (incomingWidget?.type === WIDGET_TYPE_HIERARCHY && context.variables.endCursor) {
+                if (
+                  incomingWidget?.type === WIDGET_TYPE_HIERARCHY &&
+                  context.variables.endCursor &&
+                  incomingWidget.children?.nodes
+                ) {
                   // concatPagination won't work because we were placing new widget here so we have to do this manually
                   return {
                     ...incomingWidget,
@@ -148,6 +158,11 @@ export const config = {
                   };
                 }
 
+                // Prevent cache being overwritten when opening a design
+                if (incomingWidget?.type === WIDGET_TYPE_DESIGNS && context.variables.filenames) {
+                  return existingWidget;
+                }
+
                 return { ...existingWidget, ...incomingWidget };
               });
             },
@@ -250,9 +265,33 @@ export const resolvers = {
     updateNewWorkItem(_, { input }, { cache }) {
       updateNewWorkItemCache(input, cache);
     },
-    workItemBulkUpdate(_, { input }) {
+    localWorkItemBulkUpdate(_, { input }) {
       return workItemBulkEdit(input);
     },
+    toggleHierarchyTreeChild(_, { id, isExpanded = false }, { cache }) {
+      cache.writeQuery({
+        query: isExpandedHierarchyTreeChildQuery,
+        variables: { id },
+        data: {
+          isExpandedHierarchyTreeChild: {
+            id,
+            isExpanded,
+            __typename: 'LocalWorkItemChildIsExpanded',
+          },
+        },
+      });
+    },
+    updateActiveDesignDiscussion: (_, { id = null, source }, { cache }) => {
+      const data = {
+        activeDesignDiscussion: {
+          __typename: 'ActiveDesignDiscussion',
+          id,
+          source,
+        },
+      };
+
+      cache.writeQuery({ query: activeDiscussionQuery, data });
+    },
   },
 };
 
