@@ -1,5 +1,6 @@
 import axios from '~/lib/utils/axios_utils';
 import { joinPaths } from '~/lib/utils/url_utility';
+import { getGroupMembers } from '~/rest_api';
 
 const GROUP_SUBGROUPS_PATH = '/-/autocomplete/group_subgroups.json';
 
@@ -25,3 +26,10 @@ export const getSubGroups = (options = defaultOptions) => {
     },
   });
 };
+
+export const getUsers = (query) => {
+  return getGroupMembers(gon.current_group_id, false, {
+    query,
+    per_page: 20,
+  });
+};
