@@ -1,6 +1,4 @@
-export const LEVEL_TYPES = {
-  GROUP: 'group',
-};
+export const LEVEL_TYPES = { ROLE: 'role', GROUP: 'group', USER: 'user' };
 
 export const README_MODAL_ID = 'add_group_readme_modal';
 export const GITLAB_README_PROJECT = 'gitlab-profile';
