@@ -24,24 +24,21 @@ export async function startIde(options) {
     return;
   }
 
-  const oAuthCallbackDomainMismatchApp = new OAuthCallbackDomainMismatchErrorApp(
-    ideElement,
-    ideElement.dataset.callbackUrls,
-  );
-
-  if (oAuthCallbackDomainMismatchApp.isVisitingFromNonRegisteredOrigin()) {
-    oAuthCallbackDomainMismatchApp.renderError();
-    return;
-  }
-
   const useNewWebIde = parseBoolean(ideElement.dataset.useNewWebIde);
 
-  if (useNewWebIde) {
-    const { initGitlabWebIDE } = await import('./init_gitlab_web_ide');
-    initGitlabWebIDE(ideElement);
-  } else {
+  if (!useNewWebIde) {
     resetServiceWorkersPublicPath();
     const { initLegacyWebIDE } = await import('./init_legacy_web_ide');
     initLegacyWebIDE(ideElement, options);
+    return;
   }
+
+  const oAuthCallbackDomainMismatchApp = new OAuthCallbackDomainMismatchErrorApp(ideElement);
+
+  if (oAuthCallbackDomainMismatchApp.shouldRenderError()) {
+    oAuthCallbackDomainMismatchApp.renderError();
+    return;
+  }
+  const { initGitlabWebIDE } = await import('./init_gitlab_web_ide');
+  initGitlabWebIDE(ideElement);
 }
