@@ -7,7 +7,13 @@
 export const setupRootElement = (el) => {
   const newEl = document.createElement(el.tagName);
   newEl.id = el.id;
-  newEl.classList.add('gl--flex-center', 'gl-relative', 'gl-h-full');
+  newEl.classList.add(
+    'gl-flex',
+    'gl-justify-center',
+    'gl-items-center',
+    'gl-relative',
+    'gl-h-full',
+  );
   el.replaceWith(newEl);
 
   return newEl;
