@@ -51,17 +51,17 @@ export const DEFAULT_WORKLOAD_TABLE_FIELDS = [
   {
     key: 'name',
     label: s__('KubernetesDashboard|Name'),
-    tdClass: 'gl-md-w-half gl-lg-w-40p gl-break-anywhere',
+    tdClass: 'md:gl-w-1/2 lg:gl-w-4/10 gl-break-anywhere',
   },
   {
     key: 'status',
     label: s__('KubernetesDashboard|Status'),
-    tdClass: 'gl-md-w-15',
+    tdClass: 'md:gl-w-15',
   },
   {
     key: 'namespace',
     label: s__('KubernetesDashboard|Namespace'),
-    tdClass: 'gl-md-w-30p gl-lg-w-40p gl-break-anywhere',
+    tdClass: 'gl-md-w-30p lg:gl-w-4/10 gl-break-anywhere',
   },
   {
     key: 'age',
