@@ -2,7 +2,13 @@ import Vue from 'vue';
 
 export const staticBreadcrumbs = Vue.observable({});
 
-export const injectVueAppBreadcrumbs = (router, BreadcrumbsComponent, apolloProvider = null) => {
+export const injectVueAppBreadcrumbs = (
+  router,
+  BreadcrumbsComponent,
+  apolloProvider = null,
+  provide = {},
+  // eslint-disable-next-line max-params
+) => {
   const injectBreadcrumbEl = document.querySelector('#js-injected-page-breadcrumbs');
 
   if (!injectBreadcrumbEl) {
@@ -18,6 +24,7 @@ export const injectVueAppBreadcrumbs = (router, BreadcrumbsComponent, apolloProv
     el: injectBreadcrumbEl,
     router,
     apolloProvider,
+    provide,
     render(createElement) {
       return createElement(BreadcrumbsComponent, {
         class: injectBreadcrumbEl.className,
