@@ -1,6 +1,4 @@
-export * from './datetime/timeago_utility';
-export * from './datetime/date_format_utility';
 export * from './datetime/date_calculation_utility';
-export * from './datetime/pikaday_utility';
-export * from './datetime/time_spent_utility';
+export * from './datetime/date_format_utility';
 export * from './datetime/locale_dateformat';
+export * from './datetime/timeago_utility';
