@@ -452,19 +452,6 @@ export function isValidURL(url) {
   }
 }
 
-/**
- * Returns the sanitized url when not safe
- *
- * @param {String} url
- * @returns {String}
- */
-export function sanitizeUrl(url) {
-  if (!isValidURL(url)) {
-    return 'about:blank';
-  }
-  return url;
-}
-
 /**
  * Returns a normalized url
  *
@@ -793,3 +780,14 @@ export function buildURLwithRefType({ base = window.location.origin, path, refTy
   }
   return url.pathname + url.search;
 }
+
+export function stripRelativeUrlRootFromPath(path) {
+  const relativeUrlRoot = joinPaths(window.gon.relative_url_root, '/');
+
+  // If we have no relative url root or path doesn't start with it, just return the path
+  if (relativeUrlRoot === '/' || !path.startsWith(relativeUrlRoot)) {
+    return path;
+  }
+
+  return joinPaths('/', path.substring(relativeUrlRoot.length));
+}
