@@ -1,4 +1,3 @@
-import Vue from 'vue';
 import { s__ } from '~/locale';
 import * as types from './mutation_types';
 import { findMember } from './utils';
@@ -17,7 +16,7 @@ export default {
       return;
     }
 
-    Vue.set(member, 'expiresAt', expiresAt);
+    member.expiresAt = expiresAt;
   },
   [types.RECEIVE_MEMBER_EXPIRATION_ERROR](state, { error }) {
     state.errorMessage =
