@@ -119,6 +119,7 @@ function mountPipelines() {
           targetProjectFullPath: mrWidgetData?.target_project_full_path || '',
           projectId: pipelineTableViewEl.dataset.projectId,
           mergeRequestId: mrWidgetData ? mrWidgetData.iid : null,
+          isMergeRequestTable: true,
         },
       });
     },
@@ -172,7 +173,7 @@ export function toggleLoader(state) {
 }
 
 export function getActionFromHref(pathName) {
-  let action = pathName.match(/\/(\d+)\/(commits|diffs|pipelines).*$/);
+  let action = pathName.match(/\/(\d+)\/(commits|diffs|pipelines|reports).*$/);
 
   if (action) {
     action = action.at(-1).replace(/(^\/|\.html)/g, '');
@@ -186,6 +187,7 @@ export function getActionFromHref(pathName) {
 export const pageBundles = {
   show: () => import(/* webpackPrefetch: true */ '~/mr_notes/mount_app'),
   diffs: () => import(/* webpackPrefetch: true */ '~/diffs'),
+  reports: () => import('ee_else_ce/merge_requests/reports'),
 };
 
 export default class MergeRequestTabs {
@@ -208,7 +210,7 @@ export default class MergeRequestTabs {
     this.pageLayout = document.querySelector('.layout-page');
     this.expandSidebar = document.querySelectorAll('.js-expand-sidebar, .js-sidebar-toggle');
     this.paddingTop = 16;
-    this.actionRegex = /\/(commits|diffs|pipelines)(\.html)?\/?$/;
+    this.actionRegex = /\/(commits|diffs|pipelines|reports)(\.html)?\/?$/;
 
     this.scrollPositions = {};
 
@@ -365,6 +367,8 @@ export default class MergeRequestTabs {
         // this.hideSidebar();
         this.resetViewContainer();
         this.mountPipelinesView();
+      } else if (action === 'reports') {
+        this.resetViewContainer();
       } else {
         const notesTab = this.mergeRequestTabs.querySelector('.notes-tab');
         const notesPane = this.mergeRequestTabPanes.querySelector('#notes');
@@ -433,18 +437,20 @@ export default class MergeRequestTabs {
   setCurrentAction(action) {
     this.currentAction = action;
 
+    const pathname = location.pathname.replace(/\/*$/, '');
+
     // Remove a trailing '/commits' '/diffs' '/pipelines'
-    let newState = location.pathname.replace(this.actionRegex, '');
+    let newStatePathname = pathname.replace(this.actionRegex, '');
 
     // Append the new action if we're on a tab other than 'notes'
     if (this.currentAction !== 'show' && this.currentAction !== 'new') {
-      newState += `/${this.currentAction}`;
+      newStatePathname += `/${this.currentAction}`;
     }
 
     // Ensure parameters and hash come along for the ride
-    newState += location.search + location.hash;
+    const newState = newStatePathname + location.search + location.hash;
 
-    if (window.location.pathname !== newState) {
+    if (pathname !== newStatePathname) {
       window.history.pushState(
         {
           url: newState,
