@@ -17,6 +17,7 @@ export async function mountMergeRequestListsApp() {
   Vue.use(VueRouter);
 
   const {
+    autocompleteAwardEmojisPath,
     fullPath,
     hasAnyMergeRequests,
     hasScopedLabelsFeature,
@@ -30,6 +31,16 @@ export async function mountMergeRequestListsApp() {
     email,
     exportCsvPath,
     rssUrl,
+    releasesEndpoint,
+    canBulkUpdate,
+    environmentNamesPath,
+    mergeTrainsPath,
+    defaultBranch,
+    initialEmail,
+    emailsHelpPagePath,
+    quickActionsHelpPath,
+    markdownHelpPath,
+    resetPath,
   } = el.dataset;
 
   return new Vue({
@@ -45,6 +56,7 @@ export async function mountMergeRequestListsApp() {
     }),
     provide: {
       fullPath,
+      autocompleteAwardEmojisPath,
       hasAnyMergeRequests: parseBoolean(hasAnyMergeRequests),
       hasScopedLabelsFeature: parseBoolean(hasScopedLabelsFeature),
       initialSort,
@@ -57,6 +69,16 @@ export async function mountMergeRequestListsApp() {
       email,
       exportCsvPath,
       rssUrl,
+      releasesEndpoint,
+      canBulkUpdate: parseBoolean(canBulkUpdate),
+      environmentNamesPath,
+      mergeTrainsPath,
+      defaultBranch,
+      initialEmail,
+      emailsHelpPagePath,
+      quickActionsHelpPath,
+      markdownHelpPath,
+      resetPath,
     },
     render: (createComponent) => createComponent(MergeRequestsListApp),
   });
