@@ -16,7 +16,6 @@ export default function InitMoreActionsDropdown() {
       isActive,
       showDelete,
       isDetailPage,
-      canReadMilestone,
       milestoneUrl,
       editUrl,
       closeUrl,
@@ -25,6 +24,7 @@ export default function InitMoreActionsDropdown() {
       groupName,
       issueCount,
       mergeRequestCount,
+      size,
     } = el.dataset;
 
     return new Vue({
@@ -36,7 +36,6 @@ export default function InitMoreActionsDropdown() {
         isActive: parseBoolean(isActive),
         showDelete: parseBoolean(showDelete),
         isDetailPage: parseBoolean(isDetailPage),
-        canReadMilestone: parseBoolean(canReadMilestone),
         milestoneUrl,
         editUrl,
         closeUrl,
@@ -45,6 +44,7 @@ export default function InitMoreActionsDropdown() {
         groupName,
         issueCount: Number(issueCount),
         mergeRequestCount: Number(mergeRequestCount),
+        size: size || 'medium',
       },
       render: (createElement) => createElement(MoreActionsDropdown),
     });
