@@ -9,6 +9,7 @@ export const uploadModel = ({
   subfolder,
   maxAllowedFileSize,
   onUploadProgress,
+  cancelToken,
 }) => {
   if (!file) {
     return Promise.resolve();
@@ -37,5 +38,5 @@ export const uploadModel = ({
   }
 
   const importUrl = joinPaths(importPath, subfolder, encodeURIComponent(file.name));
-  return axios.put(importUrl, file, { onUploadProgress });
+  return axios.put(importUrl, file, { onUploadProgress, cancelToken });
 };
