@@ -8,7 +8,8 @@ export const initOrganizationsActivity = () => {
   const {
     dataset: { appData },
   } = el;
-  const { organizationActivityPath } = convertObjectPropsToCamelCase(JSON.parse(appData));
+  const { organizationActivityPath, organizationActivityEventTypes, organizationActivityAllEvent } =
+    convertObjectPropsToCamelCase(JSON.parse(appData));
 
   return new Vue({
     el,
@@ -17,6 +18,8 @@ export const initOrganizationsActivity = () => {
       return createElement(OrganizationsActivityApp, {
         props: {
           organizationActivityPath,
+          organizationActivityEventTypes,
+          organizationActivityAllEvent,
         },
       });
     },
