@@ -1,5 +1,12 @@
 import { __ } from '~/locale';
-import { SORT_ITEM_NAME, SORT_ITEM_CREATED_AT, SORT_ITEM_UPDATED_AT } from '../shared/constants';
+import {
+  SORT_ITEM_NAME,
+  SORT_ITEM_CREATED_AT,
+  SORT_ITEM_UPDATED_AT,
+  SORT_NAME,
+  SORT_CREATED_AT,
+  SORT_UPDATED_AT,
+} from '../shared/constants';
 
 export const DISPLAY_QUERY_GROUPS = 'groups';
 export const DISPLAY_QUERY_PROJECTS = 'projects';
@@ -19,3 +26,9 @@ export const DISPLAY_LISTBOX_ITEMS = [
 ];
 
 export const SORT_ITEMS = [SORT_ITEM_NAME, SORT_ITEM_CREATED_AT, SORT_ITEM_UPDATED_AT];
+
+export const SORT_ITEMS_GRAPHQL_ENUMS = {
+  [SORT_NAME]: 'NAME',
+  [SORT_CREATED_AT]: 'CREATED',
+  [SORT_UPDATED_AT]: 'UPDATED',
+};
