@@ -4,6 +4,7 @@ import VueRouter from 'vue-router';
 import createDefaultClient from '~/lib/graphql';
 import { convertObjectPropsToCamelCase } from '~/lib/utils/common_utils';
 import { ORGANIZATION_ROOT_ROUTE_NAME } from '~/organizations/shared/constants';
+import { userPreferenceSortName, userPreferenceSortDirection } from './utils';
 import App from './components/app.vue';
 
 export const createRouter = () => {
@@ -28,13 +29,14 @@ export const initOrganizationsGroupsAndProjects = () => {
   } = el;
   const {
     organizationGid,
-    projectsEmptyStateSvgPath,
-    groupsEmptyStateSvgPath,
     newGroupPath,
+    groupsPath,
     newProjectPath,
     canCreateGroup,
     canCreateProject,
     hasGroups,
+    userPreferenceSort,
+    userPreferenceDisplay,
   } = convertObjectPropsToCamelCase(JSON.parse(appData));
 
   Vue.use(VueRouter);
@@ -50,13 +52,15 @@ export const initOrganizationsGroupsAndProjects = () => {
     router,
     provide: {
       organizationGid,
-      projectsEmptyStateSvgPath,
-      groupsEmptyStateSvgPath,
       newGroupPath,
+      groupsPath,
       newProjectPath,
       canCreateGroup,
       canCreateProject,
       hasGroups,
+      userPreferenceSortName: userPreferenceSortName(userPreferenceSort),
+      userPreferenceSortDirection: userPreferenceSortDirection(userPreferenceSort),
+      userPreferenceDisplay,
     },
     render(createElement) {
       return createElement(App);
