@@ -31,9 +31,8 @@ export const initOrganizationsShow = () => {
     organization,
     groupsAndProjectsOrganizationPath,
     usersOrganizationPath,
-    projectsEmptyStateSvgPath,
-    groupsEmptyStateSvgPath,
     newGroupPath,
+    groupsPath,
     newProjectPath,
     associationCounts,
     canCreateProject,
@@ -54,9 +53,8 @@ export const initOrganizationsShow = () => {
     router,
     provide: {
       organizationGid,
-      projectsEmptyStateSvgPath,
-      groupsEmptyStateSvgPath,
       newGroupPath,
+      groupsPath,
       newProjectPath,
       canCreateProject,
       canCreateGroup,
