@@ -11,14 +11,8 @@ export const initDependencyProxyApp = () => {
   if (!el) {
     return null;
   }
-  const {
-    endpoint,
-    groupPath,
-    groupId,
-    noManifestsIllustration,
-    canClearCache,
-    settingsPath,
-  } = el.dataset;
+  const { endpoint, groupPath, groupId, noManifestsIllustration, canClearCache, settingsPath } =
+    el.dataset;
   return new Vue({
     el,
     apolloProvider,
