@@ -1,15 +1,7 @@
 import { parseIntPagination, normalizeHeaders } from '~/lib/utils/common_utils';
-import { GROUP_PAGE_TYPE } from '../constants';
 import * as types from './mutation_types';
 
 export default {
-  [types.SET_INITIAL_STATE](state, config) {
-    state.config = {
-      ...config,
-      isGroupPage: config.pageType === GROUP_PAGE_TYPE,
-    };
-  },
-
   [types.SET_PACKAGE_LIST_SUCCESS](state, packages) {
     state.packages = packages;
   },
