@@ -3,16 +3,6 @@ export default () => ({
    * Determine if the component is loading data from the API
    */
   isLoading: false,
-  /**
-   * configuration object, set once at store creation with the following structure
-   * {
-   *  resourceId: String,
-   *  pageType: String,
-   *  emptyListIllustration: String,
-   *  comingSoon: { projectPath: String, suggestedContributions : String } | null;
-   * }
-   */
-  config: {},
   /**
    * Each object in `packages` has the following structure:
    * {
