@@ -1,5 +1,6 @@
 import { addShortcutsExtension } from '~/behaviors/shortcuts';
 import ShortcutsBlob from '~/behaviors/shortcuts/shortcuts_blob';
+import { shortcircuitPermalinkButton } from '~/blob/utils';
 import ShortcutsNavigation from '~/behaviors/shortcuts/shortcuts_navigation';
 import BlobForkSuggestion from '~/blob/blob_fork_suggestion';
 import BlobLinePermalinkUpdater from '~/blob/blob_line_permalink_updater';
@@ -15,15 +16,10 @@ export default () => {
     document.querySelectorAll('.js-data-file-blob-permalink-url, .js-blob-blame-link'),
   );
 
-  const fileBlobPermalinkUrlElement = document.querySelector('.js-data-file-blob-permalink-url');
-  const fileBlobPermalinkUrl =
-    fileBlobPermalinkUrlElement && fileBlobPermalinkUrlElement.getAttribute('href');
+  shortcircuitPermalinkButton();
 
   addShortcutsExtension(ShortcutsNavigation);
-  addShortcutsExtension(ShortcutsBlob, {
-    fileBlobPermalinkUrl,
-    fileBlobPermalinkUrlElement,
-  });
+  addShortcutsExtension(ShortcutsBlob);
 
   new BlobForkSuggestion({
     openButtons: document.querySelectorAll('.js-edit-blob-link-fork-toggler'),
