@@ -1,7 +1,7 @@
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import createDefaultClient from '~/lib/graphql';
-import { parseBoolean } from '~/lib/utils/common_utils';
+import { parseBoolean, convertObjectPropsToCamelCase } from '~/lib/utils/common_utils';
 import settingsPanel from './components/settings_panel.vue';
 
 Vue.use(VueApollo);
@@ -20,6 +20,7 @@ export default function initProjectPermissionsSettings() {
 
   const {
     additionalInformation,
+    cascadingSettingsData,
     confirmButtonText,
     confirmDangerMessage,
     htmlConfirmationMessage,
@@ -28,12 +29,23 @@ export default function initProjectPermissionsSettings() {
     phrase: confirmationPhrase,
   } = mountPoint.dataset;
 
+  let cascadingSettingsDataParsed;
+
+  try {
+    cascadingSettingsDataParsed = convertObjectPropsToCamelCase(JSON.parse(cascadingSettingsData), {
+      deep: true,
+    });
+  } catch {
+    cascadingSettingsDataParsed = null;
+  }
+
   return new Vue({
     el: mountPoint,
     name: 'ProjectPermissionsRoot',
     apolloProvider,
     provide: {
       additionalInformation,
+      cascadingSettingsData: cascadingSettingsDataParsed,
       confirmDangerMessage,
       confirmButtonText,
       htmlConfirmationMessage: parseBoolean(htmlConfirmationMessage),
