@@ -23,11 +23,12 @@ const PERSISTENT_USER_CALLOUTS = [
   '.js-geo-migrate-hashed-storage-callout',
   '.js-unlimited-members-during-trial-alert',
   '.js-branch-rules-info-callout',
+  '.js-branch-rules-tip-callout',
   '.js-namespace-over-storage-users-combined-alert',
   '.js-joining-a-project-alert',
   '.js-all-seats-used',
   '.js-period-in-terraform-state-name-alert',
-  '.js-expired-duo-pro-trial-widget',
+  '.js-new-mr-dashboard-banner',
 ];
 
 const initCallouts = () => {
