@@ -81,11 +81,11 @@ const validateGroupNamespaceDropdown = (e) => {
     e.preventDefault();
     dropdownButton().classList.add(invalidDropdownClass);
     namespaceButton().classList.add(invalidDropdownClass);
-    namespaceError().classList.remove('gl-display-none');
+    namespaceError().classList.remove('gl-hidden');
   } else {
     dropdownButton().classList.remove(invalidDropdownClass);
     namespaceButton().classList.remove(invalidDropdownClass);
-    namespaceError().classList.add('gl-display-none');
+    namespaceError().classList.add('gl-hidden');
   }
 };
 
@@ -96,11 +96,11 @@ const checkProjectName = (projectNameInput) => {
   if (!projectNameError) return;
   if (msg) {
     projectNameError.innerText = msg;
-    projectNameError.classList.remove('gl-display-none');
-    projectNameDescription.classList.add('gl-display-none');
+    projectNameError.classList.remove('gl-hidden');
+    projectNameDescription.classList.add('gl-hidden');
   } else {
-    projectNameError.classList.add('gl-display-none');
-    projectNameDescription.classList.remove('gl-display-none');
+    projectNameError.classList.add('gl-hidden');
+    projectNameDescription.classList.remove('gl-hidden');
   }
 };
 
@@ -123,7 +123,7 @@ const setProjectNamePathHandlers = ($projectNameInput, $projectPathInput) => {
     hasUserDefinedProjectPath = $projectPathInput.value.trim().length > 0;
 
     specialRepo.classList.toggle(
-      'gl-display-none',
+      'gl-hidden',
       $projectPathInput.value !== $projectPathInput.dataset.username,
     );
   };
@@ -262,7 +262,7 @@ const bindEvents = () => {
     const selectedTemplate = DEFAULT_PROJECT_TEMPLATES[value];
     $selectedTemplateText.textContent = selectedTemplate.text;
     const clone = document.querySelector(selectedTemplate.icon).cloneNode(true);
-    clone.classList.add('d-block');
+    clone.classList.add('gl-block');
 
     $selectedIcon.append(clone);
 
