@@ -26,6 +26,8 @@ export default function mountBranchRules(el, store) {
     showStatusChecks,
     showApprovers,
     showCodeOwners,
+    showEnterpriseAccessLevels,
+    canAdminProtectedBranches,
   } = el.dataset;
 
   return new Vue({
@@ -43,6 +45,8 @@ export default function mountBranchRules(el, store) {
       showStatusChecks: parseBoolean(showStatusChecks),
       showApprovers: parseBoolean(showApprovers),
       showCodeOwners: parseBoolean(showCodeOwners),
+      showEnterpriseAccessLevels: parseBoolean(showEnterpriseAccessLevels),
+      canAdminProtectedBranches: parseBoolean(canAdminProtectedBranches),
     },
     render(h) {
       return h(View);
