@@ -1,5 +1,5 @@
 import Tracking from '~/tracking';
-import { MAX_ITEM_LENGTH } from './data';
+import { LANGUAGE_DEFAULT_ITEM_LENGTH } from '../../constants';
 
 export const TRACKING_CATEGORY = 'Language filters';
 export const TRACKING_LABEL_FILTERS = 'Filters';
@@ -9,7 +9,7 @@ export const TRACKING_LABEL_SHOW_MORE = 'Show More';
 export const TRACKING_LABEL_APPLY = 'Apply Filters';
 export const TRACKING_LABEL_RESET = 'Reset Filters';
 export const TRACKING_LABEL_ALL = 'All Filters';
-export const TRACKING_PROPERTY_MAX = `More than ${MAX_ITEM_LENGTH} filters to show`;
+export const TRACKING_PROPERTY_MAX = `More than ${LANGUAGE_DEFAULT_ITEM_LENGTH} filters to show`;
 
 export const TRACKING_ACTION_CLICK = 'search:agreggations:language:click';
 export const TRACKING_ACTION_SHOW = 'search:agreggations:language:show';
@@ -27,3 +27,6 @@ export const trackShowHasOverMax = () =>
     label: TRACKING_LABEL_MAX,
     property: TRACKING_PROPERTY_MAX,
   });
+
+export const TRACKING_LABEL_SET = 'set';
+export const TRACKING_LABEL_CHECKBOX = 'checkbox';
