@@ -1,5 +1,3 @@
-import { languageFilterData } from '~/search/sidebar/components/language_filter/data';
-
 export const convertFiltersData = (rawBuckets) =>
   rawBuckets.reduce(
     (acc, bucket) => ({
@@ -13,5 +11,5 @@ export const convertFiltersData = (rawBuckets) =>
         },
       },
     }),
-    { ...languageFilterData, filters: {} },
+    { filters: {} },
   );
