@@ -1,11 +1,11 @@
+import { omitBy } from 'lodash';
 import Api from '~/api';
 import { createAlert } from '~/alert';
 import axios from '~/lib/utils/axios_utils';
 import { visitUrl, setUrlParams, getNormalizedURL, updateHistory } from '~/lib/utils/url_utility';
 import { logError } from '~/lib/logger';
 import { __ } from '~/locale';
-import { labelFilterData } from '~/search/sidebar/components/label_filter/data';
-import { SCOPE_BLOB, SEARCH_TYPE_ZOEKT } from '~/search/sidebar/constants';
+import { SCOPE_BLOB, SEARCH_TYPE_ZOEKT, LABEL_FILTER_PARAM } from '~/search/sidebar/constants';
 import {
   GROUPS_LOCAL_STORAGE_KEY,
   PROJECTS_LOCAL_STORAGE_KEY,
@@ -118,13 +118,14 @@ export const setQuery = ({ state, commit, getters }, { key, value }) => {
     getters.currentScope === SCOPE_BLOB &&
     gon.features.zoektMultimatchFrontend
   ) {
-    const newUrl = setUrlParams({ ...state.query, page: null }, window.location.href, false, true);
+    const newUrl = setUrlParams({ ...state.query }, window.location.href, false, true);
     updateHistory({ state: state.query, url: newUrl, replace: true });
   }
 };
 
 export const applyQuery = ({ state }) => {
-  visitUrl(setUrlParams({ ...state.query, page: null }, window.location.href, false, true));
+  const query = omitBy(state.query, (item) => item === '');
+  visitUrl(setUrlParams({ ...query, page: null }, window.location.href, true, true));
 };
 
 export const resetQuery = ({ state }) => {
@@ -146,10 +147,9 @@ export const resetQuery = ({ state }) => {
   );
 };
 
-export const closeLabel = ({ state, commit }, { key }) => {
-  const labels = state?.query?.labels.filter((labelKey) => labelKey !== key);
-
-  setQuery({ state, commit }, { key: labelFilterData.filterParam, value: labels });
+export const closeLabel = ({ state, commit }, { title }) => {
+  const labels = state?.query?.[LABEL_FILTER_PARAM].filter((labelName) => labelName !== title);
+  setQuery({ state, commit }, { key: LABEL_FILTER_PARAM, value: labels });
 };
 
 export const setLabelFilterSearch = ({ commit }, { value }) => {
