@@ -1,28 +1,34 @@
-import { findKey, intersection } from 'lodash';
-import { languageFilterData } from '~/search/sidebar/components/language_filter/data';
-import { labelFilterData } from '~/search/sidebar/components/label_filter/data';
+import { findKey, intersection, difference } from 'lodash';
 import {
   formatSearchResultCount,
   addCountOverLimit,
   injectRegexSearch,
 } from '~/search/store/utils';
 
-import { PROJECT_DATA, SCOPE_BLOB } from '~/search/sidebar/constants';
+import {
+  SCOPE_BLOB,
+  LABEL_FILTER_PARAM,
+  LABEL_AGREGATION_NAME,
+  LANGUAGE_FILTER_PARAM,
+} from '~/search/sidebar/constants';
 import { GROUPS_LOCAL_STORAGE_KEY, PROJECTS_LOCAL_STORAGE_KEY, ICON_MAP } from './constants';
 
-const queryLabelFilters = (state) => state?.query?.[labelFilterData.filterParam] || [];
-const urlQueryLabelFilters = (state) => state?.urlQuery?.[labelFilterData.filterParam] || [];
+const queryLabelFilters = (state) => state?.query?.[LABEL_FILTER_PARAM] || [];
+const urlQueryLabelFilters = (state) => state?.urlQuery?.[LABEL_FILTER_PARAM] || [];
 
 const appliedSelectedLabelsKeys = (state) =>
   intersection(urlQueryLabelFilters(state), queryLabelFilters(state));
 
 const unselectedLabelsKeys = (state) =>
-  urlQueryLabelFilters(state)?.filter((label) => !queryLabelFilters(state)?.includes(label));
+  difference(urlQueryLabelFilters(state), queryLabelFilters(state));
 
-const unappliedNewLabelKeys = (state) =>
-  state?.query?.labels?.filter((label) => !urlQueryLabelFilters(state)?.includes(label));
+const unappliedNewLabelKeys = (state) => {
+  return state?.query?.[LABEL_FILTER_PARAM]?.filter(
+    (label) => !urlQueryLabelFilters(state)?.includes(label),
+  );
+};
 
-export const queryLanguageFilters = (state) => state.query[languageFilterData.filterParam] || [];
+export const queryLanguageFilters = (state) => state.query[LANGUAGE_FILTER_PARAM] || [];
 
 export const frequentGroups = (state) => {
   return state.frequentItems[GROUPS_LOCAL_STORAGE_KEY];
@@ -34,17 +40,15 @@ export const frequentProjects = (state) => {
 
 export const languageAggregationBuckets = (state) => {
   return (
-    state.aggregations.data.find(
-      (aggregation) => aggregation.name === languageFilterData.filterParam,
-    )?.buckets || []
+    state.aggregations.data.find((aggregation) => aggregation.name === LANGUAGE_FILTER_PARAM)
+      ?.buckets || []
   );
 };
 
 export const labelAggregationBuckets = (state) => {
   return (
-    state?.aggregations?.data?.find(
-      (aggregation) => aggregation.name === labelFilterData.filterParam,
-    )?.buckets || []
+    state?.aggregations?.data?.find((aggregation) => aggregation.name === LABEL_AGREGATION_NAME)
+      ?.buckets || []
   );
 };
 
@@ -58,26 +62,25 @@ export const filteredLabels = (state) => {
 };
 
 export const filteredAppliedSelectedLabels = (state) =>
-  filteredLabels(state)?.filter((label) => urlQueryLabelFilters(state)?.includes(label.key));
+  filteredLabels(state)?.filter((label) => urlQueryLabelFilters(state)?.includes(label.title));
 
-export const appliedSelectedLabels = (state) => {
-  return labelAggregationBuckets(state)?.filter((label) =>
-    appliedSelectedLabelsKeys(state)?.includes(label.key),
+export const appliedSelectedLabels = (state) =>
+  labelAggregationBuckets(state)?.filter((label) =>
+    appliedSelectedLabelsKeys(state)?.includes(label.title),
   );
-};
 
 export const filteredUnselectedLabels = (state) =>
-  filteredLabels(state)?.filter((label) => !urlQueryLabelFilters(state)?.includes(label.key));
+  filteredLabels(state)?.filter((label) => !urlQueryLabelFilters(state)?.includes(label.title));
 
 export const unselectedLabels = (state) =>
   labelAggregationBuckets(state).filter((label) =>
-    unselectedLabelsKeys(state)?.includes(label.key),
+    unselectedLabelsKeys(state)?.includes(label.title),
   );
 
 export const unappliedNewLabels = (state) =>
-  labelAggregationBuckets(state).filter((label) =>
-    unappliedNewLabelKeys(state)?.includes(label.key),
-  );
+  labelAggregationBuckets(state).filter((label) => {
+    return unappliedNewLabelKeys(state)?.includes(label.title);
+  });
 
 export const currentScope = (state) => findKey(state.navigation, { active: true });
 
@@ -91,4 +94,4 @@ export const navigationItems = (state) =>
     items: [],
   }));
 
-export const hasProjectContext = (state) => !state.query?.[PROJECT_DATA.queryParam];
+export const hasMissingProjectContext = (state) => !state?.projectInitialJson?.id;
