@@ -6,9 +6,12 @@ const createState = ({
   navigation,
   searchType,
   searchLevel,
+  advancedSearchAvailable,
+  zoektAvailable,
   groupInitialJson,
   projectInitialJson,
   defaultBranchName,
+  repositoryRef,
 }) => ({
   urlQuery: cloneDeep(query),
   query,
@@ -30,9 +33,12 @@ const createState = ({
   searchLabelString: '',
   searchType,
   searchLevel,
+  advancedSearchAvailable,
+  zoektAvailable,
   groupInitialJson,
   projectInitialJson,
   defaultBranchName,
+  repositoryRef,
 });
 
 export default createState;
