@@ -9,19 +9,21 @@ export default () => {
     return null;
   }
 
-  const { obfuscatedEmail, verifyPath, resendPath, offerEmailReset, updateEmailPath } = el.dataset;
+  const { username, obfuscatedEmail, verifyPath, resendPath, offerEmailReset, updateEmailPath } =
+    el.dataset;
 
   return new Vue({
     el,
     name: 'EmailVerificationRoot',
+    provide: { updateEmailPath },
     render(createElement) {
       return createElement(EmailVerification, {
         props: {
+          username,
           obfuscatedEmail,
           verifyPath,
           resendPath,
           isOfferEmailReset: parseBoolean(offerEmailReset),
-          updateEmailPath,
         },
       });
     },
