@@ -1,4 +1,4 @@
-import { s__, sprintf } from '~/locale';
+import { s__ } from '~/locale';
 
 export const COMMAND_HANDLE = '>';
 export const USER_HANDLE = '@';
@@ -17,19 +17,6 @@ export const TRACKING_HANDLE_LABEL_MAP = {
 };
 
 export const COMMON_HANDLES = [COMMAND_HANDLE, USER_HANDLE, PROJECT_HANDLE, PATH_HANDLE];
-export const SEARCH_OR_COMMAND_MODE_PLACEHOLDER = sprintf(
-  s__(
-    'CommandPalette|Type %{commandHandle} for command, %{userHandle} for user, %{projectHandle} for project, %{pathHandle} for project file, or perform generic search...',
-  ),
-  {
-    commandHandle: COMMAND_HANDLE,
-    userHandle: USER_HANDLE,
-    issueHandle: ISSUE_HANDLE,
-    projectHandle: PROJECT_HANDLE,
-    pathHandle: PATH_HANDLE,
-  },
-  false,
-);
 
 export const SEARCH_SCOPE_PLACEHOLDER = {
   [COMMAND_HANDLE]: s__('CommandPalette|command'),
