@@ -19,14 +19,16 @@ export const initTokenAccess = (containerId = 'js-ci-token-access-app') => {
     return false;
   }
 
-  const { fullPath } = containerEl.dataset;
+  const { fullPath, csvDownloadPath, enforceAllowlist } = containerEl.dataset;
 
   return new Vue({
     el: containerEl,
     name: 'TokenAccessAppsRoot',
     apolloProvider,
     provide: {
+      enforceAllowlist: JSON.parse(enforceAllowlist),
       fullPath,
+      csvDownloadPath,
     },
     render(createElement) {
       return createElement(TokenAccessApp);
