@@ -1,5 +1,5 @@
 import Api from '~/api';
-import { redirectTo } from '~/lib/utils/url_utility'; // eslint-disable-line import/no-deprecated
+import { visitUrl } from '~/lib/utils/url_utility';
 import { getErrorMessages } from '../utils';
 import * as types from './mutation_types';
 
@@ -10,6 +10,6 @@ export const createUserList = ({ commit, state }, userList) => {
     ...state.userList,
     ...userList,
   })
-    .then(({ data }) => redirectTo(data.path)) // eslint-disable-line import/no-deprecated
+    .then(({ data }) => visitUrl(data.path))
     .catch((response) => commit(types.RECEIVE_CREATE_USER_LIST_ERROR, getErrorMessages(response)));
 };
