@@ -1,8 +1,9 @@
 import getStateKey from 'ee_else_ce/vue_merge_request_widget/stores/get_state_key';
 import { STATUS_CLOSED, STATUS_MERGED, STATUS_OPEN } from '~/issues/constants';
-import { formatDate, getTimeago, timeagoLanguageCode } from '~/lib/utils/datetime_utility';
+import { formatDate, getTimeago, newDate, timeagoLanguageCode } from '~/lib/utils/datetime_utility';
 import { machine } from '~/lib/utils/finite_state_machine';
 import { badgeState } from '~/merge_requests/components/merge_request_header.vue';
+import { cleanLeadingSeparator } from '~/lib/utils/url_utility';
 import {
   MTWPS_MERGE_STRATEGY,
   MT_MERGE_STRATEGY,
@@ -141,6 +142,10 @@ export default class MergeRequestStore {
     this.isPipelineSkipped = this.ciStatus === 'skipped';
     this.pipelineDetailedStatus = pipelineStatus;
     this.isPipelineActive = data.pipeline ? data.pipeline.active : false;
+    this.pipelineIid = data.pipeline?.iid?.toString() || '';
+    this.pipelineProjectPath = data.pipeline?.project_path
+      ? cleanLeadingSeparator(data.pipeline?.project_path)
+      : '';
     this.isPipelineBlocked =
       data.only_allow_merge_if_pipeline_succeeds && pipelineStatus?.group === 'manual';
     this.faviconOverlayPath = data.favicon_overlay_path;
@@ -181,7 +186,6 @@ export default class MergeRequestStore {
 
   setGraphqlData(project) {
     const { mergeRequest } = project;
-    const pipeline = mergeRequest.headPipeline;
 
     this.updateStatusState(mergeRequest.state);
 
@@ -193,11 +197,6 @@ export default class MergeRequestStore {
     this.autoMergeEnabled = mergeRequest.autoMergeEnabled;
     this.canBeMerged = mergeRequest.mergeStatus === 'can_be_merged';
     this.canMerge = mergeRequest.userPermissions.canMerge;
-    this.ciStatus = pipeline?.status.toLowerCase();
-
-    if (pipeline?.warnings && this.ciStatus === 'success') {
-      this.ciStatus = `${this.ciStatus}-with-warnings`;
-    }
 
     this.commitsCount = mergeRequest.commitCount;
     this.branchMissing =
@@ -207,6 +206,7 @@ export default class MergeRequestStore {
     this.hasMergeableDiscussionsState = mergeRequest.mergeableDiscussionsState === false;
     this.mergeError = mergeRequest.mergeError;
     this.mergeStatus = mergeRequest.mergeStatus;
+    this.mergeAfter = mergeRequest.mergeAfter;
     this.isPipelineFailed = this.ciStatus === 'failed' || this.ciStatus === 'canceled';
     this.isSHAMismatch = this.sha !== mergeRequest.diffHeadSha;
     this.shouldBeRebased = mergeRequest.shouldBeRebased;
@@ -350,7 +350,7 @@ export default class MergeRequestStore {
       return '';
     }
 
-    return format(date, timeagoLanguageCode);
+    return format(newDate(date), timeagoLanguageCode);
   }
 
   static getPreferredAutoMergeStrategy(availableAutoMergeStrategies) {
@@ -386,6 +386,10 @@ export default class MergeRequestStore {
     this.setState();
   }
 
+  setRemoveSourceBranch(removeSourceBranch) {
+    this.shouldRemoveSourceBranch = removeSourceBranch;
+  }
+
   // eslint-disable-next-line class-methods-use-this
   get hasMergeChecksFailed() {
     return false;
