@@ -267,14 +267,24 @@ export function urlQueryToFilter(
  * based on provided recentSuggestionsStorageKey
  *
  * @param {String} recentSuggestionsStorageKey
+ * @param {Array} appliedTokens
+ * @param {Function} valueIdentifier
  * @returns
  */
-export function getRecentlyUsedSuggestions(recentSuggestionsStorageKey) {
+export function getRecentlyUsedSuggestions(
+  recentSuggestionsStorageKey,
+  appliedTokens,
+  valueIdentifier,
+) {
   let recentlyUsedSuggestions = [];
   if (AccessorUtilities.canUseLocalStorage()) {
     recentlyUsedSuggestions = JSON.parse(localStorage.getItem(recentSuggestionsStorageKey)) || [];
   }
-  return recentlyUsedSuggestions;
+  return recentlyUsedSuggestions.filter((suggestion) => {
+    return !appliedTokens?.some(
+      (appliedToken) => appliedToken.value.data === valueIdentifier(suggestion),
+    );
+  });
 }
 
 /**
