@@ -25,8 +25,23 @@ const Template = (args, { argTypes }) => ({
       :readonly="readonly"
       :form-input-group-props="formInputGroupProps"
       :copy-button-title="copyButtonTitle"
+      invalid-feedback="Oh no, there is some validation error"
     />`,
 });
 
 export const Default = Template.bind({});
 Default.args = defaultProps;
+
+export const WithValidationError = Template.bind({});
+WithValidationError.args = {
+  ...defaultProps,
+  formInputGroupProps: { state: false },
+};
+WithValidationError.parameters = {
+  docs: {
+    description: {
+      story:
+        'An invalid state can be set on the component by providing a message via `:invalid-feedback`, and managing the input validity via `formInputGroupProps.state`, like other `<gl-form-input>`s',
+    },
+  },
+};
