@@ -19,7 +19,10 @@ const transform = (el, binding) => {
   }
 };
 
-const clear = (el) => {
+const clear = (el, binding) => {
+  // Fixes https://gitlab.com/gitlab-org/gitlab-ui/-/issues/2455
+  // eslint-disable-next-line no-param-reassign
+  delete binding.oldValue;
   el.textContent = '';
 };
 
