@@ -6,11 +6,12 @@ module ApplicationCable
     include Gitlab::Auth::AuthFinders
 
     before_subscribe :validate_token_scope
+    periodically :validate_token_scope, every: 10.minutes
 
     def validate_token_scope
-      validate_and_save_access_token!(scopes: authorization_scopes)
+      validate_and_save_access_token!(scopes: authorization_scopes, reset_token: true)
     rescue Gitlab::Auth::AuthenticationError
-      reject
+      handle_authentication_error
     end
 
     def authorization_scopes
@@ -19,6 +20,18 @@ module ApplicationCable
 
     private
 
+    def client_subscribed?
+      !subscription_rejected? && subscription_confirmation_sent?
+    end
+
+    def handle_authentication_error
+      if client_subscribed?
+        unsubscribe_from_channel
+      else
+        reject
+      end
+    end
+
     def notification_payload(_)
       super.merge!(params: params.except(:channel))
     end
