@@ -8,7 +8,9 @@ module Layouts
     # @param [String] testid
     # @param [Boolean] expanded
     # @param [Hash] button_options
-    def initialize(heading, description: nil, id: nil, testid: nil, expanded: nil, button_options: {}, css_class: nil)
+    def initialize(
+      heading, description: nil, id: nil, testid: nil, expanded: nil, button_options: {},
+      css_class: nil)
       @heading = heading
       @description = description
       @id = id
@@ -20,6 +22,7 @@ module Layouts
 
     renders_one :heading
     renders_one :description
+    renders_one :callout
     renders_one :body
 
     private
@@ -38,5 +41,9 @@ module Layouts
     def button_text
       @expanded ? _('Collapse') : _('Expand')
     end
+
+    def aria_label
+      @expanded ? "#{_('Collapse')} #{@heading}" : "#{_('Expand')} #{@heading}"
+    end
   end
 end
