@@ -8,7 +8,7 @@ module Admin
     around_action :support_multiple_databases
 
     def show
-      @job = Gitlab::Database::BackgroundMigration::BatchedJob.find(params[:id])
+      @job = Gitlab::Database::BackgroundMigration::BatchedJob.find(safe_params[:id])
 
       @transition_logs = @job.batched_job_transition_logs
     end
@@ -22,9 +22,13 @@ module Admin
     end
 
     def base_model
-      @selected_database = params[:database] || Gitlab::Database::MAIN_DATABASE_NAME
+      @selected_database = safe_params[:database] || Gitlab::Database::MAIN_DATABASE_NAME
 
       Gitlab::Database.database_base_models[@selected_database]
     end
+
+    def safe_params
+      params.permit(:id, :database)
+    end
   end
 end
