@@ -14,10 +14,12 @@ class Admin::ImpersonationTokensController < Admin::ApplicationController
 
   def create
     @impersonation_token = finder.build(impersonation_token_params)
+    @impersonation_token.organization = Current.organization
 
     if @impersonation_token.save
+      active_access_tokens = active_impersonation_tokens
       render json: { new_token: @impersonation_token.token,
-                     active_access_tokens: active_impersonation_tokens }, status: :ok
+                     active_access_tokens: active_access_tokens, total: active_access_tokens.length }, status: :ok
     else
       render json: { errors: @impersonation_token.errors.full_messages }, status: :unprocessable_entity
     end
@@ -44,11 +46,11 @@ class Admin::ImpersonationTokensController < Admin::ApplicationController
   # rubocop: enable CodeReuse/ActiveRecord
 
   def verify_impersonation_enabled!
-    access_denied! unless helpers.impersonation_enabled?
+    access_denied! unless helpers.impersonation_tokens_enabled?
   end
 
   def finder(options = {})
-    PersonalAccessTokensFinder.new({ user: user, impersonation: true }.merge(options))
+    PersonalAccessTokensFinder.new({ user: user, impersonation: true, organization: Current.organization }.merge(options))
   end
 
   def active_impersonation_tokens
