@@ -21,7 +21,7 @@ module Admin
     end
 
     def installation_service
-      Integrations::SlackInstallation::InstanceService.new(current_user: current_user, params: params)
+      Integrations::SlackInstallation::InstanceService.new(current_user: current_user, params: params.permit(:code))
     end
   end
 end
