@@ -9,15 +9,17 @@ class Admin::TopicsController < Admin::ApplicationController
   feature_category :groups_and_projects
 
   def index
-    @topics = Projects::TopicsFinder.new(params: params.permit(:search)).execute.page(pagination_params[:page]).without_count
+    @topics = Projects::TopicsFinder.new(
+      params: params.permit(:search),
+      organization_id: organization_id
+    ).execute.page(pagination_params[:page]).without_count
   end
 
   def new
     @topic = Projects::Topic.new
   end
 
-  def edit
-  end
+  def edit; end
 
   def create
     @topic = Projects::Topic.new(topic_params)
@@ -60,11 +62,11 @@ class Admin::TopicsController < Admin::ApplicationController
   private
 
   def topic
-    @topic ||= Projects::Topic.find(params.permit(:id)[:id])
+    @topic ||= Projects::Topic.find_by_id_and_organization_id!(params.permit(:id)[:id], organization_id)
   end
 
   def topic_params
-    params.require(:projects_topic).permit(allowed_topic_params)
+    params.require(:projects_topic).permit(allowed_topic_params).merge({ organization_id: organization_id })
   end
 
   def allowed_topic_params
@@ -79,4 +81,8 @@ class Admin::TopicsController < Admin::ApplicationController
   def merge_params
     params.permit([:source_topic_id, :target_topic_id])
   end
+
+  def organization_id
+    ::Current.organization&.id
+  end
 end
