@@ -4,6 +4,8 @@ require 'gon'
 require 'fogbugz'
 
 class ApplicationController < BaseActionController
+  use Gitlab::Middleware::ActionControllerStaticContext
+
   include Gitlab::GonHelper
   include Gitlab::NoCacheHeaders
   include GitlabRoutingHelper
@@ -26,6 +28,8 @@ class ApplicationController < BaseActionController
   include CheckRateLimit
   include RequestPayloadLogger
   include StrongPaginationParams
+  include Gitlab::HttpRouter::RuleContext
+  include Gitlab::HttpRouter::RuleMetrics
 
   before_action :authenticate_user!, except: [:route_not_found]
   before_action :set_current_organization
@@ -39,12 +43,13 @@ class ApplicationController < BaseActionController
   before_action :active_user_check, unless: :devise_controller?
   before_action :set_usage_stats_consent_flag
   before_action :check_impersonation_availability
+  before_action :increment_http_router_metrics
 
   # Make sure the `auth_user` is memoized so it can be logged, we do this after
   # all other before filters that could have set the user.
   before_action :auth_user
 
-  prepend_around_action :set_current_context
+  around_action :set_current_context
 
   around_action :sessionless_bypass_admin_mode!, if: :sessionless_user?
   around_action :set_locale
@@ -95,7 +100,7 @@ class ApplicationController < BaseActionController
       env: :blocklist,
       remote_ip: request.ip,
       request_method: request.request_method,
-      path: request.fullpath
+      path: request.filtered_path
     )
 
     render plain: e.message, status: :forbidden
@@ -113,7 +118,12 @@ class ApplicationController < BaseActionController
 
   rescue_from Gitlab::Git::ResourceExhaustedError do |e|
     response.headers.merge!(e.headers)
-    render plain: e.message, status: :service_unavailable
+    render_503(e.message)
+  end
+
+  rescue_from Regexp::TimeoutError do |e|
+    log_exception(e)
+    head :service_unavailable
   end
 
   def redirect_back_or_default(default: root_path, options: {})
@@ -134,6 +144,14 @@ class ApplicationController < BaseActionController
     end
   end
 
+  def handle_unverified_request
+    Gitlab::Auth::Activity
+      .new(controller: self)
+      .user_csrf_token_mismatch!
+
+    super
+  end
+
   def render(*args)
     super.tap do
       # Set a header for custom error pages to prevent them from being intercepted by gitlab-workhorse
@@ -162,14 +180,13 @@ class ApplicationController < BaseActionController
   # (e.g. tokens) to authenticate the user, whereas Devise sets current_user.
   #
   def auth_user
-    strong_memoize(:auth_user) do
-      if user_signed_in?
-        current_user
-      else
-        try(:authenticated_user)
-      end
+    if user_signed_in?
+      current_user
+    else
+      try(:authenticated_user)
     end
   end
+  strong_memoize_attr :auth_user
 
   # Devise defines current_user to be:
   #
@@ -258,6 +275,13 @@ class ApplicationController < BaseActionController
     end
   end
 
+  def render_503(message = nil)
+    respond_to do |format|
+      format.html { render template: "errors/service_unavailable", formats: :html, layout: "errors", status: :service_unavailable, locals: { message: message } }
+      format.any { head :service_unavailable }
+    end
+  end
+
   def render_409(message = nil)
     respond_to do |format|
       format.html { render template: "errors/request_conflict", formats: :html, layout: "errors", status: :conflict, locals: { message: message } }
@@ -391,11 +415,11 @@ class ApplicationController < BaseActionController
   end
 
   def bitbucket_server_import_enabled?
-    Gitlab::CurrentSettings.import_sources.include?('bitbucket_server')
+    Gitlab::CurrentSettings.import_sources.include?('bitbucket_server') || Feature.enabled?(:override_bitbucket_server_disabled, current_user, type: :ops)
   end
 
   def github_import_enabled?
-    Gitlab::CurrentSettings.import_sources.include?('github')
+    Gitlab::CurrentSettings.import_sources.include?('github') || Feature.enabled?(:override_github_disabled, current_user, type: :ops)
   end
 
   def gitea_import_enabled?
@@ -438,13 +462,18 @@ class ApplicationController < BaseActionController
   end
 
   def set_current_context(&block)
+    # even though feature_category is pre-populated by
+    # Gitlab::Middleware::ActionControllerStaticContext
+    # using the static annotation on controllers, the
+    # controllers can override feature_category conditionally
+    Gitlab::ApplicationContext.push(feature_category: feature_category) if feature_category.present?
+
     Gitlab::ApplicationContext.push(
       user: -> { context_user },
       project: -> { @project if @project&.persisted? },
       namespace: -> { @group if @group&.persisted? },
-      caller_id: self.class.endpoint_id_for_action(action_name),
       remote_ip: request.ip,
-      feature_category: feature_category
+      **http_router_rule_context
     )
     yield
   ensure
@@ -531,7 +560,7 @@ class ApplicationController < BaseActionController
   end
 
   def set_current_organization
-    return if ::Current.lock_organization
+    return if ::Current.organization_assigned
 
     ::Current.organization = Gitlab::Current::Organization.new(
       params: params.permit(
