@@ -50,6 +50,7 @@ module Integrations
       :google_play_protected_refs,
       :group_confidential_mention_events,
       :group_mention_events,
+      :hostname,
       :incident_events,
       :inherit_from_id,
       # We're using `issues_events` and `merge_requests_events`
@@ -66,6 +67,9 @@ module Integrations
       :jira_issue_regex,
       :jira_issue_transition_automatic,
       :jira_issue_transition_id,
+      :jira_cloud_app_service_ids,
+      :jira_cloud_app_enable_deployment_gating,
+      :jira_cloud_app_deployment_gating_environments,
       :manual_configuration,
       :merge_requests_events,
       :mock_service_url,
