@@ -2,9 +2,13 @@
 
 module Onboarding
   class Status
-    def initialize(params, session, user)
+    def self.registration_path_params(params:) # rubocop:disable Lint/UnusedMethodArgument -- overridden in EE
+      {}
+    end
+
+    def initialize(params, user_return_to, user)
       @params = params
-      @session = session
+      @user_return_to = user_return_to
       @user = user
     end
 
@@ -22,6 +26,11 @@ module Onboarding
       last_invited_member&.source
     end
 
+    # overridden in EE
+    def registration_omniauth_params
+      {}
+    end
+
     private
 
     attr_reader :user
