@@ -5,13 +5,12 @@ module RenderAccessTokens
 
   def active_access_tokens
     tokens = finder(state: 'active', sort: 'expires_at_asc_id_desc').execute.preload_users
+    size = tokens.size
 
-    if Feature.enabled?('access_token_pagination')
-      tokens = tokens.page(page)
-      add_pagination_headers(tokens)
-    end
+    tokens = tokens.page(page)
+    add_pagination_headers(tokens)
 
-    represent(tokens)
+    [represent(tokens), size]
   end
 
   def inactive_access_tokens
