@@ -18,14 +18,13 @@ module WebHooks
     end
 
     def create
-      self.hook = relation.new(hook_params)
-      hook.save
+      result = WebHooks::CreateService.new(current_user).execute(hook_params, relation)
 
-      if hook.valid?
+      if result.success?
         flash[:notice] = _('Webhook was created')
       else
         self.hooks = relation.select(&:persisted?)
-        flash[:alert] = hook.errors.full_messages.to_sentence.html_safe
+        flash[:alert] = result.message
       end
 
       redirect_to action: :index
@@ -87,7 +86,7 @@ module WebHooks
     end
 
     def hook_logs
-      @hook_logs ||= hook.web_hook_logs.recent.page(params[:page]).without_count
+      @hook_logs ||= hook.web_hook_logs.recent.page(pagination_params[:page]).without_count
     end
 
     def hook_value_from_param_or_db(key, value)
