@@ -118,13 +118,20 @@ class Explore::ProjectsController < Explore::ApplicationController
   end
 
   def load_topics
-    @topics = Projects::TopicsFinder.new(params: params.permit(:search)).execute.page(pagination_params[:page]).without_count
+    @topics = Projects::TopicsFinder.new(
+      params: params.permit(:search),
+      organization_id: organization_id
+    ).execute.page(pagination_params[:page]).without_count
   end
 
   def load_topic
-    topic_name = Feature.enabled?(:explore_topics_cleaned_path) ? URI.decode_www_form_component(params[:topic_name]) : params[:topic_name]
+    topic_name = if Feature.enabled?(:explore_topics_cleaned_path)
+                   URI.decode_www_form_component(params[:topic_name])
+                 else
+                   params[:topic_name]
+                 end
 
-    @topic = Projects::Topic.find_by_name_case_insensitive(topic_name)
+    @topic = Projects::Topic.for_organization(organization_id).find_by_name_case_insensitive(topic_name)
   end
 
   # rubocop: disable CodeReuse/ActiveRecord
@@ -164,12 +171,17 @@ class Explore::ProjectsController < Explore::ApplicationController
   end
 
   def show_alert_if_search_is_disabled
-    if current_user || (params[:name].blank? && params[:search].blank?) || !html_request? || Feature.disabled?(:disable_anonymous_project_search, type: :ops)
+    if current_user || (params[:name].blank? && params[:search].blank?) || !html_request? || Feature.disabled?(
+      :disable_anonymous_project_search, type: :ops)
       return
     end
 
     flash.now[:notice] = _('You must sign in to search for specific projects.')
   end
+
+  def organization_id
+    ::Current.organization&.id
+  end
 end
 
 Explore::ProjectsController.prepend_mod_with('Explore::ProjectsController')
