@@ -164,10 +164,16 @@ class GraphqlController < ApplicationController
   def disable_query_limiting
     return unless Gitlab::QueryLimiting.enabled_for_env?
 
-    disable_issue = request.headers[DISABLE_SQL_QUERY_LIMIT_HEADER]
-    return unless disable_issue
+    disable_reference = request.headers[DISABLE_SQL_QUERY_LIMIT_HEADER]
+    return unless disable_reference
 
-    Gitlab::QueryLimiting.disable!(disable_issue)
+    first, second = disable_reference.split(',')
+
+    if first.match?(/^\d+$/)
+      Gitlab::QueryLimiting.disable!(second, new_threshold: first&.to_i)
+    else
+      Gitlab::QueryLimiting.disable!(first)
+    end
   end
 
   def set_user_last_activity
@@ -214,7 +220,6 @@ class GraphqlController < ApplicationController
   def execute_query
     variables = build_variables(permitted_params[:variables])
     operation_name = permitted_params[:operationName]
-
     GitlabSchema.execute(query, variables: variables, context: context, operation_name: operation_name)
   end
 
@@ -263,7 +268,7 @@ class GraphqlController < ApplicationController
   def authorize_access_api!
     if current_user.nil? &&
         request_authenticator.authentication_token_present?
-      render_error('Invalid token', status: :unauthorized)
+      return render_error('Invalid token', status: :unauthorized)
     end
 
     return if can?(current_user, :access_api)
@@ -299,6 +304,8 @@ class GraphqlController < ApplicationController
   end
 
   def execute_introspection_query
+    context[:introspection] = true
+
     if introspection_query_can_use_cache?
       # Context for caching: https://gitlab.com/gitlab-org/gitlab/-/issues/409448
       Rails.cache.fetch(
@@ -338,3 +345,5 @@ class GraphqlController < ApplicationController
       variables: build_variables(permitted_params[:variables]))
   end
 end
+
+GraphqlController.prepend_mod_with('GraphqlController')
