@@ -15,6 +15,7 @@ class Groups::ApplicationController < ApplicationController
 
   before_action do
     push_namespace_setting(:math_rendering_limits_enabled, @group)
+    push_frontend_feature_flag(:async_sidebar_counts, @group&.root_ancestor)
   end
 
   private
@@ -77,8 +78,8 @@ class Groups::ApplicationController < ApplicationController
     false
   end
 
-  def validate_root_group!
-    render_404 unless group.root?
+  def validate_crm_group!
+    render_404 unless group.crm_group?
   end
 
   def authorize_action!(action)
