@@ -7,6 +7,8 @@ class Groups::BoardsController < Groups::ApplicationController
 
   before_action do
     push_frontend_feature_flag(:board_multi_select, group)
+    push_frontend_feature_flag(:issues_list_drawer, group)
+    push_force_frontend_feature_flag(:work_items_beta, group&.work_items_beta_feature_flag_enabled?)
   end
 
   feature_category :team_planning
