@@ -14,8 +14,7 @@ module Groups
       feature_category :package_registry
       urgency :low
 
-      def show
-      end
+      def show; end
 
       private
 
