@@ -4,7 +4,6 @@ module Groups
   class UsageQuotasController < Groups::ApplicationController
     before_action :authorize_read_usage_quotas!
     before_action :verify_usage_quotas_enabled!
-    before_action :push_frontend_feature_flags
 
     feature_category :consumables_cost_management
     urgency :low
@@ -16,10 +15,6 @@ module Groups
 
     private
 
-    def push_frontend_feature_flags
-      push_frontend_feature_flag(:usage_quotas_for_all_editions, @group)
-    end
-
     def verify_usage_quotas_enabled!
       render_404 unless group.usage_quotas_enabled?
     end
