@@ -4,13 +4,14 @@ class Import::FogbugzController < Import::BaseController
   extend ::Gitlab::Utils::Override
 
   before_action :verify_fogbugz_import_enabled
+  before_action -> { check_rate_limit!(:fogbugz_import, scope: current_user, redirect_back: true) }, only: :callback
+
   before_action :user_map, only: [:new_user_map, :create_user_map]
   before_action :verify_blocked_uri, only: :callback
 
   rescue_from Fogbugz::AuthenticationException, with: :fogbugz_unauthorized
 
-  def new
-  end
+  def new; end
 
   def callback
     begin
@@ -25,8 +26,7 @@ class Import::FogbugzController < Import::BaseController
     redirect_to new_user_map_import_fogbugz_path(namespace_id: params[:namespace_id])
   end
 
-  def new_user_map
-  end
+  def new_user_map; end
 
   def create_user_map
     user_map = user_map_params.to_h[:users]
