@@ -5,6 +5,9 @@
 # https://developer.atlassian.com/cloud/jira/platform/app-descriptor/
 
 class JiraConnect::AppDescriptorController < JiraConnect::ApplicationController
+  HOME_URL = 'https://gitlab.com'
+  DOC_URL = 'https://docs.gitlab.com/ee/integration/jira/'
+
   skip_before_action :verify_atlassian_jwt!
 
   def show
@@ -22,7 +25,7 @@ class JiraConnect::AppDescriptorController < JiraConnect::ApplicationController
         url: 'https://gitlab.com'
       },
       links: {
-        documentation: help_page_url('integration/jira_development_panel', anchor: 'gitlabcom-1')
+        documentation: help_page_url('integration/jira/development_panel.md')
       },
       authentication: {
         type: 'jwt'
@@ -40,9 +43,6 @@ class JiraConnect::AppDescriptorController < JiraConnect::ApplicationController
 
   private
 
-  HOME_URL = 'https://gitlab.com'
-  DOC_URL = 'https://docs.gitlab.com/ee/integration/jira/'
-
   def modules
     modules = {
       postInstallPage: {
