@@ -14,9 +14,9 @@ class Oauth::AuthorizedApplicationsController < Doorkeeper::AuthorizedApplicatio
 
   def destroy
     if params[:token_id].present?
-      current_resource_owner.oauth_authorized_tokens.find(params[:token_id]).revoke
+      current_resource_owner.oauth_authorized_tokens.find(params[:token_id].to_s).revoke
     else
-      Doorkeeper::Application.revoke_tokens_and_grants_for(params[:id], current_resource_owner)
+      Doorkeeper::Application.revoke_tokens_and_grants_for(params[:id].to_s, current_resource_owner)
     end
 
     redirect_to user_settings_applications_url,
