@@ -8,8 +8,7 @@ class Profiles::PreferencesController < Profiles::ApplicationController
   urgency :low, [:show]
   urgency :medium, [:update]
 
-  def show
-  end
+  def show; end
 
   def update
     result = Users::UpdateService.new(current_user, preferences_params.merge(user: user)).execute
@@ -63,7 +62,9 @@ class Profiles::PreferencesController < Profiles::ApplicationController
       :markdown_surround_selection,
       :markdown_automatic_lists,
       :use_new_navigation,
-      :enabled_following
+      :enabled_following,
+      :use_work_items_view,
+      :text_editor
     ]
   end
 end
