@@ -3,7 +3,9 @@
 class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
   skip_before_action :check_two_factor_requirement
   before_action :ensure_verified_primary_email, only: [:show, :create]
-  before_action :validate_current_password, only: [:create, :codes, :destroy, :create_webauthn], if: :current_password_required?
+  before_action :validate_current_password,
+    only: [:create, :codes, :destroy, :destroy_otp, :destroy_webauthn, :create_webauthn],
+    if: :current_password_required?
   before_action :update_current_user_otp!, only: [:show]
 
   helper_method :current_password_required?
@@ -19,7 +21,7 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
       ::Users::ValidateManualOtpService.new(current_user).execute(params[:pin_code])
     validated = (otp_validation_result[:status] == :success)
 
-    if validated && current_user.otp_backup_codes? && Feature.enabled?(:webauthn_without_totp)
+    if validated && current_user.otp_backup_codes?
       ActiveSession.destroy_all_but_current(current_user, session)
       Users::UpdateService.new(current_user, user: current_user, otp_required_for_login: true).execute!
       redirect_to profile_two_factor_auth_path, notice: _("Your Time-based OTP device was registered!")
@@ -44,27 +46,26 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
   end
 
   def create_webauthn
-    @webauthn_registration = Webauthn::RegisterService.new(current_user, device_registration_params, session[:challenge]).execute
+    @webauthn_registration = Webauthn::RegisterService.new(
+      current_user,
+      device_registration_params,
+      session[:challenge]
+    ).execute
 
     notice = _("Your WebAuthn device was registered!")
     if @webauthn_registration.persisted?
       session.delete(:challenge)
 
-      if Feature.enabled?(:webauthn_without_totp)
-
-        if current_user.otp_backup_codes?
-          redirect_to profile_two_factor_auth_path, notice: notice
-        else
-
-          Users::UpdateService.new(current_user, user: current_user).execute! do |user|
-            @codes = current_user.generate_otp_backup_codes!
-          end
-          helpers.dismiss_two_factor_auth_recovery_settings_check
-          flash[:notice] = notice
-          render 'create'
-        end
-      else
+      if current_user.otp_backup_codes?
         redirect_to profile_two_factor_auth_path, notice: notice
+      else
+
+        Users::UpdateService.new(current_user, user: current_user).execute! do |user|
+          @codes = current_user.generate_otp_backup_codes!
+        end
+        helpers.dismiss_two_factor_auth_recovery_settings_check
+        flash[:notice] = notice
+        render 'create'
       end
     else
       @qr_code = build_qr_code
@@ -87,18 +88,38 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
     result = TwoFactor::DestroyService.new(current_user, user: current_user).execute
 
     if result[:status] == :success
-      redirect_to profile_account_path, status: :found, notice: s_('Two-factor authentication has been disabled successfully!')
+      redirect_to profile_account_path,
+        status: :found,
+        notice: _('Two-factor authentication has been disabled successfully!')
     else
       redirect_to profile_account_path, status: :found, alert: result[:message]
     end
   end
 
+  def destroy_otp
+    result = TwoFactor::DestroyOtpService.new(current_user, user: current_user).execute
+
+    if result[:status] == :success
+      redirect_to profile_two_factor_auth_path,
+        status: :found,
+        notice: _('One-time password authenticator has been deleted!')
+    else
+      redirect_to profile_two_factor_auth_path, status: :found, alert: result[:message]
+    end
+  end
+
+  def destroy_webauthn
+    Webauthn::DestroyService.new(current_user, current_user, params[:id]).execute
+
+    redirect_to profile_two_factor_auth_path, status: :found, notice: _("Successfully deleted WebAuthn device.")
+  end
+
   def skip
     if two_factor_grace_period_expired?
-      redirect_to new_profile_two_factor_auth_path, alert: _('Cannot skip two factor authentication setup')
+      redirect_to profile_two_factor_auth_url, alert: _('Cannot skip two factor authentication setup')
     else
       session[:skip_two_factor] = current_user.otp_grace_period_started_at + two_factor_grace_period.hours
-      redirect_to root_path
+      redirect_to root_url
     end
   end
 
@@ -115,7 +136,6 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
   end
 
   def validate_current_password
-    return if Feature.disabled?(:webauthn_without_totp) && params[:action] == 'create_webauthn'
     return if current_user.valid_password?(params[:current_password])
 
     current_user.increment_failed_attempts!
@@ -123,6 +143,8 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
     error_message = { message: _('You must provide a valid current password.') }
     if params[:action] == 'create_webauthn'
       @webauthn_error = error_message
+    elsif params[:action] == 'create'
+      @otp_error = error_message
     else
       @error = error_message
     end
@@ -173,7 +195,7 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
       {
         name: webauthn_registration.name,
         created_at: webauthn_registration.created_at,
-        delete_path: profile_webauthn_registration_path(webauthn_registration)
+        delete_path: destroy_webauthn_profile_two_factor_auth_path(webauthn_registration)
       }
     end
   end
@@ -189,15 +211,22 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
 
   def groups_notification(groups)
     group_links = groups.map { |group| view_context.link_to group.full_name, group_path(group) }.to_sentence
-    leave_group_links = groups.map { |group| view_context.link_to (s_("leave %{group_name}") % { group_name: group.full_name }), leave_group_members_path(group), remote: false, method: :delete }.to_sentence
+    leave_group_links = groups.map do |group|
+      view_context.link_to (s_("leave %{group_name}") % { group_name: group.full_name }),
+        leave_group_members_path(group),
+        remote: false, method: :delete
+    end.to_sentence
 
-    s_(%(The group settings for %{group_links} require you to enable Two-Factor Authentication for your account. You can %{leave_group_links}.))
-        .html_safe % { group_links: group_links.html_safe, leave_group_links: leave_group_links.html_safe }
+    s_(
+      'The group settings for %{group_links} require you to enable Two-Factor Authentication for your account. ' \
+        'You can %{leave_group_links}.'
+    ).html_safe % { group_links: group_links.html_safe, leave_group_links: leave_group_links.html_safe }
   end
 
   def ensure_verified_primary_email
     unless current_user.two_factor_enabled? || current_user.primary_email_verified?
-      redirect_to profile_emails_path, notice: s_('You need to verify your primary email first before enabling Two-Factor Authentication.')
+      redirect_to profile_emails_path,
+        notice: s_('You need to verify your primary email first before enabling Two-Factor Authentication.')
     end
   end
 
@@ -205,22 +234,18 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
     if two_factor_authentication_required? && !current_user.two_factor_enabled?
       two_factor_auth_actions = {
         global: ->(_) do
-          flash.now[:alert] =
-            _('The global settings require you to enable Two-Factor Authentication for your account.')
+          _('The global settings require you to enable Two-Factor Authentication for your account.')
         end,
         admin_2fa: ->(_) do
-          flash.now[:alert] = _('Administrator users are required to enable Two-Factor Authentication for their account.')
+          _('Administrator users are required to enable Two-Factor Authentication for their account.')
         end,
         group: ->(groups) do
-          flash.now[:alert] = groups_notification(groups)
+          groups_notification(groups)
         end
       }
-      execute_action_for_2fa_reason(two_factor_auth_actions)
-
-      unless two_factor_grace_period_expired?
-        grace_period_deadline = current_user.otp_grace_period_started_at + two_factor_grace_period.hours
-        flash.now[:alert] = flash.now[:alert] + (_(" You need to do this before %{grace_period_deadline}.") % { grace_period_deadline: l(grace_period_deadline) })
-      end
+      message = execute_action_for_2fa_reason(two_factor_auth_actions)
+      message = append_configure_2fa_later(message) unless two_factor_grace_period_expired?
+      flash.now[:alert] = message
     end
 
     @qr_code = build_qr_code
@@ -228,4 +253,10 @@ class Profiles::TwoFactorAuthsController < Profiles::ApplicationController
 
     setup_webauthn_registration
   end
+
+  def append_configure_2fa_later(message)
+    grace_period_deadline = current_user.otp_grace_period_started_at + two_factor_grace_period.hours
+    render_to_string partial: 'configure_later_button',
+      locals: { message: message, grace_period_deadline: grace_period_deadline }
+  end
 end
