@@ -21,7 +21,7 @@ class Projects::ArtifactsController < Projects::ApplicationController
 
   MAX_PER_PAGE = 20
 
-  feature_category :build_artifacts
+  feature_category :job_artifacts
 
   def index; end
 
@@ -115,7 +115,9 @@ class Projects::ArtifactsController < Projects::ApplicationController
   def extract_ref_name_and_path
     return unless params[:ref_name_and_path]
 
-    @ref_name, @path = extract_ref(params[:ref_name_and_path])
+    ref_extractor = ExtractsRef::RefExtractor.new(@project, {})
+
+    @ref_name, @path = ref_extractor.extract_ref(params[:ref_name_and_path])
   end
 
   def artifacts_params
