@@ -6,7 +6,8 @@ class Projects::AutocompleteSourcesController < Projects::ApplicationController
   before_action :authorize_read_milestone!, only: :milestones
   before_action :authorize_read_crm_contact!, only: :contacts
 
-  feature_category :team_planning, [:issues, :labels, :milestones, :commands, :contacts, :wikis]
+  feature_category :team_planning, [:issues, :labels, :milestones, :commands, :contacts]
+  feature_category :wiki, [:wikis]
   feature_category :code_review_workflow, [:merge_requests]
   feature_category :groups_and_projects, [:members]
   feature_category :source_code_management, [:snippets]
