@@ -11,8 +11,7 @@ class Projects::Ci::PipelineEditorController < Projects::ApplicationController
 
   urgency :low, [:show]
 
-  def show
-  end
+  def show; end
 
   private
 
