@@ -9,19 +9,22 @@ class Projects::CommitController < Projects::ApplicationController
   include DiffForPath
   include DiffHelper
   include SourcegraphDecorator
+  include DiffsStreamResource
 
   # Authorize
   before_action :require_non_empty_project
   before_action :authorize_read_code!
   before_action :authorize_read_pipeline!, only: [:pipelines]
   before_action :commit
-  before_action :define_commit_vars, only: [:show, :diff_for_path, :diff_files, :pipelines, :merge_requests, :rapid_diffs]
+  before_action :define_commit_vars,
+    only: [:show, :diff_for_path, :diff_files, :pipelines, :merge_requests, :rapid_diffs]
   before_action :define_commit_box_vars, only: [:show, :pipelines, :rapid_diffs]
   before_action :define_note_vars, only: [:show, :diff_for_path, :diff_files]
   before_action :authorize_edit_tree!, only: [:revert, :cherry_pick]
   before_action do
     push_frontend_feature_flag(:ci_graphql_pipeline_mini_graph, @project)
   end
+  before_action :rate_limit_for_expanded_diff_files, only: :diff_files
 
   BRANCH_SEARCH_LIMIT = 1000
   COMMIT_DIFFS_PER_PAGE = 20
@@ -53,7 +56,12 @@ class Projects::CommitController < Projects::ApplicationController
   def diff_files
     respond_to do |format|
       format.html do
-        render template: 'projects/commit/diff_files', layout: false, locals: { diffs: @diffs, environment: @environment }
+        render template: 'projects/commit/diff_files',
+          layout: false,
+          locals: {
+            diffs: diffs_expanded? ? @diffs.with_highlights_preloaded : @diffs,
+            environment: @environment
+          }
       end
     end
   end
@@ -144,7 +152,8 @@ class Projects::CommitController < Projects::ApplicationController
 
     create_commit(
       Commits::CherryPickService,
-      success_notice: "The #{@commit.change_type_title(current_user)} has been successfully cherry-picked into #{@branch_name}.",
+      success_notice: "The #{@commit.change_type_title(current_user)} has been successfully " \
+        "cherry-picked into #{@branch_name}.",
       success_path: -> { successful_change_path(target_project) },
       failure_path: failed_change_path,
       target_project: target_project
@@ -154,11 +163,22 @@ class Projects::CommitController < Projects::ApplicationController
   def rapid_diffs
     return render_404 unless ::Feature.enabled?(:rapid_diffs, current_user, type: :wip)
 
+    streaming_offset = 5
+    @stream_url = diffs_stream_url(@commit, streaming_offset, diff_view)
+    @diffs_slice = @commit.first_diffs_slice(streaming_offset, commit_diff_options)
+
     show
   end
 
   private
 
+  def commit_diff_options
+    opts = diff_options
+    opts[:ignore_whitespace_change] = true if params[:format] == 'diff'
+    opts[:use_extra_viewer_as_main] = false
+    opts
+  end
+
   def create_new_branch?
     params[:create_merge_request].present? || !can?(current_user, :push_code, @project)
   end
@@ -187,13 +207,13 @@ class Projects::CommitController < Projects::ApplicationController
   def define_commit_vars
     return git_not_found! unless commit
 
-    opts = diff_options
-    opts[:ignore_whitespace_change] = true if params[:format] == 'diff'
-    opts[:use_extra_viewer_as_main] = false
-
-    @diffs = commit.diffs(opts)
-
-    @environment = ::Environments::EnvironmentsByDeploymentsFinder.new(@project, current_user, commit: @commit, find_latest: true).execute.last
+    @diffs = commit.diffs(commit_diff_options)
+    @environment = ::Environments::EnvironmentsByDeploymentsFinder.new(
+      @project,
+      current_user,
+      commit: @commit,
+      find_latest: true
+    ).execute.last
   end
 
   # rubocop: disable CodeReuse/ActiveRecord
@@ -236,7 +256,10 @@ class Projects::CommitController < Projects::ApplicationController
 
     return unless @commit.last_pipeline
 
-    @last_pipeline_stages = StageSerializer.new(project: @project, current_user: @current_user).represent(@last_pipeline.stages)
+    @last_pipeline_stages = StageSerializer.new(
+      project: @project,
+      current_user: @current_user
+    ).represent(@last_pipeline.stages)
   end
 
   def assign_change_commit_vars
@@ -261,4 +284,22 @@ class Projects::CommitController < Projects::ApplicationController
     payload[:metadata] ||= {}
     payload[:metadata]['meta.diffs_files_count'] = @diffs.size
   end
+
+  def diffs_stream_resource_url(commit, offset, diff_view)
+    diffs_stream_namespace_project_commit_path(
+      namespace_id: commit.project.namespace.to_param,
+      project_id: commit.project.to_param,
+      id: commit.id,
+      offset: offset,
+      view: diff_view
+    )
+  end
+
+  def rate_limit_for_expanded_diff_files
+    return unless diffs_expanded?
+
+    check_rate_limit!(:expanded_diff_files, scope: current_user || request.ip)
+  end
 end
+
+Projects::CommitController.prepend_mod_with('Projects::CommitController')
