@@ -5,8 +5,7 @@ class Projects::ConfluencesController < Projects::ApplicationController
 
   feature_category :integrations
 
-  def show
-  end
+  def show; end
 
   private
 
