@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 class Projects::HookLogsController < Projects::ApplicationController
-  before_action :authorize_admin_project!
+  before_action :authorize_admin_hook!
 
   include WebHooks::HookLogActions
 
@@ -16,4 +16,8 @@ class Projects::HookLogsController < Projects::ApplicationController
   def after_retry_redirect_path
     edit_project_hook_path(@project, hook)
   end
+
+  def authorize_admin_hook!
+    render_404 unless can?(current_user, :admin_web_hook, project)
+  end
 end
