@@ -9,8 +9,7 @@ module Projects
 
       feature_category :integrations
 
-      def show
-      end
+      def show; end
 
       private
 
