@@ -11,7 +11,7 @@ module Projects
       end
 
       before_action only: [:index, :show] do
-        push_frontend_feature_flag(:container_registry_protected_containers, project)
+        push_frontend_feature_flag(:container_registry_protected_containers, project.root_ancestor)
       end
 
       before_action :authorize_update_container_image!, only: [:destroy]
