@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 class Projects::RunnerProjectsController < Projects::ApplicationController
-  before_action :authorize_admin_build!
+  before_action :authorize_admin_runner!
 
   layout 'project_settings'
 
@@ -15,12 +15,13 @@ class Projects::RunnerProjectsController < Projects::ApplicationController
 
     path = project_runners_path(project)
 
-    if ::Ci::Runners::AssignRunnerService.new(@runner, @project, current_user).execute.success?
+    response = ::Ci::Runners::AssignRunnerService.new(@runner, @project, current_user).execute
+    if response.success?
       flash[:success] = s_('Runners|Runner assigned to project.')
       redirect_to path
     else
-      assign_to_messages = @runner.errors.messages[:assign_to]
-      alert = assign_to_messages&.join(',') || 'Failed adding runner to project'
+      assign_to_messages = [response.message] + (@runner.errors.messages[:assign_to] || [])
+      alert = assign_to_messages.join(', ').presence || 'Failed adding runner to project'
 
       redirect_to path, alert: alert
     end
