@@ -13,8 +13,7 @@ module Projects
       feature_category :package_registry
       urgency :low
 
-      def show
-      end
+      def show; end
 
       def cleanup_tags
         registry_settings_enabled!
@@ -34,11 +33,12 @@ module Projects
       end
 
       def set_feature_flag_packages_protected_packages
-        push_frontend_feature_flag(:packages_protected_packages, project)
+        push_frontend_feature_flag(:packages_protected_packages_pypi, project)
+        push_frontend_feature_flag(:packages_protected_packages_conan, project)
       end
 
       def set_feature_flag_container_registry_protected_containers
-        push_frontend_feature_flag(:container_registry_protected_containers, project)
+        push_frontend_feature_flag(:container_registry_protected_containers, project.root_ancestor)
       end
     end
   end
