@@ -48,6 +48,6 @@ class Projects::VariablesController < Projects::ApplicationController
   end
 
   def variable_params_attributes
-    %i[id variable_type key description secret_value protected masked raw environment_scope _destroy]
+    %i[id variable_type key description secret_value protected masked hidden raw environment_scope _destroy]
   end
 end
