@@ -9,7 +9,6 @@ class ProjectsController < Projects::ApplicationController
   include ImportUrlParams
   include FiltersEvents
   include SourcegraphDecorator
-  include PlanningHierarchy
 
   REFS_LIMIT = 100
 
@@ -37,8 +36,10 @@ class ProjectsController < Projects::ApplicationController
   before_action :check_export_rate_limit!, only: [:export, :download_export, :generate_new_export]
 
   before_action do
+    push_frontend_feature_flag(:inline_blame, @project)
     push_frontend_feature_flag(:remove_monitor_metrics, @project)
     push_frontend_feature_flag(:explain_code_chat, current_user)
+    push_frontend_feature_flag(:upgrade_pdfjs, current_user)
     push_frontend_feature_flag(:issue_email_participants, @project)
     push_frontend_feature_flag(:edit_branch_rules, @project)
     # TODO: We need to remove the FF eventually when we rollout page_specific_styles
@@ -66,7 +67,6 @@ class ProjectsController < Projects::ApplicationController
   feature_category :team_planning, [:preview_markdown, :new_issuable_address]
   feature_category :importers, [:export, :remove_export, :generate_new_export, :download_export]
   feature_category :code_review_workflow, [:unfoldered_environment_names]
-  feature_category :portfolio_management, [:planning_hierarchy]
 
   urgency :low, [:export, :remove_export, :generate_new_export, :download_export]
   urgency :low, [:preview_markdown, :new_issuable_address]
@@ -571,7 +571,11 @@ class ProjectsController < Projects::ApplicationController
     # behaviour when the user isn't authorized to see the project
     return if project.nil? || performed?
 
-    redirect_to(request.original_url.sub(%r{\.git/?\Z}, ''))
+    uri = URI(request.original_url)
+    # Strip the '.git' part from the path
+    uri.path = uri.path.sub(%r{\.git/?\Z}, '')
+
+    redirect_to(uri.to_s)
   end
 
   def disable_query_limiting
