@@ -74,12 +74,12 @@ module Repositories
 
     def render_access_denied
       help_page = help_page_url(
-        'topics/git/troubleshooting_git',
+        'topics/git/troubleshooting_git.md',
         anchor: 'error-on-git-fetch-http-basic-access-denied'
       )
 
       render(
-        plain: format(_("HTTP Basic: Access denied. The provided password or token is incorrect or your account has 2FA enabled and you must use a personal access token instead of a password. See %{help_page_url}"), help_page_url: help_page),
+        plain: format(_("HTTP Basic: Access denied. If a password was provided for Git authentication, the password was incorrect or you're required to use a token instead of a password. If a token was provided, it was either incorrect, expired, or improperly scoped. See %{help_page_url}"), help_page_url: help_page),
         status: :unauthorized
       )
     end
