@@ -12,7 +12,21 @@ module UserSettings
 
     def index
       set_index_vars
-      scopes = params[:scopes].split(',').map(&:squish).select(&:present?).map(&:to_sym) unless params[:scopes].nil?
+
+      unless params[:scopes].nil?
+        scopes = []
+        # An over engineered solution to generate scopes array without extra object allocations
+        params[:scopes].split(",", Gitlab::Auth.all_available_scopes.count + 1) do |scope|
+          scope = scope.squish
+          next if scope.empty?
+
+          scope = scope.to_sym
+          next if Gitlab::Auth.all_available_scopes.exclude?(scope)
+
+          scopes << scope
+        end
+      end
+
       @personal_access_token = finder.build(
         name: params[:name],
         scopes: scopes
@@ -38,6 +52,7 @@ module UserSettings
       result = ::PersonalAccessTokens::CreateService.new(
         current_user: current_user,
         target_user: current_user,
+        organization_id: Current.organization_id,
         params: personal_access_token_params,
         concatenate_errors: false
       ).execute
@@ -45,8 +60,9 @@ module UserSettings
       @personal_access_token = result.payload[:personal_access_token]
 
       if result.success?
+        tokens, size = active_access_tokens
         render json: { new_token: @personal_access_token.token,
-                       active_access_tokens: active_access_tokens }, status: :ok
+                       active_access_tokens: tokens, total: size }, status: :ok
       else
         render json: { errors: result.errors }, status: :unprocessable_entity
       end
@@ -60,6 +76,20 @@ module UserSettings
       redirect_to user_settings_personal_access_tokens_path
     end
 
+    def rotate
+      token = finder.find(params[:id])
+      result = PersonalAccessTokens::RotateService.new(current_user, token, nil, keep_token_lifetime: true).execute
+
+      @personal_access_token = result.payload[:personal_access_token]
+      if result.success?
+        tokens, size = active_access_tokens
+        render json: { new_token: @personal_access_token.token,
+                       active_access_tokens: tokens, total: size }, status: :ok
+      else
+        render json: { message: result.message }, status: :unprocessable_entity
+      end
+    end
+
     private
 
     def finder(options = {})
@@ -72,7 +102,7 @@ module UserSettings
 
     def set_index_vars
       @scopes = Gitlab::Auth.available_scopes_for(current_user)
-      @active_access_tokens = active_access_tokens
+      @active_access_tokens, @active_access_tokens_size = active_access_tokens
     end
 
     def represent(tokens)
