@@ -7,7 +7,7 @@ module Users
     def create
       return head :bad_request unless params[:type].present? && params[:id].present?
 
-      Users::TrackNamespaceVisitsWorker.perform_async(params[:type], params[:id], current_user.id, DateTime.now) # rubocop:disable CodeReuse/Worker
+      Users::TrackNamespaceVisitsWorker.perform_async(params[:type], params[:id], current_user.id, DateTime.now.to_s) # rubocop:disable CodeReuse/Worker
       head :ok
     end
   end
