@@ -8,6 +8,8 @@ class UsersController < ApplicationController
   include ControllerWithCrossProjectAccessCheck
   include Gitlab::NoteableMetadata
 
+  FOLLOWERS_FOLLOWING_USERS_PER_PAGE = 21
+
   requires_cross_project_access show: false,
     groups: false,
     projects: false,
@@ -28,7 +30,7 @@ class UsersController < ApplicationController
   before_action only: [:exists] do
     check_rate_limit!(:username_exists, scope: request.ip)
   end
-  before_action only: [:show] do
+  before_action only: [:show, :activity, :groups, :projects, :contributed, :starred, :snippets, :followers, :following] do
     push_frontend_feature_flag(:profile_tabs_vue, current_user)
   end
 
@@ -130,13 +132,13 @@ class UsersController < ApplicationController
 
   def followers
     present_users do
-      @user_followers = user.followers.page(params[:page])
+      @user_followers = user.followers.page(params[:page]).per(FOLLOWERS_FOLLOWING_USERS_PER_PAGE)
     end
   end
 
   def following
     present_users do
-      @user_following = user.followees.page(params[:page])
+      @user_following = user.followees.page(params[:page]).per(FOLLOWERS_FOLLOWING_USERS_PER_PAGE)
     end
   end
 
@@ -186,7 +188,7 @@ class UsersController < ApplicationController
 
   def exists
     if Gitlab::CurrentSettings.signup_enabled? || current_user
-      render json: { exists: !!Namespace.without_project_namespaces.find_by_path_or_name(params[:username]) }
+      render json: { exists: Namespace.username_reserved?(params[:username]) }
     else
       render json: { error: _('You must be authenticated to access this path.') }, status: :unauthorized
     end
@@ -229,7 +231,9 @@ class UsersController < ApplicationController
   end
 
   def contributed_projects
-    ContributedProjectsFinder.new(user).execute(current_user, order_by: 'latest_activity_desc')
+    ContributedProjectsFinder.new(
+      user: user, current_user: current_user, params: { sort: 'latest_activity_desc' }
+    ).execute
   end
 
   def starred_projects
