@@ -8,7 +8,8 @@ module Members
         'required' => %w[source_id source_type],
         'properties' => {
           'source_id' => { 'type' => 'integer' },
-          'source_type' => { 'type' => 'string' }
+          'source_type' => { 'type' => 'string' },
+          'invited_user_ids' => { 'type' => 'array' }
         }
       }
     end
