@@ -29,7 +29,7 @@ module Autocomplete
         .excluding_project(project_id)
         .eager_load_namespace_and_owner
         .sorted_by_stars_desc
-        .limit(LIMIT) # rubocop: disable CodeReuse/ActiveRecord
+        .limit(LIMIT)
     end
   end
 end
