@@ -34,7 +34,7 @@ module Autocomplete
         # Include current user if available to filter by "Me"
         items.unshift(current_user) if prepend_current_user?
 
-        items.unshift(author) if prepend_author? && author&.active?
+        items.unshift(author) if prepend_author? && author&.active? && !author&.import_user? && !author&.placeholder?
       end
 
       items = filter_users_by_push_ability(items)
@@ -101,11 +101,9 @@ module Autocomplete
       items.select { |user| user.can?(:push_code, project) }
     end
 
-    # rubocop: disable CodeReuse/ActiveRecord
     def preload_associations(items)
       ActiveRecord::Associations::Preloader.new(records: items, associations: :status).call
     end
-    # rubocop: enable CodeReuse/ActiveRecord
 
     def use_minimum_char_limit
       return if project.blank? && group.blank? # We return nil so that we use the default defined in the User model
