@@ -10,7 +10,7 @@ module Packages
     private
 
     def packages_for_project(project)
-      project.packages.installable
+      packages_class.for_projects(project).installable
     end
 
     # /!\ This function doesn't check user permissions
@@ -29,25 +29,19 @@ module Packages
     end
 
     def packages_visible_to_user(user, within_group:, with_package_registry_enabled: false)
-      return ::Packages::Package.none unless within_group
-      return ::Packages::Package.none unless Ability.allowed?(user, :read_group, within_group)
+      return packages_class.none unless within_group
+      return packages_class.none unless Ability.allowed?(user, :read_group, within_group)
 
       projects = projects_visible_to_reporters(user, within_group: within_group)
       projects = projects.with_package_registry_enabled if with_package_registry_enabled
 
-      ::Packages::Package.for_projects(projects.select(:id)).installable
+      packages_class.for_projects(projects.select(:id)).installable
     end
 
     def packages_visible_to_user_including_public_registries(user, within_group:)
-      return ::Packages::Package.none unless within_group
+      projects = projects_visible_to_user_including_public_registries(user, within_group: within_group)
 
-      return ::Packages::Package.none unless Ability.allowed?(user, :read_package_within_public_registries,
-        within_group.packages_policy_subject)
-
-      projects = projects_visible_to_reporters(user, within_group: within_group,
-        within_public_package_registry: !Ability.allowed?(user, :read_group, within_group))
-
-      ::Packages::Package.for_projects(projects.select(:id)).installable
+      packages_class.for_projects(projects.select(:id)).installable
     end
 
     def projects_visible_to_user(user, within_group:)
@@ -57,6 +51,15 @@ module Packages
       projects_visible_to_reporters(user, within_group: within_group)
     end
 
+    def projects_visible_to_user_including_public_registries(user, within_group:)
+      return ::Project.none unless within_group
+
+      return ::Project.none unless Ability.allowed?(user, :read_package_within_public_registries,
+        within_group.packages_policy_subject)
+
+      projects_visible_to_reporters(user, within_group: within_group, within_public_package_registry: true)
+    end
+
     def projects_visible_to_reporters(user, within_group:, within_public_package_registry: false)
       return user.accessible_projects if user.is_a?(DeployToken)
 
@@ -111,5 +114,9 @@ module Packages
 
       packages.with_status(params[:status])
     end
+
+    def packages_class
+      ::Packages::Package
+    end
   end
 end
