@@ -21,6 +21,7 @@
 #     author_id: integer
 #     author_username: string
 #     assignee_id: integer or 'None' or 'Any'
+#     closed_by_id: integer
 #     assignee_username: string
 #     search: string
 #     in: 'title', 'description', or a string joining them with comma
@@ -61,17 +62,19 @@ class IssuableFinder
     def scalar_params
       @scalar_params ||= %i[
         assignee_id
+        closed_by_id
         assignee_username
         author_id
         author_username
         crm_contact_id
         crm_organization_id
+        in
         label_name
         milestone_title
         release_tag
         my_reaction_emoji
         search
-        in
+        subscribed
       ]
     end
 
@@ -137,6 +140,7 @@ class IssuableFinder
     items = by_closed_at(items)
     items = by_state(items)
     items = by_assignee(items)
+    items = by_closed_by(items)
     items = by_author(items)
     items = by_non_archived(items)
     items = by_iids(items)
@@ -145,6 +149,7 @@ class IssuableFinder
     items = by_label(items)
     items = by_my_reaction_emoji(items)
     items = by_crm_contact(items)
+    items = by_subscribed(items)
     by_crm_organization(items)
   end
 
@@ -389,6 +394,14 @@ class IssuableFinder
     end
   end
 
+  # rubocop: disable CodeReuse/ActiveRecord
+  def by_closed_by(items)
+    return items if params[:closed_by_id].blank?
+
+    items.where(closed_by_id: params[:closed_by_id])
+  end
+  # rubocop: enable CodeReuse/ActiveRecord
+
   def by_label(items)
     label_filter.filter(items)
   end
@@ -498,6 +511,20 @@ class IssuableFinder
     Issuables::CrmOrganizationFilter.new(params: original_params).filter(items)
   end
 
+  def by_subscribed(items)
+    return items unless current_user
+    return items unless Feature.enabled?(:filter_subscriptions, current_user)
+
+    case params[:subscribed]
+    when :explicitly_subscribed
+      items.explicitly_subscribed(current_user)
+    when :explicitly_unsubscribed
+      items.explicitly_unsubscribed(current_user)
+    else
+      items
+    end
+  end
+
   def can_filter_by_crm_contact?
     current_user&.can?(:read_crm_contact, root_group)
   end
