@@ -20,6 +20,14 @@ class MergeRequestsFinder
       end
     end
 
+    def assigned_user
+      strong_memoize(:assigned_user) do
+        next unless params[:assigned_user_id].present?
+
+        User.find_by_id(params[:assigned_user_id])
+      end
+    end
+
     def merge_user
       strong_memoize(:merge_user) do
         if merge_user_id?
@@ -30,6 +38,18 @@ class MergeRequestsFinder
       end
     end
 
+    def assigned_review_states
+      return unless params[:assigned_review_states].present?
+
+      params[:assigned_review_states].map { |state| MergeRequestReviewer.states[state] }
+    end
+
+    def reviewer_review_states
+      return unless params[:reviewer_review_states].present?
+
+      params[:reviewer_review_states].map { |state| MergeRequestReviewer.states[state] }
+    end
+
     def review_state
       if params[:review_state].present?
         MergeRequestReviewer.states[params[:review_state]]
