@@ -12,7 +12,6 @@ module Organizations
       return Organizations::Organization.none unless can_read_user_organizations?
       return Organizations::Organization.none if target_user.blank?
 
-      organizations = target_user.organizations
       by_search(organizations)
     end
 
@@ -20,6 +19,10 @@ module Organizations
 
     attr_reader :current_user, :target_user, :params
 
+    def organizations
+      params[:solo_owned] ? target_user.solo_owned_organizations : target_user.organizations
+    end
+
     def can_read_user_organizations?
       current_user&.can?(:read_user_organizations, target_user)
     end
