@@ -1,8 +1,12 @@
 # frozen_string_literal: true
+
 module Packages
   module Composer
     class PackagesFinder < Packages::GroupPackagesFinder
-      def initialize(current_user, group, params = { package_type: :composer, with_package_registry_enabled: true })
+      def initialize(
+        current_user, group, params = { with_package_registry_enabled: true,
+                                        packages_class: ::Packages::Composer::Package }
+      )
         super(current_user, group, params)
       end
 
