@@ -30,7 +30,7 @@ module Packages
       elsif group?
         group_packages
       else
-        ::Packages::Package.none
+        packages_class.none
       end
     end
 
@@ -49,5 +49,9 @@ module Packages
     def group_packages
       packages_visible_to_user(@current_user, within_group: @project_or_group)
     end
+
+    def packages_class
+      ::Packages::Package
+    end
   end
 end
