@@ -24,7 +24,9 @@ class TodosFinder
 
   NONE = '0'
 
-  TODO_TYPES = Set.new(%w[Issue WorkItem MergeRequest DesignManagement::Design AlertManagement::Alert Namespace Project]).freeze
+  TODO_TYPES = Set.new(
+    %w[Commit Issue WorkItem MergeRequest DesignManagement::Design AlertManagement::Alert Namespace Project Key]
+  ).freeze
 
   attr_accessor :current_user, :params
 
@@ -134,12 +136,24 @@ class TodosFinder
   end
 
   def invalid_type_message
-    _("Unsupported todo type passed. Supported todo types are: %{todo_types}") % { todo_types: self.class.todo_types.to_a.join(', ') }
+    _("Unsupported todo type passed. Supported todo types are: %{todo_types}") % {
+      todo_types: self.class.todo_types.to_a.join(', ')
+    }
   end
 
   def sort(items)
     if params[:sort]
-      items.sort_by_attribute(params[:sort])
+      # For users with a lot of todos, sorting by created_at can be unusably slow.
+      # Given that todos have sequential ids, we can simply sort by them instead
+      sort_by = case params[:sort]
+                when :created_desc
+                  :id_desc
+                when :created_asc
+                  :id_asc
+                else
+                  params[:sort]
+                end
+      items.sort_by_attribute(sort_by)
     else
       items.order_id_desc
     end
