@@ -1,12 +1,16 @@
 # frozen_string_literal: true
 
 class UploaderFinder
-  # Instantiates a a new FileUploader
+  # Instantiates a new FileUploader or NamespaceFileUploader based on container type
   # FileUploader can be opened via .open agnostic of storage type
   # Arguments correspond to Upload.secret, Upload.model_type and Upload.file_path
   # Returns a FileUploader with uploaded file retrieved into the object state
-  def initialize(project, secret, file_path)
-    @project = project
+  #
+  # container - project, project namespace or group
+  # secret - secret string in path to the file, based on FileUploader::MARKDOWN_PATTERN regex
+  # file_path - relative path to the file based on FileUploader::MARKDOWN_PATTERN regex
+  def initialize(container, secret, file_path)
+    @container = container
     @secret = secret
     @file_path = file_path
   end
@@ -20,6 +24,8 @@ class UploaderFinder
     nil # no-op if for incorrect files
   end
 
+  private
+
   def prevent_path_traversal_attack!
     Gitlab::PathTraversal.check_path_traversal!(@file_path)
   end
@@ -29,6 +35,10 @@ class UploaderFinder
   end
 
   def uploader
-    @uploader ||= FileUploader.new(@project, secret: @secret)
+    @uploader ||= uploader_klass.new(@container, secret: @secret)
+  end
+
+  def uploader_klass
+    @container.is_a?(Group) ? NamespaceFileUploader : FileUploader
   end
 end
