@@ -54,8 +54,7 @@ module Mutations
     end
 
     def self.authorized?(object, context)
-      auth = ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(:execute_graphql_mutation, :api)
-
+      auth = ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(:execute_graphql_mutation, authorization_scopes)
       return true if auth.ok?(:global, context[:current_user],
         scope_validator: context[:scope_validator])
 
@@ -63,9 +62,13 @@ module Mutations
       raise_resource_not_available_error!
     end
 
+    def self.authorization_scopes
+      [:api]
+    end
+
     # See: AuthorizeResource#authorized_resource?
     def self.authorization
-      @authorization ||= ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(authorize)
+      @authorization ||= ::Gitlab::Graphql::Authorize::ObjectAuthorization.new(authorize, authorization_scopes)
     end
   end
 end
