@@ -6,6 +6,10 @@ module Mutations
       class Play < Base
         graphql_name 'JobPlay'
 
+        argument :id, ::Types::GlobalIDType[::Ci::Processable],
+          required: true,
+          description: 'ID of the job to mutate.'
+
         field :job,
           Types::Ci::JobType,
           null: true,
@@ -21,10 +25,9 @@ module Mutations
 
         def resolve(id:, variables:)
           job = authorized_find!(id: id)
-          project = job.project
           variables = variables.map(&:to_h)
 
-          ::Ci::PlayBuildService.new(project, current_user).execute(job, variables)
+          job.play(current_user, variables)
 
           {
             job: job,
