@@ -27,7 +27,13 @@ module Mutations
           },
           description: 'Direction of access, which defaults to INBOUND.'
 
-        field :ci_job_token_scope,
+        field :ci_job_token_scope_allowlist_entry,
+          Types::Ci::JobTokenScope::AllowlistEntryType,
+          null: true,
+          experiment: { milestone: '17.6' },
+          description: "Allowlist entry for the CI job token's access scope."
+
+        field :ci_job_token_scope, # rubocop: disable GraphQL/ExtractType -- no value for now
           Types::Ci::JobTokenScopeType,
           null: true,
           description: "CI job token's access scope."
@@ -38,7 +44,7 @@ module Mutations
 
           if direction == :outbound
             raise Gitlab::Graphql::Errors::ArgumentError, 'direction: OUTBOUND scope entries can only be removed. ' \
-                                                          'Only INBOUND scope can be expanded.'
+              'Only INBOUND scope can be expanded.'
           end
 
           direction ||= :inbound
@@ -50,11 +56,13 @@ module Mutations
           if result.success?
             {
               ci_job_token_scope: ::Ci::JobToken::Scope.new(project),
+              ci_job_token_scope_allowlist_entry: result.payload[:project_link],
               errors: []
             }
           else
             {
               ci_job_token_scope: nil,
+              ci_job_token_scope_allowlist_entry: nil,
               errors: [result.message]
             }
           end
