@@ -10,7 +10,7 @@ module Mutations
         widget_keys = ::WorkItems::WidgetDefinition.available_widgets.map(&:api_symbol)
         widget_params = attributes.extract!(*widget_keys)
 
-        not_supported_keys = widget_params.keys - work_item_type.widgets(resource_parent).map(&:api_symbol)
+        not_supported_keys = widget_params.keys - work_item_type.widget_classes(resource_parent).map(&:api_symbol)
         if not_supported_keys.present?
           raise Gitlab::Graphql::Errors::ArgumentError,
             "Following widget keys are not supported by #{work_item_type.name} type: #{not_supported_keys}"
