@@ -18,7 +18,8 @@ module Mutations
         target_project = resolve_project(full_path: target_project_path).sync
 
         begin
-          moved_issue = ::Issues::MoveService.new(container: source_project, current_user: current_user).execute(issue, target_project)
+          moved_issue = ::Issues::MoveService.new(container: source_project, current_user: current_user)
+                                             .execute(issue, target_project)
         rescue ::Issues::MoveService::MoveError => e
           errors = e.message
         end
