@@ -1,5 +1,7 @@
 # frozen_string_literal: true
 
+# Deprecated:
+#   Remove from MutationType during any major release.
 module Mutations
   module Metrics
     module Dashboard
@@ -7,17 +9,13 @@ module Mutations
         class Delete < BaseMutation
           graphql_name 'DeleteAnnotation'
 
-          authorize :admin_metrics_dashboard_annotation
-
           argument :id, GraphQL::Types::String,
             required: true,
             description: 'Global ID of the annotation to delete.'
 
-          # rubocop:disable Lint/UnusedMethodArgument
-          def resolve(id:)
+          def resolve(_args)
             raise_resource_not_available_error!
           end
-          # rubocop:enable Lint/UnusedMethodArgument
         end
       end
     end
