@@ -15,7 +15,10 @@ module Mutations
       def resolve(id:)
         package = authorized_find!(id: id)
 
-        result = ::Packages::MarkPackageForDestructionService.new(container: package, current_user: current_user).execute
+        result = ::Packages::MarkPackageForDestructionService.new(
+          container: package,
+          current_user: current_user
+        ).execute
 
         errors = result.error? ? Array.wrap(result[:message]) : []
 
