@@ -6,7 +6,7 @@ module Resolvers
 
     authorize :read_label
 
-    type Types::LabelType.connection_type, null: true
+    type Types::AntiAbuse::AbuseReportLabelType.connection_type, null: true
 
     argument :search_term, GraphQL::Types::String,
       required: false,
