@@ -27,7 +27,7 @@ module Resolvers
     alias_method :container_repository, :object
 
     def resolve(sort:, **filters)
-      if container_repository.migrated?
+      if container_repository.gitlab_api_client.supports_gitlab_api?
         page_size = [filters[:first], filters[:last]].map(&:to_i).max
 
         result = container_repository.tags_page(
