@@ -6,6 +6,11 @@ module Resolvers
 
     type Types::GroupType.connection_type, null: true
 
+    argument :ids, [GraphQL::Types::ID],
+      required: false,
+      description: 'Filter groups by IDs.',
+      prepare: ->(global_ids, _ctx) { GitlabSchema.parse_gids(global_ids, expected_type: ::Group).map(&:model_id) }
+
     argument :search, GraphQL::Types::String,
       required: false,
       description: 'Search query for group name or group full path.'
@@ -13,7 +18,7 @@ module Resolvers
     argument :sort, GraphQL::Types::String,
       required: false,
       description: "Sort order of results. Format: `<field_name>_<sort_direction>`, " \
-                   "for example: `id_desc` or `name_asc`",
+        "for example: `id_desc` or `name_asc`",
       default_value: 'name_asc'
 
     private
