@@ -23,6 +23,18 @@ module Resolvers
       required: false,
       description: "Return only projects with merge requests enabled."
 
+    argument :archived, ::Types::Projects::ArchivedEnum,
+      required: false,
+      description: 'Filter projects by archived status.'
+
+    argument :min_access_level, ::Types::AccessLevelEnum,
+      required: false,
+      description: 'Return only projects where current user has at least the specified access level.'
+
+    argument :programming_language_name, GraphQL::Types::String,
+      required: false,
+      description: 'Filter projects by programming language name (case insensitive). For example: "css" or "ruby".'
+
     def resolve_with_lookahead(**args)
       validate_args!(args)
 
@@ -64,7 +76,10 @@ module Resolvers
         **project_finder_params(args),
         with_issues_enabled: args[:with_issues_enabled],
         with_merge_requests_enabled: args[:with_merge_requests_enabled],
-        full_paths: args[:full_paths]
+        full_paths: args[:full_paths],
+        archived: args[:archived],
+        min_access_level: args[:min_access_level],
+        language_name: args[:programming_language_name]
       }
     end
 
