@@ -9,6 +9,17 @@ module Resolvers
     def resolve
       authorize!(object)
 
+      load_notes_counts
+    end
+
+    def authorized_resource?(object)
+      ability = "read_#{object.class.name.underscore}".to_sym
+      Ability.allowed?(context[:current_user], ability, object)
+    end
+
+    private
+
+    def load_notes_counts
       BatchLoader::GraphQL.for(object.id).batch(key: :user_notes_count) do |ids, loader, args|
         counts = Note.count_for_collection(ids, object.class.name).index_by(&:noteable_id)
 
@@ -17,10 +28,7 @@ module Resolvers
         end
       end
     end
-
-    def authorized_resource?(object)
-      ability = "read_#{object.class.name.underscore}".to_sym
-      Ability.allowed?(context[:current_user], ability, object)
-    end
   end
 end
+
+::Resolvers::UserNotesCountResolver.prepend_mod
