@@ -15,7 +15,7 @@ module Resolvers
       description: 'List of usernames.'
 
     argument :sort, Types::SortEnum,
-      description: 'Sort users by this criteria.',
+      description: 'Sort users by the criteria.',
       required: false,
       default_value: :created_desc
 
@@ -28,18 +28,27 @@ module Resolvers
       default_value: false,
       description: 'Return only admin users.'
 
+    argument :active, GraphQL::Types::Boolean,
+      required: false,
+      description: 'Filter by active users. When true, returns active users. When false, returns non-active users.'
+
+    argument :humans, GraphQL::Types::Boolean,
+      required: false,
+      description: 'Filter by regular users. When true, returns only users that are not bot or internal users. ' \
+        'When false, returns only users that are bot or internal users.'
+
     argument :group_id, ::Types::GlobalIDType[::Group],
       required: false,
       description: 'Return users member of a given group.'
 
-    def resolve(ids: nil, usernames: nil, sort: nil, search: nil, admins: nil, group_id: nil)
+    def resolve(ids: nil, usernames: nil, sort: nil, search: nil, admins: nil, humans: nil, active: nil, group_id: nil)
       authorize!(usernames)
 
       group = group_id ? find_authorized_group!(group_id) : nil
 
       ::UsersFinder.new(
         context[:current_user],
-        finder_params(ids, usernames, sort, search, admins, group)
+        finder_params(ids, usernames, sort, search, admins, group, humans, active)
       ).execute
     end
 
@@ -61,13 +70,17 @@ module Resolvers
 
     private
 
-    def finder_params(ids, usernames, sort, search, admins, group)
+    def finder_params(ids, usernames, sort, search, admins, group, humans, active)
       params = {}
       params[:sort] = sort if sort
       params[:username] = usernames if usernames
       params[:id] = parse_gids(ids) if ids
       params[:search] = search if search
       params[:admins] = admins if admins
+      params[:humans] = humans == true
+      params[:without_humans] = humans == false
+      params[:active] = active == true
+      params[:without_active] = active == false
       params[:group] = group if group
       params
     end
