@@ -8,15 +8,15 @@ module Resolvers
       type Types::WorkItems::TypeType.connection_type, null: true
 
       argument :name, Types::IssueTypeEnum,
-               description: 'Filter work item types by the given name.',
-               required: false
+        description: 'Filter work item types by the given name.',
+        required: false
 
       def resolve_with_lookahead(name: nil)
         context.scoped_set!(:resource_parent, object)
 
         # This will require a finder in the future when groups/projects get their work item types
-        # All groups/projects use the default types for now
-        base_scope = ::WorkItems::Type.default
+        # All groups/projects use all types for now
+        base_scope = ::WorkItems::Type
         base_scope = base_scope.by_type(name) if name
 
         apply_lookahead(base_scope.order_by_name_asc)
@@ -32,7 +32,8 @@ module Resolvers
 
       def nested_preloads
         {
-          widget_definitions: { allowed_child_types: :allowed_child_types_by_name }
+          widget_definitions: { allowed_child_types: :allowed_child_types_by_name,
+                                allowed_parent_types: :allowed_parent_types_by_name }
         }
       end
     end
