@@ -4,8 +4,6 @@ module Types
   class AbuseReportType < BaseObject
     graphql_name 'AbuseReport'
 
-    implements Types::Notes::NoteableInterface
-
     description 'An abuse report'
 
     authorize :read_abuse_report
@@ -15,5 +13,10 @@ module Types
 
     field :labels, ::Types::LabelType.connection_type,
       null: true, description: 'Labels of the abuse report.'
+
+    field :discussions, ::Types::Notes::AbuseReport::DiscussionType.connection_type,
+      null: false, description: "All discussions on the noteable."
+    field :notes, ::Types::Notes::AbuseReport::NoteType.connection_type,
+      null: false, description: "All notes on the noteable."
   end
 end
