@@ -36,7 +36,10 @@ module Types
     end
 
     def self.authorized?(object, context)
-      authorization.ok?(object, context[:current_user], scope_validator: context[:scope_validator])
+      authorization.ok?(object, context[:current_user],
+        scope_validator: context[:scope_validator],
+        skip_abilities: context[:skip_type_authorization]
+      )
     end
 
     def current_user
