@@ -9,29 +9,26 @@ module Types
           graphql_name 'CiCatalogResourceComponent'
 
           field :id, ::Types::GlobalIDType[::Ci::Catalog::Resources::Component], null: false,
-            description: 'ID of the component.',
-            alpha: { milestone: '16.7' }
+            description: 'ID of the component.'
 
           field :name, GraphQL::Types::String, null: true,
-            description: 'Name of the component.',
-            alpha: { milestone: '16.7' }
+            description: 'Name of the component.'
 
           field :include_path, GraphQL::Types::String, null: true,
-            description: 'Path used to include the component.',
-            alpha: { milestone: '16.7' }
+            description: 'Path used to include the component.'
 
           field :inputs, [Types::Ci::Catalog::Resources::Components::InputType], null: true,
-            description: 'Inputs for the component.',
-            alpha: { milestone: '16.7' }
+            description: 'Inputs for the component.'
 
           def inputs
-            spec_inputs = object.spec.fetch('inputs', {})
-
-            spec_inputs.map do |key, value|
+            object.spec.fetch('inputs', {}).map do |key, value|
               {
                 name: key,
                 required: !value&.key?('default'),
-                default: value&.dig('default')
+                default: value&.dig('default'),
+                description: value&.dig('description'),
+                regex: value&.dig('regex'),
+                type: value&.dig('type') || 'string'
               }
             end
           end
