@@ -8,12 +8,12 @@ module Types
       value 'IDLE',
         description: "Runner is idle.",
         value: :idle,
-        alpha: { milestone: '15.7' }
+        experiment: { milestone: '15.7' }
 
       value 'ACTIVE',
         description: 'Runner is busy.',
         value: :active,
-        alpha: { milestone: '17.2' }
+        experiment: { milestone: '17.2' }
     end
   end
 end
