@@ -10,7 +10,7 @@ module Types
         ::ContainerRegistry::Protection::Rule.minimum_access_level_for_pushes.each_key do |access_level_key|
           value access_level_key.upcase,
             value: access_level_key.to_s,
-            alpha: { milestone: '16.6' },
+            experiment: { milestone: '16.6' },
             description: "#{access_level_key.capitalize} access."
         end
       end
