@@ -11,7 +11,7 @@ module Types
 
     expose_permissions Types::PermissionTypes::Environment,
       description: 'Permissions for the current user on the resource. '\
-                   'This field can only be resolved for one environment in any single request.' do
+        'This field can only be resolved for one environment in any single request.' do
       extension ::Gitlab::Graphql::Limit::FieldCallCount, limit: 1
     end
 
@@ -33,6 +33,9 @@ module Types
     field :external_url, GraphQL::Types::String, null: true,
       description: 'External URL of the environment.'
 
+    field :description, GraphQL::Types::String, null: true,
+      description: 'Description of the environment.'
+
     field :kubernetes_namespace, GraphQL::Types::String, null: true,
       description: 'Kubernetes namespace of the environment.'
 
@@ -59,7 +62,7 @@ module Types
 
     field :deployments_display_count, GraphQL::Types::String, null: true,
       description: 'Number of deployments in the environment for display. '\
-                   'Returns the precise number up to 999, and "999+" for counts exceeding this limit.'
+        'Returns the precise number up to 999, and "999+" for counts exceeding this limit.'
 
     field :latest_opened_most_severe_alert,
       Types::AlertManagement::AlertType,
@@ -91,6 +94,8 @@ module Types
       extension ::Gitlab::Graphql::Limit::FieldCallCount, limit: 1
     end
 
+    markdown_field :description_html, null: true
+
     def tier
       object.tier.to_sym
     end
