@@ -7,6 +7,8 @@ module Types
       description 'An integration to override the level settings of instance specific integrations.'
       authorize :admin_all_resources
 
+      field :group, ::Types::GroupType,
+        description: 'Group that has been excluded from the instance specific integration.'
       field :project, ::Types::ProjectType,
         description: 'Project that has been excluded from the instance specific integration.'
     end
