@@ -11,14 +11,14 @@ module Types
 
     value 'OBJECTIVE', value: 'objective',
       description: 'Objective issue type. Available only when feature flag `okrs_mvc` is enabled.',
-      alpha: { milestone: '15.6' }
+      experiment: { milestone: '15.6' }
 
     value 'KEY_RESULT', value: 'key_result',
       description: 'Key Result issue type. Available only when feature flag `okrs_mvc` is enabled.',
-      alpha: { milestone: '15.7' }
+      experiment: { milestone: '15.7' }
     value 'EPIC', value: 'epic',
       description: 'Epic issue type. ' \
-                   'Available only when feature epics is available and the feature flag `work_item_epics` is enabled.',
-      alpha: { milestone: '16.7' }
+        'Available only when feature epics is available and the feature flag `work_item_epics` is enabled.',
+      experiment: { milestone: '16.7' }
   end
 end
