@@ -5,6 +5,8 @@ module Types
     graphql_name 'Key'
     description 'Represents an SSH key.'
 
+    implements Types::TodoableInterface
+
     field :created_at, Types::TimeType, null: false,
       description: 'Timestamp of when the key was created.'
     field :expires_at, Types::TimeType, null: false,
@@ -13,5 +15,9 @@ module Types
     field :key, GraphQL::Types::String, null: false, method: :publishable_key,
       description: 'Public key of the key pair.'
     field :title, GraphQL::Types::String, null: false, description: 'Title of the key.'
+
+    def web_url
+      Gitlab::UrlBuilder.build(object)
+    end
   end
 end
