@@ -16,6 +16,8 @@ module Types
 
     present_using MergeRequestPresenter
 
+    field :closed_at, Types::TimeType, null: true, complexity: 5,
+      description: 'Timestamp of when the merge request was closed, null if not closed.'
     field :created_at, Types::TimeType, null: false,
       description: 'Timestamp of when the merge request was created.'
     field :description, GraphQL::Types::String, null: true,
@@ -54,6 +56,9 @@ module Types
       description: 'State of the merge request.'
     field :target_branch, GraphQL::Types::String, null: false,
       description: 'Target branch of the merge request.'
+    field :target_branch_path, GraphQL::Types::String, method: :target_branch_commits_path, null: true,
+      calls_gitaly: true,
+      description: 'Path to the target branch of the merge request.'
     field :target_project, Types::ProjectType, null: false,
       description: 'Target project of the merge request.'
     field :target_project_id, GraphQL::Types::Int, null: false,
@@ -98,6 +103,11 @@ module Types
       method: :public_merge_status, null: true,
       description: 'Merge status of the merge request.'
 
+    field :merge_after, ::Types::TimeType,
+      null: true,
+      description: 'Date after which the merge request can be merged.',
+      experiment: { milestone: '17.5' }
+
     field :detailed_merge_status, ::Types::MergeRequests::DetailedMergeStatusEnum, null: true,
       calls_gitaly: true,
       description: 'Detailed merge status of the merge request.'
@@ -106,12 +116,12 @@ module Types
       null: false,
       description: 'Status of all mergeability checks of the merge request.',
       method: :all_mergeability_checks_results,
-      alpha: { milestone: '16.5' },
+      experiment: { milestone: '16.5' },
       calls_gitaly: true
 
-    field :mergeable_discussions_state, GraphQL::Types::Boolean, null: true,
-      calls_gitaly: true,
-      description: 'Indicates if all discussions in the merge request have been resolved, allowing the merge request to be merged.'
+    field :mergeable_discussions_state, GraphQL::Types::Boolean, null: true, calls_gitaly: true,
+      description: 'Indicates if all discussions in the merge request have been resolved, ' \
+        'allowing the merge request to be merged.'
     field :rebase_commit_sha, GraphQL::Types::String, null: true,
       description: 'Rebase commit SHA of the merge request.'
     field :rebase_in_progress, GraphQL::Types::Boolean, method: :rebase_in_progress?, null: false, calls_gitaly: true,
@@ -153,7 +163,8 @@ module Types
       description: 'Pipeline running on the branch HEAD of the merge request.'
     field :pipelines,
       null: true,
-      description: 'Pipelines for the merge request. Note: for performance reasons, no more than the most recent 500 pipelines will be returned.',
+      description: 'Pipelines for the merge request. Note: for performance reasons, ' \
+        'no more than the most recent 500 pipelines will be returned.',
       resolver: Resolvers::MergeRequestPipelinesResolver
 
     field :assignees,
@@ -183,8 +194,12 @@ module Types
       description: 'Indicates if the merge request has conflicts.'
     field :milestone, Types::MilestoneType, null: true,
       description: 'Milestone of the merge request.'
-    field :participants, Types::MergeRequests::ParticipantType.connection_type, null: true, complexity: 15,
-      description: 'Participants in the merge request. This includes the author, assignees, reviewers, and users mentioned in notes.',
+    field :participants,
+      Types::MergeRequests::ParticipantType.connection_type,
+      null: true,
+      complexity: 15,
+      description: 'Participants in the merge request. This includes the author, ' \
+        'assignees, reviewers, and users mentioned in notes.',
       resolver: Resolvers::Users::ParticipantsResolver
     field :reference, GraphQL::Types::String, null: false, method: :to_reference,
       description: 'Internal reference of the merge request. Returned in shortened format by default.' do
@@ -230,11 +245,22 @@ module Types
       description: 'User who merged this merge request or set it to auto-merge.'
     field :mergeable, GraphQL::Types::Boolean, null: false, method: :mergeable?, calls_gitaly: true,
       description: 'Indicates if the merge request is mergeable.'
-    field :security_auto_fix, GraphQL::Types::Boolean, null: true,
-      description: 'Indicates if the merge request is created by @GitLab-Security-Bot.', deprecated: { reason: 'Security Auto Fix experiment feature was removed. It was always hidden behind `security_auto_fix` feature flag', milestone: '16.11' }
+    field :security_auto_fix,
+      GraphQL::Types::Boolean,
+      null: true,
+      description: 'Indicates if the merge request is created by @GitLab-Security-Bot.',
+      deprecated: {
+        reason: 'Security Auto Fix experiment feature was removed. ' \
+          'It was always hidden behind `security_auto_fix` feature flag',
+        milestone: '16.11'
+      }
 
     field :squash, GraphQL::Types::Boolean, null: false,
-      description: 'Indicates if the merge request is set to be squashed when merged. [Project settings](https://docs.gitlab.com/ee/user/project/merge_requests/squash_and_merge.html#configure-squash-options-for-a-project) may override this value. Use `squash_on_merge` instead to take project squash options into account.'
+      description: <<~HEREDOC.squish
+                   Indicates if the merge request is set to be squashed when merged.
+                   [Project settings](https://docs.gitlab.com/ee/user/project/merge_requests/squash_and_merge.html#configure-squash-options-for-a-project)
+                   may override this value. Use `squash_on_merge` instead to take project squash options into account.
+      HEREDOC
     field :squash_on_merge, GraphQL::Types::Boolean, null: false, method: :squash_on_merge?,
       description: 'Indicates if the merge request will be squashed when merged.'
     field :timelogs, Types::TimelogType.connection_type, null: false,
@@ -268,6 +294,9 @@ module Types
     field :retargeted, GraphQL::Types::Boolean, null: true,
       description: 'Indicates if merge request was retargeted.'
 
+    field :hidden, GraphQL::Types::Boolean, null: true,
+      description: 'Indicates the merge request is hidden because the author has been banned.', method: :hidden?
+
     markdown_field :title_html, null: true
     markdown_field :description_html, null: true
 
@@ -283,7 +312,11 @@ module Types
 
     def user_discussions_count
       BatchLoader::GraphQL.for(object.id).batch(key: :merge_request_user_discussions_count) do |ids, loader, args|
-        counts = Note.count_for_collection(ids, 'MergeRequest', 'COUNT(DISTINCT discussion_id) as count').index_by(&:noteable_id)
+        counts = Note.count_for_collection(
+          ids,
+          'MergeRequest',
+          'COUNT(DISTINCT discussion_id) as count'
+        ).index_by(&:noteable_id)
 
         ids.each do |id|
           loader.call(id, counts[id]&.count || 0)
@@ -325,6 +358,10 @@ module Types
       AutoMergeService.new(object.project, current_user).available_strategies(object)
     end
 
+    def closed_at
+      object.metrics&.latest_closed_at
+    end
+
     def commits
       object.commits.commits
     end
@@ -341,6 +378,10 @@ module Types
       object.metrics&.merged_by || object.merge_user
     end
 
+    def merge_after
+      object.merge_schedule&.merge_after
+    end
+
     def detailed_merge_status
       ::MergeRequests::Mergeability::DetailedMergeStatusService.new(merge_request: object).execute
     end
