@@ -19,6 +19,8 @@ module Types
 
       field :created_at, Types::TimeType, null: false, description: 'Date of creation.'
 
+      field :author, ::Types::UserType, null: true, description: 'User that created the model.'
+
       field :description, ::GraphQL::Types::String,
         null: true,
         description: 'Description of the model.'
@@ -44,10 +46,6 @@ module Types
       field :version, ::Types::Ml::ModelVersionType, null: true,
         description: 'Version of the model.',
         resolver: ::Resolvers::Ml::FindModelVersionResolver
-
-      def description_html_resolver
-        ::MarkupHelper.markdown(object.description, context.to_h.dup)
-      end
     end
     # rubocop: enable Graphql/AuthorizeTypes
   end
