@@ -5,8 +5,10 @@ module Types
     module NoteableInterface
       include Types::BaseInterface
 
-      field :notes, resolver: Resolvers::Noteable::NotesResolver, null: false, description: "All notes on this noteable."
-      field :discussions, Types::Notes::DiscussionType.connection_type, null: false, description: "All discussions on this noteable."
+      field :notes, resolver: Resolvers::Noteable::NotesResolver, null: false,
+        description: "All notes on this noteable."
+      field :discussions, Types::Notes::DiscussionType.connection_type, null: false,
+        description: "All discussions on this noteable."
       field :commenters, Types::UserType.connection_type, null: false, description: "All commenters on this noteable."
 
       def self.resolve_type(object, context)
@@ -21,17 +23,14 @@ module Types
           Types::DesignManagement::DesignType
         when ::AlertManagement::Alert
           Types::AlertManagement::AlertType
-        when AbuseReport
-          Types::AbuseReportType
+        when WikiPage::Meta
+          Types::Wikis::WikiPageType
         else
           raise "Unknown GraphQL type for #{object}"
         end
       end
 
       def commenters
-        # TODO: Implement as part of completion https://gitlab.com/gitlab-org/gitlab/-/issues/458264
-        return [] if object.is_a?(AbuseReport)
-
         object.commenters(user: current_user)
       end
     end
