@@ -8,7 +8,7 @@ module Types
 
       abilities :read_work_item, :update_work_item, :delete_work_item,
         :admin_work_item, :admin_parent_link, :set_work_item_metadata,
-        :create_note, :admin_work_item_link
+        :create_note, :admin_work_item_link, :mark_note_as_internal
     end
   end
 end
