@@ -12,7 +12,7 @@ module Types
 
         field :linked_items, Types::WorkItems::LinkedItemType.connection_type,
           null: true, complexity: 5,
-          alpha: { milestone: '16.3' },
+          experiment: { milestone: '16.3' },
           extras: [:lookahead],
           description: 'Linked items for the work item.',
           resolver: Resolvers::WorkItems::LinkedItemsResolver
