@@ -6,13 +6,17 @@ module Types
       class StartAndDueDateUpdateInputType < BaseInputObject
         graphql_name 'WorkItemWidgetStartAndDueDateUpdateInput'
 
-        argument :due_date, Types::DateType,
+        argument :due_date,
+          Types::DateType,
           required: false,
           description: 'Due date for the work item.'
-        argument :start_date, Types::DateType,
+
+        argument :start_date,
+          Types::DateType,
           required: false,
           description: 'Start date for the work item.'
       end
     end
   end
 end
+Types::WorkItems::Widgets::StartAndDueDateUpdateInputType.prepend_mod
