@@ -36,10 +36,16 @@ module AccessTokensHelper
   end
 
   def expires_at_field_data
+    return {} unless Gitlab::CurrentSettings.require_personal_access_token_expiry?
+
     {
       min_date: 1.day.from_now.iso8601
     }
   end
+
+  def show_token_expiration_banner?
+    Gitlab::Auth::TokenExpirationBanner.show_token_expiration_banner?
+  end
 end
 
 AccessTokensHelper.prepend_mod
