@@ -24,9 +24,12 @@ module BranchesHelper
 
   def merge_request_status(merge_request)
     return unless merge_request.present?
-    return if merge_request.closed?
 
-    if merge_request.open? || merge_request.locked?
+    if merge_request.closed?
+      variant = :danger
+      mr_icon = 'merge-request-close'
+      mr_status = _('Closed')
+    elsif merge_request.open? || merge_request.locked?
       variant = :success
       variant = :warning if merge_request.draft?
 
