@@ -22,7 +22,7 @@ module BreadcrumbsHelper
   end
 
   def breadcrumb_list_item(link)
-    content_tag :li, link, class: 'gl-breadcrumb-item gl-display-inline-flex'
+    content_tag :li, link, class: 'gl-breadcrumb-item gl-inline-flex'
   end
 
   def add_to_breadcrumb_collapsed_links(link, location: :before)
@@ -39,7 +39,7 @@ module BreadcrumbsHelper
     {
       '@context': 'https://schema.org',
       '@type': 'BreadcrumbList',
-      'itemListElement': build_item_list_elements&.map&.with_index do |item, index|
+      itemListElement: build_item_list_elements&.map&.with_index do |item, index|
         {
           '@type' => 'ListItem',
           'position' => index + 1,
