@@ -12,10 +12,9 @@ module Ci
         "artifact_help_url" => help_page_path('user/gitlab_com/index.md', anchor: 'gitlab-cicd'),
         "deployment_help_url" => help_page_path('user/project/clusters/deploy_to_cluster.md', anchor: 'troubleshooting'),
         "runner_settings_url" => project_runners_path(build.project, anchor: 'js-runners-settings'),
-        "retry_outdated_job_docs_url" => help_page_path('ci/pipelines/settings', anchor: 'retry-outdated-jobs'),
+        "retry_outdated_job_docs_url" => help_page_path('ci/pipelines/settings.md', anchor: 'prevent-outdated-deployment-jobs'),
         "pipeline_test_report_url" => test_report_project_pipeline_path(project, build.pipeline),
-        "log_viewer_path" => viewer_project_job_path(project, build),
-        "job_gid" => build.to_gid.to_s
+        "log_viewer_path" => viewer_project_job_path(project, build)
       }
     end
 
