@@ -26,7 +26,7 @@ module InviteMembersHelper
       name: source.name,
       default_access_level: Gitlab::Access::GUEST,
       invalid_groups: source.related_group_ids,
-      help_link: help_page_url('user/permissions'),
+      help_link: help_page_url('user/permissions.md'),
       is_project: is_project,
       access_levels: member_class.permissible_access_level_roles(current_user, source).to_json,
       full_path: source.full_path
@@ -44,6 +44,11 @@ module InviteMembersHelper
     }
   end
 
+  # Overridden in EE
+  def invite_group_dataset(source)
+    {}
+  end
+
   private
 
   def group_select_data(source)
