@@ -3,6 +3,8 @@
 module PlanLimitsHelper
   def plan_limit_setting_description(limit_name)
     case limit_name
+    when :ci_instance_level_variables
+      s_('AdminSettings|Maximum number of Instance-level CI/CD variables that can be defined')
     when :ci_pipeline_size
       s_('AdminSettings|Maximum number of jobs in a single pipeline')
     when :ci_active_jobs
@@ -12,11 +14,15 @@ module PlanLimitsHelper
     when :ci_pipeline_schedules
       s_('AdminSettings|Maximum number of pipeline schedules')
     when :ci_needs_size_limit
-      s_('AdminSettings|Maximum number of DAG dependencies that a job can have')
+      s_('AdminSettings|Maximum number of needs dependencies that a job can have')
     when :ci_registered_group_runners
       s_('AdminSettings|Maximum number of runners registered per group')
     when :ci_registered_project_runners
       s_('AdminSettings|Maximum number of runners registered per project')
+    when :dotenv_size
+      s_('AdminSettings|Maximum size of a dotenv artifact in bytes')
+    when :dotenv_variables
+      s_('AdminSettings|Maximum number of variables in a dotenv artifact')
     when :pipeline_hierarchy_size
       s_("AdminSettings|Maximum number of downstream pipelines in a pipeline's hierarchy tree")
     else
