@@ -15,8 +15,10 @@ module Users
     REGISTRATION_ENABLED_CALLOUT_ALLOWED_CONTROLLER_PATHS = [/^root/, /^dashboard\S*/, /^admin\S*/].freeze
     WEB_HOOK_DISABLED = 'web_hook_disabled'
     BRANCH_RULES_INFO_CALLOUT = 'branch_rules_info_callout'
+    BRANCH_RULES_TIP_CALLOUT = 'branch_rules_tip_callout'
     TRANSITION_TO_JIHU_CALLOUT = 'transition_to_jihu_callout'
     PERIOD_IN_TERRAFORM_STATE_NAME_ALERT = 'period_in_terraform_state_name_alert'
+    NEW_MR_DASHBOARD_BANNER = 'new_mr_dashboard_banner'
 
     def show_gke_cluster_integration_callout?(project)
       active_nav_link?(controller: sidebar_operations_paths) &&
@@ -28,11 +30,9 @@ module Users
       !user_dismissed?(GCP_SIGNUP_OFFER)
     end
 
-    def render_dashboard_ultimate_trial(user)
-    end
+    def render_dashboard_ultimate_trial(user); end
 
-    def render_two_factor_auth_recovery_settings_check
-    end
+    def render_two_factor_auth_recovery_settings_check; end
 
     def show_suggest_popover?
       !user_dismissed?(SUGGEST_POPOVER_DISMISSED)
@@ -63,8 +63,7 @@ module Users
         controller.controller_path.match?(%r{^admin(/\S*)?$})
     end
 
-    def dismiss_two_factor_auth_recovery_settings_check
-    end
+    def dismiss_two_factor_auth_recovery_settings_check; end
 
     def show_security_newsletter_user_callout?
       current_user&.can_admin_all_resources? &&
@@ -81,6 +80,10 @@ module Users
       !user_dismissed?(BRANCH_RULES_INFO_CALLOUT)
     end
 
+    def show_branch_rules_tip?
+      !user_dismissed?(BRANCH_RULES_TIP_CALLOUT)
+    end
+
     def show_transition_to_jihu_callout?
       !Gitlab.jh? &&
         current_user&.can_admin_all_resources? &&
@@ -92,6 +95,10 @@ module Users
       !user_dismissed?(PERIOD_IN_TERRAFORM_STATE_NAME_ALERT)
     end
 
+    def show_new_mr_dashboard_banner?
+      !user_dismissed?(NEW_MR_DASHBOARD_BANNER)
+    end
+
     private
 
     def user_dismissed?(feature_name, ignore_dismissal_earlier_than = nil, object: nil)
