@@ -7,7 +7,7 @@ module Emails
     include Gitlab::Experiment::Dsl
 
     included do
-      helper_method :member_source, :member
+      helper_method :member, :member_source, :member_source_organization
       helper_method :experiment
     end
 
@@ -35,44 +35,6 @@ module Emails
         subject: subject("Access to the #{member_source.human_name} #{member_source.model_name.singular} was granted"))
     end
 
-    def member_access_denied_email(member_source_type, source_id, user_id)
-      @member_source_type = member_source_type
-      @member_source = member_source_class.find(source_id)
-
-      user = User.find(user_id)
-
-      @source_hidden = !member_source.readable_by?(user)
-
-      human_name = @source_hidden ? 'Hidden' : member_source.human_name
-
-      email_with_layout(
-        to: user.notification_email_for(notification_group),
-        subject: subject("Access to the #{human_name} #{member_source.model_name.singular} was denied"))
-    end
-
-    def member_invited_reminder_email(member_source_type, member_id, token, reminder_index)
-      @member_source_type = member_source_type
-      @member_id = member_id
-      @token = token
-      @reminder_index = reminder_index
-
-      return unless member_exists? && member.created_by && member.invite_to_unknown_user?
-
-      subjects = {
-        0 => s_("InviteReminderEmail|%{inviter}'s invitation to GitLab is pending"),
-        1 => s_('InviteReminderEmail|%{inviter} is waiting for you to join GitLab'),
-        2 => s_('InviteReminderEmail|%{inviter} is still waiting for you to join GitLab')
-      }
-
-      subject_line = subjects[reminder_index] % { inviter: member.created_by.name }
-
-      email_with_layout(
-        layout: 'unknown_user_mailer',
-        to: member.invite_email,
-        subject: subject(subject_line)
-      )
-    end
-
     def member_invite_accepted_email(member_source_type, member_id)
       @member_source_type = member_source_type
       @member_id = member_id
@@ -129,7 +91,12 @@ module Emails
 
       email_with_layout(
         to: member.user.notification_email_for(notification_group),
-        subject: subject(s_("Your membership will expire in %{days_to_expire} days") % { days_to_expire: @days_to_expire }))
+        subject: subject(
+          s_("Your membership will expire in %{days_to_expire} days") % {
+            days_to_expire: @days_to_expire
+          }
+        )
+      )
     end
 
     # rubocop: disable CodeReuse/ActiveRecord
@@ -142,6 +109,10 @@ module Emails
       @member_source ||= member.source
     end
 
+    def member_source_organization
+      @member_source_organization ||= member_source.organization
+    end
+
     def notification_group
       @member_source_type.casecmp?('project') ? member_source.group : member_source
     end
@@ -149,7 +120,12 @@ module Emails
     private
 
     def member_exists?
-      Gitlab::AppLogger.info("Tried to send an email invitation for a deleted group. Member id: #{@member_id}") if member.blank?
+      if member.blank?
+        Gitlab::AppLogger.info(
+          "Tried to send an email invitation for a deleted group. Member id: #{@member_id}"
+        )
+      end
+
       member.present?
     end
 
