@@ -10,10 +10,12 @@ module Analytics
 
       alias_attribute :state, :state_id
       enum state: Issue.available_states, _suffix: true
+      belongs_to :issuable, class_name: 'Issue', foreign_key: 'issue_id', inverse_of: :issue_stage_events
 
       scope :assigned_to, ->(user) do
         assignees_class = IssueAssignee
-        condition = assignees_class.where(user_id: user).where(arel_table[:issue_id].eq(assignees_class.arel_table[:issue_id]))
+        condition = assignees_class.where(user_id: user)
+                                   .where(arel_table[:issue_id].eq(assignees_class.arel_table[:issue_id]))
         where(condition.arel.exists)
       end
 
@@ -53,6 +55,10 @@ module Analytics
             :sprint_id
           ]
         end
+
+        def assignees_model
+          IssueAssignee
+        end
       end
     end
   end
