@@ -11,6 +11,8 @@ module Analytics
       alias_attribute :state, :state_id
       enum state: MergeRequest.available_states, _suffix: true
 
+      belongs_to :issuable, class_name: 'MergeRequest', foreign_key: 'merge_request_id', inverse_of: :merge_request_stage_events
+
       scope :assigned_to, ->(user) do
         assignees_class = MergeRequestAssignee
         condition = assignees_class.where(user_id: user).where(arel_table[:merge_request_id].eq(assignees_class.arel_table[:merge_request_id]))
@@ -28,6 +30,10 @@ module Analytics
       def self.issuable_model
         ::MergeRequest
       end
+
+      def self.assignees_model
+        MergeRequestAssignee
+      end
     end
   end
 end
