@@ -3,6 +3,8 @@
 module AntiAbuse
   module Reports
     class Discussion < ::Discussion
+      delegate :abuse_report, to: :first_note
+
       def self.base_discussion_id(_note)
         [:discussion, :abuse_report_id]
       end
@@ -11,6 +13,14 @@ module AntiAbuse
         DiscussionNote
       end
 
+      def self.model_class
+        AntiAbuse::Reports::Note
+      end
+
+      def discussion_class
+        self.class
+      end
+
       def reply_attributes
         first_note.slice(:type, :abuse_report_id, :discussion_id)
       end
