@@ -5,22 +5,20 @@ class ApplicationSetting < ApplicationRecord
   include CacheMarkdownField
   include TokenAuthenticatable
   include ChronicDurationAttribute
-  include IgnorableColumns
   include Sanitizable
-  include SafelyChangeColumnDefault
 
-  ignore_columns %i[elasticsearch_shards elasticsearch_replicas], remove_with: '14.4', remove_after: '2021-09-22'
-  ignore_columns %i[static_objects_external_storage_auth_token], remove_with: '14.9', remove_after: '2022-03-22'
-  ignore_column :web_ide_clientside_preview_enabled, remove_with: '15.11', remove_after: '2023-04-22'
-  ignore_columns %i[instance_administration_project_id instance_administrators_group_id], remove_with: '16.2', remove_after: '2023-06-22'
-  ignore_columns %i[repository_storages], remove_with: '16.8', remove_after: '2023-12-21'
-  ignore_column :required_instance_ci_template, remove_with: '17.1', remove_after: '2024-05-10'
-  ignore_column %i[sign_in_text help_text], remove_with: '17.3', remove_after: '2024-08-15'
-  ignore_column :sign_in_text_html, remove_with: '17.5', remove_after: '2024-10-17'
-  ignore_columns %i[openai_api_key anthropic_api_key vertex_ai_credentials vertex_ai_access_token], remove_with: '17.3', remove_after: '2024-08-15'
-  ignore_columns %i[arkose_labs_verify_api_url], remove_with: '17.4', remove_after: '2024-08-09'
-
-  columns_changing_default %i[ci_max_total_yaml_size_bytes max_yaml_size_bytes]
+  ignore_columns %i[
+    encrypted_openai_api_key
+    encrypted_openai_api_key_iv
+    encrypted_anthropic_api_key
+    encrypted_anthropic_api_key_iv
+    encrypted_vertex_ai_credentials
+    encrypted_vertex_ai_credentials_iv
+    encrypted_vertex_ai_access_token
+    encrypted_vertex_ai_access_token_iv
+  ], remove_with: '17.5', remove_after: '2024-09-19'
+  ignore_columns %i[toggle_security_policy_custom_ci lock_toggle_security_policy_custom_ci], remove_with: '17.6', remove_after: '2024-10-17'
+  ignore_column :runners_registration_token, remove_with: '17.7', remove_after: '2024-11-22'
 
   INSTANCE_REVIEW_MIN_USERS = 50
   GRAFANA_URL_ERROR_MESSAGE = 'Please check your Grafana URL setting in ' \
@@ -44,6 +42,8 @@ class ApplicationSetting < ApplicationRecord
 
   USERS_UNCONFIRMED_SECONDARY_EMAILS_DELETE_AFTER_DAYS = 3
 
+  INACTIVE_RESOURCE_ACCESS_TOKENS_DELETE_AFTER_DAYS = 30
+
   enum whats_new_variant: { all_tiers: 0, current_tier: 1, disabled: 2 }, _prefix: true
   enum email_confirmation_setting: { off: 0, soft: 1, hard: 2 }, _prefix: true
 
@@ -530,6 +530,7 @@ class ApplicationSetting < ApplicationRecord
       :concurrent_bitbucket_import_jobs_limit,
       :concurrent_bitbucket_server_import_jobs_limit,
       :concurrent_github_import_jobs_limit,
+      :concurrent_relation_batch_export_limit,
       :container_registry_token_expire_delay,
       :housekeeping_optimize_repository_period,
       :inactive_projects_delete_after_months,
@@ -598,10 +599,13 @@ class ApplicationSetting < ApplicationRecord
       :max_terraform_state_size_bytes,
       :members_delete_limit,
       :notes_create_limit,
+      :create_organization_api_limit,
       :package_registry_cleanup_policies_worker_capacity,
       :packages_cleanup_package_file_worker_capacity,
+      :pages_extra_deployments_default_expiry_seconds,
       :pipeline_limit_per_project_user_sha,
       :project_api_limit,
+      :project_invited_groups_api_limit,
       :projects_api_limit,
       :projects_api_rate_limit_unauthenticated,
       :raw_blob_request_limit,
@@ -620,6 +624,7 @@ class ApplicationSetting < ApplicationRecord
     concurrent_bitbucket_import_jobs_limit: [:integer, { default: 100 }],
     concurrent_bitbucket_server_import_jobs_limit: [:integer, { default: 100 }],
     concurrent_github_import_jobs_limit: [:integer, { default: 1000 }],
+    concurrent_relation_batch_export_limit: [:integer, { default: 8 }],
     downstream_pipeline_trigger_limit_per_project_user_sha: [:integer, { default: 0 }],
     group_api_limit: [:integer, { default: 400 }],
     group_invited_groups_api_limit: [:integer, { default: 60 }],
@@ -627,7 +632,9 @@ class ApplicationSetting < ApplicationRecord
     group_shared_groups_api_limit: [:integer, { default: 60 }],
     groups_api_limit: [:integer, { default: 200 }],
     members_delete_limit: [:integer, { default: 60 }],
+    create_organization_api_limit: [:integer, { default: 10 }],
     project_api_limit: [:integer, { default: 400 }],
+    project_invited_groups_api_limit: [:integer, { default: 60 }],
     projects_api_limit: [:integer, { default: 2000 }],
     user_contributed_projects_api_limit: [:integer, { default: 100 }],
     user_projects_api_limit: [:integer, { default: 300 }],
@@ -642,12 +649,23 @@ class ApplicationSetting < ApplicationRecord
     throttle_unauthenticated_git_http_period_in_seconds: [:integer, { default: 3600 }]
 
   jsonb_accessor :importers,
-    silent_admin_exports_enabled: [:boolean, { default: false }]
+    silent_admin_exports_enabled: [:boolean, { default: false }],
+    allow_contribution_mapping_to_admins: [:boolean, { default: false }]
+
+  jsonb_accessor :sign_in_restrictions,
+    disable_password_authentication_for_users_with_sso_identities: [:boolean, { default: false }]
+
+  validates :sign_in_restrictions, json_schema: { filename: 'application_setting_sign_in_restrictions' }
 
   validates :rate_limits, json_schema: { filename: "application_setting_rate_limits" }
 
   validates :importers, json_schema: { filename: "application_setting_importers" }
 
+  jsonb_accessor :transactional_emails,
+    resource_token_expiry_inherited_members: [:boolean, { default: true }]
+
+  validates :transactional_emails, json_schema: { filename: "application_setting_transactional_emails" }
+
   jsonb_accessor :package_registry, nuget_skip_metadata_url_validation: [:boolean, { default: false }]
 
   validates :package_registry, json_schema: { filename: 'application_setting_package_registry' }
@@ -730,6 +748,15 @@ class ApplicationSetting < ApplicationRecord
   validates :asciidoc_max_includes,
     numericality: { only_integer: true, greater_than_or_equal_to: 0, less_than_or_equal_to: 64 }
 
+  jsonb_accessor :pages,
+    pages_extra_deployments_default_expiry_seconds: [:integer, { default: 86400 }]
+
+  validates :pages, json_schema: { filename: "application_setting_pages" }
+
+  validates :enforce_ci_inbound_job_token_scope_enabled,
+    allow_nil: false,
+    inclusion: { in: [true, false], message: N_('must be a boolean value') }
+
   attr_encrypted :asset_proxy_secret_key,
     mode: :per_attribute_iv,
     key: Settings.attr_encrypted_db_key_base_truncated,
