@@ -1,12 +1,15 @@
 # frozen_string_literal: true
 
 class AwardEmoji < ApplicationRecord
-  DOWNVOTE_NAME = "thumbsdown"
-  UPVOTE_NAME   = "thumbsup"
+  THUMBS_UP     = 'thumbsup'
+  THUMBS_DOWN   = 'thumbsdown'
+  UPVOTE_NAME   = THUMBS_UP
+  DOWNVOTE_NAME = THUMBS_DOWN
 
   include Participable
   include GhostUser
   include Importable
+  include EachBatch
 
   belongs_to :awardable, polymorphic: true # rubocop:disable Cop/PolymorphicAssociations
   belongs_to :user
