@@ -52,13 +52,10 @@ class BulkImport < ApplicationRecord
       transition any => :canceled
     end
 
-    # rubocop:disable Style/SymbolProc
     after_transition any => [:finished, :failed, :timeout] do |bulk_import|
       bulk_import.update_has_failures
-      bulk_import.notify_owners_of_completion
+      bulk_import.send_completion_notification
     end
-    # rubocop:enable Style/SymbolProc
-
     after_transition any => [:canceled] do |bulk_import|
       bulk_import.run_after_commit do
         bulk_import.propagate_cancel
@@ -103,22 +100,27 @@ class BulkImport < ApplicationRecord
     finished? || failed? || timeout? || canceled?
   end
 
-  def notify_owners_of_completion
-    users_to_notify = parent_group_entity&.group&.owners
-
-    return if users_to_notify.blank?
-
-    users_to_notify.each do |owner|
-      run_after_commit do
-        Notify.bulk_import_complete(owner.id, id).deliver_later
-      end
+  def send_completion_notification
+    run_after_commit do
+      Notify.bulk_import_complete(user.id, id).deliver_later
     end
   end
 
-  # Finds the root group entity of the BulkImport's entity tree.
-  # @return [BulkImports::Entity, nil]
-  def parent_group_entity
-    entities.group_entity.where(parent: nil).first
+  def destination_group_roots
+    entities.where(parent: nil).filter_map do |entity|
+      entity.group || entity.project
+    end.map(&:root_ancestor).uniq
+  end
+
+  def namespaces_with_unassigned_placeholders
+    namespaces = destination_group_roots
+    namespace_ids = namespaces.collect(&:id)
+
+    reassignable_statuses = Import::SourceUser::STATUSES.slice(*Import::SourceUser::REASSIGNABLE_STATUSES).values
+    source_users = Import::SourceUser.for_namespace(namespace_ids).by_statuses(reassignable_statuses)
+    valid_namespace_ids = source_users.collect(&:namespace_id).uniq
+
+    namespaces.select { |namespace| valid_namespace_ids.include?(namespace.id) }
   end
 
   def source_url
