@@ -5,6 +5,10 @@
 class BulkImports::Configuration < ApplicationRecord
   self.table_name = 'bulk_import_configurations'
 
+  include IgnorableColumns
+
+  ignore_column :migrate_memberships, remove_with: '17.8', remove_after: '2025-01-20'
+
   belongs_to :bulk_import, inverse_of: :configuration, optional: false
 
   validates :url, :access_token, length: { maximum: 255 }, presence: true
@@ -19,8 +23,4 @@ class BulkImports::Configuration < ApplicationRecord
     key: Settings.attr_encrypted_db_key_base_32,
     mode: :per_attribute_iv,
     algorithm: 'aes-256-gcm'
-
-  def source_hostname
-    URI.parse(url).host
-  end
 end
