@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 
 class BulkImports::Tracker < ApplicationRecord
+  include AfterCommitQueue
+
   self.table_name = 'bulk_import_trackers'
 
   alias_attribute :pipeline_name, :relation
@@ -52,6 +54,7 @@ class BulkImports::Tracker < ApplicationRecord
     state :timeout, value: 4
     state :failed, value: -1
     state :skipped, value: -2
+    state :canceled, value: -3
 
     event :start do
       transition enqueued: :started
@@ -83,6 +86,10 @@ class BulkImports::Tracker < ApplicationRecord
       transition any => :failed
     end
 
+    event :cancel do
+      transition any => :canceled
+    end
+
     event :cleanup_stale do
       transition [:created, :started] => :timeout
     end
@@ -90,6 +97,12 @@ class BulkImports::Tracker < ApplicationRecord
     after_transition any => [:finished, :failed] do |tracker|
       BulkImports::ObjectCounter.persist!(tracker)
     end
+
+    after_transition any => [:canceled] do |tracker|
+      tracker.run_after_commit do
+        tracker.propagate_cancel
+      end
+    end
   end
 
   def checksums
@@ -111,6 +124,10 @@ class BulkImports::Tracker < ApplicationRecord
     pipeline_class.relation.to_sym
   end
 
+  def propagate_cancel
+    batches.each(&:cancel)
+  end
+
   private
 
   def cached_checksums
