@@ -4,9 +4,7 @@ module Ci
   class ApplicationRecord < ::ApplicationRecord
     self.abstract_class = true
 
-    if Gitlab::Database.has_config?(:ci)
-      connects_to database: { writing: :ci, reading: :ci }
-    end
+    connects_to database: { writing: :ci, reading: :ci } if Gitlab::Database.has_config?(:ci)
 
     def self.table_name_prefix
       'ci_'
