@@ -70,6 +70,7 @@ module Ci
     def self.with_preloads
       preload(
         :metadata,
+        user: [:followers, :followees],
         downstream_pipeline: [project: [:route, { namespace: :route }]],
         project: [:namespace]
       )
@@ -77,9 +78,9 @@ module Ci
 
     def self.clone_accessors
       %i[pipeline project ref tag options name
-         allow_failure stage stage_idx
-         yaml_variables when environment description needs_attributes
-         scheduling_type ci_stage partition_id].freeze
+        allow_failure stage stage_idx
+        yaml_variables when environment description needs_attributes
+        scheduling_type ci_stage partition_id].freeze
     end
 
     def inherit_status_from_downstream!(pipeline)
@@ -188,7 +189,7 @@ module Ci
     def runner; end
 
     def tag_list
-      ActsAsTaggableOn::TagList.new
+      Gitlab::Ci::Tags::TagList.new
     end
 
     def artifacts?
