@@ -96,6 +96,18 @@ module Ci
 
     has_many :pages_deployments, foreign_key: :ci_build_id, inverse_of: :ci_build
 
+    has_many :tag_links,
+      ->(build) { in_partition(build) },
+      class_name: 'Ci::BuildTag',
+      foreign_key: :build_id,
+      partition_foreign_key: :partition_id,
+      inverse_of: :build
+
+    has_many :simple_tags,
+      class_name: 'Ci::Tag',
+      through: :tag_links,
+      source: :tag
+
     Ci::JobArtifact.file_types.each_key do |key|
       has_one :"job_artifacts_#{key}", ->(build) { in_partition(build).with_file_types([key]) },
         class_name: 'Ci::JobArtifact',
@@ -191,9 +203,9 @@ module Ci
     # See https://gitlab.com/gitlab-org/gitlab/-/merge_requests/123131
     scope :with_runner_type, ->(runner_type) { joins(:runner).where(runner: { runner_type: runner_type }) }
 
-    scope :belonging_to_runner_manager, ->(runner_machine_id) {
+    scope :belonging_to_runner_manager, ->(runner_machine_id) do
       joins(:runner_manager_build).where(p_ci_runner_machine_builds: { runner_machine_id: runner_machine_id })
-    }
+    end
 
     scope :with_secure_reports_from_config_options, ->(job_types) do
       joins(:metadata).where("#{Ci::BuildMetadata.quoted_table_name}.config_options -> 'artifacts' -> 'reports' ?| array[:job_types]", job_types: job_types)
@@ -220,6 +232,11 @@ module Ci
       .or(with_job_artifacts.where(project_id: project_id, job_artifacts: { file_type: 'dotenv' })).distinct
     end
 
+    scope :with_pipeline_source_type, ->(pipeline_source_type) { joins(:pipeline).where(pipeline: { source: pipeline_source_type }) }
+    scope :created_after, ->(time) { where(arel_table[:created_at].gt(time)) }
+    scope :updated_after, ->(time) { where(arel_table[:updated_at].gt(time)) }
+    scope :for_project_ids, ->(project_ids) { where(project_id: project_ids) }
+
     add_authentication_token_field :token,
       encrypted: :required,
       format_with_prefix: :prefix_and_partition_for_token
@@ -374,13 +391,15 @@ module Ci
       after_transition any => [:failed] do |build|
         next unless build.project
 
-        if build.auto_retry_allowed?
-          begin
-            # rubocop: disable CodeReuse/ServiceClass
-            Ci::RetryJobService.new(build.project, build.user).execute(build)
-            # rubocop: enable CodeReuse/ServiceClass
-          rescue Gitlab::Access::AccessDeniedError => e
-            Gitlab::AppLogger.error "Unable to auto-retry job #{build.id}: #{e}"
+        build.run_after_commit do
+          if build.auto_retry_allowed?
+            begin
+              # rubocop: disable CodeReuse/ServiceClass -- https://gitlab.com/gitlab-org/gitlab/-/issues/494865
+              Ci::RetryJobService.new(build.project, build.user).execute(build)
+              # rubocop: enable CodeReuse/ServiceClass
+            rescue Gitlab::Access::AccessDeniedError => e
+              Gitlab::AppLogger.error "Unable to auto-retry job #{build.id}: #{e}"
+            end
           end
         end
       end
@@ -406,6 +425,18 @@ module Ci
       in_merge_request(merge_request_id).pluck(:id)
     end
 
+    def self.arel_tag_names_array
+      ::Ci::BuildTag
+        .joins(:tag)
+        .where(::Ci::BuildTag.arel_table[:build_id].eq(arel_table[:id]))
+        .where(::Ci::BuildTag.arel_table[:partition_id].eq(arel_table[:partition_id]))
+        .select('COALESCE(array_agg(tags.name ORDER BY name), ARRAY[]::text[])')
+    end
+
+    def tags_ids_relation
+      simple_tags
+    end
+
     # A Ci::Bridge may transition to `canceling` as a result of strategy: :depend
     # but only a Ci::Build will transition to `canceling`` via `.cancel`
     def supports_canceling?
@@ -428,7 +459,9 @@ module Ci
     end
 
     def exit_code=(value)
-      ensure_metadata.exit_code = value
+      return unless value
+
+      ensure_metadata.exit_code = value.to_i.clamp(0, Gitlab::Database::MAX_SMALLINT_VALUE)
     end
 
     def auto_retry_expected?
@@ -446,8 +479,10 @@ module Ci
     end
 
     def pages_generator?
-      Gitlab.config.pages.enabled &&
-        name == 'pages'
+      return false unless Gitlab.config.pages.enabled
+      return true if options[:pages].is_a?(Hash) || options[:pages] == true
+
+      options[:pages] != false && name == 'pages' # Legacy behaviour
     end
 
     # Overriden on EE
@@ -487,7 +522,7 @@ module Ci
     end
 
     def action?
-      %w[manual delayed].include?(self.when)
+      ACTIONABLE_WHEN.include?(self.when)
     end
 
     def can_auto_cancel_pipeline_on_job_failure?
@@ -787,7 +822,9 @@ module Ci
       artifacts_public = options.dig(:artifacts, :public)
       artifacts_access = options.dig(:artifacts, :access)
 
-      raise ArgumentError, 'artifacts:public and artifacts:access are mutually exclusive' if !artifacts_public.nil? && !artifacts_access.nil?
+      if !artifacts_public.nil? && !artifacts_access.nil?
+        raise ArgumentError, 'artifacts:public and artifacts:access are mutually exclusive'
+      end
 
       return :public if artifacts_public == true || artifacts_access == 'all'
       return :private if artifacts_public == false || artifacts_access == 'developer'
@@ -826,9 +863,7 @@ module Ci
 
     def artifacts_expire_in=(value)
       self.artifacts_expire_at =
-        if value
-          ChronicDuration.parse(value)&.seconds&.from_now
-        end
+        (ChronicDuration.parse(value)&.seconds&.from_now if value)
     end
 
     def has_expired_locked_archive_artifacts?
@@ -946,7 +981,7 @@ module Ci
     end
 
     def multi_build_steps?
-      options.dig(:release)&.any?
+      options[:release]&.any?
     end
 
     def hide_secrets(data, metrics = ::Gitlab::Ci::Trace::Metrics.new)
@@ -956,9 +991,7 @@ module Ci
         Gitlab::Ci::MaskSecret.mask!(trace, project.runners_token) if project
         Gitlab::Ci::MaskSecret.mask!(trace, token) if token
 
-        if trace != data
-          metrics.increment_trace_operation(operation: :mutated)
-        end
+        metrics.increment_trace_operation(operation: :mutated) if trace != data
       end
     end
 
@@ -1114,6 +1147,8 @@ module Ci
 
     def each_report(report_types)
       job_artifacts_for_types(report_types).each do |report_artifact|
+        next if report_artifact&.artifact_report&.faulty?
+
         report_artifact.each_blob do |blob|
           yield report_artifact.file_type, blob, report_artifact
         end
@@ -1294,6 +1329,30 @@ module Ci
     def prefix_and_partition_for_token
       TOKEN_PREFIX + partition_id_prefix_in_16_bit_encode
     end
+
+    override :save_tags
+    def save_tags
+      super do |new_tags, old_tags|
+        if old_tags.present?
+          tag_links
+            .where(tag_id: old_tags)
+            .delete_all
+        end
+
+        ci_builds_tags = new_tags.map do |tag|
+          Ci::BuildTag.new(
+            build_id: id, partition_id: partition_id,
+            tag_id: tag.id, project_id: project_id)
+        end
+
+        ::Ci::BuildTag.bulk_insert!(
+          ci_builds_tags,
+          validate: false,
+          unique_by: [:tag_id, :build_id, :partition_id],
+          returns: :id
+        )
+      end
+    end
   end
 end
 
