@@ -6,18 +6,21 @@ module Ci
       # This class represents a CI/CD Catalog resource component.
       # The data will be used as metadata of a component.
       class Component < ::ApplicationRecord
+        ignore_column :resource_type, remove_with: '17.8', remove_after: '2024-11-18'
+
         self.table_name = 'catalog_resource_components'
 
         belongs_to :project, inverse_of: :ci_components
         belongs_to :catalog_resource, class_name: 'Ci::Catalog::Resource', inverse_of: :components
         belongs_to :version, class_name: 'Ci::Catalog::Resources::Version', inverse_of: :components
         has_many :usages, class_name: 'Ci::Catalog::Resources::Components::Usage', inverse_of: :component
+        has_many :last_usages, class_name: 'Ci::Catalog::Resources::Components::LastUsage', inverse_of: :component
 
         # BulkInsertSafe must be included after the `has_many` declaration, otherwise it raises
         # an error about the save callback that is auto generated for this association.
         include BulkInsertSafe
 
-        enum resource_type: { template: 1 }
+        enum component_type: { template: 1 }
 
         validates :spec, json_schema: { filename: 'catalog_resource_component_spec' }
         validates :version, :catalog_resource, :project, :name, presence: true
