@@ -13,6 +13,9 @@ module Ci
     belongs_to :group, class_name: '::Group', foreign_key: :namespace_id
 
     validates :runner_id, uniqueness: { scope: :namespace_id }
+    # NOTE: `on:` hook can be removed the milestone after https://gitlab.com/gitlab-org/gitlab/-/merge_requests/155761
+    # is merged
+    validates :namespace, presence: true, on: [:create, :update]
     validate :group_runner_type
 
     scope :for_runner, ->(runner_id) { where(runner_id: runner_id) }
