@@ -17,8 +17,6 @@ module Ci
 
     validates :runner, presence: true
     validates :runner_id, uniqueness: { scope: :project_id }
-    # NOTE: `on:` hook can be removed the milestone after https://gitlab.com/gitlab-org/gitlab/-/merge_requests/155760
-    # is merged
-    validates :project, presence: true, on: [:create, :update]
+    validates :project, presence: true
   end
 end
