@@ -36,10 +36,7 @@ module Clusters
     scope :with_name, ->(name) { where(name: name) }
     scope :has_vulnerabilities, ->(value = true) { where(has_vulnerabilities: value) }
 
-    enum connection_mode: {
-      outgoing: 0, # agentk -> kas
-      incoming: 1  # kas -> agentk
-    }, _prefix: true
+    ignore_column :connection_mode, remove_with: '17.6', remove_after: '2024-11-01'
 
     validates :name,
       presence: true,
@@ -93,7 +90,7 @@ module Clusters
       self.class.from_union(
         user_access_project_authorizations.select('config').limit(1),
         user_access_group_authorizations.select('config').limit(1)
-      ).compact.first
+      ).select('config').compact.first
     end
 
     private
