@@ -23,7 +23,7 @@ module Clusters
           }
 
           scope :for_project, ->(project) {
-            where("all_groups_with_membership.traversal_ids @> '{?}'", project.namespace_id)
+            where(all_groups_with_membership: { id: project.namespace.self_and_ancestor_ids })
           }
 
           validates :config, json_schema: { filename: 'clusters_agents_authorizations_user_access_config' }
@@ -49,7 +49,6 @@ module Clusters
               ::Group.joins('INNER JOIN groups_with_direct_membership ON ' \
                             'namespaces.traversal_ids @> ARRAY[groups_with_direct_membership.id]')
                      .select('namespaces.id AS id, ' \
-                             'namespaces.traversal_ids AS traversal_ids, ' \
                              'groups_with_direct_membership.access_level AS access_level')
             end
 
@@ -58,10 +57,10 @@ module Clusters
             end
 
             def groups_with_direct_membership_for(user)
-              ::Group.joins("INNER JOIN members ON " \
-                            "members.source_id = namespaces.id AND members.source_type = 'Namespace'")
-                     .where(members: { user_id: user.id, access_level: Gitlab::Access::DEVELOPER.. })
-                     .select('namespaces.id AS id, members.access_level AS access_level')
+              user
+                .groups_with_active_memberships
+                .merge(GroupMember.by_access_level(Gitlab::Access::DEVELOPER..))
+                .select('namespaces.id AS id, members.access_level AS access_level')
             end
           end
         end
