@@ -41,4 +41,23 @@ module CommitSignature
   def signed_by_user
     raise NoMethodError, 'must implement `signed_by_user` method'
   end
+
+  def reverified_status
+    return verification_status unless Feature.enabled?(:check_for_mailmapped_commit_emails, project)
+    return verification_status unless verified_signature_type? || verified_system?
+
+    verified_emails = signed_by_user&.verified_emails
+    if verified_emails&.exclude?(commit.author_email)
+      'unverified_author_email'
+    else
+      verification_status
+    end
+  end
+
+  private
+
+  # We are omitting x509 signature types until https://gitlab.com/gitlab-org/gitlab/-/issues/498188 is complete
+  def verified_signature_type?
+    verified? && (ssh? || gpg?)
+  end
 end
