@@ -141,19 +141,20 @@ module CounterAttribute
     end
   end
 
+  def update_counters(increments)
+    self.class.update_counters(id, increments)
+  end
+
   def update_counters_with_lease(increments)
     detect_race_on_record(log_fields: { caller: __method__, attributes: increments.keys }) do
-      self.class.update_counters(id, increments)
+      update_counters(increments)
     end
   end
 
   def initiate_refresh!(attribute)
     raise ArgumentError, %(attribute "#{attribute}" cannot be refreshed) unless counter_attribute_enabled?(attribute)
 
-    detect_race_on_record(log_fields: { caller: __method__, attributes: attribute }) do
-      counter(attribute).initiate_refresh!
-    end
-
+    counter(attribute).initiate_refresh!
     log_clear_counter(attribute)
   end
 
@@ -191,10 +192,9 @@ module CounterAttribute
     "project:{#{project_id}}:#{self.class}:#{id}"
   end
 
-  # detect_race_on_record uses a lease to monitor access
-  # to the project statistics row. This is needed to detect
-  # concurrent attempts to increment columns, which could result in a
-  # race condition.
+  # This method uses a lease to monitor access to the model row.
+  # This is needed to detect concurrent attempts to increment columns,
+  # which could result in a race condition.
   #
   # As the purpose is to detect and warn concurrent attempts,
   # it falls back to direct update on the row if it fails to obtain the lease.
