@@ -20,7 +20,14 @@ module Enums
       deb: 11,
       'cbl-mariner': 12,
       wolfi: 13,
-      cargo: 14
+      cargo: 14,
+      swift: 15,
+      conda: 16
+    }.with_indifferent_access.freeze
+
+    REACHABILITY_TYPES = {
+      unknown: 0,
+      in_use: 1 # In case package imported and being used in code.
     }.with_indifferent_access.freeze
 
     DEPENDENCY_SCANNING_PURL_TYPES = %w[
@@ -33,6 +40,8 @@ module Enums
       nuget
       pypi
       cargo
+      swift
+      conda
     ].freeze
 
     CONTAINER_SCANNING_PURL_TYPES = %w[
@@ -85,6 +94,7 @@ module Enums
       nuget: 'nuget',
       'dotnet-core': 'nuget',
       'conda-pkg': 'conda',
+      'conda-environment': 'conda',
       'python-pkg': 'pip',
       pip: 'pip',
       pipenv: 'pipenv',
@@ -120,6 +130,10 @@ module Enums
       purl_types.invert
     end
 
+    def self.reachability_types
+      REACHABILITY_TYPES
+    end
+
     def self.package_manager_from_trivy_pkg_type(pkg_type)
       PACKAGE_MANAGERS_FROM_TRIVY_PKG_TYPE[pkg_type]
     end
