@@ -9,7 +9,8 @@ module MergeRequestReviewerState
       reviewed: 1,
       requested_changes: 2,
       approved: 3,
-      unapproved: 4
+      unapproved: 4,
+      review_started: 5
     }
 
     validates :state,
