@@ -2,7 +2,7 @@
 
 module Packages
   # This module requires a status column.
-  # It also requires a constant INSTALLABLE_STATUSES. This should be
+  # It also requires a class method `installable_statuses`. This should be
   # an array that defines which values of the status column are
   # considered as installable.
   module Installable
@@ -10,7 +10,7 @@ module Packages
 
     included do
       scope :with_status, ->(status) { where(status: status) }
-      scope :installable, -> { with_status(const_get(:INSTALLABLE_STATUSES, false)) }
+      scope :installable, -> { with_status(installable_statuses) }
     end
   end
 end
