@@ -71,13 +71,6 @@ module TokenAuthenticatable
         token.present? && ActiveSupport::SecurityUtils.secure_compare(other_token, token)
       end
 
-      # Base strategy delegates to this method for formatting a token before
-      # calling set_token. Can be overridden in models to e.g. add a prefix
-      # to the tokens
-      mod.define_method("format_#{token_field}") do |token|
-        token
-      end
-
       mod.define_method("#{token_field}_expires_at") do
         strategy.expires_at(self)
       end
