@@ -8,6 +8,7 @@ class CustomerRelations::Organization < ApplicationRecord
   self.table_name = "customer_relations_organizations"
 
   belongs_to :group, -> { where(type: Group.sti_name) }, foreign_key: 'group_id'
+  has_many :contacts
 
   strip_attributes! :name
 
@@ -21,7 +22,7 @@ class CustomerRelations::Organization < ApplicationRecord
   validates :name, uniqueness: { case_sensitive: false, scope: [:group_id] }
   validates :name, length: { maximum: 255 }
   validates :description, length: { maximum: 1024 }
-  validate :validate_root_group
+  validate :validate_crm_group
 
   scope :order_scope_asc, ->(field) { order(arel_table[field].asc.nulls_last) }
   scope :order_scope_desc, ->(field) { order(arel_table[field].desc.nulls_last) }
@@ -58,26 +59,6 @@ class CustomerRelations::Organization < ApplicationRecord
     .where('LOWER(name) = LOWER(?)', name)
   end
 
-  def self.move_to_root_group(group)
-    update_query = <<~SQL
-      UPDATE #{CustomerRelations::Contact.table_name}
-      SET organization_id = new_organizations.id
-      FROM #{table_name} AS existing_organizations
-      JOIN #{table_name} AS new_organizations ON new_organizations.group_id = :old_group_id AND LOWER(new_organizations.name) = LOWER(existing_organizations.name)
-      WHERE existing_organizations.group_id = :new_group_id AND organization_id = existing_organizations.id
-    SQL
-    connection.execute(sanitize_sql([update_query, { old_group_id: group.root_ancestor.id, new_group_id: group.id }]))
-
-    dupes_query = <<~SQL
-      DELETE FROM #{table_name} AS existing_organizations
-      USING #{table_name} AS new_organizations
-      WHERE existing_organizations.group_id = :new_group_id AND new_organizations.group_id = :old_group_id AND LOWER(new_organizations.name) = LOWER(existing_organizations.name)
-    SQL
-    connection.execute(sanitize_sql([dupes_query, { old_group_id: group.root_ancestor.id, new_group_id: group.id }]))
-
-    where(group: group).update_all(group_id: group.root_ancestor.id)
-  end
-
   def self.counts_by_state
     default_state_counts.merge(group(:state).count)
   end
@@ -90,9 +71,9 @@ class CustomerRelations::Organization < ApplicationRecord
     end
   end
 
-  def validate_root_group
-    return if group&.root?
+  def validate_crm_group
+    return if group&.crm_group?
 
-    self.errors.add(:base, _('organizations can only be added to root groups'))
+    self.errors.add(:base, _('organizations can only be added to root groups and groups configured as CRM targets'))
   end
 end
