@@ -5,15 +5,23 @@ class Email < ApplicationRecord
   include Gitlab::SQL::Pattern
 
   belongs_to :user, optional: false
+  belongs_to :banned_user, class_name: '::Users::BannedUser', foreign_key: 'user_id', inverse_of: 'emails'
 
   validates :email, presence: true, uniqueness: true, devise_email: true
 
   validate :unique_email, if: ->(email) { email.email_changed? }
 
+  scope :users_by_detumbled_email_count, ->(email) do
+    normalized_email = ::Gitlab::Utils::Email.normalize_email(email)
+
+    where(detumbled_email: normalized_email).distinct.count(:user_id)
+  end
+
   scope :confirmed, -> { where.not(confirmed_at: nil) }
   scope :unconfirmed, -> { where(confirmed_at: nil) }
   scope :unconfirmed_and_created_before, ->(created_cut_off) { unconfirmed.where('created_at < ?', created_cut_off) }
 
+  before_save :detumble_email!, if: ->(email) { email.email_changed? }
   after_commit :update_invalid_gpg_signatures, if: -> { previous_changes.key?('confirmed_at') }
 
   devise :confirmable
@@ -49,4 +57,8 @@ class Email < ApplicationRecord
   def primary_email_of_another_user?
     User.where(email: email).where.not(id: user_id).exists?
   end
+
+  def detumble_email!
+    self.detumbled_email = ::Gitlab::Utils::Email.normalize_email(email)
+  end
 end
