@@ -19,8 +19,9 @@ class Group < Namespace
   include BulkUsersByEmailLoad
   include ChronicDurationAttribute
   include RunnerTokenExpirationInterval
-  include Todoable
   include Importable
+  include IdInOrdered
+  include Members::Enumerable
 
   extend ::Gitlab::Utils::Override
 
@@ -40,6 +41,11 @@ class Group < Namespace
   has_many :all_owner_members, -> { non_request.all_owners }, as: :source, class_name: 'GroupMember'
   has_many :group_members, -> { non_request.non_minimal_access }, dependent: :destroy, as: :source # rubocop:disable Cop/ActiveRecordDependent
   has_many :non_invite_group_members, -> { non_request.non_minimal_access.non_invite }, class_name: 'GroupMember', as: :source
+  has_many :non_invite_owner_members, -> { non_request.non_invite.all_owners }, class_name: 'GroupMember', as: :source
+  has_many :request_group_members, -> do
+    request.non_minimal_access
+  end, inverse_of: :group, class_name: 'GroupMember', as: :source
+
   has_many :namespace_members, -> { non_request.non_minimal_access.unscope(where: %i[source_id source_type]) },
     foreign_key: :member_namespace_id, inverse_of: :group, class_name: 'GroupMember'
   alias_method :members, :group_members
@@ -100,6 +106,9 @@ class Group < Namespace
   # AR defaults to nullify when trying to delete via has_many associations unless we set dependent: :delete_all
   has_many :crm_organizations, class_name: 'CustomerRelations::Organization', inverse_of: :group, dependent: :delete_all # rubocop:disable Cop/ActiveRecordDependent
   has_many :contacts, class_name: 'CustomerRelations::Contact', inverse_of: :group, dependent: :delete_all # rubocop:disable Cop/ActiveRecordDependent
+  has_one :crm_settings, class_name: 'Group::CrmSettings', inverse_of: :group
+  # Groups for which this is the source of CRM contacts/organizations
+  has_many :crm_targets, class_name: 'Group::CrmSettings', inverse_of: :source_group, foreign_key: 'source_group_id'
 
   has_many :cluster_groups, class_name: 'Clusters::Group'
   has_many :clusters, through: :cluster_groups, class_name: 'Clusters::Cluster'
@@ -139,13 +148,11 @@ class Group < Namespace
 
   has_one :group_feature, inverse_of: :group, class_name: 'Groups::FeatureSetting'
 
-  delegate :prevent_sharing_groups_outside_hierarchy, :new_user_signups_cap, :setup_for_company, :jobs_to_be_done, to: :namespace_settings
+  delegate :prevent_sharing_groups_outside_hierarchy, :new_user_signups_cap, :setup_for_company, :jobs_to_be_done, :seat_control, to: :namespace_settings
   delegate :runner_token_expiration_interval, :runner_token_expiration_interval=, :runner_token_expiration_interval_human_readable, :runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
   delegate :subgroup_runner_token_expiration_interval, :subgroup_runner_token_expiration_interval=, :subgroup_runner_token_expiration_interval_human_readable, :subgroup_runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
   delegate :project_runner_token_expiration_interval, :project_runner_token_expiration_interval=, :project_runner_token_expiration_interval_human_readable, :project_runner_token_expiration_interval_human_readable=, to: :namespace_settings, allow_nil: true
 
-  has_one :crm_settings, class_name: 'Group::CrmSettings', inverse_of: :group
-
   accepts_nested_attributes_for :variables, allow_destroy: true
   accepts_nested_attributes_for :group_feature, update_only: true
 
@@ -167,6 +174,8 @@ class Group < Namespace
 
   validates :group_feature, presence: true
 
+  validate :top_level_group_name_not_assigned_to_pages_unique_domain, if: :path_changed?
+
   add_authentication_token_field :runners_token,
     encrypted: :required,
     format_with_prefix: :runners_token_prefix,
@@ -180,11 +189,10 @@ class Group < Namespace
 
   scope :with_users, -> { includes(:users) }
 
-  scope :with_onboarding_progress, -> { joins(:onboarding_progress) }
-
   scope :with_non_archived_projects, -> { includes(:non_archived_projects) }
 
   scope :with_non_invite_group_members, -> { includes(:non_invite_group_members) }
+  scope :with_request_group_members, -> { includes(:request_group_members) }
 
   scope :by_id, ->(groups) { where(id: groups) }
 
@@ -240,22 +248,10 @@ class Group < Namespace
   end
 
   scope :project_creation_allowed, ->(user) do
-    project_creation_allowed_on_levels = [
-      ::Gitlab::Access::DEVELOPER_MAINTAINER_PROJECT_ACCESS,
-      ::Gitlab::Access::MAINTAINER_PROJECT_ACCESS,
-      nil
-    ]
+    project_creation_levels_for_user = project_creation_levels_for_user(user)
 
-    # When the value of application_settings.default_project_creation is set to `NO_ONE_PROJECT_ACCESS`,
-    # it means that a `nil` value for `groups.project_creation_level` is telling us:
-    # do not allow project creation in such groups.
-    # ie, `nil` is a placeholder value for inheriting the value from the ApplicationSetting.
-    # So we remove `nil` from the list when the application_setting's value is `NO_ONE_PROJECT_ACCESS`
-    if ::Gitlab::CurrentSettings.default_project_creation == ::Gitlab::Access::NO_ONE_PROJECT_ACCESS
-      project_creation_allowed_on_levels.delete(nil)
-    end
-
-    with_project_creation_levels(project_creation_allowed_on_levels).excluding_restricted_visibility_levels_for_user(user)
+    with_project_creation_levels(project_creation_levels_for_user)
+      .excluding_restricted_visibility_levels_for_user(user)
   end
 
   scope :shared_into_ancestors, ->(group) do
@@ -408,6 +404,42 @@ class Group < Namespace
       preload(:namespace_settings, :group_feature, :parent)
     end
 
+    # Handle project creation permissions based on application setting and group setting. The `default_project_creation`
+    # application setting is the default value and can be overridden by the `project_creation_level` group setting.
+    # `nil` value of namespaces.project_creation_level` means that allowed creation level has not been explicitly set by
+    # the group owner and is a placeholder value for inheriting the value from the ApplicationSetting.
+    def project_creation_levels_for_user(user)
+      project_creation_allowed_on_levels = [
+        ::Gitlab::Access::DEVELOPER_MAINTAINER_PROJECT_ACCESS,
+        ::Gitlab::Access::MAINTAINER_PROJECT_ACCESS,
+        nil
+      ]
+
+      if user.can_admin_all_resources?
+        project_creation_allowed_on_levels << ::Gitlab::Access::ADMINISTRATOR_PROJECT_ACCESS
+      end
+
+      default_project_creation = ::Gitlab::CurrentSettings.default_project_creation
+      prevent_project_creation_by_default = prevent_project_creation?(user, default_project_creation)
+
+      # Remove nil (i.e. inherited `default_project_creation`) when the application setting is:
+      # 1. NO_ONE_PROJECT_ACCESS
+      # 2. ADMINISTRATOR_PROJECT_ACCESS and the user is not an admin
+      #
+      # To prevent showing groups in the namespaces dropdown on the project creation page that have no explicit group
+      # setting for `project_creation_level`.
+      project_creation_allowed_on_levels.delete(nil) if prevent_project_creation_by_default
+
+      project_creation_allowed_on_levels
+    end
+
+    def prevent_project_creation?(user, project_creation_setting)
+      return true if project_creation_setting == ::Gitlab::Access::NO_ONE_PROJECT_ACCESS
+      return false if user.can_admin_all_resources?
+
+      project_creation_setting == ::Gitlab::Access::ADMINISTRATOR_PROJECT_ACCESS
+    end
+
     private
 
     def public_to_user_arel(user)
@@ -459,10 +491,6 @@ class Group < Namespace
     notification_settings.find { |n| n.notification_email.present? }&.notification_email
   end
 
-  def web_url(only_path: nil)
-    Gitlab::UrlBuilder.build(self, only_path: only_path)
-  end
-
   def dependency_proxy_image_prefix
     # The namespace path can include uppercase letters, which
     # Docker doesn't allow. The proxy expects it to be downcased.
@@ -506,7 +534,7 @@ class Group < Namespace
   def owned_by?(user)
     return false unless user
 
-    all_owner_members.non_invite.exists?(user: user)
+    non_invite_owner_members.exists?(user: user)
   end
 
   def add_members(users, access_level, current_user: nil, expires_at: nil)
@@ -882,7 +910,7 @@ class Group < Namespace
   def parent_allows_two_factor_authentication?
     return true unless has_parent?
 
-    ancestor_settings = ancestors.find_by(parent_id: nil).namespace_settings
+    ancestor_settings = ancestors.find_top_level.namespace_settings
     ancestor_settings.allow_mfa_for_subgroups
   end
 
@@ -954,8 +982,12 @@ class Group < Namespace
     feature_flag_enabled_for_self_or_ancestor?(:glql_integration)
   end
 
+  def wiki_comments_feature_flag_enabled?
+    feature_flag_enabled_for_self_or_ancestor?(:wiki_comments, type: :wip)
+  end
+
   # Note: this method is overridden in EE to check the work_item_epics feature flag  which also enables this feature
-  def namespace_work_items_enabled?(_user = nil)
+  def namespace_work_items_enabled?
     ::Feature.enabled?(:namespace_level_work_items, self, type: :development)
   end
 
@@ -1012,11 +1044,51 @@ class Group < Namespace
   end
   strong_memoize_attr :readme_project
 
+  def notification_group
+    self
+  end
+
   def group_readme
     readme_project&.repository&.readme
   end
   strong_memoize_attr :group_readme
 
+  def hook_attrs
+    {
+      group_name: name,
+      group_path: path,
+      group_id: id,
+      full_path: full_path
+    }
+  end
+
+  def crm_group
+    Group.id_in_ordered(traversal_ids.reverse)
+      .joins(:crm_settings)
+      .where.not(crm_settings: { source_group_id: nil })
+      .first&.crm_settings&.source_group || root_ancestor
+  end
+  strong_memoize_attr :crm_group
+
+  def crm_group?
+    return true if root? && crm_settings&.source_group_id.nil?
+
+    crm_targets.present?
+  end
+  strong_memoize_attr :crm_group?
+
+  def has_issues_with_contacts?
+    CustomerRelations::IssueContact.joins(:issue).where(issue: { project_id: Project.where(namespace_id: self_and_descendant_ids) }).exists?
+  end
+
+  def delete_contacts
+    CustomerRelations::Contact.where(group_id: id).delete_all
+  end
+
+  def delete_organizations
+    CustomerRelations::Organization.where(group_id: id).delete_all
+  end
+
   private
 
   def feature_flag_enabled_for_self_or_ancestor?(feature_flag, type: :development)
@@ -1080,6 +1152,15 @@ class Group < Namespace
   def runners_token_prefix
     RunnersTokenPrefixable::RUNNERS_TOKEN_PREFIX
   end
+
+  def top_level_group_name_not_assigned_to_pages_unique_domain
+    return unless parent_id.nil?
+
+    return unless ProjectSetting.unique_domain_exists?(path)
+
+    # We cannot disclose the Pages unique domain, hence returning generic error message
+    errors.add(:path, _('has already been taken'))
+  end
 end
 
 Group.prepend_mod_with('Group')
