@@ -10,8 +10,8 @@ class ServiceHook < WebHook
   belongs_to :integration
   validates :integration, presence: true
 
-  def execute(data, hook_name = 'service_hook')
-    super(data, hook_name)
+  def execute(data, hook_name = 'service_hook', idempotency_key: nil)
+    super(data, hook_name, idempotency_key: idempotency_key)
   end
 
   override :parent
