@@ -7,7 +7,12 @@ class Identity < ApplicationRecord
   belongs_to :user
 
   validates :provider, presence: true
-  validates :extern_uid, allow_blank: true, uniqueness: { scope: UniquenessScopes.scopes, case_sensitive: false }
+  validates :extern_uid, allow_blank: true, uniqueness: {
+    scope: UniquenessScopes.scopes,
+    case_sensitive: false,
+    message: "has already been taken. Please contact your administrator to generate a unique extern_uid / NameID"
+  }
+
   validates :user, uniqueness: { scope: UniquenessScopes.scopes }
 
   before_save :ensure_normalized_extern_uid, if: :extern_uid_changed?
