@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-class Identity < MainClusterwide::ApplicationRecord
+class Identity < ApplicationRecord
   # This module and method are defined in a separate file to allow EE to
   # redefine the `scopes` method before it is used in the `Identity` model.
   module UniquenessScopes
