@@ -20,10 +20,26 @@ module Import
     belongs_to :namespace
 
     validates :namespace_id, :import_type, :source_hostname, :source_user_identifier, :status, presence: true
+    validates :source_user_identifier, uniqueness: { scope: [:namespace_id, :source_hostname, :import_type] }
     validates :placeholder_user_id, presence: true, unless: :completed?
-    validates :reassign_to_user_id, presence: true, if: -> { reassignment_in_progress? || completed? }
+    validates :reassignment_token, absence: true, unless: :awaiting_approval?
+    validates :reassignment_token, length: { is: 32 }, if: :awaiting_approval?
+    validates :reassign_to_user_id, presence: true, if: -> {
+                                                          awaiting_approval? || reassignment_in_progress? || completed?
+                                                        }
+    validates :reassign_to_user_id, absence: true, if: -> { pending_reassignment? || keep_as_placeholder? }
+    validates :reassign_to_user_id, uniqueness: {
+      scope: [:namespace_id, :source_hostname, :import_type],
+      allow_nil: true,
+      message: ->(_object, _data) {
+        s_('Import|already assigned to another placeholder')
+      }
+    }
+    validate :validate_source_hostname
 
     scope :for_namespace, ->(namespace_id) { where(namespace_id: namespace_id) }
+    scope :by_source_hostname, ->(source_hostname) { where(source_hostname: source_hostname) }
+    scope :by_import_type, ->(import_type) { where(import_type: import_type) }
     scope :by_statuses, ->(statuses) { where(status: statuses) }
     scope :awaiting_reassignment, -> { where(status: [0, 1, 2, 3, 4]) }
     scope :reassigned, -> { where(status: [5, 6]) }
@@ -47,6 +63,14 @@ module Import
         state status_name, value: value
       end
 
+      before_transition awaiting_approval: any do |source_user|
+        source_user.reassignment_token = nil
+      end
+
+      before_transition any => :awaiting_approval do |source_user|
+        source_user.reassignment_token = SecureRandom.hex
+      end
+
       event :reassign do
         transition REASSIGNABLE_STATUSES => :awaiting_approval
       end
@@ -74,10 +98,6 @@ module Import
       event :fail_reassignment do
         transition reassignment_in_progress: :failed
       end
-
-      after_transition any => [:pending_reassignment, :rejected, :keep_as_placeholder] do |status|
-        status.update!(reassign_to_user: nil)
-      end
     end
 
     class << self
@@ -103,12 +123,30 @@ module Import
 
         reorder(sort_order[:order_by] => sort_order[:sort])
       end
+
+      def namespace_placeholder_user_count(namespace, limit:)
+        for_namespace(namespace).distinct.limit(limit).count(:placeholder_user_id) -
+          (namespace.namespace_import_user.present? ? 1 : 0)
+      end
+
+      def source_users_with_missing_information(namespace:, source_hostname:, import_type:)
+        for_namespace(namespace)
+          .by_source_hostname(source_hostname)
+          .by_import_type(import_type)
+          .and(
+            where(source_name: nil).or(where(source_username: nil))
+          )
+      end
     end
 
     def mapped_user
       accepted_status? ? reassign_to_user : placeholder_user
     end
 
+    def mapped_user_id
+      accepted_status? ? reassign_to_user_id : placeholder_user_id
+    end
+
     def accepted_status?
       STATUSES.slice(*ACCEPTED_STATUSES).value?(status)
     end
@@ -120,5 +158,15 @@ module Import
     def cancelable_status?
       STATUSES.slice(*CANCELABLE_STATUSES).value?(status)
     end
+
+    def validate_source_hostname
+      return unless source_hostname
+
+      uri = Gitlab::Utils.parse_url(source_hostname)
+
+      return if uri && uri.scheme && uri.host && uri.path.blank?
+
+      errors.add(:source_hostname, :invalid, message: 'must contain scheme and host, and not path')
+    end
   end
 end
