@@ -21,7 +21,7 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/clickup',
+        'user/project/integrations/clickup.md',
         s_("IssueTracker|Use ClickUp as this project's issue tracker.")
       )
     end
