@@ -34,7 +34,7 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/discord_notifications',
+        'user/project/integrations/discord_notifications.md',
         s_("DiscordService|Send notifications about project events to a Discord channel."),
         _('How do I set up this integration?')
       )
