@@ -41,7 +41,7 @@ module Integrations
     def self.help
       docs_link = ActionController::Base.helpers.link_to(
         '',
-        Rails.application.routes.url_helpers.help_page_url('user/project/integrations/phorge'),
+        Rails.application.routes.url_helpers.help_page_url('user/project/integrations/phorge.md'),
         target: '_blank',
         rel: 'noopener noreferrer'
       )
