@@ -30,7 +30,7 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/pivotal_tracker', s_("Add commit messages as comments to Pivotal Tracker stories.")
+        'user/project/integrations/pivotal_tracker.md', s_("Add commit messages as comments to Pivotal Tracker stories.")
       )
     end
 
