@@ -34,7 +34,7 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/squash_tm',
+        'user/project/integrations/squash_tm.md',
         s_("SquashTmIntegration|Update Squash TM requirements when GitLab issues are modified.")
       )
     end
