@@ -77,7 +77,7 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/telegram',
+        'user/project/integrations/telegram.md',
         s_("TelegramIntegration|Send notifications about project events to Telegram.")
       )
     end
