@@ -31,13 +31,12 @@ module Integrations
 
     def self.help
       build_help_page_url(
-        'user/project/integrations/unify_circuit',
+        'user/project/integrations/unify_circuit.md',
         s_("Integrations|Send notifications about project events to a Unify Circuit conversation.")
       )
     end
 
-    def default_channel_placeholder
-    end
+    def default_channel_placeholder; end
 
     def self.supported_events
       %w[push issue confidential_issue merge_request note confidential_note tag_push
