@@ -23,10 +23,12 @@ class LfsObject < ApplicationRecord
     find_by(oid: oid, size: size)
   end
 
-  def self.not_linked_to_project(project)
+  def self.not_linked_to_project(project, repository_type: nil)
+    linked_to_project = project.lfs_objects_projects.where('lfs_objects_projects.lfs_object_id = lfs_objects.id')
+    linked_to_project = linked_to_project.where(repository_type: repository_type) if repository_type
     where(
       'NOT EXISTS (?)',
-      project.lfs_objects_projects.select(1).where('lfs_objects_projects.lfs_object_id = lfs_objects.id')
+      linked_to_project.select(1)
     )
   end
 
