@@ -16,6 +16,8 @@ class Member < ApplicationRecord
   include RestrictedSignup
   include Gitlab::Experiment::Dsl
 
+  ignore_column :last_activity_on, remove_with: '17.8', remove_after: '2024-12-23'
+
   AVATAR_SIZE = 40
   ACCESS_REQUEST_APPROVERS_TO_BE_NOTIFIED_LIMIT = 10
 
@@ -58,6 +60,7 @@ class Member < ApplicationRecord
     },
     if: :project_bot?
   validate :access_level_inclusion
+  validate :user_is_not_placeholder
 
   scope :with_invited_user_state, -> do
     joins('LEFT JOIN users as invited_user ON invited_user.email = members.invite_email')
@@ -66,7 +69,8 @@ class Member < ApplicationRecord
   end
 
   scope :in_hierarchy, ->(source) do
-    groups = source.root_ancestor.self_and_descendants
+    source = source.root_ancestor
+    groups = source.self_and_descendants
     group_members = Member.default_scoped.where(source: groups).select(*Member.cached_column_list)
 
     projects = source.root_ancestor.all_projects
@@ -75,10 +79,30 @@ class Member < ApplicationRecord
     Member.default_scoped.from_union([group_members, project_members]).merge(self)
   end
 
+  scope :for_self_and_descendants, ->(group, columns = Member.cached_column_list) do
+    return self if group.blank?
+
+    group_members = where(source_id: group.self_and_descendant_ids, source_type: GroupMember::SOURCE_TYPE)
+    project_members = where(source_id: group.all_project_ids, source_type: ProjectMember::SOURCE_TYPE)
+
+    Member.unscoped.from_union([
+      group_members.select(*columns),
+      project_members.select(*columns)
+    ], remove_duplicates: false)
+  end
+
+  scope :including_user_ids, ->(user_ids) do
+    where(user_id: user_ids)
+  end
+
   scope :excluding_users, ->(user_ids) do
     where.not(user_id: user_ids)
   end
 
+  scope :count_by_access_level, ->(column_name = nil) do
+    group(:access_level).count(column_name)
+  end
+
   # This scope encapsulates (most of) the conditions a row in the member table
   # must satisfy if it is a valid permission. Of particular note:
   #
@@ -154,6 +178,7 @@ class Member < ApplicationRecord
   scope :not_accepted_invitations_by_user, ->(user) { not_accepted_invitations.where(created_by: user) }
   scope :not_expired, ->(today = Date.current) { where(arel_table[:expires_at].gt(today).or(arel_table[:expires_at].eq(nil))) }
   scope :expiring_and_not_notified, ->(date) { where("expiry_notified_at is null AND expires_at >= ? AND expires_at <= ?", Date.current, date) }
+  scope :with_created_by, -> { where.associated(:created_by) }
 
   scope :created_today, -> do
     now = Date.current
@@ -185,6 +210,7 @@ class Member < ApplicationRecord
 
   scope :with_source_id, ->(source_id) { where(source_id: source_id) }
   scope :including_source, -> { includes(:source) }
+  scope :including_user, -> { includes(:user) }
 
   scope :distinct_on_user_with_max_access_level, ->(for_object) do
     valid_objects = %w[Project Namespace]
@@ -299,20 +325,21 @@ class Member < ApplicationRecord
   scope :order_updated_desc, -> { order(updated_at: :desc) }
   scope :on_project_and_ancestors, ->(project) { where(source: [project] + project.ancestors) }
   scope :with_static_role, -> { where(member_role_id: nil) }
-  scope :no_activity_today, -> { where('last_activity_on < ?', Date.today) }
 
   before_validation :set_member_namespace_id, on: :create
   before_validation :generate_invite_token, on: :create, if: ->(member) { member.invite_email.present? && !member.invite_accepted_at? }
 
   after_create :send_invite, if: :invite?, unless: :importing?
   after_create :create_notification_setting, unless: [:pending?, :importing?]
-  after_create :post_create_hook, unless: [:pending?, :importing?], if: :hook_prerequisites_met?
+  after_create :post_create_member_hook, unless: [:pending?, :importing?], if: :hook_prerequisites_met?
+  after_create :post_create_access_request_hook, if: [:request?, :hook_prerequisites_met?]
   after_create :update_two_factor_requirement, unless: :invite?
   after_create :create_organization_user_record
   after_update :post_update_hook, unless: [:pending?, :importing?], if: :hook_prerequisites_met?
-  after_update :create_organization_user_record, if: :saved_change_to_user_id? # only occurs on invite acceptance
+  after_update :create_organization_user_record, if: :accepted_invite_or_request?
   after_destroy :destroy_notification_setting
-  after_destroy :post_destroy_hook, unless: :pending?, if: :hook_prerequisites_met?
+  after_destroy :post_destroy_member_hook, unless: :pending?, if: :hook_prerequisites_met?
+  after_destroy :post_destroy_access_request_hook, if: [:request?, :hook_prerequisites_met?]
   after_destroy :update_two_factor_requirement, unless: :invite?
   after_save :log_invitation_token_cleanup
 
@@ -409,13 +436,15 @@ class Member < ApplicationRecord
       pluck(:user_id)
     end
 
-    def with_group_group_sharing_access(shared_groups)
+    def with_group_group_sharing_access(shared_groups, custom_role_for_group_link_enabled)
+      columns = member_columns_with_group_sharing_access(custom_role_for_group_link_enabled)
+
       joins("LEFT OUTER JOIN group_group_links ON members.source_id = group_group_links.shared_with_group_id")
-        .select(member_columns_with_group_sharing_access)
+        .select(columns)
         .where(group_group_links: { shared_group_id: shared_groups })
     end
 
-    def member_columns_with_group_sharing_access
+    def member_columns_with_group_sharing_access(custom_role_for_group_link_enabled)
       group_group_link_table = GroupGroupLink.arel_table
 
       column_names.map do |column_name|
@@ -424,7 +453,7 @@ class Member < ApplicationRecord
           args = [group_group_link_table[:group_access], arel_table[:access_level]]
           smallest_value_arel(args, 'access_level')
         when 'member_role_id'
-          member_role_id(group_group_link_table, arel_table)
+          member_role_id(group_group_link_table, custom_role_for_group_link_enabled)
         else
           arel_table[column_name]
         end
@@ -436,8 +465,8 @@ class Member < ApplicationRecord
     end
 
     # overriden in EE
-    def member_role_id(_group_group_link_table, group_member_table)
-      group_member_table[:member_role_id]
+    def member_role_id(_group_link_table, _custom_role_for_group_link_enabled)
+      arel_table[:member_role_id]
     end
   end
 
@@ -526,7 +555,9 @@ class Member < ApplicationRecord
 
     generate_invite_token! unless @raw_invite_token
 
-    run_after_commit_or_now { notification_service.invite_member_reminder(self, @raw_invite_token, reminder_index) }
+    run_after_commit_or_now do
+      Members::InviteReminderMailer.email(self, @raw_invite_token, reminder_index).deliver_later
+    end
   end
 
   def create_notification_setting
@@ -599,6 +630,14 @@ class Member < ApplicationRecord
     errors.add(:access_level, "is not included in the list")
   end
 
+  def user_is_not_placeholder
+    if Gitlab::Import::PlaceholderUserCreator.placeholder_email_pattern.match?(invite_email)
+      errors.add(:invite_email, _('must not be a placeholder email'))
+    elsif user&.placeholder?
+      errors.add(:user_id, _("must not be a placeholder user"))
+    end
+  end
+
   def send_invite
     run_after_commit_or_now { Members::InviteMailer.initial_email(self, @raw_invite_token).deliver_later }
   end
@@ -608,7 +647,11 @@ class Member < ApplicationRecord
     todo_service.create_member_access_request_todos(self)
   end
 
-  def post_create_hook
+  def post_create_access_request_hook
+    system_hook_service.execute_hooks_for(self, :request)
+  end
+
+  def post_create_member_hook
     # The creator of a personal project gets added as a `ProjectMember`
     # with `OWNER` access during creation of a personal project,
     # but we do not want to trigger notifications to the same person who created the personal project.
@@ -632,10 +675,14 @@ class Member < ApplicationRecord
     system_hook_service.execute_hooks_for(self, :update)
   end
 
-  def post_destroy_hook
+  def post_destroy_member_hook
     system_hook_service.execute_hooks_for(self, :destroy)
   end
 
+  def post_destroy_access_request_hook
+    system_hook_service.execute_hooks_for(self, :revoke)
+  end
+
   # Refreshes authorizations of the current member.
   #
   # This method schedules a job using Sidekiq and as such **must not** be called
@@ -657,7 +704,7 @@ class Member < ApplicationRecord
 
     update_two_factor_requirement
 
-    post_create_hook
+    post_create_member_hook
   end
 
   def after_decline_invite
@@ -665,7 +712,7 @@ class Member < ApplicationRecord
   end
 
   def after_accept_request
-    post_create_hook
+    post_create_member_hook
   end
 
   # rubocop: disable CodeReuse/ServiceClass
@@ -743,11 +790,17 @@ class Member < ApplicationRecord
   end
 
   def create_organization_user_record
-    return if invite?
+    return if pending?
     return if source.organization.blank?
 
     Organizations::OrganizationUser.create_organization_record_for(user_id, source.organization_id)
   end
+
+  def accepted_invite_or_request?
+    # `user_id` is nil for member invited through email and will be set once the user has created an account.
+    # `requested_at` is defined only while the membership access request is still pending.
+    saved_change_to_user_id? || saved_change_to_requested_at?
+  end
 end
 
 Member.prepend_mod_with('Member')
