@@ -1,13 +1,16 @@
 # frozen_string_literal: true
 
 class MergeRequestsClosingIssues < ApplicationRecord
+  include BulkInsertSafe
+
   belongs_to :merge_request
   belongs_to :issue
 
-  validates :merge_request_id, uniqueness: { scope: [:issue_id, :closes_work_item] }, presence: true
+  validates :merge_request_id, uniqueness: { scope: :issue_id }, presence: true
   validates :issue_id, presence: true
 
-  scope :closes_work_item, -> { where(closes_work_item: true) }
+  scope :with_opened_merge_request, -> { joins(:merge_request).merge(MergeRequest.with_state(:opened)) }
+  scope :from_mr_description, -> { where(from_mr_description: true) }
   scope :with_issues, ->(ids) { where(issue_id: ids) }
   scope :with_merge_requests_enabled, -> do
     joins(:merge_request)
@@ -30,11 +33,15 @@ class MergeRequestsClosingIssues < ApplicationRecord
       preload(merge_request: [:target_project, :author])
     end
 
-    def closing_count_for_collection(ids, current_user)
+    def preload_issue
+      preload(:issue)
+    end
+
+    def count_for_collection(ids, current_user)
       closing_merge_requests(ids, current_user).group(:issue_id).pluck('issue_id', Arel.sql('COUNT(*) as count'))
     end
 
-    def closing_count_for_issue(id, current_user)
+    def count_for_issue(id, current_user)
       closing_merge_requests(id, current_user).count
     end
 
@@ -44,7 +51,7 @@ class MergeRequestsClosingIssues < ApplicationRecord
       return with_issues(ids) if current_user&.admin?
       return with_issues(ids).with_merge_requests_enabled if current_user.blank?
 
-      closes_work_item.with_issues(ids).accessible_by(current_user)
+      with_issues(ids).accessible_by(current_user)
     end
   end
 end
