@@ -18,8 +18,8 @@ class Namespace < ApplicationRecord
   include Ci::NamespaceSettings
   include Referable
   include CrossDatabaseIgnoredTables
-  include IgnorableColumns
   include UseSqlFunctionForPrimaryKeyLookups
+  include Todoable
 
   ignore_column :unlock_membership_to_ldap, remove_with: '16.7', remove_after: '2023-11-16'
 
@@ -76,7 +76,6 @@ class Namespace < ApplicationRecord
   has_many :runner_namespaces, inverse_of: :namespace, class_name: 'Ci::RunnerNamespace'
   has_many :runners, through: :runner_namespaces, source: :runner, class_name: 'Ci::Runner'
   has_many :pending_builds, class_name: 'Ci::PendingBuild'
-  has_one :onboarding_progress, class_name: 'Onboarding::Progress'
 
   # This should _not_ be `inverse_of: :namespace`, because that would also set
   # `user.namespace` when this user creates a group with themselves as `owner`.
@@ -114,6 +113,9 @@ class Namespace < ApplicationRecord
   has_one :namespace_import_user, class_name: 'Import::NamespaceImportUser', foreign_key: :namespace_id, inverse_of: :namespace
   has_one :import_user, class_name: 'User', through: :namespace_import_user, foreign_key: :user_id
 
+  has_many :bot_user_details, class_name: 'UserDetail', foreign_key: 'bot_namespace_id', inverse_of: :bot_namespace
+  has_many :bot_users, through: :bot_user_details, source: :user
+
   validates :owner, presence: true, if: ->(n) { n.owner_required? }
   validates :organization, presence: true, if: :require_organization?
   validates :name,
@@ -156,6 +158,13 @@ class Namespace < ApplicationRecord
   validate :nesting_level_allowed, unless: -> { project_namespace? }
   validate :changing_shared_runners_enabled_is_allowed, unless: -> { project_namespace? }
   validate :changing_allow_descendants_override_disabled_shared_runners_is_allowed, unless: -> { project_namespace? }
+  validate :parent_organization_match, if: :require_organization?
+
+  attribute :organization_id, :integer, default: -> do
+    return 1 if Feature.enabled?(:namespace_model_default_org, Feature.current_request)
+
+    columns_hash['organization_id'].default
+  end
 
   delegate :name, to: :owner, allow_nil: true, prefix: true
   delegate :avatar_url, to: :owner, allow_nil: true
@@ -167,6 +176,7 @@ class Namespace < ApplicationRecord
     to: :namespace_settings
   delegate :emails_enabled, :emails_enabled=,
     to: :namespace_settings, allow_nil: true
+  delegate :token_expiry_notify_inherited, :token_expiry_notify_inherited=, to: :namespace_settings
   delegate :allow_runner_registration_token,
     :allow_runner_registration_token=,
     to: :namespace_settings
@@ -181,7 +191,7 @@ class Namespace < ApplicationRecord
   delegate :math_rendering_limits_enabled?,
     :lock_math_rendering_limits_enabled?,
     to: :namespace_settings
-  delegate :add_creator, :pending_delete, :pending_delete=,
+  delegate :add_creator, :pending_delete, :pending_delete=, :deleted_at, :deleted_at=,
     to: :namespace_details
 
   before_create :sync_share_with_group_lock_with_parent
@@ -200,7 +210,7 @@ class Namespace < ApplicationRecord
       saved_change_to_name?) || saved_change_to_path? || saved_change_to_parent_id?
   }
 
-  scope :without_deleted, -> { joins(:namespace_details).where(namespace_details: { pending_delete: false }) }
+  scope :without_deleted, -> { joins(:namespace_details).where(namespace_details: { deleted_at: nil }) }
   scope :user_namespaces, -> { where(type: Namespaces::UserNamespace.sti_name) }
   scope :group_namespaces, -> { where(type: Group.sti_name) }
   scope :without_project_namespaces, -> { where(Namespace.arel_table[:type].not_eq(Namespaces::ProjectNamespace.sti_name)) }
@@ -213,6 +223,7 @@ class Namespace < ApplicationRecord
   scope :in_organization, ->(organization) { where(organization: organization) }
   scope :by_name, ->(name) { where('name LIKE ?', "#{sanitize_sql_like(name)}%") }
   scope :ordered_by_name, -> { order(:name) }
+  scope :top_level, -> { by_parent(nil) }
 
   scope :with_statistics, -> do
     namespace_statistic_columns = STATISTICS_COLUMNS.map { |column| sum_project_statistics_column(column) }
@@ -272,6 +283,10 @@ class Namespace < ApplicationRecord
       find_by("lower(path) = :path OR lower(name) = :path", path: path.downcase)
     end
 
+    def find_top_level
+      top_level.take
+    end
+
     # Searches for namespaces matching the given query.
     #
     # This method uses ILIKE on PostgreSQL.
@@ -306,9 +321,14 @@ class Namespace < ApplicationRecord
     # https://gitlab.com/gitlab-org/gitlab/-/blob/5d34e3488faa3982d30d7207773991c1e0b6368a/app/assets/javascripts/gfm_auto_complete.js#L68 and
     # https://gitlab.com/gitlab-org/gitlab/-/blob/5d34e3488faa3982d30d7207773991c1e0b6368a/app/assets/javascripts/gfm_auto_complete.js#L1053
     def gfm_autocomplete_search(query)
+      namespaces_cte = Gitlab::SQL::CTE.new(table_name, without_order)
+
       # This scope does not work with `ProjectNamespace` records because they don't have a corresponding `route` association.
       # We do not chain the `without_project_namespaces` scope because it results in an expensive query plan in certain cases
-      joins(:route)
+      unscoped
+        .with(namespaces_cte.to_arel)
+        .from(namespaces_cte.table)
+        .joins(:route)
         .where(
           "REPLACE(routes.name, ' ', '') ILIKE :pattern OR routes.path ILIKE :pattern",
           pattern: "%#{sanitize_sql_like(query)}%"
@@ -327,17 +347,13 @@ class Namespace < ApplicationRecord
     def clean_path(path, limited_to: Namespace.all)
       slug = Gitlab::Slug::Path.new(path).generate
       path = Namespaces::RandomizedSuffixPath.new(slug)
-      Gitlab::Utils::Uniquify.new.string(path) { |s| limited_to.find_by_path_or_name(s) }
+      Gitlab::Utils::Uniquify.new.string(path) { |s| limited_to.find_by_path_or_name(s) || ProjectSetting.unique_domain_exists?(s) }
     end
 
     def clean_name(value)
       value.scan(Gitlab::Regex.group_name_regex_chars).join(' ')
     end
 
-    def top_most
-      by_parent(nil)
-    end
-
     def reference_prefix
       User.reference_prefix
     end
@@ -353,13 +369,8 @@ class Namespace < ApplicationRecord
       coalesce.as(column.to_s)
     end
 
-    def with_disabled_organization_validation
-      current_value = Gitlab::SafeRequestStore[:require_organization]
-      Gitlab::SafeRequestStore[:require_organization] = false
-
-      yield
-    ensure
-      Gitlab::SafeRequestStore[:require_organization] = current_value
+    def username_reserved?(username)
+      without_project_namespaces.top_level.find_by_path_or_name(username).present?
     end
   end
 
@@ -612,6 +623,14 @@ class Namespace < ApplicationRecord
       .try(name)
   end
 
+  def can_modify_token_expiry_notify_inherited?
+    ancestors.all?(&:token_expiry_notify_inherited)
+  end
+
+  def token_expiry_notify_inherited?
+    self_and_ancestors.all?(&:token_expiry_notify_inherited)
+  end
+
   def actual_plan
     Plan.default
   end
@@ -722,8 +741,34 @@ class Namespace < ApplicationRecord
       :active_pages_deployments)
   end
 
+  def web_url(only_path: nil)
+    Gitlab::UrlBuilder.build(self, only_path: only_path)
+  end
+
+  # there is no service desk feature for group level items
+  def service_desk_alias_address
+    nil
+  end
+
+  def deleted?
+    !!deleted_at
+  end
+
   private
 
+  def require_organization?
+    return false unless Feature.enabled?(:require_organization, Feature.current_request)
+
+    Gitlab::SafeRequestStore.fetch(:require_organization) { true } # rubocop:disable Style/RedundantFetchBlock -- This fetch has a different interface
+  end
+
+  def parent_organization_match
+    return unless parent
+    return if parent.organization_id == organization_id
+
+    errors.add(:organization_id, _("must match the parent organization's ID"))
+  end
+
   def cross_namespace_reference?(from)
     return false if from == self
 
@@ -735,7 +780,7 @@ class Namespace < ApplicationRecord
     when Namespaces::ProjectNamespace
       from.parent_id != comparable_namespace_id
     when Namespace
-      parent != from
+      is_a?(Group) ? from.id != id : parent != from
     when User
       true
     end
@@ -782,7 +827,7 @@ class Namespace < ApplicationRecord
   end
 
   def refresh_access_of_projects_invited_groups
-    if Feature.enabled?(:specialized_worker_for_group_lock_update_auth_recalculation)
+    if Feature.enabled?(:specialized_worker_for_group_lock_update_auth_recalculation, self)
       Project
         .where(namespace_id: id)
         .joins(:project_group_links)
