@@ -96,11 +96,17 @@ module Namespaces
         traversal_ids.present?
       end
 
+      # Return the top most ancestor of this namespace.
+      # This method aims to minimize the number of queries by trying to re-use data that has already been loaded.
       def root_ancestor
         strong_memoize(:root_ancestor) do
-          if association(:parent).loaded? && parent.present?
-            # This case is possible when parent has not been persisted or we're inside a transaction.
+          if parent_loaded_and_present?
             parent.root_ancestor
+          elsif parent_id_present_and_traversal_ids_empty?
+            # Parent is in the database, so find our root ancestor using our parent's traversal_ids.
+            parent = Namespace.where(id: parent_id).select(:traversal_ids)
+            Namespace.from("(#{parent.to_sql}) AS parent_namespace, namespaces")
+                     .find_by('namespaces.id = parent_namespace.traversal_ids[1]')
           elsif parent_id.nil?
             # There is no parent, so we are the root ancestor.
             self
@@ -114,16 +120,16 @@ module Namespaces
         all_projects.select(:id)
       end
 
-      def self_and_descendants
+      def self_and_descendants(skope: self.class)
         return super unless use_traversal_ids?
 
-        lineage(top: self)
+        lineage(top: self, skope: skope)
       end
 
-      def self_and_descendant_ids
+      def self_and_descendant_ids(skope: self.class)
         return super unless use_traversal_ids?
 
-        self_and_descendants.as_ids
+        self_and_descendants(skope: skope).as_ids
       end
 
       def descendants
@@ -253,17 +259,15 @@ module Namespaces
           .new(Namespace.where(id: parent_ids))
           .base_and_ancestors
           .reorder(nil)
-          .where(parent_id: nil)
+          .top_level
 
         Namespace.lock.select(:id).where(id: roots).order(id: :asc).load
       end
 
       # Search this namespace's lineage. Bound inclusively by top node.
-      def lineage(top: nil, bottom: nil, hierarchy_order: nil)
+      def lineage(top: nil, bottom: nil, hierarchy_order: nil, skope: self.class)
         raise UnboundedSearch, 'Must bound search by either top or bottom' unless top || bottom
 
-        skope = self.class
-
         if top
           skope = skope.where("traversal_ids @> ('{?}')", top.id)
         end
@@ -300,6 +304,16 @@ module Namespaces
           index + 1
         end
       end
+
+      # This case is possible when parent has not been persisted or we're inside a transaction.
+      def parent_loaded_and_present?
+        association(:parent).loaded? && parent.present?
+      end
+
+      # This case occurs when parent is persisted but we are not.
+      def parent_id_present_and_traversal_ids_empty?
+        parent_id.present? && traversal_ids.empty?
+      end
     end
   end
 end
