@@ -26,9 +26,15 @@ module Network
     def collect_commits
       # https://gitlab.com/gitlab-org/gitlab-foss/issues/58013
       Gitlab::GitalyClient.allow_n_plus_1_calls do
-        find_commits(count_to_display_commit_in_center).map do |commit|
-          # Decorate with app/model/network/commit.rb
-          Network::Commit.new(commit)
+        # Decorate with app/model/network/commit.rb
+        if Feature.enabled?(:use_list_commits_rpc_network_graph, @project, type: :gitlab_com_derisk)
+          list_commits(count_to_display_commit_in_center).map do |commit|
+            Network::Commit.new(commit)
+          end
+        else
+          find_commits(count_to_display_commit_in_center).map do |commit|
+            Network::Commit.new(commit)
+          end
         end
       end
     end
@@ -62,12 +68,19 @@ module Network
       days
     end
 
+    # TODO: `skip` is not a valid parameter for `ListCommitsRequest` RPC
+    # Issue: https://gitlab.com/gitlab-org/gitlab/-/issues/481720
+
     # Skip count that the target commit is displayed in center.
     def count_to_display_commit_in_center
       offset = -1
       skip = 0
       while offset == -1
-        tmp_commits = find_commits(skip)
+        tmp_commits = if Feature.enabled?(:use_list_commits_rpc_network_graph, @project, type: :gitlab_com_derisk)
+                        list_commits(skip)
+                      else
+                        find_commits(skip)
+                      end
 
         if tmp_commits.present?
           index = tmp_commits.index do |c|
@@ -108,6 +121,27 @@ module Network
       end
     end
 
+    def list_commits(skip = 0)
+      Gitlab::SafeRequestStore.fetch([@project, :network_graph_commits, skip]) do
+        opts = {
+          revisions: %w[--tags --branches],
+          pagination_params: { limit: self.class.max_count },
+          reverse: false,
+          order: :date,
+          skip: skip
+        }
+
+        if @filter_ref
+          opts[:ref] = @commit.id
+          opts[:before] = @commit.committed_date
+        else
+          opts[:ref] = @ref
+        end
+
+        Gitlab::Git::Commit.list_all(@repo.raw_repository, opts)
+      end
+    end
+
     def commits_sort_by_ref
       @commits.sort do |a, b|
         if include_ref?(a)
