@@ -2,12 +2,16 @@
 
 module Organizations
   class OrganizationUser < ApplicationRecord
+    include ActiveModel::Dirty
+
     belongs_to :organization, inverse_of: :organization_users, optional: false
     belongs_to :user, inverse_of: :organization_users, optional: false
 
     validates :user, uniqueness: { scope: :organization_id }
     validates :access_level, presence: true
 
+    validate :last_owner_access_level_change, if: :access_level_changed?
+
     before_destroy :ensure_user_has_an_organization
 
     enum access_level: {
@@ -33,15 +37,6 @@ module Organizations
       )
     end
 
-    def self.update_default_organization_record_for(user_id, user_is_admin:)
-      find_or_initialize_by(
-        user_id: user_id, organization_id: Organizations::Organization::DEFAULT_ORGANIZATION_ID
-      ).tap do |record|
-        record.access_level = default_organization_access_level(user_is_admin: user_is_admin)
-        record.save
-      end
-    end
-
     def self.default_organization_access_level(user_is_admin: false)
       if user_is_admin
         :owner
@@ -74,7 +69,6 @@ module Organizations
     def last_owner?
       return false unless owner?
 
-      other_owners = organization.organization_users.owners.id_not_in(id)
       # Try to keep the last active user as owner
       return other_owners.with_active_users.empty? if user.active?
 
@@ -83,6 +77,10 @@ module Organizations
 
     private
 
+    def other_owners
+      @other_owners ||= organization.organization_users.owners.id_not_in(id)
+    end
+
     def ensure_user_has_an_organization
       return unless user
 
@@ -90,5 +88,11 @@ module Organizations
 
       errors.add(:base, _('A user must associate with at least one organization'))
     end
+
+    def last_owner_access_level_change
+      return unless access_level_was == 'owner' && other_owners.empty?
+
+      errors.add(:base, _('You cannot change the access of the last owner from the organization'))
+    end
   end
 end
