@@ -6,7 +6,7 @@ class Packages::Dependency < ApplicationRecord
   has_many :dependency_links, class_name: 'Packages::DependencyLink'
   belongs_to :project
 
-  validates :name, :version_pattern, presence: true
+  validates :name, :version_pattern, :project_id, presence: true
 
   validates :name, uniqueness: { scope: :version_pattern }, unless: :project_id
   validates :name, uniqueness: { scope: %i[version_pattern project_id] }, if: :project_id
@@ -23,11 +23,8 @@ class Packages::Dependency < ApplicationRecord
     names_and_version_patterns.each_slice(chunk_size) do |tuples|
       where_statement = Array.new(tuples.size, NAME_VERSION_PATTERN_TUPLE_MATCHING)
                              .join(' OR ')
-      # Additionally, we look up for dependencies with `project_id IS NULL` to avoid creating duplicates:
-      # a dependency with `project_id` and the same dependency without `project_id`.
-      # We could remove `nil` value when all dependencies have a `project_id`.
       ids = where(where_statement, *tuples.flatten)
-              .where(project_id: [project_id, nil])
+              .where(project_id: project_id)
               .limit(max_rows_limit + 1)
               .pluck(:id)
       matched_ids.concat(ids)
