@@ -14,7 +14,7 @@ class ProjectGroupLink < ApplicationRecord
   validates :group_access, inclusion: { in: Gitlab::Access.all_values }, presence: true
   validate :different_group
 
-  scope :non_guests, -> { where('group_access > ?', Gitlab::Access::GUEST) }
+  scope :non_guests, -> { where('project_group_links.group_access > ?', Gitlab::Access::GUEST) }
   scope :in_group, ->(group_ids) { where(group_id: group_ids) }
   scope :for_projects, ->(project_ids) { where(project_id: project_ids) }
 
