@@ -3,7 +3,6 @@
 class ProjectSetting < ApplicationRecord
   include ::Gitlab::Utils::StrongMemoize
   include EachBatch
-  include IgnorableColumns
   include CascadingProjectSettingAttribute
 
   ALLOWED_TARGET_PLATFORMS = %w[ios osx tvos watchos android].freeze
@@ -11,6 +10,7 @@ class ProjectSetting < ApplicationRecord
   belongs_to :project, inverse_of: :project_setting
 
   scope :for_projects, ->(projects) { where(project_id: projects) }
+  scope :with_namespace, -> { joins(project: :namespace) }
 
   attr_encrypted :cube_api_key,
     mode: :per_attribute_iv,
@@ -40,7 +40,6 @@ class ProjectSetting < ApplicationRecord
   validates :issue_branch_template, length: { maximum: Issue::MAX_BRANCH_TEMPLATE }
   validates :target_platforms, inclusion: { in: ALLOWED_TARGET_PLATFORMS }
   validates :suggested_reviewers_enabled, inclusion: { in: [true, false] }
-  ignore_column :code_suggestions, remove_with: '17.0', remove_after: '2024-03-21'
 
   validates :pages_unique_domain,
     uniqueness: { if: -> { pages_unique_domain.present? } },
@@ -54,6 +53,11 @@ class ProjectSetting < ApplicationRecord
     Feature.enabled?(:legacy_open_source_license_available, type: :ops)
   end
 
+  # Checks if a given domain is already assigned to any existing project
+  def self.unique_domain_exists?(domain)
+    where(pages_unique_domain: domain).exists?
+  end
+
   def squash_enabled_by_default?
     %w[always default_on].include?(squash_option)
   end
