@@ -14,6 +14,10 @@ class SystemNoteMetadata < ApplicationRecord
     moved merge
     label milestone
     relate unrelate
+    unrelate_from_parent
+    unrelate_from_child
+    relate_to_parent
+    relate_to_child
     cloned
   ].freeze
 
