@@ -29,6 +29,7 @@ class User < ApplicationRecord
   include RestrictedSignup
   include StripAttribute
   include EachBatch
+  include IgnorableColumns
   include CrossDatabaseIgnoredTables
   include UseSqlFunctionForPrimaryKeyLookups
 
@@ -45,6 +46,8 @@ class User < ApplicationRecord
     on: :destroy
   )
 
+  ignore_column :last_access_from_pipl_country_at, remove_after: '2024-11-17', remove_with: '17.7'
+
   DEFAULT_NOTIFICATION_LEVEL = :participating
 
   INSTANCE_ACCESS_REQUEST_APPROVERS_TO_BE_NOTIFIED_LIMIT = 10
@@ -95,13 +98,13 @@ class User < ApplicationRecord
   attribute :color_mode_id, default: -> { Gitlab::ColorModes::APPLICATION_DEFAULT }
 
   attr_encrypted :otp_secret,
-    key: Gitlab::Application.secrets.otp_key_base,
+    key: Gitlab::Application.credentials.otp_key_base,
     mode: :per_attribute_iv_and_salt,
     insecure_mode: true,
     algorithm: 'aes-256-cbc'
 
   devise :two_factor_authenticatable,
-    otp_secret_encryption_key: Gitlab::Application.secrets.otp_key_base
+    otp_secret_encryption_key: Gitlab::Application.credentials.otp_key_base
 
   devise :two_factor_backupable, otp_number_of_backup_codes: 10
   devise :two_factor_backupable_pbkdf2
@@ -159,7 +162,7 @@ class User < ApplicationRecord
     dependent: :destroy, # rubocop:disable Cop/ActiveRecordDependent
     foreign_key: :owner_id,
     inverse_of: :owner,
-    autosave: true # rubocop:disable Cop/ActiveRecordDependent
+    autosave: true
 
   # Profile
   has_many :keys, -> { regular_keys }, dependent: :destroy # rubocop:disable Cop/ActiveRecordDependent
@@ -182,7 +185,7 @@ class User < ApplicationRecord
 
   # Followers
   has_many :followed_users, foreign_key: :follower_id, class_name: 'Users::UserFollowUser'
-  has_many :followees, through: :followed_users
+  has_many :followees, -> { active }, through: :followed_users
 
   has_many :following_users, foreign_key: :followee_id, class_name: 'Users::UserFollowUser'
   has_many :followers, -> { active }, through: :following_users
@@ -289,7 +292,6 @@ class User < ApplicationRecord
   has_one :user_preference
   has_one :user_detail
   has_one :user_highest_role
-  has_one :user_canonical_email
   has_one :credit_card_validation, class_name: '::Users::CreditCardValidation'
   has_one :phone_number_validation, class_name: '::Users::PhoneNumberValidation'
   has_one :atlassian_identity, class_name: 'Atlassian::Identity'
@@ -325,6 +327,7 @@ class User < ApplicationRecord
     presence: true,
     exclusion: { in: Gitlab::PathRegex::TOP_LEVEL_ROUTES, message: N_('%{value} is a reserved name') }
   validates :username, uniqueness: true, unless: :namespace
+  validate :username_not_assigned_to_pages_unique_domain, if: :username_changed?
   validates :name, presence: true, length: { maximum: 255 }
   validates :first_name, length: { maximum: 127 }
   validates :last_name, length: { maximum: 127 }
@@ -341,10 +344,11 @@ class User < ApplicationRecord
   validate :namespace_move_dir_allowed, if: :username_changed?, unless: :new_record?
 
   validate :unique_email, if: :email_changed?
+  validates_with AntiAbuse::UniqueDetumbledEmailValidator, if: :email_changed?
   validate :notification_email_verified, if: :notification_email_changed?
   validate :public_email_verified, if: :public_email_changed?
   validate :commit_email_verified, if: :commit_email_changed?
-  validate :email_allowed_by_restrictions?, if: ->(user) { user.new_record? ? !user.created_by_id : user.email_changed? }
+  validate :email_allowed_by_restrictions, if: ->(user) { user.new_record? ? !user.created_by_id : user.email_changed? }
   validate :check_username_format, if: :username_changed?
 
   validates :theme_id, allow_nil: true, inclusion: { in: Gitlab::Themes.valid_ids,
@@ -390,7 +394,6 @@ class User < ApplicationRecord
   end
 
   after_create_commit :create_default_organization_user
-  after_update_commit :update_default_organization_user, if: -> { saved_change_to_admin }
 
   # User's Layout preference
   enum layout: { fixed: 0, fluid: 1 }
@@ -416,7 +419,6 @@ class User < ApplicationRecord
     :tab_width, :tab_width=,
     :sourcegraph_enabled, :sourcegraph_enabled=,
     :gitpod_enabled, :gitpod_enabled=,
-    :use_web_ide_extension_marketplace, :use_web_ide_extension_marketplace=,
     :extensions_marketplace_opt_in_status, :extensions_marketplace_opt_in_status=,
     :organization_groups_projects_sort, :organization_groups_projects_sort=,
     :organization_groups_projects_display, :organization_groups_projects_display=,
@@ -434,6 +436,9 @@ class User < ApplicationRecord
     :achievements_enabled, :achievements_enabled=,
     :enabled_following, :enabled_following=,
     :home_organization, :home_organization_id, :home_organization_id=,
+    :dpop_enabled, :dpop_enabled=,
+    :use_work_items_view, :use_work_items_view=,
+    :text_editor, :text_editor=,
     to: :user_preference
 
   delegate :path, to: :namespace, allow_nil: true, prefix: true
@@ -454,6 +459,7 @@ class User < ApplicationRecord
   delegate :discord, :discord=, to: :user_detail, allow_nil: true
   delegate :email_reset_offered_at, :email_reset_offered_at=, to: :user_detail, allow_nil: true
   delegate :project_authorizations_recalculated_at, :project_authorizations_recalculated_at=, to: :user_detail, allow_nil: true
+  delegate :bot_namespace, :bot_namespace=, to: :user_detail, allow_nil: true
 
   accepts_nested_attributes_for :user_preference, update_only: true
   accepts_nested_attributes_for :user_detail, update_only: true
@@ -613,6 +619,9 @@ class User < ApplicationRecord
   end
   scope :by_user_email, ->(emails) { iwhere(email: Array(emails)) }
   scope :by_emails, ->(emails) { joins(:emails).where(emails: { email: Array(emails).map(&:downcase) }) }
+  scope :by_detumbled_emails, ->(detumbled_emails) do
+    joins(:emails).where(emails: { detumbled_email: Array(detumbled_emails) })
+  end
   scope :for_todos, ->(todos) { where(id: todos.select(:user_id).distinct) }
   scope :with_emails, -> { preload(:emails) }
   scope :with_dashboard, ->(dashboard) { where(dashboard: dashboard) }
@@ -643,6 +652,7 @@ class User < ApplicationRecord
   scope :order_recent_last_activity, -> { reorder(arel_table[:last_activity_on].desc.nulls_last, arel_table[:id].asc) }
   scope :order_oldest_last_activity, -> { reorder(arel_table[:last_activity_on].asc.nulls_first, arel_table[:id].desc) }
   scope :ordered_by_id_desc, -> { reorder(arel_table[:id].desc) }
+  scope :ordered_by_name_asc_id_desc, -> { order(name: :asc, id: :desc) }
 
   scope :dormant, -> { with_state(:active).human_or_service_user.where('last_activity_on <= ?', Gitlab::CurrentSettings.deactivate_dormant_users_period.day.ago.to_date) }
   scope :with_no_activity, -> { with_state(:active).human_or_service_user.where(last_activity_on: nil).where('created_at <= ?', MINIMUM_DAYS_CREATED.day.ago.to_date) }
@@ -805,6 +815,8 @@ class User < ApplicationRecord
     # @param emails [String, Array<String>] email addresses to check
     # @param confirmed [Boolean] Only return users where the primary email is confirmed
     def by_any_email(emails, confirmed: false)
+      return none if Array(emails).all?(&:nil?)
+
       from_users = by_user_email(emails)
       from_users = from_users.confirmed if confirmed
 
@@ -1056,6 +1068,10 @@ class User < ApplicationRecord
     def username_exists?(username)
       exists?(username: username)
     end
+
+    def ends_with_reserved_file_extension?(username)
+      Mime::EXTENSION_LOOKUP.keys.any? { |type| username.end_with?(".#{type}") }
+    end
   end
 
   #
@@ -1070,7 +1086,7 @@ class User < ApplicationRecord
     username
   end
 
-  def to_reference(_from = nil, target_project: nil, full: nil)
+  def to_reference(_from = nil, target_container: nil, full: nil)
     "#{self.class.reference_prefix}#{username}"
   end
 
@@ -1168,7 +1184,7 @@ class User < ApplicationRecord
   end
 
   def disable_two_factor_otp!
-    update(
+    update!(
       otp_required_for_login: false,
       encrypted_otp_secret: nil,
       encrypted_otp_secret_iv: nil,
@@ -1202,7 +1218,7 @@ class User < ApplicationRecord
   end
 
   def needs_new_otp_secret?
-    !two_factor_enabled? && otp_secret_expired?
+    !two_factor_otp_enabled? && otp_secret_expired?
   end
 
   def otp_secret_expired?
@@ -1232,7 +1248,7 @@ class User < ApplicationRecord
   def unique_email
     email_taken = errors.added?(:email, _('has already been taken'))
 
-    if !email_taken && !emails.exists?(email: email) && Email.exists?(email: email)
+    if !email_taken && Email.where.not(user: self).where(email: email).exists?
       errors.add(:email, _('has already been taken'))
       email_taken = true
     end
@@ -1242,7 +1258,7 @@ class User < ApplicationRecord
         User.find_by_any_email(email)&.deleted_own_account?
 
       help_page_url = Rails.application.routes.url_helpers.help_page_url(
-        'user/profile/account/delete_account',
+        'user/profile/account/delete_account.md',
         anchor: 'delete-your-own-account'
       )
 
@@ -1283,17 +1299,31 @@ class User < ApplicationRecord
       direct_groups_cte = Gitlab::SQL::CTE.new(:direct_groups, groups)
       direct_groups_cte_alias = direct_groups_cte.table.alias(Group.table_name)
 
+      groups_from_authorized_projects = Group.id_in(authorized_projects.select(:namespace_id)).self_and_ancestors
+      groups_from_shares = Group.joins(:shared_with_group_links)
+                             .where(group_group_links: { shared_with_group_id: Group.from(direct_groups_cte_alias) })
+                             .self_and_descendants
+
       Group
         .with(direct_groups_cte.to_arel)
         .from_union([
           Group.from(direct_groups_cte_alias).self_and_descendants,
-          Group.id_in(authorized_projects.select(:namespace_id)),
-          Group.joins(:shared_with_group_links)
-            .where(group_group_links: { shared_with_group_id: Group.from(direct_groups_cte_alias) })
+          groups_from_authorized_projects,
+          groups_from_shares
         ])
     end
   end
 
+  # Used to search on the user's authorized_groups effeciently by using a CTE
+  def search_on_authorized_groups(query, use_minimum_char_limit: true)
+    authorized_groups_cte = Gitlab::SQL::CTE.new(:authorized_groups, authorized_groups)
+    authorized_groups_cte_alias = authorized_groups_cte.table.alias(Group.table_name)
+    Group
+      .with(authorized_groups_cte.to_arel)
+      .from(authorized_groups_cte_alias)
+      .search(query, use_minimum_char_limit: use_minimum_char_limit)
+  end
+
   # Returns the groups a user is a member of, either directly or through a parent group
   def membership_groups
     groups.self_and_descendants
@@ -1429,16 +1459,17 @@ class User < ApplicationRecord
   end
 
   def allow_password_authentication_for_web?
-    Gitlab::CurrentSettings.password_authentication_enabled_for_web? && !ldap_user?
+    return false if ldap_user?
+    return false if disable_password_authentication_for_sso_users?
+
+    Gitlab::CurrentSettings.password_authentication_enabled_for_web?
   end
 
   def allow_password_authentication_for_git?
-    Gitlab::CurrentSettings.password_authentication_enabled_for_git? && !password_based_omniauth_user?
-  end
+    return false if password_based_omniauth_user?
+    return false if disable_password_authentication_for_sso_users?
 
-  # method overriden in EE
-  def password_based_login_forbidden?
-    false
+    Gitlab::CurrentSettings.password_authentication_enabled_for_git?
   end
 
   def can_change_username?
@@ -1451,6 +1482,7 @@ class User < ApplicationRecord
 
   def allow_user_to_create_group_and_project?
     return true if Gitlab::CurrentSettings.allow_project_creation_for_guest_and_below
+    return true if can_admin_all_resources?
 
     highest_role > Gitlab::Access::GUEST
   end
@@ -1463,11 +1495,9 @@ class User < ApplicationRecord
     several_namespaces? || admin
   end
 
-  # rubocop: disable Style/ArgumentsForwarding -- https://gitlab.com/gitlab-org/gitlab/-/issues/433045
   def can?(action, subject = :global, **opts)
     Ability.allowed?(self, action, subject, **opts)
   end
-  # rubocop: enable Style/ArgumentsForwarding
 
   def confirm_deletion_with_password?
     !password_automatically_set? && allow_password_authentication?
@@ -1654,7 +1684,8 @@ class User < ApplicationRecord
 
     counts = Organizations::OrganizationUser
       .owners
-      .joins('INNER JOIN ownerships ON ownerships.organization_id = organization_users.organization_id')
+      .where('organization_users.organization_id = organizations.id')
+      .group(:organization_id)
       .having('count(organization_users.user_id) = 1')
 
     Organizations::Organization
@@ -1724,6 +1755,10 @@ class User < ApplicationRecord
     verified_emails.uniq
   end
 
+  def verified_detumbled_emails
+    emails.distinct.confirmed.pluck(:detumbled_email).compact
+  end
+
   def public_verified_emails
     strong_memoize(:public_verified_emails) do
       emails = verified_emails(include_private_email: false)
@@ -1954,10 +1989,12 @@ class User < ApplicationRecord
   end
 
   # Returns true if the user can be removed, false otherwise.
-  # A user can be removed if they do not own any groups where they are the sole owner
+  # A user can be removed if they do not own any groups or organizations where they are the sole owner
   # Method `none?` is used to ensure faster retrieval, See https://gitlab.com/gitlab-org/gitlab/-/issues/417105
 
   def can_be_removed?
+    return solo_owned_groups.none? && solo_owned_organizations.none? if Feature.enabled?(:ui_for_organizations)
+
     solo_owned_groups.none?
   end
 
@@ -2041,21 +2078,20 @@ class User < ApplicationRecord
 
   def assigned_open_merge_requests_count(force: false)
     Rails.cache.fetch(['users', id, 'assigned_open_merge_requests_count', merge_request_dashboard_enabled?], force: force, expires_in: COUNT_CACHE_VALIDITY_PERIOD) do
-      review_states = if merge_request_dashboard_enabled?
-                        %w[requested_changes reviewed]
-                      end
+      params = { assignee_id: id, state: 'opened', non_archived: true }
+      params[:reviewer_id] = 'none' if merge_request_dashboard_enabled?
 
-      MergeRequestsFinder.new(self, assignee_id: self.id, review_states: review_states, state: 'opened', non_archived: true).execute.count
+      MergeRequestsFinder.new(self, params).execute.count
     end
   end
 
   def review_requested_open_merge_requests_count(force: false)
     Rails.cache.fetch(['users', id, 'review_requested_open_merge_requests_count', merge_request_dashboard_enabled?], force: force, expires_in: COUNT_CACHE_VALIDITY_PERIOD) do
-      review_state = if merge_request_dashboard_enabled?
-                       'unreviewed'
-                     end
-
-      MergeRequestsFinder.new(self, reviewer_id: id, review_state: review_state, state: 'opened', non_archived: true).execute.count
+      if merge_request_dashboard_enabled?
+        MergeRequestsFinder.new(self, assigned_user_id: id, reviewer_review_states: %w[unreviewed unapproved review_started], assigned_review_states: %w[requested_changes reviewed], state: 'opened', non_archived: true).execute.count
+      else
+        MergeRequestsFinder.new(self, reviewer_id: id, state: 'opened', non_archived: true).execute.count
+      end
     end
   end
 
@@ -2502,6 +2538,14 @@ class User < ApplicationRecord
 
   private
 
+  def disable_password_authentication_for_sso_users?
+    ::Gitlab::CurrentSettings.disable_password_authentication_for_users_with_sso_identities? && omniauth_user?
+  end
+
+  def omniauth_user?
+    identities.any?
+  end
+
   def optional_namespace?
     Feature.enabled?(:optional_personal_namespace, self)
   end
@@ -2539,6 +2583,8 @@ class User < ApplicationRecord
   end
 
   def should_delay_delete?(deleted_by)
+    return false if placeholder?
+
     is_deleting_own_record = deleted_by.id == id
 
     is_deleting_own_record &&
@@ -2621,7 +2667,9 @@ class User < ApplicationRecord
     end
   end
 
-  def email_allowed_by_restrictions?
+  def email_allowed_by_restrictions
+    return if placeholder? || import_user?
+
     error = validate_admin_signup_restrictions(email)
 
     errors.add(:email, error) if error
@@ -2632,7 +2680,7 @@ class User < ApplicationRecord
   end
 
   def check_username_format
-    return if username.blank? || Mime::EXTENSION_LOOKUP.keys.none? { |type| username.end_with?(".#{type}") }
+    return if username.blank? || !self.class.ends_with_reserved_file_extension?(username)
 
     errors.add(:username, _('ending with a reserved file extension is not allowed.'))
   end
@@ -2733,11 +2781,9 @@ class User < ApplicationRecord
   end
 
   def create_default_organization_user
-    Organizations::OrganizationUser.create_default_organization_record_for(id, user_is_admin: admin?)
-  end
+    return unless organizations.blank?
 
-  def update_default_organization_user
-    Organizations::OrganizationUser.update_default_organization_record_for(id, user_is_admin: admin?)
+    Organizations::OrganizationUser.create_default_organization_record_for(id, user_is_admin: admin?)
   end
 
   # method overridden in EE
@@ -2745,6 +2791,13 @@ class User < ApplicationRecord
 
   # method overridden in EE
   def audit_unlock_access(author: self); end
+
+  def username_not_assigned_to_pages_unique_domain
+    if ProjectSetting.unique_domain_exists?(username)
+      # We cannot disclose the Pages unique domain, hence returning generic error message
+      errors.add(:username, _('has already been taken'))
+    end
+  end
 end
 
 User.prepend_mod_with('User')
