@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-class UserAgentDetail < MainClusterwide::ApplicationRecord
+class UserAgentDetail < ApplicationRecord
   belongs_to :subject, polymorphic: true # rubocop:disable Cop/PolymorphicAssociations
 
   validates :user_agent, :ip_address, :subject_id, :subject_type, presence: true
