@@ -7,14 +7,17 @@ module Users
     belongs_to :user
     has_one :credit_card_validation, class_name: '::Users::CreditCardValidation', primary_key: 'user_id',
       foreign_key: 'user_id', inverse_of: :banned_user
-    has_one :user_canonical_email, class_name: 'UserCanonicalEmail', primary_key: 'user_id',
-      foreign_key: 'user_id', inverse_of: :banned_user
+    has_many :emails, primary_key: 'user_id', foreign_key: 'user_id', inverse_of: :banned_user
 
     validates :user, presence: true
     validates :user_id, uniqueness: { message: N_("banned user already exists") }
 
-    scope :by_canonical_email, ->(email) do
-      joins(:user_canonical_email).where({ user_canonical_emails: { canonical_email: email.downcase } })
+    scope :by_detumbled_email, ->(email) do
+      return none if email.blank?
+
+      joins(:emails)
+        .where({ emails: { detumbled_email: ::Gitlab::Utils::Email.normalize_email(email) } })
+        .where.not({ emails: { confirmed_at: nil } })
     end
   end
 end
