@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
 # Placeholder class for model that is implemented in EE
-class Vulnerability < ApplicationRecord
+class Vulnerability < Gitlab::Database::SecApplicationRecord
   include EachBatch
 
   alias_attribute :vulnerability_id, :id
 
-  scope :with_projects, -> { includes(:project) }
+  scope :with_projects, -> { includes(:project).allow_cross_joins_across_databases(url: 'https://gitlab.com/gitlab-org/gitlab/-/issues/486246') }
 
   validates :cvss, json_schema: { filename: "vulnerability_cvss_vectors", draft: 7 }
   attribute :cvss, :ind_jsonb
