@@ -193,7 +193,9 @@ class Wiki
   end
 
   def empty?
-    !repository_exists? || list_page_paths(limit: 1).empty?
+    capture_git_error(:empty, response_on_error: true) do
+      !repository_exists? || list_page_paths(limit: 1).empty?
+    end
   end
 
   def exists?
@@ -217,28 +219,30 @@ class Wiki
     limit: 0,
     offset: 0
   )
-    create_wiki_repository unless repository_exists?
+    capture_git_error(:list, response_on_error: []) do
+      create_wiki_repository unless repository_exists?
 
-    paths = list_page_paths(limit: limit, offset: offset)
-    return [] if paths.empty?
+      paths = list_page_paths(limit: limit, offset: offset)
+      next [] if paths.empty?
 
-    pages = paths.map do |path|
-      page = Gitlab::Git::WikiPage.new(
-        url_path: strip_extension(path),
-        title: canonicalize_filename(path),
-        format: find_page_format(path),
-        path: path,
-        raw_data: '',
-        name: canonicalize_filename(path),
-        historical: false
-      )
-      WikiPage.new(self, page)
+      pages = paths.map do |path|
+        page = Gitlab::Git::WikiPage.new(
+          url_path: strip_extension(path),
+          title: canonicalize_filename(path),
+          format: find_page_format(path),
+          path: path,
+          raw_data: '',
+          name: canonicalize_filename(path),
+          historical: false
+        )
+        WikiPage.new(self, page)
+      end
+      sort_pages!(pages, direction)
+      pages = pages.take(limit) if limit > 0
+      fetch_pages_content!(pages, size_limit: size_limit) if load_content
+
+      pages
     end
-    sort_pages!(pages, direction)
-    pages = pages.take(limit) if limit > 0
-    fetch_pages_content!(pages, size_limit: size_limit) if load_content
-
-    pages
   end
 
   # Finds a page within the repository based on a title
@@ -249,29 +253,33 @@ class Wiki
   #
   # Returns an initialized WikiPage instance or nil
   def find_page(title, version = nil, load_content: true)
-    create_wiki_repository unless repository_exists?
+    return unless title.present?
 
-    version = version.presence || default_branch
-    path = find_matched_file(title, version)
-    return if path.blank?
+    capture_git_error(:find, response_on_error: nil) do
+      create_wiki_repository unless repository_exists?
 
-    path = Gitlab::EncodingHelper.encode_utf8_no_detect(path)
-    blob_options = load_content ? {} : { limit: 0 }
-    blob = repository.blob_at(version, path, **blob_options)
-    commit = repository.commit(blob.commit_id)
-    format = find_page_format(path)
+      version = version.presence || default_branch
+      path = find_matched_file(title, version)
+      next if path.blank?
 
-    page = Gitlab::Git::WikiPage.new(
-      url_path: strip_extension(path),
-      title: canonicalize_filename(path),
-      format: format,
-      path: path,
-      raw_data: blob.data,
-      name: canonicalize_filename(path),
-      historical: version == default_branch ? false : check_page_historical(path, commit),
-      version: Gitlab::Git::WikiPageVersion.new(commit, format)
-    )
-    WikiPage.new(self, page)
+      path = Gitlab::EncodingHelper.encode_utf8_no_detect(path)
+      blob_options = load_content ? {} : { limit: 0 }
+      blob = repository.blob_at(version, path, **blob_options)
+      commit = repository.commit(blob.commit_id)
+      format = find_page_format(path)
+
+      page = Gitlab::Git::WikiPage.new(
+        url_path: strip_extension(path),
+        title: canonicalize_filename(path),
+        format: format,
+        path: path,
+        raw_data: blob.data,
+        name: canonicalize_filename(path),
+        historical: version == default_branch ? false : check_page_historical(path, commit),
+        version: Gitlab::Git::WikiPageVersion.new(commit, format)
+      )
+      WikiPage.new(self, page)
+    end
   end
 
   def find_sidebar(version = nil)
@@ -280,7 +288,9 @@ class Wiki
 
   def find_file(name, version = default_branch, load_content: true)
     data_limit = load_content ? -1 : 0
-    blobs = repository.blobs_at([[version, name]], blob_size_limit: data_limit)
+    blobs = capture_git_error(:blob, response_on_error: []) do
+      repository.blobs_at([[version, name]], blob_size_limit: data_limit)
+    end
 
     return if blobs.empty?
 
@@ -290,13 +300,14 @@ class Wiki
   def create_page(title, content, format = :markdown, message = nil)
     with_valid_format(format) do |default_extension|
       sanitized_path = sluggified_full_path(title, default_extension)
-      # cannot create two pages with:
-      # - the same title but different format
-      # - the same title but different capitalization
-      # - the same title, different capitalization, and different format
-      next duplicated_page_error(sanitized_path) if file_exists_by_regex?(title)
 
       capture_git_error(:created) do
+        # cannot create two pages with:
+        # - the same title but different format
+        # - the same title but different capitalization
+        # - the same title, different capitalization, and different format
+        next duplicated_page_error(sanitized_path) if file_exists_by_regex?(title)
+
         create_wiki_repository unless repository_exists?
         sanitized_path = sluggified_full_path(title, default_extension)
         options = multi_commit_options(:created, message, title)
@@ -401,7 +412,9 @@ class Wiki
 
   override :default_branch
   def default_branch
-    super || Gitlab::DefaultBranch.value(object: container)
+    capture_git_error(:default_branch, response_on_error: 'main') do
+      super || Gitlab::DefaultBranch.value(object: container)
+    end
   end
 
   def wiki_base_path
@@ -426,6 +439,8 @@ class Wiki
     @repository = nil
   end
 
+  private
+
   def capture_git_error(action, response_on_error: false, &block)
     wrapped_gitaly_errors(&block)
   rescue Gitlab::Git::Index::IndexError,
@@ -441,8 +456,6 @@ class Wiki
     response_on_error
   end
 
-  private
-
   def update_redirection_actions(new_path, old_path = nil, **options)
     return [] unless old_path != new_path
 
