@@ -17,6 +17,10 @@ module WorkItems
     belongs_to :start_date_sourcing_milestone, class_name: 'Milestone'
 
     before_validation :set_namespace
+    before_save :set_fixed_start_date, if: :start_date_is_fixed?
+    before_save :set_fixed_due_date, if: :due_date_is_fixed?
+
+    scope :work_items_in, ->(work_items) { where(work_item: work_items) }
 
     private
 
@@ -26,5 +30,13 @@ module WorkItems
 
       self.namespace = work_item.namespace
     end
+
+    def set_fixed_start_date
+      self.start_date = start_date_fixed
+    end
+
+    def set_fixed_due_date
+      self.due_date = due_date_fixed
+    end
   end
 end
