@@ -3,7 +3,7 @@
 module WorkItems
   module Widgets
     class Description < Base
-      delegate :description, :edited?, :last_edited_at, to: :work_item
+      delegate :description, :edited?, :last_edited_at, :task_completion_status, to: :work_item
 
       def last_edited_by
         return unless work_item.edited?
