@@ -142,10 +142,15 @@ class ProjectPolicy < BasePolicy
   end
 
   desc "If user is authenticated via CI job token then the target project should be in scope"
-  condition(:project_allowed_for_job_token) do
+  condition(:project_allowed_for_job_token_by_scope) do
     !@user&.from_ci_job_token? || @user.ci_job_token_scope.accessible?(project)
   end
 
+  desc "Public, internal or project in the scope allowed via CI job token"
+  condition(:project_allowed_for_job_token) do
+    public_project? || internal_access? || project_allowed_for_job_token_by_scope?
+  end
+
   desc "If the user is via CI job token and project container registry visibility allows access"
   condition(:job_token_container_registry) { job_token_access_allowed_to?(:container_registry) }
 
@@ -205,7 +210,7 @@ class ProjectPolicy < BasePolicy
 
   with_scope :subject
   condition(:model_registry_enabled) do
-    Feature.enabled?(:model_registry, @subject) && @subject.feature_available?(:model_registry, @user)
+    @subject.feature_available?(:model_registry, @user)
   end
 
   with_scope :subject
@@ -357,7 +362,6 @@ class ProjectPolicy < BasePolicy
     enable :read_wiki
     enable :read_issue
     enable :read_label
-    enable :read_planning_hierarchy
     enable :read_milestone
     enable :read_snippet
     enable :read_project_member
@@ -372,6 +376,7 @@ class ProjectPolicy < BasePolicy
     enable :read_release
     enable :read_analytics
     enable :read_insights
+    enable :read_upload
   end
 
   rule { can?(:reporter_access) & can?(:create_issue) }.enable :create_incident
@@ -414,7 +419,6 @@ class ProjectPolicy < BasePolicy
     enable :read_merge_request
     enable :read_sentry_issue
     enable :read_prometheus
-    enable :read_metrics_dashboard_annotation
     enable :metrics_dashboard
     enable :read_confidential_issues
     enable :read_package
@@ -492,11 +496,6 @@ class ProjectPolicy < BasePolicy
     enable :read_deployment
   end
 
-  rule { ~anonymous & can?(:metrics_dashboard) }.policy do
-    enable :create_metrics_user_starred_dashboard
-    enable :read_metrics_user_starred_dashboard
-  end
-
   rule { packages_disabled }.policy do
     prevent(*create_read_update_admin_destroy(:package))
   end
@@ -538,7 +537,7 @@ class ProjectPolicy < BasePolicy
     enable :create_release
     enable :update_release
     enable :destroy_release
-    enable :admin_metrics_dashboard_annotation
+    enable :publish_catalog_version
     enable :read_alert_management_alert
     enable :update_alert_management_alert
     enable :read_terraform_state
@@ -597,7 +596,6 @@ class ProjectPolicy < BasePolicy
     enable :read_deploy_token
     enable :create_deploy_token
     enable :destroy_deploy_token
-    enable :read_prometheus_alerts
     enable :admin_terraform_state
     enable :create_freeze_period
     enable :read_freeze_period
@@ -612,7 +610,6 @@ class ProjectPolicy < BasePolicy
     enable :admin_project_google_cloud
     enable :admin_project_aws
     enable :admin_secure_files
-    enable :read_upload
     enable :admin_upload
     enable :destroy_upload
     enable :admin_incident_management_timeline_event_tag
@@ -745,10 +742,10 @@ class ProjectPolicy < BasePolicy
   end
 
   # If the project is private
-  rule { ~public_project & ~internal_access & ~project_allowed_for_job_token }.prevent_all
+  rule { ~project_allowed_for_job_token }.prevent_all
 
   # If this project is public or internal we want to prevent all aside from a few public policies
-  rule { public_or_internal & ~project_allowed_for_job_token }.policy do
+  rule { public_or_internal & ~project_allowed_for_job_token_by_scope }.policy do
     prevent :guest_access
     prevent :public_access
     prevent :reporter_access
@@ -757,7 +754,7 @@ class ProjectPolicy < BasePolicy
     prevent :owner_access
   end
 
-  rule { public_project & ~project_allowed_for_job_token }.policy do
+  rule { public_project & ~project_allowed_for_job_token_by_scope }.policy do
     prevent :public_user_access
   end
 
@@ -794,7 +791,6 @@ class ProjectPolicy < BasePolicy
     enable :read_issue_board_list
     enable :read_wiki
     enable :read_label
-    enable :read_planning_hierarchy
     enable :read_milestone
     enable :read_snippet
     enable :read_project_member
@@ -812,6 +808,7 @@ class ProjectPolicy < BasePolicy
     enable :read_pages_content
     enable :read_analytics
     enable :read_insights
+    enable :read_upload
 
     # NOTE: may be overridden by IssuePolicy
     enable :read_issue
@@ -1022,7 +1019,11 @@ class ProjectPolicy < BasePolicy
     enable :read_namespace_catalog
   end
 
-  rule { reporter & model_registry_enabled }.policy do
+  rule { public_project & model_registry_enabled }.policy do
+    enable :read_model_registry
+  end
+
+  rule { ~public_project & guest & model_registry_enabled }.policy do
     enable :read_model_registry
   end
 
@@ -1030,7 +1031,11 @@ class ProjectPolicy < BasePolicy
     enable :write_model_registry
   end
 
-  rule { reporter & model_experiments_enabled }.policy do
+  rule { public_project & model_experiments_enabled }.policy do
+    enable :read_model_experiments
+  end
+
+  rule { ~public_project & guest & model_experiments_enabled }.policy do
     enable :read_model_experiments
   end
 
