@@ -49,7 +49,9 @@ class MemberPresenter < Gitlab::View::Presenter::Delegated
     raise NotImplementedError
   end
 
-  def member_role_description; end
+  def member_role_description
+    member.role_description
+  end
 
   private
 
