@@ -4,7 +4,7 @@ class CodequalityDegradationEntity < Grape::Entity
   expose :description
   expose :fingerprint
   expose :severity do |degradation|
-    severity = degradation.dig(:severity)&.downcase
+    severity = degradation[:severity]&.downcase
 
     ::Gitlab::Ci::Reports::CodequalityReports::SEVERITY_PRIORITIES.key?(severity) ? severity : 'unknown'
   end
