@@ -59,11 +59,24 @@ module Auth
           name => %w[pull push],
           "#{name}/*" => %w[pull]
         },
-        override_project_path: name
+        use_key_as_project_path: true
       )
     end
 
-    def self.access_token(names_and_actions, type = 'repository', override_project_path: nil)
+    def self.push_pull_move_repositories_access_token(name, new_namespace)
+      name = name.chomp('/')
+
+      access_token(
+        {
+          name => %w[pull push],
+          "#{name}/*" => %w[pull],
+          "#{new_namespace}/*" => %w[push]
+        },
+        use_key_as_project_path: true
+      )
+    end
+
+    def self.access_token(names_and_actions, type = 'repository', use_key_as_project_path: false)
       registry = Gitlab.config.registry
       token = JSONWebToken::RSAToken.new(registry.key)
       token.issuer = registry.issuer
@@ -75,7 +88,7 @@ module Auth
           type: type,
           name: name,
           actions: actions,
-          meta: access_metadata(path: name, override_project_path: override_project_path)
+          meta: access_metadata(path: name, use_key_as_project_path: use_key_as_project_path)
         }.compact
       end
 
@@ -86,8 +99,8 @@ module Auth
       Time.current + Gitlab::CurrentSettings.container_registry_token_expire_delay.minutes
     end
 
-    def self.access_metadata(project: nil, path: nil, override_project_path: nil)
-      return { project_path: override_project_path.downcase } if override_project_path
+    def self.access_metadata(project: nil, path: nil, use_key_as_project_path: false)
+      return { project_path: path.chomp('/*').downcase } if use_key_as_project_path
 
       # If the project is not given, try to infer it from the provided path
       if project.nil?
@@ -213,6 +226,11 @@ module Auth
       return if path.has_repository?
       return unless actions.include?('push')
 
+      find_or_create_repository_from_path(path)
+    end
+
+    # Overridden in EE
+    def find_or_create_repository_from_path(path)
       ContainerRepository.find_or_create_from_path!(path)
     end
 
@@ -310,7 +328,8 @@ module Auth
     end
 
     def repository_path_push_protected?
-      return false if Feature.disabled?(:container_registry_protected_containers, project)
+      return false if Feature.disabled?(:container_registry_protected_containers, project&.root_ancestor)
+      return false if current_user&.can_admin_all_resources?
 
       push_scopes = scopes.select { |scope| scope[:actions].include?('push') || scope[:actions].include?('*') }
 
