@@ -35,16 +35,22 @@ module Ci
           })
         elsif component_path.invalid_usage_for_latest?
           ServiceResponse.error(
-            message: 'The ~latest version reference is not supported for non-catalog resources. ' \
-                     'Use a tag, branch, or SHA instead',
+            message: "#{error_prefix} The ~latest version reference is not supported for non-catalog resources. " \
+                     'Use a tag, branch, or commit SHA instead.',
             reason: :invalid_usage)
         else
           ServiceResponse.error(message: "#{error_prefix} content not found", reason: :content_not_found)
         end
       rescue Gitlab::Access::AccessDeniedError
-        ServiceResponse.error(
-          message: "#{error_prefix} project does not exist or you don't have sufficient permissions",
-          reason: :not_allowed)
+        if current_user.external? && component_path.project.internal?
+          ServiceResponse.error(
+            message: "#{error_prefix} project is `Internal`, it cannot be accessed by an External User",
+            reason: :not_allowed)
+        else
+          ServiceResponse.error(
+            message: "#{error_prefix} project does not exist or you don't have sufficient permissions",
+            reason: :not_allowed)
+        end
       end
 
       private
@@ -57,7 +63,7 @@ module Ci
       strong_memoize_attr :component_path_class
 
       def error_prefix
-        "component '#{address}' -"
+        "Component '#{address}' -"
       end
     end
   end
