@@ -19,12 +19,22 @@ module Ci
             used_by_project_id: used_by_project.id
           )
 
+          component_last_usage = Ci::Catalog::Resources::Components::LastUsage.get_usage_for(component, used_by_project)
+
+          if component_last_usage.new_record?
+            component_last_usage.last_used_date = Time.current.to_date
+          else
+            component_last_usage.touch(:last_used_date)
+          end
+
+          component_last_usage.save # Save last usage regardless of component_usage
+
           if component_usage.save
             ServiceResponse.success(message: 'Usage recorded')
           else
-            errors = component_usage.errors
+            errors = component_usage.errors || component_last_usage.errors
 
-            if errors.size == 1 && errors.first.type == :taken # Only unique validation failed
+            if errors.size == 1 && errors.first.type == :taken
               ServiceResponse.success(message: 'Usage already recorded for today')
             else
               exception = ValidationError.new(errors.full_messages.join(', '))
