@@ -18,26 +18,18 @@ module Ci
     end
 
     def execute(ref)
+      # "ref" is not a enough for a cache key because the name is static but that branch can be changed any time
       sha = project.commit(ref).try(:sha)
 
-      with_reactive_cache(sha) { |result| result }
+      with_reactive_cache(sha, ref) { |result| result }
     end
 
-    def calculate_reactive_cache(sha)
+    def calculate_reactive_cache(sha, ref)
       config = ::Gitlab::Ci::ProjectConfig.new(project: project, sha: sha)
 
       return {} unless config.exists?
 
-      ref_name = Gitlab::Ci::RefFinder.new(project).find_by_sha(sha)
-
-      result = Gitlab::Ci::YamlProcessor.new(
-        config.content,
-        project: project,
-        user: current_user,
-        sha: sha,
-        ref: ref_name,
-        verify_project_sha: true
-      ).execute
+      result = execute_yaml_processor(sha, ref, config)
 
       result.valid? ? result.root_variables_with_prefill_data : {}
     end
@@ -46,5 +38,23 @@ module Ci
     def id
       "#{project.id}-#{current_user.id}"
     end
+
+    private
+
+    def execute_yaml_processor(sha, ref, config)
+      # The `ref` parameter should be branch or tag name. However, the API also accepts a commit SHA and we can't
+      # change it to not introduce breaking changes. Instead, here we're checking if a commit SHA is passed
+      # as `ref`. If so, we should verify the sha whether it belongs to the project in YamlProcessor.
+      sha_passed_as_ref_parameter = !project.repository.branch_or_tag?(ref)
+
+      Gitlab::Ci::YamlProcessor.new(
+        config.content,
+        project: project,
+        user: current_user,
+        sha: sha,
+        ref: ref,
+        verify_project_sha: sha_passed_as_ref_parameter
+      ).execute
+    end
   end
 end
