@@ -8,8 +8,10 @@ module Ci
       begin
         pipeline.source_bridge.inherit_status_from_downstream!(pipeline)
       rescue StateMachines::InvalidTransition => e
+        error = Ci::Bridge::InvalidTransitionError.new(e.message)
+        error.set_backtrace(caller)
         Gitlab::ErrorTracking.track_exception(
-          Ci::Bridge::InvalidTransitionError.new(e.message),
+          error,
           bridge_id: pipeline.source_bridge.id,
           downstream_pipeline_id: pipeline.id)
       end
