@@ -21,9 +21,7 @@ module Ci
 
         new_builds_relation = new_builds.where("ci_pending_builds.namespace_traversal_ids && '{?}'", runner.namespace_ids)
 
-        return order(new_builds_relation) if ::Feature.enabled?(:order_builds_for_group_runner)
-
-        new_builds_relation
+        order(new_builds_relation)
       end
 
       def builds_matching_tag_ids(relation, ids)
