@@ -87,7 +87,7 @@ module Integrations
 
       award_emoji = AwardEmoji.new(
         id: 1,
-        name: 'thumbsup',
+        name: AwardEmoji::THUMBS_UP,
         user: current_user,
         awardable: project.notes.last,
         created_at: Time.zone.now,
@@ -115,5 +115,9 @@ module Integrations
         current_user: current_user
       }
     end
+
+    def project_events_data
+      Gitlab::HookData::ProjectBuilder.new(project).build(:create)
+    end
   end
 end
