@@ -8,9 +8,7 @@ module Search
       {
         state: params[:state],
         confidential: params[:confidential],
-        include_archived: params[:include_archived],
-        num_context_lines: params[:num_context_lines]&.to_i,
-        hybrid_similarity: params[:hybrid_similarity]&.to_f
+        include_archived: params[:include_archived]
       }
     end
   end
