@@ -12,10 +12,20 @@ module Environments
         )
       end
 
+      unsafe_execute!(environment)
+    end
+
+    ##
+    # Stops the environment without checking user permissions. This
+    # should only be used if initiated by a system action and a user
+    # cannot be specified.
+    def unsafe_execute!(environment)
       if params[:force]
+        actions = []
+
         environment.stop_complete!
       else
-        environment.stop_with_actions!
+        actions = environment.stop_with_actions!
       end
 
       unless environment.saved_change_to_attribute?(:state)
@@ -25,7 +35,7 @@ module Environments
         )
       end
 
-      ServiceResponse.success(payload: { environment: environment })
+      ServiceResponse.success(payload: { environment: environment, actions: actions })
     end
 
     def execute_for_branch(branch_name)
