@@ -4,6 +4,8 @@ module Groups
   class AutocompleteService < Groups::BaseService
     include LabelsAsHash
 
+    SEARCH_LIMIT = 5
+
     # rubocop: disable CodeReuse/ActiveRecord
     def issues(confidential_only: false, issue_types: nil)
       finder_params = { group_id: group.id, state: 'opened' }
@@ -11,7 +13,7 @@ module Groups
       finder_params[:issue_types] = issue_types if issue_types.present?
 
       finder_class =
-        if group.namespace_work_items_enabled?(current_user)
+        if group.namespace_work_items_enabled?
           finder_params[:include_descendants] = true
           WorkItems::WorkItemsFinder
         else
@@ -19,11 +21,14 @@ module Groups
           IssuesFinder
         end
 
-      finder_class.new(current_user, finder_params)
-                  .execute
-                  .preload(project: :namespace)
-                  .with_work_item_type
-                  .select(:iid, :title, :project_id, :namespace_id, 'work_item_types.icon_name')
+      relation = finder_class.new(current_user, finder_params).execute
+
+      relation = relation.gfm_autocomplete_search(params[:search]).limit(SEARCH_LIMIT) if params[:search]
+
+      relation
+        .preload(project: :namespace)
+        .with_work_item_type
+        .select(:iid, :title, :project_id, :namespace_id, 'work_item_types.icon_name')
     end
     # rubocop: enable CodeReuse/ActiveRecord
 
