@@ -3,9 +3,18 @@
 module Groups
   # Service class for counting and caching the number of open issues of a group.
   class OpenIssuesCountService < Groups::CountService
+    extend ::Gitlab::Utils::Override
+
     PUBLIC_COUNT_KEY = 'group_public_open_issues_count'
     TOTAL_COUNT_KEY = 'group_total_open_issues_count'
 
+    override :initialize
+    def initialize(*args, fast_timeout: false)
+      super(*args)
+
+      @fast_timeout = fast_timeout
+    end
+
     def clear_all_cache_keys
       [cache_key(PUBLIC_COUNT_KEY), cache_key(TOTAL_COUNT_KEY)].each do |key|
         Rails.cache.delete(key)
@@ -14,6 +23,15 @@ module Groups
 
     private
 
+    override :uncached_count
+    def uncached_count
+      return super unless @fast_timeout
+
+      ApplicationRecord.with_fast_read_statement_timeout do # rubocop:disable Performance/ActiveRecordSubtransactionMethods -- this is called outside a transaction
+        super
+      end
+    end
+
     def cache_key_name
       public_only? ? PUBLIC_COUNT_KEY : TOTAL_COUNT_KEY
     end
