@@ -10,9 +10,21 @@ module Import
 
       def execute
         return error_invalid_permissions unless current_user.can?(:admin_import_source_user, import_source_user)
-        return error_invalid_status unless import_source_user.cancelable_status?
 
-        if cancel_reassignment
+        invalid_status = false
+        cancel_successful = false
+
+        import_source_user.with_lock do
+          if import_source_user.cancelable_status?
+            cancel_successful = cancel_reassignment
+          else
+            invalid_status = true
+          end
+        end
+
+        return error_invalid_status if invalid_status
+
+        if cancel_successful
           ServiceResponse.success(payload: import_source_user)
         else
           ServiceResponse.error(payload: import_source_user, message: import_source_user.errors.full_messages)
