@@ -15,9 +15,11 @@ module Issuable
       def after_initialize; end
       def before_create; end
       def before_update; end
+      def after_create; end
+      def after_update; end
+      def after_save; end
       def after_update_commit; end
       def after_save_commit; end
-      def after_save; end
 
       private
 
