@@ -13,5 +13,9 @@ module Keys
     def notification_service
       NotificationService.new
     end
+
+    def todo_service
+      TodoService.new
+    end
   end
 end
