@@ -15,8 +15,10 @@ module Keys
       return unless allowed?
 
       if expiring_soon
+        create_expiring_soon_todos
         trigger_expiring_soon_notification
       else
+        create_expired_todos
         trigger_expired_notification
       end
     end
@@ -38,5 +40,13 @@ module Keys
 
       keys.update_all(expiry_notification_delivered_at: Time.current.utc)
     end
+
+    def create_expiring_soon_todos
+      todo_service.ssh_key_expiring_soon(keys)
+    end
+
+    def create_expired_todos
+      todo_service.ssh_key_expired(keys)
+    end
   end
 end
