@@ -24,11 +24,13 @@ module Lfs
       if lock.can_be_unlocked_by?(current_user, forced)
         lock.destroy!
 
+        project.refresh_lfs_file_locks_changed_epoch
+
         success(lock: lock, http_status: :ok)
       elsif forced
         error(_('You must have maintainer access to force delete a lock'), 403)
       else
-        error(_("%{lock_path} is locked by GitLab User %{lock_user_id}") % { lock_path: lock.path, lock_user_id: lock.user_id }, 403)
+        error(format(_("'%{lock_path}' is locked by @%{lock_user_name}"), lock_path: lock.path, lock_user_name: lock.user.username), 403)
       end
     end
 
