@@ -81,13 +81,13 @@ module MergeRequests
       notification_service.async.changed_reviewer_of_merge_request(merge_request, current_user, old_reviewers)
       todo_service.reassigned_reviewable(merge_request, current_user, old_reviewers)
       invalidate_cache_counts(merge_request, users: affected_reviewers.compact)
+      invalidate_cache_counts(merge_request, users: merge_request.assignees)
 
       new_reviewers = merge_request.reviewers - old_reviewers
       merge_request_activity_counter.track_users_review_requested(users: new_reviewers)
       merge_request_activity_counter.track_reviewers_changed_action(user: current_user)
       trigger_merge_request_reviewers_updated(merge_request)
 
-      capture_suggested_reviewers_accepted(merge_request)
       set_first_reviewer_assigned_at_metrics(merge_request) if new_reviewers.any?
     end
 
@@ -275,10 +275,6 @@ module MergeRequests
       GraphqlTriggers.merge_request_approval_state_updated(merge_request)
     end
 
-    def capture_suggested_reviewers_accepted(merge_request)
-      # Implemented in EE
-    end
-
     def set_first_reviewer_assigned_at_metrics(merge_request)
       metrics = merge_request.metrics
       return unless metrics
