@@ -39,6 +39,11 @@ module MergeRequests
           .success(payload: default_payload(args))
       end
 
+      def checking(**args)
+        Gitlab::MergeRequests::Mergeability::CheckResult
+          .checking(payload: default_payload(args))
+      end
+
       def failure(**args)
         Gitlab::MergeRequests::Mergeability::CheckResult
           .failed(payload: default_payload(args))
