@@ -15,6 +15,11 @@ module MergeRequests
         merge_request.title = merge_request.draft_title
       end
 
+      if params.key?(:merge_after)
+        merge_after = params.delete(:merge_after)
+        UpdateMergeScheduleService.new(merge_request, merge_after: merge_after).execute
+      end
+
       update_merge_request_with_specialized_service(merge_request) || general_fallback(merge_request)
     end
 
@@ -69,15 +74,51 @@ module MergeRequests
       MergeRequests::CloseService
     end
 
-    def after_update(issuable, old_associations)
+    def after_update(merge_request, old_associations)
       super
-      issuable.cache_merge_request_closes_issues!(current_user)
+
+      merge_request.cache_merge_request_closes_issues!(current_user) unless merge_request.auto_merge_enabled?
+      @trigger_work_item_updated = true
     end
 
     private
 
     attr_reader :target_branch_was_deleted
 
+    def trigger_updated_work_item_on_closing_issues(merge_request, old_closing_issues_ids)
+      new_issue_ids = merge_request.merge_requests_closing_issues.limit(1000).pluck(:issue_id) # rubocop:disable CodeReuse/ActiveRecord -- Implementation would be the same in the model
+      all_issue_ids = new_issue_ids | old_closing_issues_ids
+      return if all_issue_ids.blank?
+
+      WorkItem.id_in(all_issue_ids).find_each(batch_size: 100) do |work_item| # rubocop:disable CodeReuse/ActiveRecord -- Implementation would be the same in the model
+        GraphqlTriggers.work_item_updated(work_item)
+      end
+    end
+
+    override :associations_before_update
+    def associations_before_update(merge_request)
+      super.merge(
+        closing_issues_ids: merge_request.merge_requests_closing_issues.limit(1000).pluck(:issue_id) # rubocop:disable CodeReuse/ActiveRecord -- Implementation would be the same in the model
+      )
+    end
+
+    override :change_state
+    def change_state(merge_request)
+      return unless super
+
+      @trigger_work_item_updated = true
+    end
+
+    override :trigger_update_subscriptions
+    def trigger_update_subscriptions(merge_request, old_associations)
+      return unless @trigger_work_item_updated
+
+      trigger_updated_work_item_on_closing_issues(
+        merge_request,
+        old_associations.fetch(:closing_issues_ids, [])
+      )
+    end
+
     def general_fallback(merge_request)
       # We don't allow change of source/target projects and source branch
       # after merge request was created
