@@ -12,15 +12,10 @@ module Milestones
         Milestones::CloseService.new(parent, current_user, {}).execute(milestone)
       end
 
-      if params.present?
-        milestone.assign_attributes(params.except(:state_event))
-      end
+      milestone.assign_attributes(params.except(:state_event)) if params.present?
+      before_update(milestone) if milestone.changed?
+      publish_event(milestone) if milestone.save
 
-      if milestone.changed?
-        before_update(milestone)
-      end
-
-      milestone.save
       milestone
     end
 
@@ -29,6 +24,17 @@ module Milestones
     def before_update(milestone)
       milestone.check_for_spam(user: current_user, action: :update)
     end
+
+    def publish_event(milestone)
+      Gitlab::EventStore.publish(
+        Milestones::MilestoneUpdatedEvent.new(data: {
+          id: milestone.id,
+          group_id: milestone.group_id,
+          project_id: milestone.project_id,
+          updated_attributes: milestone.previous_changes&.keys&.map(&:to_s)
+        }.tap(&:compact_blank!))
+      )
+    end
   end
 end
 
