@@ -2,21 +2,18 @@
 
 module Notes
   class BuildService < ::BaseService
-    def execute
+    def execute(executing_user: nil)
       in_reply_to_discussion_id = params.delete(:in_reply_to_discussion_id)
-      external_author = params.delete(:external_author)
+      handle_external_author
+
+      executing_user ||= current_user
 
       discussion = nil
 
-      if external_author.present?
-        note_metadata = Notes::NoteMetadata.new(email_participant: external_author)
-        params[:note_metadata] = note_metadata
-      end
-
       if in_reply_to_discussion_id.present?
         discussion = find_discussion(in_reply_to_discussion_id)
 
-        return discussion_not_found unless discussion && can?(current_user, :create_note, discussion.noteable)
+        return discussion_not_found unless discussion && can?(executing_user, :create_note, discussion.noteable)
 
         discussion = discussion.convert_to_discussion! if discussion.can_convert_to_discussion?
 
@@ -27,6 +24,23 @@ module Notes
         params.merge!(reply_attributes)
       end
 
+      handle_confidentiality_params
+
+      new_note(params, discussion)
+    end
+
+    private
+
+    def handle_external_author
+      external_author = params.delete(:external_author)
+
+      return unless external_author.present?
+
+      note_metadata = Notes::NoteMetadata.new(email_participant: external_author)
+      params[:note_metadata] = note_metadata
+    end
+
+    def handle_confidentiality_params
       # The `confidential` param for notes is deprecated with 15.3
       # and renamed to `internal`.
       # We still accept `confidential` until the param gets removed from the API.
@@ -34,12 +48,8 @@ module Notes
       # the parameter. Issue: https://gitlab.com/gitlab-org/gitlab/-/issues/367923.
       params[:confidential] = params[:internal] || params[:confidential]
       params.delete(:internal)
-
-      new_note(params, discussion)
     end
 
-    private
-
     def new_note(params, discussion)
       note = Note.new(params)
       note.project = project
