@@ -75,7 +75,7 @@ class NotificationService
     end
   end
 
-  def bot_resource_access_token_about_to_expire(bot_user, token_name)
+  def bot_resource_access_token_about_to_expire(bot_user, token_name, params = {})
     recipients = bot_user.resource_bot_owners_and_maintainers.select { |user| user.can?(:receive_notifications) }
     resource = bot_user.resource_bot_resource
 
@@ -85,7 +85,8 @@ class NotificationService
       mailer.bot_resource_access_token_about_to_expire_email(
         recipient,
         resource,
-        token_name
+        token_name,
+        params
       ).deliver_later
     end
   end
@@ -99,12 +100,12 @@ class NotificationService
 
   # Notify the owner of the personal access token, when it is about to expire
   # And mark the token with about_to_expire_delivered
-  def access_token_about_to_expire(user, token_names)
+  def access_token_about_to_expire(user, token_names, params = {})
     return unless user.can?(:receive_notifications)
 
     log_info("Notifying User about expiring tokens", user)
 
-    mailer.access_token_about_to_expire_email(user, token_names).deliver_later
+    mailer.access_token_about_to_expire_email(user, token_names, params).deliver_later
   end
 
   # Notify the user when at least one of their personal access tokens has expired today
@@ -137,10 +138,10 @@ class NotificationService
 
   # Notify a user when a previously unknown IP or device is used to
   # sign in to their account
-  def unknown_sign_in(user, ip, time)
+  def unknown_sign_in(user, ip, time, request_info)
     return unless user.can?(:receive_notifications)
 
-    mailer.unknown_sign_in_email(user, ip, time).deliver_later
+    mailer.unknown_sign_in_email(user, ip, time, country: request_info.country, city: request_info.city).deliver_later
   end
 
   # Notify a user when a wrong 2FA OTP has been entered to
@@ -512,12 +513,6 @@ class NotificationService
     recipients.each { |recipient| deliver_access_request_email(recipient, member) }
   end
 
-  def decline_access_request(member)
-    return true unless member.notifiable?(:subscription)
-
-    mailer.member_access_denied_email(member.real_source_type, member.source_id, member.user_id).deliver_later
-  end
-
   def decline_invite(member)
     # Must always send, regardless of project/namespace configuration since it's a
     # response to the user's action.
@@ -568,10 +563,6 @@ class NotificationService
     mailer.member_about_to_expire_email(member.real_source_type, member.id).deliver_later
   end
 
-  def invite_member_reminder(group_member, token, reminder_index)
-    mailer.member_invited_reminder_email(group_member.real_source_type, group_member.id, token, reminder_index).deliver_later
-  end
-
   def project_was_moved(project, old_path_with_namespace)
     recipients = project_moved_recipients(project)
     recipients = notifiable_users(recipients, :custom, custom_action: :moved_project, project: project)
@@ -704,6 +695,18 @@ class NotificationService
     mailer.send(:repository_cleanup_failure_email, project, user, error).deliver_later
   end
 
+  def repository_rewrite_history_success(project, user)
+    return if project.emails_disabled?
+
+    mailer.repository_rewrite_history_success_email(project, user).deliver_later
+  end
+
+  def repository_rewrite_history_failure(project, user, error)
+    return if project.emails_disabled?
+
+    mailer.repository_rewrite_history_failure_email(project, user, error).deliver_later
+  end
+
   def remote_mirror_update_failed(remote_mirror)
     recipients = project_maintainers_recipients(remote_mirror, action: 'update_failed')
 
