@@ -6,7 +6,7 @@ module Packages
       include ActiveRecord::Sanitization::ClassMethods
 
       WILDCARD = '*'
-      RECIPE_SEPARATOR = '@'
+      SLASH = '/'
 
       def execute
         ServiceResponse.success(payload: { results: search_results })
@@ -17,8 +17,6 @@ module Packages
       def search_results
         return [] if wildcard_query?
 
-        return search_for_single_package(sanitized_query) if params[:query].include?(RECIPE_SEPARATOR)
-
         search_packages
       end
 
@@ -30,12 +28,6 @@ module Packages
         @sanitized_query ||= sanitize_sql_like(params[:query].delete(WILDCARD))
       end
 
-      def search_for_single_package(query)
-        ::Packages::Conan::SinglePackageSearchService
-          .new(query, current_user)
-          .execute[:results]
-      end
-
       def search_packages
         ::Packages::Conan::PackageFinder
           .new(current_user, { query: build_query }, project: project)
@@ -44,7 +36,7 @@ module Packages
       end
 
       def build_query
-        return "#{sanitized_query}%" if params[:query].end_with?(WILDCARD)
+        return "#{sanitized_query}%" if params[:query].end_with?(WILDCARD) && !sanitized_query.end_with?(SLASH)
 
         sanitized_query
       end
