@@ -25,7 +25,10 @@ module PagesDomains
       )
 
       challenge.request_validation
-      saved_order
+
+      ServiceResponse.success(payload: { acme_order: saved_order })
+    rescue Acme::Client::Error => e
+      ServiceResponse.error(message: e.message, payload: { acme_order: saved_order })
     end
   end
 end
