@@ -5,9 +5,14 @@ module Projects
     include LabelsAsHash
     include Routing::WikiHelper
 
+    SEARCH_LIMIT = 5
+
     def issues
-      IssuesFinder.new(current_user, project_id: project.id, state: 'opened')
-        .execute
+      relation = IssuesFinder.new(current_user, project_id: project.id, state: 'opened').execute
+
+      relation = relation.gfm_autocomplete_search(params[:search]).limit(SEARCH_LIMIT) if params[:search]
+
+      relation
         .with_work_item_type
         .select([:iid, :title, 'work_item_types.icon_name'])
     end
