@@ -65,18 +65,26 @@ module Projects
     end
 
     def push_access_level
-      if default_branch_protection.developer_can_push?
+      if default_branch_protection.no_one_can_push?
+        Gitlab::Access::NO_ACCESS
+      elsif default_branch_protection.developer_can_push?
         Gitlab::Access::DEVELOPER
-      else
+      elsif default_branch_protection.maintainer_can_push?
         Gitlab::Access::MAINTAINER
+      else
+        Gitlab::Access::ADMIN
       end
     end
 
     def merge_access_level
-      if default_branch_protection.developer_can_merge?
+      if default_branch_protection.no_one_can_merge?
+        Gitlab::Access::NO_ACCESS
+      elsif default_branch_protection.developer_can_merge?
         Gitlab::Access::DEVELOPER
-      else
+      elsif default_branch_protection.maintainer_can_merge?
         Gitlab::Access::MAINTAINER
+      else
+        Gitlab::Access::ADMIN
       end
     end
   end
