@@ -2,21 +2,17 @@
 
 module Tags
   class DestroyService < BaseService
-    def execute(tag_name)
+    def execute(tag_name, skip_find: false)
       repository = project.repository
-      tag = repository.find_tag(tag_name)
 
-      unless tag
-        return error('No such tag', 404)
-      end
+      # If we've found the tag upstream we don't need to refind it so we can
+      # pass skip_find: true
+      return error('No such tag', 404) unless skip_find || tag_exists?(tag_name)
 
       if repository.rm_tag(current_user, tag_name)
-        ##
-        # When a tag in a repository is destroyed,
-        # release assets will be destroyed too.
-        Releases::DestroyService
-          .new(project, current_user, tag: tag_name)
-          .execute
+        # When a tag in a repository is destroyed, release assets will be
+        # destroyed too.
+        destroy_releases(tag_name)
 
         unlock_artifacts(tag_name)
 
@@ -38,6 +34,14 @@ module Tags
 
     private
 
+    def tag_exists?(tag_name)
+      repository.find_tag(tag_name)
+    end
+
+    def destroy_releases(tag_name)
+      Releases::DestroyService.new(project, current_user, tag: tag_name).execute
+    end
+
     def unlock_artifacts(tag_name)
       Ci::RefDeleteUnlockArtifactsWorker.perform_async(project.id, current_user.id, "#{::Gitlab::Git::TAG_REF_PREFIX}#{tag_name}")
     end
