@@ -7,7 +7,12 @@ module Users
     private
 
     def update_user(user)
-      user.ban
+      if user.ban
+        ban_duplicate_users(user)
+        true
+      else
+        false
+      end
     end
 
     def valid_state?(user)
@@ -17,6 +22,10 @@ module Users
     def action
       :ban
     end
+
+    def ban_duplicate_users(user)
+      AntiAbuse::BanDuplicateUsersWorker.perform_async(user.id)
+    end
   end
 end
 
