@@ -13,9 +13,7 @@ module Users
       user = build_class.new(current_user, params).execute
       reset_token = user.generate_reset_token if user.recently_sent_password_reset?
 
-      Namespace.with_disabled_organization_validation do
-        after_create_hook(user, reset_token) if user.save
-      end
+      after_create_hook(user, reset_token) if user.save
 
       user
     end
