@@ -16,13 +16,8 @@ module WebHooks
     def execute(web_hook)
       return error(DENIED, 401) unless authorized?(web_hook)
 
-      hook_id = web_hook.id
-
       if web_hook.destroy
-        WebHooks::LogDestroyWorker.perform_async({ 'hook_id' => hook_id })
-        Gitlab::AppLogger.info(log_message(web_hook))
-
-        success({ async: false })
+        after_destroy(web_hook)
       else
         error("Unable to destroy #{web_hook.model_name.human}", 500)
       end
@@ -30,12 +25,21 @@ module WebHooks
 
     private
 
+    def after_destroy(web_hook)
+      WebHooks::LogDestroyWorker.perform_async({ 'hook_id' => web_hook.id })
+      Gitlab::AppLogger.info(log_message(web_hook))
+
+      success({ async: false })
+    end
+
     def log_message(hook)
       "User #{current_user&.id} scheduled a deletion of logs for hook ID #{hook.id}"
     end
 
     def authorized?(web_hook)
-      Ability.allowed?(current_user, :destroy_web_hook, web_hook)
+      Ability.allowed?(current_user, :admin_web_hook, web_hook)
     end
   end
 end
+
+WebHooks::DestroyService.prepend_mod_with('WebHooks::DestroyService')
