@@ -6,9 +6,8 @@ module WorkItems
       alias_method :work_item, :issuable
 
       def raise_error(message)
-        raise ::WorkItems::Widgets::BaseService::WidgetError, message
+        raise Error, message
       end
     end
   end
 end
-WorkItems::Callbacks::Base.prepend_mod
