@@ -275,6 +275,21 @@ module ObjectStorage
       def file_path
         @file.path
       end
+
+      # CarrierWave#cache! calls filename, which calls original_filename
+      def original_filename
+        return File.basename(file_path) if file_path.present?
+
+        nil
+      end
+    end
+
+    def proxy_download_enabled?
+      self.class.proxy_download_enabled?
+    end
+
+    def direct_download_enabled?
+      self.class.direct_download_enabled?
     end
 
     # allow to configure and overwrite the filename
@@ -302,6 +317,7 @@ module ObjectStorage
     # rubocop:disable Gitlab/ModuleWithInstanceVariables
     def object_store=(value)
       @object_store = value || Store::LOCAL
+      model[store_serialization_column] = @object_store if sync_model_object_store? && persist_object_store?
       @storage = storage_for(object_store)
     end
     # rubocop:enable Gitlab/ModuleWithInstanceVariables
@@ -489,7 +505,7 @@ module ObjectStorage
       # instead of using custom upload directory,
       # using tmp/cache makes this implementation way easier than it is today
       CarrierWave::Storage::Fog::File.new(self, storage_for(Store::REMOTE), file_path).tap do |file|
-        raise RemoteStoreError, 'Missing file' unless file.exists?
+        raise RemoteStoreError, 'Missing file' if check_remote_file_existence_on_upload? && !file.exists?
 
         # Remote stored file, we force to store on remote storage
         self.object_store = Store::REMOTE
