@@ -3,6 +3,7 @@
 module VirtualRegistries
   class CachedResponseUploader < GitlabUploader
     include ObjectStorage::Concern
+    extend ::Gitlab::Utils::Override
 
     storage_location :dependency_proxy
 
@@ -10,10 +11,22 @@ module VirtualRegistries
 
     before :cache, :set_content_type
 
+    delegate :filename, to: :model
+
     def store_dir
       dynamic_segment
     end
 
+    override :check_remote_file_existence_on_upload?
+    def check_remote_file_existence_on_upload?
+      false
+    end
+
+    override :sync_model_object_store?
+    def sync_model_object_store?
+      true
+    end
+
     private
 
     def set_content_type(file)
