@@ -8,7 +8,7 @@ module Analytics
       extend ::Gitlab::Utils::Override
       include ApplicationWorker
 
-      data_consistency :always
+      data_consistency :sticky
 
       sidekiq_options retry: 3
 
