@@ -4,10 +4,10 @@ module AuthorizedProjectUpdate
   class ProjectRecalculateWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :always # rubocop:disable SidekiqLoadBalancing/WorkerDataConsistency -- will change to sticky with feature-flag
     include Gitlab::ExclusiveLeaseHelpers
 
-    feature_category :system_access
+    feature_category :permissions
     urgency :high
     queue_namespace :authorized_project_update
 
