@@ -2,10 +2,8 @@
 
 module AuthorizedProjectUpdate
   class UserRefreshWithLowUrgencyWorker < ::AuthorizedProjectsWorker
-    feature_category :system_access
     urgency :low
     queue_namespace :authorized_project_update
-    deduplicate :until_executing, including_scheduled: true
 
     idempotent!
   end
