@@ -4,7 +4,7 @@ module AutoDevops
   class DisableWorker # rubocop:disable Scalability/IdempotentWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :sticky
 
     sidekiq_options retry: 3
     include AutoDevopsQueue
