@@ -5,6 +5,7 @@ module BulkImports
     include ApplicationWorker
     include ExclusiveLeaseGuard
     include Gitlab::Utils::StrongMemoize
+    include Sidekiq::InterruptionsExhausted
 
     FILE_EXTRACTION_PIPELINE_PERFORM_DELAY = 10.seconds
 
@@ -12,9 +13,10 @@ module BulkImports
 
     DEFER_ON_HEALTH_DELAY = 5.minutes
 
-    data_consistency :always
+    data_consistency :sticky
     feature_category :importers
     sidekiq_options dead: false, retry: 6
+    sidekiq_options max_retries_after_interruption: 20
     worker_has_external_dependencies!
     deduplicate :until_executing
     worker_resource_boundary :memory
@@ -22,8 +24,12 @@ module BulkImports
 
     version 2
 
-    sidekiq_retries_exhausted do |msg, exception|
-      new.perform_failure(msg['args'][0], msg['args'][2], exception)
+    sidekiq_retries_exhausted do |job, exception|
+      new.perform_failure(job['args'][0], job['args'][2], exception)
+    end
+
+    sidekiq_interruptions_exhausted do |job|
+      new.perform_failure(job['args'][0], job['args'][2], Import::Exceptions::SidekiqExhaustedInterruptionsError.new)
     end
 
     defer_on_database_health_signal(:gitlab_main, [], DEFER_ON_HEALTH_DELAY) do |job_args, schema, tables|
