@@ -3,13 +3,13 @@
 module ConcurrencyLimit
   class ResumeWorker
     include ApplicationWorker
+    include Search::Worker
     include CronjobQueue # rubocop:disable Scalability/CronWorkerContext -- There is no onward scheduling and this cron handles work from across the
     # application, so there's no useful context to add.
 
-    DEFAULT_LIMIT = 1_000
+    BATCH_SIZE = 1_000
     RESCHEDULE_DELAY = 1.second
 
-    feature_category :global_search
     data_consistency :sticky
     idempotent!
     urgency :low
@@ -18,24 +18,30 @@ module ConcurrencyLimit
       reschedule_job = false
 
       workers.each do |worker|
-        limit = ::Gitlab::SidekiqMiddleware::ConcurrencyLimit::WorkersMap.limit_for(worker: worker)&.call
+        limit = ::Gitlab::SidekiqMiddleware::ConcurrencyLimit::WorkersMap.limit_for(worker: worker)
         queue_size = queue_size(worker)
         report_prometheus_metrics(worker, queue_size, limit)
 
         next unless queue_size > 0
+        next if limit < 0 # do not re-queue jobs if circuit-broken
+
+        current = concurrent_worker_count(worker)
+        Gitlab::SidekiqLogging::ConcurrencyLimitLogger.instance.worker_stats_log(
+          worker.name, limit, queue_size, current
+        )
 
         reschedule_job = true
 
-        processing_limit = if limit
-                             current = current_concurrency(worker: worker)
+        processing_limit = if limit > 0
                              limit - current
                            else
-                             DEFAULT_LIMIT
+                             BATCH_SIZE
                            end
 
         next unless processing_limit > 0
 
         resume_processing!(worker, limit: processing_limit)
+        cleanup_stale_trackers(worker)
       end
 
       self.class.perform_in(RESCHEDULE_DELAY) if reschedule_job
@@ -43,18 +49,18 @@ module ConcurrencyLimit
 
     private
 
-    def current_concurrency(worker:)
-      @current_concurrency ||= ::Gitlab::SidekiqMiddleware::ConcurrencyLimit::WorkersConcurrency.workers(
-        skip_cache: true
-      )
-
-      @current_concurrency[worker.name].to_i
+    def concurrent_worker_count(worker)
+      Gitlab::SidekiqMiddleware::ConcurrencyLimit::ConcurrencyLimitService.concurrent_worker_count(worker.name)
     end
 
     def queue_size(worker)
       Gitlab::SidekiqMiddleware::ConcurrencyLimit::ConcurrencyLimitService.queue_size(worker.name)
     end
 
+    def cleanup_stale_trackers(worker)
+      Gitlab::SidekiqMiddleware::ConcurrencyLimit::ConcurrencyLimitService.cleanup_stale_trackers(worker.name)
+    end
+
     def resume_processing!(worker, limit:)
       Gitlab::SidekiqMiddleware::ConcurrencyLimit::ConcurrencyLimitService.resume_processing!(worker.name, limit: limit)
     end
@@ -73,7 +79,7 @@ module ConcurrencyLimit
       limit_metric = Gitlab::Metrics.gauge(:sidekiq_concurrency_limit_max_concurrent_jobs,
         'Max number of concurrent running jobs.',
         {})
-      limit_metric.set({ worker: worker.name }, limit || DEFAULT_LIMIT)
+      limit_metric.set({ worker: worker.name }, limit || BATCH_SIZE)
     end
   end
 end
