@@ -3,7 +3,7 @@
 class CreatePipelineWorker # rubocop:disable Scalability/IdempotentWorker
   include ApplicationWorker
 
-  data_consistency :always
+  data_consistency :sticky
 
   sidekiq_options retry: 3
   include PipelineQueue
