@@ -6,9 +6,7 @@ module DependencyProxy
     include ::Packages::CleanupArtifactWorker
     include Gitlab::Utils::StrongMemoize
 
-    data_consistency :always
-
-    sidekiq_options retry: 3
+    data_consistency :sticky
 
     queue_namespace :dependency_proxy_manifest
     feature_category :virtual_registry
