@@ -4,7 +4,7 @@ module Integrations
   class ExecuteWorker # rubocop:disable Scalability/IdempotentWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :delayed
     sidekiq_options retry: 3
     sidekiq_options dead: false
     feature_category :integrations
