@@ -22,7 +22,8 @@ module LooseForeignKeys
       in_lock(self.class.name.underscore, ttl: lock_ttl, retries: 0) do
         stats = ProcessDeletedRecordsService.new(
           connection: base_model.connection,
-          modification_tracker: modification_tracker
+          modification_tracker: modification_tracker,
+          logger: Sidekiq.logger
         ).execute
         stats[:connection] = connection_name
         stats[:turbo_mode] = turbo_mode
