@@ -13,9 +13,15 @@ module MailScheduler
 
     # rubocop: disable CodeReuse/ActiveRecord
     def perform(project_id)
-      Issue.opened.due_tomorrow.in_projects(project_id).preload(:project).find_each do |issue|
-        notification_service.issue_due(issue)
-      end
+      Issue
+        .with_issue_type(:issue)
+        .opened
+        .due_tomorrow
+        .in_projects(project_id)
+        .preload(:project)
+        .find_each do |issue|
+          notification_service.issue_due(issue)
+        end
     end
     # rubocop: enable CodeReuse/ActiveRecord
   end
