@@ -6,7 +6,7 @@ module Packages
     include ::Packages::CleanupArtifactWorker
     include Gitlab::Utils::StrongMemoize
 
-    data_consistency :always
+    data_consistency :sticky
     queue_namespace :package_cleanup
     feature_category :package_registry
     urgency :low
@@ -21,6 +21,9 @@ module Packages
 
     def after_destroy
       pkg = artifact.package
+      # Ml::ModelVersion need the package to be able to upload files later
+      # Issue https://gitlab.com/gitlab-org/gitlab/-/issues/461322
+      return if pkg.ml_model?
 
       pkg.transaction do
         pkg.destroy if model.for_package_ids(pkg.id).empty?
