@@ -27,6 +27,7 @@ module Projects
 
         extract_import_file
         process_import
+        perform_post_import_tasks
 
         tracker.finish!
       rescue StandardError => error
@@ -99,6 +100,10 @@ module Projects
           importable: project
         )
       end
+
+      def perform_post_import_tasks
+        project.reset_counters_and_iids
+      end
     end
   end
 end
