@@ -3,7 +3,7 @@
 class PruneOldEventsWorker # rubocop:disable Scalability/IdempotentWorker
   include ApplicationWorker
 
-  data_consistency :always
+  data_consistency :sticky
 
   # rubocop:disable Scalability/CronWorkerContext
   # This worker does not perform work scoped to a context
