@@ -1,10 +1,9 @@
 # frozen_string_literal: true
 
-# As discussed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/148637#note_1850247875,
-# Rails 7.1 introduces enqueue_all which is not covered in this patch.
 # We deliver emails using the `deliver_later` method and it uses ActiveJob
 # under the hood, which later processes the email via the defined ActiveJob adapter's `enqueue` method.
 # For GitLab, the ActiveJob adapter is Sidekiq (in development and production environments).
+#
 # We need to set the following up to override the ActiveJob adapater
 # so as to ensure that mailer jobs are enqueued in a shard-aware manner.
 
@@ -15,8 +14,18 @@ end
 module ActiveJob
   module QueueAdapters
     module ActiveJobShardSupport
+      if ::Gitlab.next_rails?
+        def enqueue_all(jobs)
+          Gitlab::SidekiqSharding::Router.route(ActionMailer::MailDeliveryJob) do
+            super(jobs)
+          end
+        end
+      end
+
       %i[enqueue enqueue_at].each do |name|
         define_method(name) do |*args|
+          return super(*args) if ::Gitlab.next_rails?
+
           Gitlab::SidekiqSharding::Router.route(ActionMailer::MailDeliveryJob) do
             super(*args)
           end
