@@ -129,6 +129,11 @@ InitializerConnections.raise_if_new_database_connection do
         end
       end
 
+      # HTTP Router
+      # Creating a black hole for /-/http_router/version since it is taken by the
+      # cloudflare worker, see: https://gitlab.com/gitlab-org/cells/http-router/-/issues/47
+      match '/http_router/version', to: proc { [204, {}, ['']] }, via: :all
+
       # '/-/health' implemented by BasicHealthCheck middleware
       get 'liveness' => 'health#liveness'
       get 'readiness' => 'health#readiness'
@@ -145,6 +150,7 @@ InitializerConnections.raise_if_new_database_connection do
       scope :ide, as: :ide, format: false do
         get '/', to: 'ide#index'
         get '/project', to: 'ide#index'
+        # note: This path has a hardcoded reference in the FE `app/assets/javascripts/ide/constants.js`
         get '/oauth_redirect', to: 'ide#oauth_redirect'
 
         scope path: 'project/:project_id', as: :project, constraints: { project_id: Gitlab::PathRegex.full_namespace_route_regex } do
@@ -176,6 +182,7 @@ InitializerConnections.raise_if_new_database_connection do
         draw :subscription
         draw :gitlab_subscriptions
         draw :phone_verification
+        draw :arkose
 
         scope '/push_from_secondary/:geo_node_id' do
           draw :git_http
@@ -207,7 +214,7 @@ InitializerConnections.raise_if_new_database_connection do
 
       resources :sent_notifications, only: [], constraints: { id: /\h{32}/ } do
         member do
-          get :unsubscribe
+          match :unsubscribe, via: [:get, :post]
         end
       end
 
@@ -269,11 +276,14 @@ InitializerConnections.raise_if_new_database_connection do
 
     resources :groups, only: [:index, :new, :create]
 
+    get '/-/g/:id' => 'groups/redirect#redirect_from_id'
+
     draw :group
 
     resources :projects, only: [:index, :new, :create]
 
     get '/projects/:id' => 'projects/redirect#redirect_from_id'
+    get '/-/p/:id' => 'projects/redirect#redirect_from_id'
 
     draw :git_http
     draw :api
