@@ -5,6 +5,8 @@ resource :dashboard, controller: 'dashboard', only: [] do
   get :issues
   get :merge_requests
   get :activity
+  get 'merge_requests/following', to: 'dashboard#merge_requests'
+  get 'merge_requests/search', to: 'dashboard#search_merge_requests'
 
   scope module: :dashboard do
     resources :milestones, only: [:index]
@@ -15,6 +17,7 @@ resource :dashboard, controller: 'dashboard', only: [] do
 
     resources :todos, only: [:index, :destroy] do
       collection do
+        get :vue
         delete :destroy_all
         patch :bulk_restore
       end
@@ -25,12 +28,10 @@ resource :dashboard, controller: 'dashboard', only: [] do
 
     resources :projects, only: [:index] do
       collection do
-        ## TODO: Migrate this over to to: 'projects#index' as part of `:your_work_projects_vue` FF rollout
+        ## TODO: Migrate `starred` route to 'projects#index' when removing `:your_work_projects_vue` FF
         ## https://gitlab.com/gitlab-org/gitlab/-/issues/465889
         get :starred
-        get :contributed, to: 'projects#index'
-        get :personal, to: 'projects#index'
-        get :member, to: 'projects#index'
+        get :contributed, :personal, :member, :inactive, to: 'projects#index'
       end
     end
   end
