@@ -10,7 +10,7 @@ constraints(::Constraints::GroupUrlConstrainer.new) do
       # These routes are legit and the cop rule will be improved in
       # https://gitlab.com/gitlab-org/gitlab/-/issues/230703
       get :edit, as: :edit_group # rubocop:disable Cop/PutGroupRoutesUnderScope
-      get :issues, as: :issues_group_calendar, action: :issues_calendar, constraints: lambda { |req| req.format == :ics } # rubocop:disable Cop/PutGroupRoutesUnderScope
+      get :issues, as: :issues_group_calendar, action: :issues_calendar, constraints: ->(req) { req.format == :ics } # rubocop:disable Cop/PutGroupRoutesUnderScope
       get :issues, as: :issues_group # rubocop:disable Cop/PutGroupRoutesUnderScope
       get :merge_requests, as: :merge_requests_group # rubocop:disable Cop/PutGroupRoutesUnderScope
       get :projects, as: :projects_group # rubocop:disable Cop/PutGroupRoutesUnderScope
@@ -113,7 +113,11 @@ constraints(::Constraints::GroupUrlConstrainer.new) do
 
     resources :group_members, only: [:index, :update, :destroy], concerns: :access_requestable do
       post :resend_invite, on: :member
-      delete :leave, on: :collection
+
+      collection do
+        get :bulk_reassignment_file
+        delete :leave
+      end
     end
 
     resources :group_links, only: [:update, :destroy], constraints: { id: /\d+|:id/ }
