@@ -12,7 +12,11 @@ namespace :jira_connect do
   end
 
   resources :subscriptions, only: [:index, :create, :destroy]
-  resources :branches, only: [:new]
+  resources :branches, only: [:new] do
+    collection do
+      get :route
+    end
+  end
   resources :public_keys, only: :show
 
   resources :workspaces, only: [] do
