@@ -6,12 +6,19 @@
 # Don't use format parameter as file extension (old 3.0.x behavior)
 # See http://guides.rubyonrails.org/routing.html#route-globbing-and-wildcard-segments
 scope format: false do
-  get '/compare/:from...:to', to: 'compare#show', as: 'compare', constraints: { from: /.+/, to: /.+/ }
+  get '/compare/:from...:to/', to: 'compare#rapid_diffs', as: 'rapid_diffs_compare',
+    constraints: ->(params) { params[:rapid_diffs] == 'true' && params[:from] =~ /.+/ && params[:to] =~ /.+/ }
+  get '/compare/:from..:to/', to: 'compare#rapid_diffs', as: 'rapid_diffs_compare_with_two_dots',
+    constraints: ->(params) { params[:rapid_diffs] == 'true' && params[:from] =~ /.+/ && params[:to] =~ /.+/ }, defaults: { straight: "true" }
+
+  get '/compare/:from...:to/', to: 'compare#show', as: 'compare', constraints: { from: /.+/, to: /.+/ }
+  get '/compare/:from..:to/', to: 'compare#show', as: 'compare_with_two_dots', constraints: { from: /.+/, to: /.+/ }, defaults: { straight: "true" }
 
   resources :compare, only: [:index, :create] do
     collection do
       get :diff_for_path
       get :signatures
+      get :diffs_stream, to: 'compare_diffs_stream#diffs'
     end
   end
 
@@ -96,6 +103,7 @@ resources :commit, only: [:show], constraints: { id: Gitlab::Git::Commit::SHA_PA
   member do
     get :show, to: 'commit#rapid_diffs',
       constraints: ->(params) { params[:rapid_diffs] == 'true' }
+    get :diffs_stream, to: 'commit_diffs_stream#diffs'
     get :branches
     get :pipelines
     post :revert
