@@ -1,11 +1,11 @@
 def save(settings, topic)
   if settings.save
-    puts "Saved #{topic}".color(:green)
+    puts Rainbow("Saved #{topic}").green
   else
-    puts "Could not save #{topic}".color(:red)
+    puts Rainbow("Could not save #{topic}").red
     puts
     settings.errors.full_messages.map do |message|
-      puts "--> #{message}".color(:red)
+      puts Rainbow("--> #{message}").red
     end
     puts
     exit(1)
