@@ -7,7 +7,7 @@ class CreateIndexVulnerabilityProjectIdAndOnIdSync < Gitlab::Database::Migration
   disable_ddl_transaction!
 
   def up
-    add_concurrent_index :vulnerabilities, COLUMN_NAMES, name: INDEX_NAME
+    add_concurrent_index :vulnerabilities, COLUMN_NAMES, name: INDEX_NAME # rubocop:disable Migration/PreventIndexCreation -- Legacy migration
   end
 
   def down
