@@ -8,8 +8,11 @@ class UnscheduleStuckBulkImportCron < Gitlab::Database::Migration[2.2]
     # This is to clean up the cron schedule for BulkImports::StuckImportWorker
     # which was removed in
     # https://gitlab.com/gitlab-org/gitlab/-/merge_requests/143806
-    removed_job = Sidekiq::Cron::Job.find('bulk_imports_stuck_import_worker')
-    removed_job.destroy if removed_job
+    # TODO: make shard-aware. See https://gitlab.com/gitlab-com/gl-infra/scalability/-/issues/3430
+    Gitlab::SidekiqSharding::Validator.allow_unrouted_sidekiq_calls do
+      removed_job = Sidekiq::Cron::Job.find('bulk_imports_stuck_import_worker')
+      removed_job.destroy if removed_job
+    end
 
     sidekiq_remove_jobs(job_klasses: %w[BulkImports::StuckImportWorker])
   end
