@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 class BackfillVulnerabilityOccurrencePipelinesPipelineIdBigint < Gitlab::Database::Migration[2.2]
-  restrict_gitlab_migration gitlab_schema: :gitlab_main
+  restrict_gitlab_migration gitlab_schema: :gitlab_sec
   milestone '16.11'
 
   TABLE = :vulnerability_occurrence_pipelines
