@@ -10,12 +10,12 @@ class SyncIndexForPipelinesIdBigintPart5 < Gitlab::Database::Migration[2.2]
     {
       name: :p_ci_builds_project_id_bigint_name_ref_idx,
       columns: [:project_id_convert_to_bigint, :name, :ref],
-      options: { where: "type::text = 'Ci::Build'::text AND status::text = 'success'::text AND (retried = false OR retried IS NULL)" } # rubocop:disable Layout/LineLength -- it's just too long
+      options: { where: "type::text = 'Ci::Build'::text AND status::text = 'success'::text AND (retried = false OR retried IS NULL)" }
     },
     {
       name: :p_ci_builds_project_id_bigint_status_idx,
       columns: [:project_id_convert_to_bigint, :status],
-      options: { where: "type::text = 'Ci::Build'::text AND (status::text = ANY (ARRAY['running'::character varying::text, 'pending'::character varying::text, 'created'::character varying::text]))" } # rubocop:disable Layout/LineLength -- it's just too long
+      options: { where: "type::text = 'Ci::Build'::text AND (status::text = ANY (ARRAY['running'::character varying::text, 'pending'::character varying::text, 'created'::character varying::text]))" }
     },
     {
       name: :p_ci_builds_status_created_at_project_id_bigint_idx,
