@@ -2,7 +2,7 @@
 
 class QueueBackfillVulnerabilityFindingSignaturesProjectId < Gitlab::Database::Migration[2.2]
   milestone '17.2'
-  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell
+  restrict_gitlab_migration gitlab_schema: :gitlab_sec
 
   MIGRATION = "BackfillVulnerabilityFindingSignaturesProjectId"
   DELAY_INTERVAL = 2.minutes
