@@ -7,10 +7,10 @@ class PrepareIndexMergeRequestDiffFiles99208b8facOnProjectId < Gitlab::Database:
   INDEX_NAME = 'index_merge_request_diff_files_99208b8fac_on_project_id'
 
   def up
-    prepare_async_index :merge_request_diff_files_99208b8fac, :project_id, name: INDEX_NAME
+    # no-op
   end
 
   def down
-    unprepare_async_index :merge_request_diff_files_99208b8fac, INDEX_NAME
+    # no-op
   end
 end
