@@ -28,11 +28,17 @@ module CsvBuilder
   # * +collection+ - The data collection to be used
   # * +header_to_value_hash+ - A hash of 'Column Heading' => 'value_method'.
   # * +associations_to_preload+ - An array of records to preload with a batch of records.
+  # * +replace_newlines+ - default: false - If true, replaces newline characters with a literal "\n"
   #
   # The value method will be called once for each object in the collection, to
   # determine the value for that row. It can either be the name of a method on
   # the object, or a lamda to call passing in the object.
-  def self.new(collection, header_to_value_hash, associations_to_preload = [])
-    CsvBuilder::Builder.new(collection, header_to_value_hash, associations_to_preload)
+  def self.new(collection, header_to_value_hash, associations_to_preload = [], replace_newlines: false)
+    CsvBuilder::Builder.new(
+      collection,
+      header_to_value_hash,
+      associations_to_preload,
+      replace_newlines: replace_newlines
+    )
   end
 end
