@@ -13,8 +13,8 @@ module Gitlab
 
           private
 
-          def target
-            check_object_storage(::Backup::Targets::Files.new(nil, storage_path, options: options, excludes: ['tmp']))
+          def local
+            Gitlab::Backup::Cli::Targets::Files.new(context, storage_path, excludes: ['tmp'])
           end
 
           def storage_path = context.ci_secure_files_path
