@@ -13,8 +13,8 @@ module Gitlab
 
           private
 
-          def target
-            check_object_storage(::Backup::Targets::Files.new(nil, storage_path, options: options))
+          def local
+            Gitlab::Backup::Cli::Targets::Files.new(context, storage_path)
           end
 
           def storage_path = context.ci_lfs_path
