@@ -13,16 +13,22 @@ module Gitlab
 
           def destination_path = 'registry.tar.gz'
 
+          attr_reader :registry_bucket
+
+          def set_registry_bucket(registry_bucket)
+            @registry_bucket = registry_bucket
+          end
+
           def object_storage?
-            !options.container_registry_bucket.nil?
+            !registry_bucket.nil?
           end
 
           # Registry does not use consolidated object storage config.
           def config
             settings = {
               object_store: {
-                connection: Gitlab::Backup::Cli::SourceContext.new.config('object_store').connection.to_hash,
-                remote_directory: options.container_registry_bucket
+                connection: context.gitlab_config('object_store').connection.to_hash,
+                remote_directory: registry_bucket
               }
             }
             GitlabSettings::Options.build(settings)
@@ -30,8 +36,8 @@ module Gitlab
 
           private
 
-          def target
-            check_object_storage(::Backup::Targets::Files.new(nil, storage_path, options: options))
+          def local
+            Gitlab::Backup::Cli::Targets::Files.new(context, storage_path)
           end
 
           def storage_path = context.registry_path
