@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'active_support/hash_with_indifferent_access'
+require 'active_support/core_ext/hash/keys'
 require 'delegate'
 
 require_relative 'flaky_example'
