@@ -8,7 +8,7 @@ module Gitlab
       FOUND = 1 # When scan operation completes with one or more findings
       FOUND_WITH_ERRORS = 2 # When scan operation completes with one or more findings along with some errors
       SCAN_TIMEOUT = 3 # When the scan operation runs beyond given time out
-      BLOB_TIMEOUT = 4 # When the scan operation on a blob runs beyond given time out
+      PAYLOAD_TIMEOUT = 4 # When the scan operation on a diff runs beyond given time out
       SCAN_ERROR = 5 # When the scan operation fails due to regex error
       INPUT_ERROR = 6 # When the scan operation fails due to invalid input
     end
