@@ -9,6 +9,10 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
     Struct.new(:id, :data).new(id, data)
   end
 
+  let(:exclusion) do
+    Struct.new('Exclusion', :value, :keyword_init)
+  end
+
   let(:ruleset) do
     {
       "title" => "gitleaks config",
@@ -45,6 +49,8 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
     }
   end
 
+  let(:empty_applied_exclusions) { [] }
+
   it "does not raise an error parsing the toml file" do
     expect { scan }.not_to raise_error
   end
@@ -72,7 +78,11 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
       end
 
       it "does not match" do
-        expected_response = Gitlab::SecretDetection::Response.new(Gitlab::SecretDetection::Status::NOT_FOUND)
+        expected_response = Gitlab::SecretDetection::Response.new(
+          Gitlab::SecretDetection::Status::NOT_FOUND,
+          nil,
+          empty_applied_exclusions
+        )
 
         expect(scan.secrets_scan(blobs)).to eq(expected_response)
       end
@@ -161,7 +171,8 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
               ruleset['rules'][2]['id'],
               ruleset['rules'][2]['description']
             )
-          ]
+          ],
+          empty_applied_exclusions
         )
       end
 
@@ -245,7 +256,11 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
       it "whole secret detection scan operation times out" do
         scan_timeout_secs = 0.000_001 # 1 micro-sec to intentionally timeout large blob
 
-        expected_response = Gitlab::SecretDetection::Response.new(Gitlab::SecretDetection::Status::SCAN_TIMEOUT)
+        expected_response = Gitlab::SecretDetection::Response.new(
+          Gitlab::SecretDetection::Status::SCAN_TIMEOUT,
+          nil,
+          empty_applied_exclusions
+        )
 
         begin
           response = scan.secrets_scan(blobs, timeout: scan_timeout_secs)
@@ -277,9 +292,10 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
             ),
             Gitlab::SecretDetection::Finding.new(
               blobs[2].id,
-              Gitlab::SecretDetection::Status::BLOB_TIMEOUT
+              Gitlab::SecretDetection::Status::PAYLOAD_TIMEOUT
             )
-          ]
+          ],
+          empty_applied_exclusions
         )
 
         expect(scan.secrets_scan(blobs, blob_timeout: each_blob_timeout_secs)).to eq(expected_response)
@@ -294,21 +310,126 @@ RSpec.describe Gitlab::SecretDetection::Scan, feature_category: :secret_detectio
           [
             Gitlab::SecretDetection::Finding.new(
               all_large_blobs[0].id,
-              Gitlab::SecretDetection::Status::BLOB_TIMEOUT
+              Gitlab::SecretDetection::Status::PAYLOAD_TIMEOUT
             ),
             Gitlab::SecretDetection::Finding.new(
               all_large_blobs[1].id,
-              Gitlab::SecretDetection::Status::BLOB_TIMEOUT
+              Gitlab::SecretDetection::Status::PAYLOAD_TIMEOUT
             ),
             Gitlab::SecretDetection::Finding.new(
               all_large_blobs[2].id,
-              Gitlab::SecretDetection::Status::BLOB_TIMEOUT
+              Gitlab::SecretDetection::Status::PAYLOAD_TIMEOUT
             )
-          ]
+          ],
+          empty_applied_exclusions
         )
 
         expect(scan.secrets_scan(all_large_blobs, blob_timeout: each_blob_timeout_secs)).to eq(expected_response)
       end
     end
+
+    context "when using exclusions" do
+      let(:blobs) do
+        [
+          new_blob(id: 111, data: "data with no secret"),
+          new_blob(id: 222, data: "GR134894145645645645645645645"), # gitleaks:allow
+          new_blob(id: 333, data: "GR134894145645645645645645789"), # gitleaks:allow
+          new_blob(id: 444, data: "GR134894112312312312312312312"), # gitleaks:allow
+          new_blob(id: 555, data: "glpat-12312312312312312312"), # gitleaks:allow,
+          new_blob(
+            id: 666, data: "test data\nglptt-1231231231231231231212312312312312312312\nline contd" # gitleaks:allow
+          )
+        ]
+      end
+
+      context "when excluding secrets based on raw values" do
+        let(:exclusions) do
+          {
+            raw_value: [
+              exclusion.new(value: 'GR134894112312312312312312312'), # gitleaks:allow
+              exclusion.new(value: 'glpat-12312312312312312312') # gitleaks:allow
+            ]
+          }
+        end
+
+        let(:valid_lines) do
+          [
+            blobs[1].data,
+            blobs[2].data,
+            *blobs[5].data.lines
+          ]
+        end
+
+        it "excludes values from being detected" do
+          expected_scan_status = Gitlab::SecretDetection::Status::FOUND
+
+          expected_response = Gitlab::SecretDetection::Response.new(
+            expected_scan_status,
+            [
+              Gitlab::SecretDetection::Finding.new(
+                blobs[1].id,
+                expected_scan_status,
+                1,
+                ruleset['rules'][2]['id'],
+                ruleset['rules'][2]['description']
+              ),
+              Gitlab::SecretDetection::Finding.new(
+                blobs[2].id,
+                expected_scan_status,
+                1,
+                ruleset['rules'][2]['id'],
+                ruleset['rules'][2]['description']
+              ),
+              Gitlab::SecretDetection::Finding.new(
+                blobs[5].id,
+                expected_scan_status,
+                2,
+                ruleset['rules'][1]['id'],
+                ruleset['rules'][1]['description']
+              )
+            ],
+            exclusions[:raw_value]
+          )
+
+          expect(scan.secrets_scan(blobs, exclusions:)).to eq(expected_response)
+        end
+      end
+
+      context "when excluding secrets based on rules from default ruleset" do
+        let(:exclusions) do
+          {
+            rule: [
+              exclusion.new(value: "gitlab_runner_registration_token"),
+              exclusion.new(value: "gitlab_personal_access_token")
+            ]
+          }
+        end
+
+        it 'filters out secrets matching excluded rules from detected findings' do
+          expected_scan_status = Gitlab::SecretDetection::Status::FOUND
+
+          expected_response = Gitlab::SecretDetection::Response.new(
+            expected_scan_status,
+            [
+              Gitlab::SecretDetection::Finding.new(
+                blobs[5].id,
+                expected_scan_status,
+                2,
+                ruleset['rules'][1]['id'],
+                ruleset['rules'][1]['description']
+              )
+            ],
+            [
+              exclusion.new(value: "gitlab_runner_registration_token"),
+              exclusion.new(value: "gitlab_runner_registration_token"),
+              exclusion.new(value: "gitlab_runner_registration_token"),
+              exclusion.new(value: "gitlab_personal_access_token")
+            ]
+          )
+
+          expect(scan.secrets_scan(blobs, exclusions:)).to eq(expected_response)
+        end
+      end
+    end
   end
 end
