@@ -21,7 +21,7 @@ module API
           optional :type, type: String, values: ::Ci::Runner::AVAILABLE_TYPES, desc: 'The type of runners to return'
           optional :paused, type: Boolean,
             desc: 'Whether to include only runners that are accepting or ignoring new jobs'
-          optional :status, type: String, values: ::Ci::Runner::AVAILABLE_STATUSES,
+          optional :status, type: String, values: ::Ci::Runner::AVAILABLE_STATUSES_INCL_DEPRECATED,
             desc: 'The status of runners to return'
           optional :tag_list, type: Array[String], coerce_with: ::API::Validations::Types::CommaSeparatedToArray.coerce,
             desc: 'A list of runner tags', documentation: { example: "['macos', 'shell']" }
@@ -48,7 +48,7 @@ module API
 
         def apply_filter(runners, params)
           runners = filter_runners(runners, params[:type], allowed_scopes: ::Ci::Runner::AVAILABLE_TYPES)
-          runners = filter_runners(runners, params[:status], allowed_scopes: ::Ci::Runner::AVAILABLE_STATUSES)
+          runners = filter_runners(runners, params[:status], allowed_scopes: ::Ci::Runner::AVAILABLE_STATUSES_INCL_DEPRECATED)
           runners = filter_runners(runners, params[:paused] ? 'paused' : 'active', allowed_scopes: %w[paused active]) if params.include?(:paused)
           runners = runners.with_version_prefix(params[:version_prefix]) if params[:version_prefix]
           runners = runners.tagged_with(params[:tag_list]) if params[:tag_list]
@@ -122,7 +122,7 @@ module API
         end
         get do
           runners = current_user.ci_owned_runners
-          runners = filter_runners(runners, params[:scope], allowed_scopes: ::Ci::Runner::AVAILABLE_STATUSES)
+          runners = filter_runners(runners, params[:scope], allowed_scopes: ::Ci::Runner::AVAILABLE_STATUSES_INCL_DEPRECATED)
           runners = apply_filter(runners, params)
 
           present paginate(runners), with: Entities::Ci::Runner
@@ -197,10 +197,9 @@ module API
           optional :access_level, type: String, values: ::Ci::Runner.access_levels.keys,
             desc: 'The access level of the runner'
           optional :maximum_timeout, type: Integer,
-            desc: 'Maximum timeout that limits the amount of time (in seconds) ' \
-                  'that runners can run jobs'
+            desc: 'Maximum timeout that limits the amount of time (in seconds) that runners can run jobs'
           optional :maintenance_note, type: String,
-            desc: %q(Free-form maintenance notes for the runner (1024 characters))
+            desc: 'Free-form maintenance notes for the runner (1024 characters)'
           at_least_one_of :description, :active, :paused, :tag_list, :run_untagged, :locked, :access_level, :maximum_timeout, :maintenance_note
           mutually_exclusive :active, :paused
         end
@@ -208,7 +207,7 @@ module API
           runner = get_runner(params.delete(:id))
           authenticate_update_runner!(runner)
           params[:active] = !params.delete(:paused) if params.include?(:paused)
-          update_service = ::Ci::Runners::UpdateRunnerService.new(runner)
+          update_service = ::Ci::Runners::UpdateRunnerService.new(current_user, runner)
 
           if update_service.execute(declared_params(include_missing: false)).success?
             present runner, with: Entities::Ci::RunnerDetails, current_user: current_user
