@@ -47,6 +47,33 @@ module API
         with: Entities::DeployKey, include_projects_with_write_access: true, include_projects_with_readonly_access: true
     end
 
+    desc 'Create a deploy key' do
+      detail 'Create a deploy key for the GitLab instance. This endpoint requires administrator access.'
+      success Entities::DeployKey
+      failure [
+        { code: 400, message: 'Bad request' },
+        { code: 401, message: 'Unauthorized' },
+        { code: 403, message: 'Forbidden' }
+      ]
+      tags deploy_keys_tags
+    end
+    params do
+      requires :key, type: String, desc: 'New deploy key'
+      requires :title, type: String, desc: "New deploy key's title"
+      optional :expires_at, type: DateTime, desc: 'The expiration date of the SSH key in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ)'
+    end
+    post "deploy_keys" do
+      authenticated_as_admin!
+
+      deploy_key = ::DeployKeys::CreateService.new(current_user, declared_params.merge(public: true)).execute
+
+      if deploy_key.persisted?
+        present deploy_key, with: Entities::DeployKey
+      else
+        render_validation_error!(deploy_key)
+      end
+    end
+
     params do
       requires :id, types: [String, Integer], desc: 'The ID or URL-encoded path of the project owned by the authenticated user'
     end
