@@ -15,9 +15,7 @@ module API
         todo_target_class(todo.target_type).represent(todo.target, todo_options)
       end
 
-      expose :target_url do |todo, options|
-        todo_target_url(todo)
-      end
+      expose :target_url
 
       expose :body
       expose :state
@@ -30,18 +28,6 @@ module API
         ::API::Entities.const_get(target_type, false)
       end
 
-      def todo_target_url(todo)
-        return design_todo_target_url(todo) if todo.for_design?
-        return todo.access_request_url if todo.member_access_requested?
-
-        target_type = todo.target_type.gsub('::', '_').underscore
-        target_url = "#{todo.resource_parent.class.to_s.underscore}_#{target_type}_url"
-
-        Gitlab::Routing
-          .url_helpers
-          .public_send(target_url, todo.resource_parent, todo.target, anchor: todo_target_anchor(todo)) # rubocop:disable GitlabSecurity/PublicSend
-      end
-
       def todo_target_anchor(todo)
         "note_#{todo.note_id}" if todo.note_id?
       end
