@@ -23,9 +23,7 @@ module API
         wiki_page.content.encoding.name
       end
 
-      expose :front_matter, documentation: { type: 'Hash', example: { title: "deploy" } }, if: ->(wiki_page) {
-        ::Feature.enabled?(:wiki_front_matter_title, wiki_page.container)
-      }
+      expose :front_matter, documentation: { type: 'Hash', example: { title: "deploy" } }
     end
   end
 end
