@@ -25,7 +25,7 @@ module API
       route_setting :authentication, job_token_allowed: true, basic_auth_personal_access_token: true, deploy_token_allowed: true
 
       namespace ':id/packages/generic' do
-        namespace ':package_name/*package_version/:file_name', requirements: GENERIC_PACKAGES_REQUIREMENTS do
+        namespace ':package_name/*package_version/(*path/):file_name', requirements: GENERIC_PACKAGES_REQUIREMENTS do
           desc 'Workhorse authorize generic package file' do
             detail 'This feature was introduced in GitLab 13.5'
             success code: 200
@@ -68,6 +68,7 @@ module API
           params do
             requires :package_name, type: String, desc: 'Package name', regexp: Gitlab::Regex.generic_package_name_regex, file_path: true
             requires :package_version, type: String, desc: 'Package version', regexp: Gitlab::Regex.generic_package_version_regex
+            optional :path, type: String, desc: 'File directory path', file_path: true
             requires :file_name, type: String, desc: 'Package file name', regexp: Gitlab::Regex.generic_package_file_name_regex, file_path: true
             optional :status, type: String, values: ALLOWED_STATUSES, desc: 'Package status'
             requires :file, type: ::API::Validations::Types::WorkhorseFile, desc: 'The package file to be published (generated by Multipart middleware)', documentation: { type: 'file' }
@@ -83,8 +84,10 @@ module API
             bad_request!('File is too large') if max_file_size_exceeded?
 
             track_package_event('push_package', :generic, project: project, namespace: project.namespace)
-
-            create_package_file_params = declared_params.merge(build: current_authenticated_job)
+            create_package_file_params = declared_params.merge(
+              file_name: encoded_file_name,
+              build: current_authenticated_job
+            )
             package_file = ::Packages::Generic::CreatePackageFileService
               .new(project, current_user, create_package_file_params)
               .execute
@@ -116,6 +119,7 @@ module API
           params do
             requires :package_name, type: String, desc: 'Package name', regexp: Gitlab::Regex.generic_package_name_regex, file_path: true
             requires :package_version, type: String, desc: 'Package version', regexp: Gitlab::Regex.generic_package_version_regex
+            optional :path, type: String, desc: 'File directory path', file_path: true
             requires :file_name, type: String, desc: 'Package file name', regexp: Gitlab::Regex.generic_package_file_name_regex, file_path: true
           end
 
@@ -127,7 +131,7 @@ module API
             authorize_read_package!(project)
 
             package = ::Packages::Generic::PackageFinder.new(project).execute!(params[:package_name], params[:package_version])
-            package_file = ::Packages::PackageFileFinder.new(package, params[:file_name]).execute!
+            package_file = ::Packages::PackageFileFinder.new(package, encoded_file_name).execute!
 
             track_package_event('pull_package', :generic, project: project, namespace: project.namespace)
 
@@ -154,6 +158,11 @@ module API
           use_final_store_path: true
         }
       end
+
+      def encoded_file_name
+        file_name = [declared_params[:path], declared_params[:file_name]].compact.join('/')
+        declared_params[:path].present? ? URI.encode_uri_component(file_name) : file_name
+      end
     end
   end
 end
