@@ -55,7 +55,11 @@ module API
       post ':id/export' do
         check_rate_limit! :group_export, scope: current_user
 
-        export_service = ::Groups::ImportExport::ExportService.new(group: user_group, user: current_user)
+        export_service = ::Groups::ImportExport::ExportService.new(
+          group: user_group,
+          user: current_user,
+          exported_by_admin: current_user.can_admin_all_resources?
+        )
 
         if export_service.async_execute
           accepted!
