@@ -5,7 +5,10 @@ module API
     include PaginationParams
     include Helpers::CustomAttributes
 
-    before { authenticate_non_get! }
+    before do
+      authenticate_non_get!
+      set_current_organization
+    end
 
     helpers Helpers::GroupsHelpers
 
@@ -376,7 +379,7 @@ module API
         tags %w[groups]
       end
       params do
-        optional :relation, type: String, values: %w[direct inherited], desc: 'Include group relations'
+        optional :relation, type: Array[String], coerce_with: ::API::Validations::Types::CommaSeparatedToArray.coerce, values: %w[direct inherited], desc: 'Include group relations'
         optional :search, type: String, desc: 'Search for a specific group'
         optional :min_access_level, type: Integer, values: Gitlab::Access.all_values, desc: 'Minimum access level of authenticated user'
 
@@ -384,12 +387,10 @@ module API
         use :with_custom_attributes
       end
       get ":id/invited_groups", feature_category: :groups_and_projects do
-        if Feature.enabled?(:rate_limit_groups_and_projects_api, current_user)
-          check_rate_limit_by_user_or_ip!(:group_invited_groups_api)
-        end
+        check_rate_limit_by_user_or_ip!(:group_invited_groups_api)
 
         group = find_group!(params[:id])
-        groups = ::Namespaces::Groups::InvitedGroupsFinder.new(group, current_user, declared(params)).execute
+        groups = ::Namespaces::Groups::InvitedGroupsFinder.new(group, current_user, declared_params).execute
         present_groups params, groups
       end
 
@@ -622,7 +623,8 @@ The following criteria must be met:
   - Personal access token
   - Group access token
   - Project access token
-  - Group Deploy Token
+  - Group deploy token
+  - User feed token
 
 This feature is gated by the :group_agnostic_token_revocation feature flag.
         DETAIL
@@ -641,7 +643,7 @@ This feature is gated by the :group_agnostic_token_revocation feature flag.
 
         if result.success?
           status :ok
-          present result.payload[:token], with: "API::Entities::#{result.payload[:type]}".constantize
+          present result.payload[:revocable], with: "API::Entities::#{result.payload[:api_entity]}".constantize
         else
           # No matter the error, we always return a 422.
           # This prevents disclosing cases like: token is invalid,
