@@ -95,6 +95,13 @@ module API
     end
     # rubocop:enable Gitlab/ModuleWithInstanceVariables
 
+    def set_current_organization(user: current_user)
+      ::Current.organization = Gitlab::Current::Organization.new(
+        params: {},
+        user: user
+      ).organization
+    end
+
     def save_current_user_in_env(user)
       env[API_USER_ENV] = { user_id: user.id, username: user.username }
     end
@@ -148,12 +155,13 @@ module API
     def find_project!(id)
       project = find_project(id)
 
-      return forbidden! unless authorized_project_scope?(project)
+      return forbidden!("This project's CI/CD job token cannot be used to authenticate with the container registry of a different project.") unless authorized_project_scope?(project)
+      return not_found!('Project') if project.nil?
 
       unless can?(current_user, read_project_ability, project)
         return unauthorized! if authenticate_non_public?
 
-        return not_found!('Project')
+        return handle_job_token_failure!(project)
       end
 
       if project_moved?(id, project)
@@ -180,7 +188,7 @@ module API
     def find_pipeline(id)
       return unless id
 
-      if id.to_s =~ INTEGER_ID_REGEX
+      if INTEGER_ID_REGEX.match?(id.to_s)
         ::Ci::Pipeline.find_by(id: id)
       end
     end
@@ -201,7 +209,7 @@ module API
     end
 
     def find_organization!(id)
-      organization = Organizations::Organization.find_by_id(id)
+      organization = ::Organizations::Organization.find_by_id(id)
       check_organization_access(organization)
     end
 
@@ -209,7 +217,7 @@ module API
     def find_group(id, organization: nil)
       collection = organization.present? ? Group.in_organization(organization) : Group.all
 
-      if id.to_s =~ INTEGER_ID_REGEX
+      if INTEGER_ID_REGEX.match?(id.to_s)
         collection.find_by(id: id)
       else
         collection.find_by_full_path(id)
@@ -226,12 +234,10 @@ module API
       check_group_access(group)
     end
 
-    # rubocop: disable CodeReuse/ActiveRecord
     def find_group_by_full_path!(full_path)
       group = Group.find_by_full_path(full_path)
       check_group_access(group)
     end
-    # rubocop: enable CodeReuse/ActiveRecord
 
     def check_group_access(group)
       return group if can?(current_user, :read_group, group)
@@ -249,7 +255,7 @@ module API
     # find_namespace returns the namespace regardless of user access level on the namespace
     # rubocop: disable CodeReuse/ActiveRecord
     def find_namespace(id)
-      if id.to_s =~ INTEGER_ID_REGEX
+      if INTEGER_ID_REGEX.match?(id.to_s)
         Namespace.without_project_namespaces.find_by(id: id)
       else
         find_namespace_by_path(id)
@@ -576,14 +582,18 @@ module API
       render_api_error!('201 Created', 201)
     end
 
-    def accepted!
-      render_api_error!('202 Accepted', 202)
+    def accepted!(message = '202 Accepted')
+      render_api_error!(message, 202)
     end
 
-    def render_validation_error!(model, status = 400)
-      if model.errors.any?
-        render_api_error!(model_errors(model).messages || '400 Bad Request', status)
-      end
+    def render_validation_error!(models, status = 400)
+      models = Array(models)
+
+      errors = models.map { |m| model_errors(m) }.filter(&:present?)
+      messages = errors.map(&:messages)
+      messages = messages.count == 1 ? messages.first : messages.join(" ")
+
+      render_api_error!(messages || '400 Bad Request', status) if errors.any?
     end
 
     def model_errors(model)
@@ -680,24 +690,29 @@ module API
       present_carrierwave_file!(file, **args)
     end
 
-    def present_carrierwave_file!(file, supports_direct_download: true, content_disposition: nil)
+    def present_carrierwave_file!(file, supports_direct_download: true, content_disposition: nil, content_type: nil)
       return not_found! unless file&.exists?
 
+      if content_disposition
+        response_disposition = ActionDispatch::Http::ContentDisposition.format(disposition: content_disposition, filename: file.filename)
+      end
+
       if file.file_storage?
-        present_disk_file!(file.path, file.filename)
-      elsif supports_direct_download && file.class.direct_download_enabled?
+        file_content_type = content_type || 'application/octet-stream'
+        present_disk_file!(file.path, file.filename, file_content_type)
+      elsif supports_direct_download && file.direct_download_enabled?
         return redirect(ObjectStorage::S3.signed_head_url(file)) if request.head? && file.fog_credentials[:provider] == 'AWS'
 
         redirect_params = {}
         if content_disposition
-          response_disposition = ActionDispatch::Http::ContentDisposition.format(disposition: content_disposition, filename: file.filename)
-          redirect_params[:query] = { 'response-content-disposition' => response_disposition, 'response-content-type' => file.content_type }
+          redirect_params[:query] = { 'response-content-disposition' => response_disposition, 'response-content-type' => content_type || file.content_type }
         end
 
         file_url = ObjectStorage::CDN::FileUrl.new(file: file, ip_address: ip_address, redirect_params: redirect_params)
         redirect(file_url.url)
       else
-        header(*Gitlab::Workhorse.send_url(file.url))
+        response_headers = { 'Content-Type' => content_type, 'Content-Disposition' => response_disposition }.compact_blank
+        header(*Gitlab::Workhorse.send_url(file.url, response_headers: response_headers))
         status :ok
         body '' # to avoid an error from API::APIGuard::ResponseCoercerMiddleware
       end
@@ -733,7 +748,7 @@ module API
         namespace: namespace,
         project: project
       )
-    rescue Gitlab::InternalEvents::UnknownEventError => e
+    rescue Gitlab::Tracking::EventValidator::UnknownEventError => e
       Gitlab::ErrorTracking.track_exception(e, event_name: event_name)
 
       # We want to keep the error silent on production to keep the behavior
@@ -941,6 +956,17 @@ module API
         r.path_info = "/#{new_path}"
       end.url
     end
+
+    def handle_job_token_failure!(project)
+      if current_user&.from_ci_job_token? && current_user&.ci_job_token_scope
+        source_project = current_user.ci_job_token_scope.current_project
+        error_message = format("Authentication by CI/CD job token not allowed from %{source_project_path} to %{target_project_path}.", source_project_path: source_project.path, target_project_path: project.path)
+
+        forbidden!(error_message)
+      else
+        not_found!('Project')
+      end
+    end
   end
 end
 
