@@ -2,7 +2,10 @@
 
 module API
   class ImportBitbucket < ::API::Base
-    before { authenticate! }
+    before do
+      authenticate!
+      set_current_organization
+    end
 
     feature_category :importers
     urgency :low
