@@ -14,6 +14,7 @@ module API
 
         if actor.user
           load_balancer_stick_request(::User, :user, actor.user.id)
+          set_current_organization(user: actor.user)
         end
 
         Gitlab::ApplicationContext.push(
@@ -131,12 +132,19 @@ module API
         #   changes - changes as "oldrev newrev ref", see Gitlab::ChangesList
         #   check_ip - optional, only in EE version, may limit access to
         #     group resources based on its IP restrictions
+        #
+        # /internal/allowed
+        #
         post "/allowed", feature_category: :source_code_management do
           # It was moved to a separate method so that EE can alter its behaviour more
           # easily.
           check_allowed(params)
         end
 
+        # Validate LFS authentication request
+        #
+        # /internal/lfs_authenticate
+        #
         post "/lfs_authenticate", feature_category: :source_code_management, urgency: :high do
           not_found! unless container&.lfs_enabled?
 
@@ -153,9 +161,10 @@ module API
             .authentication_payload(lfs_authentication_url(container))
         end
 
-        #
         # Check whether an SSH key is known to GitLab
         #
+        # /internal/authorized_keys
+        #
         get '/authorized_keys', feature_category: :source_code_management, urgency: :high do
           fingerprint = Gitlab::InsecureKeyFingerprint.new(params.fetch(:key)).fingerprint_sha256
 
@@ -164,13 +173,16 @@ module API
           present key, with: Entities::SSHKey
         end
 
-        #
         # Discover user by ssh key, user id or username
         #
+        # /internal/discover
+        #
         get '/discover', feature_category: :system_access do
           present actor.user, with: Entities::UserSafe
         end
 
+        # /internal/check
+        #
         get '/check', feature_category: :not_owned do # rubocop:todo Gitlab/AvoidFeatureCategoryNotOwned
           {
             api_version: API.version,
@@ -180,6 +192,8 @@ module API
           }
         end
 
+        # /internal/two_factor_recovery_codes
+        #
         post '/two_factor_recovery_codes', feature_category: :system_access do
           status 200
 
@@ -209,6 +223,8 @@ module API
           { success: true, recovery_codes: codes }
         end
 
+        # /internal/personal_access_token
+        #
         post '/personal_access_token', feature_category: :system_access do
           status 200
 
@@ -247,7 +263,7 @@ module API
           end
 
           result = ::PersonalAccessTokens::CreateService.new(
-            current_user: user, target_user: user, params: { name: params[:name], scopes: params[:scopes], expires_at: expires_at }
+            current_user: user, target_user: user, organization_id: Current.organization_id, params: { name: params[:name], scopes: params[:scopes], expires_at: expires_at }
           ).execute
 
           unless result.status == :success
@@ -259,6 +275,8 @@ module API
           { success: true, token: access_token.token, scopes: access_token.scopes, expires_at: access_token.expires_at }
         end
 
+        # /internal/pre_receive
+        #
         post '/pre_receive', feature_category: :source_code_management do
           status 200
 
@@ -267,6 +285,8 @@ module API
           { reference_counter_increased: reference_counter_increased }
         end
 
+        # /internal/post_receive
+        #
         post '/post_receive', feature_category: :source_code_management do
           status 200
 
@@ -280,6 +300,9 @@ module API
         # decided to pursue a different approach, so it's currently not used.
         # We might revive the PAM module though as it provides better user
         # flow.
+        #
+        # /internal/two_factor_config
+        #
         post '/two_factor_config', feature_category: :system_access do
           status 200
 
@@ -302,12 +325,16 @@ module API
           end
         end
 
+        # /internal/two_factor_push_otp_check
+        #
         post '/two_factor_push_otp_check', feature_category: :system_access do
           status 200
 
           two_factor_push_otp_check
         end
 
+        # /internal/two_factor_manual_otp_check
+        #
         post '/two_factor_manual_otp_check', feature_category: :system_access do
           status 200
 
