@@ -2,6 +2,7 @@
 
 module API
   class MergeRequests < ::API::Base
+    include APIGuard
     include PaginationParams
     include Helpers::Unidiff
 
@@ -9,6 +10,11 @@ module API
 
     before { authenticate_non_get! }
 
+    allow_access_with_scope :ai_workflows, if: ->(request) do
+      request.get? || request.head? ||
+        (request.put? && request.path.match?(%r{/api/v\d+/projects/\d+/merge_requests/\d+$})) # Only allow basic MR updates
+    end
+
     rescue_from ActiveRecord::QueryCanceled do |_e|
       render_api_error!({ error: 'Request timed out' }, 408)
     end
@@ -87,14 +93,35 @@ module API
       end
       # rubocop: enable CodeReuse/ActiveRecord
 
+      def render_merge_requests(merge_requests, options, skip_cache: false)
+        return present merge_requests, options if skip_cache
+
+        cache_context = ->(mr) do
+          [
+            current_user&.cache_key,
+            mr.merge_status,
+            mr.labels.map(&:cache_key),
+            mr.merge_request_assignees.map(&:cache_key),
+            mr.merge_request_reviewers.map(&:cache_key)
+          ].join(":")
+        end
+
+        present_cached merge_requests,
+          expires_in: 8.hours,
+          cache_context: cache_context,
+          **options
+      end
+
       def merge_request_pipelines_with_access
         mr = find_merge_request_with_access(params[:merge_request_iid])
         ::Ci::PipelinesForMergeRequestFinder.new(mr, current_user).execute
       end
 
       def automatically_mergeable?(merge_when_pipeline_succeeds, merge_request)
-        pipeline_active = merge_request.head_pipeline_active? || merge_request.diff_head_pipeline_active?
-        merge_when_pipeline_succeeds && merge_request.mergeable_state?(skip_ci_check: true) && pipeline_active
+        available_strategies = AutoMergeService.new(merge_request.project,
+          current_user).available_strategies(merge_request)
+
+        merge_when_pipeline_succeeds && available_strategies.include?(merge_request.default_auto_merge_strategy)
       end
 
       def immediately_mergeable?(merge_when_pipeline_succeeds, merge_request)
@@ -219,6 +246,7 @@ module API
     params do
       requires :id, types: [String, Integer], desc: 'The ID or URL-encoded path of the project.'
     end
+
     resource :projects, requirements: API::NAMESPACE_OR_PROJECT_REQUIREMENTS do
       include TimeTrackingEndpoints
 
@@ -289,18 +317,11 @@ module API
 
         recheck_mergeability_of(merge_requests: merge_requests) unless options[:skip_merge_status_recheck]
 
-        present_cached merge_requests,
-          expires_in: 8.hours,
-          cache_context: ->(mr) do
-            [
-              current_user&.cache_key,
-              mr.merge_status,
-              mr.labels.map(&:cache_key),
-              mr.merge_request_assignees.map(&:cache_key),
-              mr.merge_request_reviewers.map(&:cache_key)
-            ].join(":")
-          end,
-          **options
+        skip_cache = [
+          declared_params[:with_labels_details] == true
+        ].any?
+
+        render_merge_requests(merge_requests, options, skip_cache: skip_cache)
       end
 
       desc 'Create merge request' do
@@ -598,14 +619,14 @@ module API
 
         merge_request_params = { allow_duplicate: true }
 
+        service = ::MergeRequests::CreatePipelineService.new(
+          project: user_project, current_user: current_user, params: merge_request_params
+        )
+
         if params[:async]
-          ::MergeRequests::CreatePipelineWorker # rubocop:disable CodeReuse/Worker -- Worker wraps service and another service wrapping that is pointless
-            .perform_async(user_project.id, current_user.id, merge_request.id, merge_request_params)
+          service.execute_async(merge_request)
         else
-          pipeline = ::MergeRequests::CreatePipelineService
-            .new(project: user_project, current_user: current_user, params: merge_request_params)
-            .execute(merge_request)
-            .payload
+          pipeline = service.execute(merge_request).payload
         end
 
         if params[:async]
@@ -693,8 +714,7 @@ module API
         merge_request = find_project_merge_request(params[:merge_request_iid])
 
         # Merge request can not be merged because the user doesn't have
-        #   permissions to push into target branch
-        #
+        #   permissions to push into target branch.
         unauthorized! unless merge_request.can_be_merged_by?(current_user)
 
         merge_when_pipeline_succeeds = to_boolean(params[:merge_when_pipeline_succeeds])
@@ -703,7 +723,7 @@ module API
 
         not_allowed! if !immediately_mergeable && !automatically_mergeable
 
-        render_api_error!('Branch cannot be merged', 422) unless merge_request.mergeable?(skip_ci_check: automatically_mergeable)
+        render_api_error!('Branch cannot be merged', 422) unless automatically_mergeable || merge_request.mergeable?(skip_ci_check: automatically_mergeable)
 
         check_sha_param!(params, merge_request)
 
