@@ -2,19 +2,17 @@
 
 module API
   class NpmGroupPackages < ::API::Base
-    helpers ::API::Helpers::Packages::Npm
-
     feature_category :package_registry
     urgency :low
 
     helpers do
-      def endpoint_scope
-        :group
-      end
+      include Gitlab::Utils::StrongMemoize
 
       def group_or_namespace
-        group
+        group = find_group(params[:id])
+        check_group_access(group)
       end
+      strong_memoize_attr :group_or_namespace
     end
 
     params do
@@ -23,6 +21,7 @@ module API
     resource :groups, requirements: API::NAMESPACE_OR_PROJECT_REQUIREMENTS do
       namespace ':id/-/packages/npm' do
         include ::API::Concerns::Packages::NpmEndpoints
+        include ::API::Concerns::Packages::NpmNamespaceEndpoints
       end
     end
   end
