@@ -234,11 +234,14 @@ module API
       end
       params do
         use :pagination
+        optional :ref, type: String,
+          desc: 'The name of a repository branch or tag, if not given the default branch is used',
+          documentation: { example: 'main' }
         optional :order_by, type: String, values: %w[email name commits], default: 'commits', desc: 'Return contributors ordered by `name` or `email` or `commits`'
         optional :sort, type: String, values: %w[asc desc], default: 'asc', desc: 'Sort by asc (ascending) or desc (descending)'
       end
       get ':id/repository/contributors' do
-        contributors = ::Kaminari.paginate_array(user_project.repository.contributors(order_by: params[:order_by], sort: params[:sort]))
+        contributors = ::Kaminari.paginate_array(user_project.repository.contributors(ref: params[:ref], order_by: params[:order_by], sort: params[:sort]))
         present paginate(contributors), with: Entities::Contributor
       rescue StandardError
         not_found!
@@ -288,6 +291,10 @@ module API
           desc: "The file path to the configuration file as stored in the project's Git repository. Defaults to '.gitlab/changelog_config.yml'"
       end
       get ':id/repository/changelog' do
+        check_rate_limit!(:project_repositories_changelog, scope: [current_user, user_project]) do
+          render_api_error!({ error: 'This changelog has been requested too many times. Try again later.' }, 429)
+        end
+
         service = ::Repositories::ChangelogService.new(
           user_project,
           current_user,
@@ -329,6 +336,10 @@ module API
           documentation: { example: 'Initial commit' }
       end
       post ':id/repository/changelog' do
+        check_rate_limit!(:project_repositories_changelog, scope: [current_user, user_project]) do
+          render_api_error!({ error: 'This changelog has been requested too many times. Try again later.' }, 429)
+        end
+
         branch = params[:branch] || user_project.default_branch_or_main
         access = Gitlab::UserAccess.new(current_user, container: user_project)
 
