@@ -6,6 +6,20 @@ module API
 
     feature_category :groups_and_projects
 
+    before do
+      set_current_organization
+    end
+
+    helpers do
+      def find_topic!(id)
+        topic = ::Projects::Topic.find(id)
+
+        find_organization!(topic.organization_id)
+
+        topic
+      end
+    end
+
     desc 'Get topics' do
       detail 'This feature was introduced in GitLab 14.5.'
       success Entities::Projects::Topic
@@ -15,10 +29,17 @@ module API
         desc: 'Return list of topics matching the search criteria',
         documentation: { example: 'search' }
       optional :without_projects, type: Boolean, desc: 'Return list of topics without assigned projects'
+      optional :organization_id, type: Integer, default: -> { ::Current.organization_id },
+        desc: 'The organization id for the topics'
       use :pagination
     end
     get 'topics' do
-      topics = ::Projects::TopicsFinder.new(params: declared_params(include_missing: false)).execute
+      organization = find_organization!(params[:organization_id])
+
+      topics = ::Projects::TopicsFinder.new(
+        params: declared_params(include_missing: false),
+        organization_id: organization.id
+      ).execute
 
       present paginate(topics), with: Entities::Projects::Topic
     end
@@ -31,7 +52,7 @@ module API
       requires :id, type: Integer, desc: 'ID of project topic'
     end
     get 'topics/:id' do
-      topic = ::Projects::Topic.find(params[:id])
+      topic = find_topic!(params[:id])
 
       present topic, with: Entities::Projects::Topic
     end
@@ -46,10 +67,13 @@ module API
       optional :description, type: String, desc: 'Description'
       optional :avatar, type: ::API::Validations::Types::WorkhorseFile, desc: 'Avatar image for topic',
         documentation: { type: 'file' }
+      optional :organization_id, type: Integer, default: -> { ::Current.organization_id },
+        desc: 'The organization id for the topic'
     end
     post 'topics' do
       authenticated_as_admin!
 
+      find_organization!(params[:organization_id]) if params[:organization_id].present?
       topic = ::Projects::Topic.new(declared_params(include_missing: false))
 
       if topic.save
@@ -74,7 +98,7 @@ module API
     put 'topics/:id' do
       authenticated_as_admin!
 
-      topic = ::Projects::Topic.find(params[:id])
+      topic = find_topic!(params[:id])
 
       topic.remove_avatar! if params.key?(:avatar) && params[:avatar].nil?
 
@@ -94,7 +118,7 @@ module API
     delete 'topics/:id' do
       authenticated_as_admin!
 
-      topic = ::Projects::Topic.find(params[:id])
+      topic = find_topic!(params[:id])
 
       destroy_conditionally!(topic)
     end
@@ -110,8 +134,8 @@ module API
     post 'topics/merge' do
       authenticated_as_admin!
 
-      source_topic = ::Projects::Topic.find(params[:source_topic_id])
-      target_topic = ::Projects::Topic.find(params[:target_topic_id])
+      source_topic = find_topic!(params[:source_topic_id])
+      target_topic = find_topic!(params[:target_topic_id])
 
       response = ::Topics::MergeService.new(source_topic, target_topic).execute
       render_api_error!(response.message, :bad_request) if response.error?
