@@ -26,6 +26,7 @@ module API
 
       before do
         authenticate_non_get!
+        set_current_organization
       end
 
       helpers Helpers::UsersHelpers
@@ -1027,6 +1028,7 @@ module API
           end
           post feature_category: :system_access do
             impersonation_token = finder.build(declared_params(include_missing: false))
+            impersonation_token.organization = Current.organization
 
             if impersonation_token.save
               present impersonation_token, with: Entities::ImpersonationTokenWithToken
@@ -1082,7 +1084,7 @@ module API
           end
           post feature_category: :system_access do
             response = ::PersonalAccessTokens::CreateService.new(
-              current_user: current_user, target_user: target_user, params: declared_params(include_missing: false)
+              current_user: current_user, target_user: target_user, organization_id: Current.organization_id, params: declared_params(include_missing: false)
             ).execute
 
             if response.success?
@@ -1098,6 +1100,7 @@ module API
     resource :user do
       before do
         authenticate!
+        set_current_organization
       end
 
       # Enabling /user endpoint for the v3 version to allow oauth
@@ -1497,7 +1500,7 @@ module API
         end
         post feature_category: :system_access do
           response = ::PersonalAccessTokens::CreateService.new(
-            current_user: current_user, target_user: current_user, params: declared_params(include_missing: false)
+            current_user: current_user, target_user: current_user, params: declared_params(include_missing: false), organization_id: Current.organization_id
           ).execute
 
           if response.success?
