@@ -53,11 +53,6 @@ module Atlassian
         end
 
         def description
-          unless Feature.enabled?(:enable_jira_connect_configuration) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- flag must be global
-            return "Deployment #{deployment.iid} of #{project.name} at #{short_sha} (#{build&.name}) to
-             #{environment.name}"
-          end
-
           "Deployment #{deployment.iid} (deployment-#{deployment.id}) of #{project.name} (project-#{project.id})
           at #{short_sha} (#{build&.name}) to #{environment.name}"
         end
@@ -134,7 +129,6 @@ module Atlassian
         end
 
         def service_ids_from_integration_configuration
-          return [] unless Feature.enabled?(:enable_jira_connect_configuration) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- flag must be global
           return [] unless project.jira_cloud_app_integration&.active
           return [] if project.jira_cloud_app_integration&.jira_cloud_app_service_ids.blank?
 
@@ -143,8 +137,6 @@ module Atlassian
         end
 
         def generate_deployment_commands_from_integration_configuration
-          return unless Feature.enabled?(:enable_jira_cloud_deployment_gating) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- flag must be global
-
           jira_cloud_app_integration = project.jira_cloud_app_integration
 
           return unless jira_cloud_app_integration&.active
