@@ -43,11 +43,20 @@ module Backup
         enqueue_consecutive
 
       ensure
-        strategy.finish!
+        begin
+          strategy.finish!
+
+        rescue Error => e
+          logger.error(e.message)
+        end
 
         restore_object_pools
       end
 
+      def asynchronous?
+        false
+      end
+
       private
 
       attr_reader :strategy, :storages, :paths, :skip_paths, :logger
