@@ -6,7 +6,7 @@ module Backup
       # Backup creation and restore option flags
       #
       # @return [Backup::Options]
-      attr_reader :options
+      attr_reader :options, :progress
 
       def initialize(progress, options:)
         @progress = progress
@@ -25,15 +25,6 @@ module Backup
       def restore(path, backup_id)
         raise NotImplementedError
       end
-
-      private
-
-      attr_reader :progress
-
-      def puts_time(msg)
-        progress.puts "#{Time.zone.now} -- #{msg}"
-        Gitlab::BackupLogger.info(message: Rainbow.uncolor(msg).to_s)
-      end
     end
   end
 end
