@@ -11,8 +11,9 @@ module Banzai
         self.object_class   = CommitRange
 
         def references_in(text, pattern = object_reference_pattern)
-          text.gsub(pattern) do |match|
-            yield match, $~[:commit_range], $~[:project], $~[:namespace], $~
+          Gitlab::Utils::Gsub.gsub_with_limit(text, pattern, limit: Banzai::Filter::FILTER_ITEM_LIMIT) do |match_data|
+            yield match_data[0], match_data[:commit_range], match_data[:project], match_data[:namespace],
+              match_data
           end
         end
 
