@@ -22,7 +22,8 @@ module Banzai
         end
 
         def parent_records(parent, ids)
-          parent.issues.where(iid: ids.to_a).includes(:project, :namespace, :work_item_type)
+          parent.issues.where(iid: ids.to_a)
+                .includes(:project, :namespace, ::Gitlab::Issues::TypeAssociationGetter.call)
         end
 
         def object_link_text_extras(issue, matches)
