@@ -70,8 +70,9 @@ module Banzai
         pre_node.add_class("language-#{language}") if language
         pre_node.set_attribute('v-pre', 'true')
         copy_code_btn = "<copy-code></copy-code>" unless language == 'suggestion'
+        insert_code_snippet_btn = "<insert-code-snippet></insert-code-snippet>" unless language == 'suggestion'
 
-        highlighted = %(<div class="gl-relative markdown-code-block js-markdown-code">#{pre_node.to_html}#{copy_code_btn}</div>)
+        highlighted = %(<div class="gl-relative markdown-code-block js-markdown-code">#{pre_node.to_html}#{copy_code_btn}#{insert_code_snippet_btn}</div>)
 
         # Extracted to a method to measure it
         replace_pre_element(pre_node, highlighted)
