@@ -11,7 +11,8 @@ module BulkImports
             destination_name: entry['path'],
             destination_namespace: context.entity.group.full_path,
             parent_id: context.entity.id,
-            migrate_projects: context.entity.migrate_projects
+            migrate_projects: context.entity.migrate_projects,
+            migrate_memberships: context.entity.migrate_memberships
           }
         end
       end
