@@ -183,7 +183,7 @@ module Gitlab
         ::Ci::Runner.find_by_token(token.to_s) || raise(UnauthorizedError)
       end
 
-      def validate_and_save_access_token!(scopes: [], save_auth_context: true)
+      def validate_and_save_access_token!(scopes: [], save_auth_context: true, reset_token: false)
         # return early if we've already authenticated via a job token
         return if @current_authenticated_job.present? # rubocop:disable Gitlab/ModuleWithInstanceVariables
 
@@ -192,6 +192,12 @@ module Gitlab
 
         return unless access_token
 
+        # Originally, we tried to use `reset` here to follow the rubocop rule introduced by
+        # https://gitlab.com/gitlab-org/gitlab-foss/-/issues/60218, but this caused a NoMethodError for OAuth tokens,
+        # leading to incident 18980 (see https://gitlab.com/gitlab-com/gl-infra/production/-/issues/18988).
+        # We're using reload instead and disabling the rubocop rule to prevent similar incidents.
+        access_token.reload if reset_token # rubocop:disable Cop/ActiveRecordAssociationReload
+
         case AccessTokenValidationService.new(access_token, request: request).validate(scopes: scopes)
         when AccessTokenValidationService::INSUFFICIENT_SCOPE
           save_auth_failure_in_application_context(access_token, :insufficient_scope) if save_auth_context
@@ -472,6 +478,47 @@ module Gitlab
         current_request.path.match(%r{access_tokens/\d+/rotate$}) ||
           current_request.path.match(%r{/personal_access_tokens/self/rotate$})
       end
+
+      # To prevent Rack Attack from incorrectly rate limiting
+      # authenticated Git activity, we need to authenticate the user
+      # from other means (e.g. HTTP Basic Authentication) only if the
+      # request originated from a Git or Git LFS
+      # request. Repositories::GitHttpClientController or
+      # Repositories::LfsApiController normally does the authentication,
+      # but Rack Attack runs before those controllers.
+      def find_user_for_git_or_lfs_request
+        return unless git_or_lfs_request?
+
+        find_user_from_lfs_token || find_user_from_basic_auth_password
+      end
+
+      def find_user_from_personal_access_token_for_api_or_git
+        return unless api_request? || git_or_lfs_request?
+
+        find_user_from_personal_access_token
+      end
+
+      def find_user_from_dependency_proxy_token
+        return unless dependency_proxy_request?
+
+        token, _ = ActionController::HttpAuthentication::Token.token_and_options(current_request)
+
+        return unless token
+
+        user_or_deploy_token = ::DependencyProxy::AuthTokenService.user_or_deploy_token_from_jwt(token)
+
+        # Do not return deploy tokens
+        # See https://gitlab.com/gitlab-org/gitlab/-/issues/342481
+        return unless user_or_deploy_token.is_a?(::User)
+
+        user_or_deploy_token
+      rescue ActiveRecord::RecordNotFound
+        nil # invalid id used return no user
+      end
+
+      def dependency_proxy_request?
+        Gitlab::PathRegex.dependency_proxy_route_regex.match?(current_request.path)
+      end
     end
   end
 end
