@@ -29,8 +29,9 @@ module Gitlab
 
         attr_reader :auth_hash
 
-        def initialize(auth_hash)
+        def initialize(auth_hash, user_params = {})
           self.auth_hash = auth_hash
+          @user_params = user_params
           update_profile
           add_or_update_user_identities
         end
@@ -44,7 +45,7 @@ module Gitlab
         end
 
         def valid?
-          gl_user.try(:valid?)
+          !any_auth_hash_errors? && gl_user.try(:valid?)
         end
 
         def valid_sign_in?
@@ -52,14 +53,14 @@ module Gitlab
         end
 
         def save(provider = protocol_name)
+          return false if any_auth_hash_errors?
+
           raise SigninDisabledForProviderError if oauth_provider_disabled?
           raise SignupDisabledError unless gl_user
 
           block_after_save = needs_blocking?
 
-          Namespace.with_disabled_organization_validation do
-            Users::UpdateService.new(gl_user, user: gl_user).execute!
-          end
+          Users::UpdateService.new(gl_user, user: gl_user).execute!
 
           gl_user.block_pending_approval if block_after_save
           activate_user_if_user_cap_not_reached
@@ -110,6 +111,8 @@ module Gitlab
 
         protected
 
+        attr_reader :user_params
+
         def activate_user_if_user_cap_not_reached
           nil
         end
@@ -131,8 +134,6 @@ module Gitlab
             log.info "Correct LDAP account has been found. identity to user: #{gl_user.username}."
             gl_user.identities.build(provider: ldap_person.provider, extern_uid: ldap_person.dn)
           end
-
-          identity
         end
 
         def find_or_build_ldap_user
@@ -223,8 +224,8 @@ module Gitlab
         end
 
         def build_new_user(skip_confirmation: true)
-          user_params = user_attributes.merge(skip_confirmation: skip_confirmation)
-          Users::AuthorizedBuildService.new(nil, user_params).execute
+          augmented_user_params = user_attributes.merge(skip_confirmation: skip_confirmation)
+          Users::AuthorizedBuildService.new(nil, augmented_user_params).execute
         end
 
         def user_attributes
@@ -247,7 +248,8 @@ module Gitlab
             email: email,
             password: auth_hash.password,
             password_confirmation: auth_hash.password,
-            password_automatically_set: true
+            password_automatically_set: true,
+            organization_id: user_params[:organization_id]
           }
         end
 
@@ -282,7 +284,7 @@ module Gitlab
 
           if creating_linked_ldap_user?
             metadata.set_attribute_synced(:name, true) if gl_user.name == ldap_person.name
-            metadata.set_attribute_synced(:email, true) if gl_user.email == ldap_person.email&.first
+            metadata.set_attribute_synced(:email, true) if gl_user.email.downcase == ldap_person.email&.first&.downcase
             metadata.provider = ldap_person.provider
           end
         end
@@ -308,6 +310,19 @@ module Gitlab
           auto_link = Array(auto_link)
           auto_link.include?(auth_hash.provider)
         end
+
+        def any_auth_hash_errors?
+          return false if auth_hash.errors.empty?
+
+          assign_errors_from_auth_hash
+          true
+        end
+
+        def assign_errors_from_auth_hash
+          auth_hash.errors.each do |attr, error|
+            gl_user.errors.add(attr, error)
+          end
+        end
       end
     end
   end
