@@ -7,8 +7,15 @@ module Gitlab
       feature_category :vulnerability_management
 
       def perform
-        each_sub_batch do |sub_batch|
-          connection.exec_update(update_sql(sub_batch))
+        # This allow_cross_joins_across_databases call will never be removed.
+        # The definition of this migration cannot function after the decomposition
+        # of the Sec database. As such, it must be finalised before the decomposition.
+        Gitlab::Database.allow_cross_joins_across_databases(
+          url: 'https://gitlab.com/gitlab-org/gitlab/-/merge_requests/164505'
+        ) do
+          each_sub_batch do |sub_batch|
+            connection.exec_update(update_sql(sub_batch))
+          end
         end
       end
 
