@@ -19,10 +19,17 @@ module Gitlab
       SQL
 
       def perform
-        each_sub_batch do |sub_batch|
-          update_query = update_query_for(sub_batch)
+        # This allow_cross_joins_across_databases call will never be removed.
+        # The definition of this migration cannot function after the decomposition
+        # of the Sec database. As such, it must be finalised before the decomposition.
+        Gitlab::Database.allow_cross_joins_across_databases(
+          url: 'https://gitlab.com/gitlab-org/gitlab/-/merge_requests/164505'
+        ) do
+          each_sub_batch do |sub_batch|
+            update_query = update_query_for(sub_batch)
 
-          connection.execute(update_query)
+            connection.execute(update_query)
+          end
         end
       end
 
