@@ -4,7 +4,7 @@ module Gitlab
   module BackgroundMigration
     class BackfillWorkspaceVariablesProjectId < BackfillDesiredShardingKeyJob
       operation_name :backfill_workspace_variables_project_id
-      feature_category :remote_development
+      feature_category :workspaces
     end
   end
 end
