@@ -2,12 +2,10 @@
 
 module Gitlab
   module BackgroundMigration
-    # rubocop: disable Style/Documentation
     class MigrateApproverToApprovalRules
       # @param target_type [String] class of target, either 'MergeRequest' or 'Project'
       # @param target_id [Integer] id of target
-      def perform(target_type, target_id, sync_code_owner_rule: true)
-      end
+      def perform(target_type, target_id, sync_code_owner_rule: true); end
     end
   end
 end
