@@ -2,14 +2,11 @@
 
 module Gitlab
   module BackgroundMigration
-    # rubocop: disable Style/Documentation
     class MigrateSharedVulnerabilityScanners < BatchedMigrationJob
       feature_category :database
 
-      def perform
-      end
+      def perform; end
     end
-    # rubocop: enable Style/Documentation
   end
 end
 
