@@ -14,17 +14,26 @@ module Gitlab
       end
 
       def execute
+        bitbucket_import_resumable_worker =
+          Feature.enabled?(:bitbucket_import_resumable_worker, current_user)
+
         ::Projects::CreateService.new(
           current_user,
           name: name,
           path: name,
           description: repo.description,
           namespace_id: namespace.id,
+          organization_id: namespace.organization_id,
           visibility_level: repo.visibility_level,
           import_type: 'bitbucket',
           import_source: repo.full_name,
           import_url: clone_url,
-          import_data: { credentials: credentials },
+          import_data: {
+            credentials: credentials,
+            data: {
+              bitbucket_import_resumable_worker: bitbucket_import_resumable_worker
+            }
+          },
           skip_wiki: skip_wiki
         ).execute
       end
