@@ -34,7 +34,8 @@ module Gitlab
             state_id: MergeRequest.available_states[object[:state]],
             author_id: user_finder.author_id(object),
             created_at: object[:created_at],
-            updated_at: object[:updated_at]
+            updated_at: object[:updated_at],
+            imported_from: ::Import::HasImportSource::IMPORT_SOURCES[:bitbucket_server]
           }
 
           creator = Gitlab::Import::MergeRequestCreator.new(project)
@@ -73,7 +74,7 @@ module Gitlab
           return [] unless object[:reviewers].present?
 
           object[:reviewers].filter_map do |reviewer|
-            if Feature.enabled?(:bitbucket_server_user_mapping_by_username, type: :ops)
+            if Feature.enabled?(:bitbucket_server_user_mapping_by_username, project, type: :ops)
               user_finder.find_user_id(by: :username, value: reviewer.dig('user', 'slug'))
             else
               user_finder.find_user_id(by: :email, value: reviewer.dig('user', 'emailAddress'))
