@@ -34,6 +34,10 @@ module Gitlab
               comment_id: comment[:id]
             )
           end
+
+          def pull_request_comment_attributes(comment)
+            super(comment).merge(imported_from: ::Import::SOURCE_BITBUCKET_SERVER)
+          end
         end
       end
     end
