@@ -28,9 +28,19 @@ module Gitlab
 
             commits.each do |commit|
               signature = commit.signature
-              if !signature.verified?
+              unless signature.verified?
                 raise ::Gitlab::GitAccess::ForbiddenError, "Signature of the commit #{commit.sha} is not verified"
-              elsif !reverified_with_integration?(signature.gpg_key)
+              end
+
+              key = signature.gpg_key
+              unless key
+                gpg_commit = commit.gpg_commit
+                gpg_commit.update_signature!(signature)
+
+                key = gpg_commit.signature.gpg_key
+              end
+
+              unless reverified_with_integration?(key)
                 raise ::Gitlab::GitAccess::ForbiddenError, "GPG Key used to sign commit #{commit.sha} is not verified"
               end
             end
@@ -52,11 +62,11 @@ module Gitlab
             break false unless key.present?
 
             gpg_key = key.is_a?(GpgKeySubkey) ? key.gpg_key : key
-            break false unless key.externally_verified?
-            break true if gpg_key.updated_at > INTEGRATION_VERIFICATION_PERIOD.ago
+
+            break gpg_key.externally_verified? unless require_reverification?(gpg_key)
 
             verified_externally?(gpg_key).tap do |verified_externally|
-              key.update!(externally_verified: verified_externally)
+              key.update!(externally_verified: verified_externally, externally_verified_at: Time.current)
             end
           end
         end
@@ -69,6 +79,12 @@ module Gitlab
           false
         end
 
+        def require_reverification?(key)
+          return true unless key.externally_verified_at.present?
+
+          key.externally_verified_at <= INTEGRATION_VERIFICATION_PERIOD.ago
+        end
+
         def integration
           project.beyond_identity_integration || ::Integrations::BeyondIdentity.for_instance.first
         end
