@@ -12,9 +12,9 @@ module Gitlab
       # - stream number: 1 byte (2 hex chars) stream number
       # - stream type: E/O (Err or Out)
       # - full line type: `+` if line is continuation of previous line, ` ` otherwise
-      TIMESTAMP_REGEX = /(\d{4}-[01][0-9]-[0-3][0-9]T[0-2][0-9]:[0-5][0-9]:[0-5][0-9]\.[0-9]{6}Z) [0-9a-f]{2}[EO][+ ]/
-      RFC3339_DATETIME_LENGTH = 27
-      TIMESTAMP_PREFIX_LENGTH = RFC3339_DATETIME_LENGTH + 5
+      TIMESTAMP_HEADER_REGEX = Gitlab::Ci::Trace::Stream::TIMESTAMP_HEADER_REGEX
+      TIMESTAMP_HEADER_DATETIME_LENGTH = Gitlab::Ci::Trace::Stream::TIMESTAMP_HEADER_DATETIME_LENGTH
+      TIMESTAMP_HEADER_LENGTH = Gitlab::Ci::Trace::Stream::TIMESTAMP_HEADER_LENGTH
 
       # keys represent the trailing digit in color changing command (30-37, 40-47, 90-97. 100-107)
       COLOR = {
@@ -104,11 +104,11 @@ module Gitlab
         def handle_line(line, next_line)
           if line.nil?
             # First line, initialize check for timestamps
-            @has_timestamps = next_line.match?(TIMESTAMP_REGEX)
+            @has_timestamps = next_line.match?(TIMESTAMP_HEADER_REGEX)
             return
           end
 
-          is_continued = @has_timestamps && next_line&.at(TIMESTAMP_PREFIX_LENGTH - 1) == '+'
+          is_continued = @has_timestamps && next_line&.at(TIMESTAMP_HEADER_LENGTH - 1) == '+'
 
           # Continued lines contain an ignored \n character at the end, so we can chop it off
           line.delete_suffix!("\n") if is_continued
@@ -117,7 +117,7 @@ module Gitlab
             @current_line_buffer = line
           else
             # Ignore timestamp from continued line
-            @current_line_buffer << line[TIMESTAMP_PREFIX_LENGTH..]
+            @current_line_buffer << line[TIMESTAMP_HEADER_LENGTH..]
           end
 
           return if is_continued
@@ -149,7 +149,7 @@ module Gitlab
             return
           elsif scanner.scan('<')
             write_in_tag '&lt;'
-          elsif scanner.scan(/\r?\n/)
+          elsif scanner.scan(/\r*\n/)
             handle_new_line
           else
             write_in_tag scanner.scan(/./m)
@@ -160,20 +160,20 @@ module Gitlab
 
         def has_timestamp_prefix?(line)
           # Avoid regex on timestamps for performance
-          return unless @has_timestamps && line && line.length >= TIMESTAMP_PREFIX_LENGTH
+          return unless @has_timestamps && line && line.length >= TIMESTAMP_HEADER_LENGTH
 
-          line[RFC3339_DATETIME_LENGTH - 1] == 'Z' &&
+          line[TIMESTAMP_HEADER_DATETIME_LENGTH - 1] == 'Z' &&
             line[4] == '-' && line[7] == '-' && line[10] == 'T' && line[13] == ':'
         end
 
         def skip_timestamp(scanner)
           return unless @has_timestamps
 
-          line = scanner.peek(TIMESTAMP_PREFIX_LENGTH + 1)
+          line = scanner.peek(TIMESTAMP_HEADER_LENGTH + 1)
           return unless has_timestamp_prefix?(line)
 
-          scanner.pos += TIMESTAMP_PREFIX_LENGTH
-          @offset += TIMESTAMP_PREFIX_LENGTH
+          scanner.pos += TIMESTAMP_HEADER_LENGTH
+          @offset += TIMESTAMP_HEADER_LENGTH
         end
 
         def handle_new_line
