@@ -19,21 +19,18 @@ module Gitlab
         Config::Yaml::Tags::TagError
       ].freeze
 
-      attr_reader :root, :context, :source_ref_path, :source, :logger, :inject_edge_stages
+      attr_reader :root, :context, :source_ref_path, :source, :logger, :inject_edge_stages, :pipeline_policy_context
 
       # rubocop: disable Metrics/ParameterLists
-      def initialize(config, project: nil, pipeline: nil, sha: nil, ref: nil, user: nil, parent_pipeline: nil, source: nil, pipeline_config: nil, logger: nil, inject_edge_stages: true)
+      def initialize(config, project: nil, pipeline: nil, sha: nil, ref: nil, user: nil, parent_pipeline: nil, source: nil, pipeline_config: nil, logger: nil, inject_edge_stages: true, pipeline_policy_context: nil)
         @logger = logger || ::Gitlab::Ci::Pipeline::Logger.new(project: project)
         @source_ref_path = pipeline&.source_ref_path
         @project = project
         @inject_edge_stages = inject_edge_stages
+        @pipeline_policy_context = pipeline_policy_context
 
         @context = self.logger.instrument(:config_build_context, once: true) do
-          pipeline ||= if ::Feature.enabled?(:project_ref_name_in_pipeline, project)
-                         ::Ci::Pipeline.new(project: project, sha: sha, ref: ref, user: user, source: source)
-                       else
-                         ::Ci::Pipeline.new(project: project, sha: sha, user: user, source: source)
-                       end
+          pipeline ||= ::Ci::Pipeline.new(project: project, sha: sha, ref: ref, user: user, source: source)
 
           build_context(project: project, pipeline: pipeline, sha: sha, user: user, parent_pipeline: parent_pipeline, pipeline_config: pipeline_config)
         end
@@ -42,7 +39,7 @@ module Gitlab
 
         @source = source
 
-        Gitlab::Ci::YamlProcessor::FeatureFlags.with_actor(project) do
+        Gitlab::Ci::Config::FeatureFlags.with_actor(project) do
           @config = self.logger.instrument(:config_expand, once: true) do
             expand_config(config)
           end
@@ -79,36 +76,55 @@ module Gitlab
       ##
       # Temporary method that should be removed after refactoring
       #
+      # rubocop:disable Gitlab/NoCodeCoverageComment -- This is an existing method and probably never called
+      # :nocov:
       def variables
-        root.variables_value
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.variables_value
+        end
       end
+      # rubocop:enable Gitlab/NoCodeCoverageComment
 
       def variables_with_data
-        root.variables_entry.value_with_data
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.variables_entry.value_with_data
+        end
       end
 
       def variables_with_prefill_data
-        root.variables_entry.value_with_prefill_data
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.variables_entry.value_with_prefill_data
+        end
       end
 
       def stages
-        root.stages_value
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.stages_value
+        end
       end
 
       def jobs
-        root.jobs_value
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.jobs_value
+        end
       end
 
       def workflow_rules
-        root.workflow_entry.rules_value
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.workflow_entry.rules_value
+        end
       end
 
       def workflow_name
-        root.workflow_entry.name
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.workflow_entry.name
+        end
       end
 
       def workflow_auto_cancel
-        root.workflow_entry.auto_cancel_value
+        Gitlab::Ci::Config::FeatureFlags.with_actor(@project) do
+          root.workflow_entry.auto_cancel_value
+        end
       end
 
       def normalized_jobs
