@@ -9,11 +9,7 @@ module Gitlab
           FeatureDisabledError = Class.new(Gitlab::Ci::Parsers::ParserError)
           InvalidLineInformationError = Class.new(Gitlab::Ci::Parsers::ParserError)
 
-          def parse!(xml_data, coverage_report, project:, merge_request_paths:, **_kwargs)
-            unless Feature.enabled?(:jacoco_coverage_reports, project)
-              raise FeatureDisabledError, "Feature jacoco_coverage_reports is disabled for project #{project.full_name}"
-            end
-
+          def parse!(xml_data, coverage_report, merge_request_paths:, **_kwargs)
             Nokogiri::XML::SAX::Parser.new(Documents::JacocoDocument.new(coverage_report,
               merge_request_paths)).parse(xml_data)
           end
