@@ -1,4 +1,3 @@
-# rubocop:disable Naming/FileName
 # frozen_string_literal: true
 
 module Gitlab
@@ -11,35 +10,18 @@ module Gitlab
           :trigger_request, :schedule, :merge_request, :external_pull_request,
           :ignore_skip_ci, :save_incompleted,
           :seeds_block, :variables_attributes, :push_options,
-          :chat_data, :allow_mirror_update, :bridge, :content, :dry_run, :logger, :execution_policy_dry_run,
+          :chat_data, :allow_mirror_update, :bridge, :content, :dry_run, :logger, :pipeline_policy_context,
           # These attributes are set by Chains during processing:
           :config_content, :yaml_processor_result, :workflow_rules_result, :pipeline_seed,
-          :pipeline_config, :pipeline_execution_policies, :partition_id
+          :pipeline_config, :partition_id,
+          keyword_init: true
         ) do
           include Gitlab::Utils::StrongMemoize
 
-          def initialize(params = {})
-            params.each do |key, value|
-              self[key] = value
-            end
-          end
-
           def dry_run?
-            dry_run || execution_policy_dry_run
+            dry_run
           end
 
-          # rubocop:disable Gitlab/NoCodeCoverageComment -- method is tested in EE
-          # :nocov:
-          def execution_policy_mode?
-            false # to be overridden in EE
-          end
-
-          def pipeline_policy_context
-            # to be overridden in EE
-          end
-          # :nocov:
-          # rubocop:enable Gitlab/NoCodeCoverageComment
-
           def branch_exists?
             strong_memoize(:is_branch) do
               branch_ref? && project.repository.branch_exists?(ref)
@@ -182,5 +164,4 @@ module Gitlab
   end
 end
 
-# rubocop:enable Naming/FileName
 Gitlab::Ci::Pipeline::Chain::Command.prepend_mod
