@@ -24,9 +24,8 @@ module Gitlab
               project: project,
               user: current_user,
               additional_properties: {
-                label: component.project.full_path,
-                property: "#{component.name}@#{component.version.name}",
-                value: component.resource_type_before_type_cast
+                label: component.id.to_s,
+                value: component.component_type_before_type_cast
               }
             )
 
