@@ -11,7 +11,7 @@ module Gitlab
 
             def perform!
               if pipeline_config&.exists?
-                @pipeline.build_pipeline_config(content: pipeline_config.content)
+                @pipeline.build_pipeline_config(content: pipeline_config.content, project_id: @pipeline.project_id)
                 @command.config_content = pipeline_config.content
                 @pipeline.config_source = pipeline_config.source
                 @command.pipeline_config = pipeline_config
@@ -34,7 +34,7 @@ module Gitlab
                   pipeline_source: @command.source, pipeline_source_bridge: @command.bridge,
                   triggered_for_branch: @pipeline.branch?,
                   ref: @pipeline.ref,
-                  has_pipeline_execution_policies: @command.pipeline_execution_policies.present?
+                  pipeline_policy_context: @command.pipeline_policy_context
                 )
               end
             end
@@ -44,3 +44,5 @@ module Gitlab
     end
   end
 end
+
+Gitlab::Ci::Pipeline::Chain::Config::Content.prepend_mod
