@@ -13,7 +13,7 @@ module Gitlab
         puts '-' * 80
         puts " Ruby:".ljust(justify) + RUBY_DESCRIPTION
         puts " GitLab:".ljust(justify) + "#{Gitlab::VERSION} (#{Gitlab.revision}) #{Gitlab.ee? ? 'EE' : 'FOSS'}"
-        puts " GitLab Shell:".ljust(justify) + "#{Gitlab::VersionInfo.parse(Gitlab::Shell.version)}"
+        puts " GitLab Shell:".ljust(justify) + Gitlab::VersionInfo.parse(Gitlab::Shell.version).to_s
 
         if ApplicationRecord.database.exists?
           puts " #{ApplicationRecord.database.human_adapter_name}:".ljust(justify) + ApplicationRecord.database.version
@@ -32,7 +32,7 @@ module Gitlab
         else
           boot_time_seconds = Gitlab::Metrics::BootTimeTracker.instance.startup_time
           booted_in = "[ booted in %.2fs ]" % [boot_time_seconds]
-          puts '-' * (80 - booted_in.length) + booted_in
+          puts ('-' * (80 - booted_in.length)) + booted_in
         end
       end
     end
