@@ -10,12 +10,7 @@ module Gitlab
           object_kind: 'access_token'
         }
 
-        if resource.is_a?(Project)
-          base_data[:project] = resource.hook_attrs
-        else
-          base_data[:group] = group_data(resource)
-        end
-
+        base_data[resource.model_name.param_key.to_sym] = resource.hook_attrs
         base_data[:object_attributes] = resource_access_token.hook_attrs
         base_data[:event_name] = event_data(event)
         base_data
@@ -29,14 +24,6 @@ module Gitlab
           'expiring_access_token'
         end
       end
-
-      def group_data(group)
-        {
-          group_name: group.name,
-          group_path: group.path,
-          group_id: group.id
-        }
-      end
     end
   end
 end
