@@ -21,6 +21,7 @@ module Gitlab
     # https://www.postgresql.org/docs/9.2/static/datatype-numeric.html
     MAX_INT_VALUE = 2147483647
     MIN_INT_VALUE = -2147483648
+    MAX_SMALLINT_VALUE = 32767
 
     # The max value between MySQL's TIMESTAMP and PostgreSQL's timestampz:
     # https://www.postgresql.org/docs/9.1/static/datatype-datetime.html
@@ -32,9 +33,6 @@ module Gitlab
     # https://gitlab.com/gitlab-org/gitlab-foss/issues/61974
     MAX_TEXT_SIZE_LIMIT = 1_000_000
 
-    # Migrations before this version may have been removed
-    MIN_SCHEMA_GITLAB_VERSION = '16.11'
-
     # Schema we store dynamically managed partitions in (e.g. for time partitioning)
     DYNAMIC_PARTITIONS_SCHEMA = :gitlab_partitions_dynamic
 
@@ -116,6 +114,16 @@ module Gitlab
           .compact.with_indifferent_access.freeze
     end
 
+    # Returns the application record that created the given connection.
+    # In single database mode, this always returns ApplicationRecord.
+    def self.application_record_for_connection(connection)
+      @gitlab_base_models ||=
+        database_base_models
+          .transform_values { |v| v == ActiveRecord::Base ? ApplicationRecord : v }
+
+      @gitlab_base_models[db_config_name(connection)]
+    end
+
     # This returns a list of base models with connection associated for a given gitlab_schema
     def self.schemas_to_base_models
       @schemas_to_base_models ||=
@@ -142,6 +150,18 @@ module Gitlab
       Gitlab::Runtime.max_threads + headroom
     end
 
+    # Expose path information so that we can use it to make sure migrations are
+    # healthy
+    def self.upgrade_path
+      path_data = YAML.safe_load_file(Rails.root.join('config/upgrade_path.yml'))
+      Gitlab::Utils::UpgradePath.new(path_data, Gitlab.version_info)
+    end
+
+    # Migrations before this version may have been removed.
+    def self.min_schema_gitlab_version
+      upgrade_path.last_required_stop
+    end
+
     # Database configured. Returns true even if the database is shared
     def self.has_config?(database_name)
       ActiveRecord::Base.configurations
@@ -205,10 +225,10 @@ module Gitlab
       # Calls to #uncached only disable caching for the current connection. Since the load balancer
       # can potentially upgrade from read to read-write mode (using a different connection), we specify
       # up-front that we'll explicitly use the primary for the duration of the operation.
-      Gitlab::Database::LoadBalancing::Session.current.use_primary do
-        base_models = database_base_models_using_load_balancing.values
-        base_models.reduce(block) { |blk, model| -> { model.uncached(&blk) } }.call
-      end
+      base_models = database_base_models_using_load_balancing.values
+      base_models.reduce(block) do |blk, model|
+        -> { Gitlab::Database::LoadBalancing::SessionMap.current(model.load_balancer).use_primary { model.uncached(&blk) } }
+      end.call
     end
 
     def self.allow_cross_joins_across_databases(url:)
@@ -282,7 +302,14 @@ module Gitlab
       return unless connection.respond_to?(:pool) &&
         connection.pool.respond_to?(:db_config)
 
-      connection.pool.db_config
+      db_config = connection.pool.db_config
+      db_config unless empty_config?(db_config)
+    end
+
+    def self.empty_config?(db_config)
+      return true unless db_config
+
+      ::Gitlab.next_rails? && db_config.is_a?(ActiveRecord::ConnectionAdapters::NullPool::NullConfig)
     end
 
     # At the moment, the connection can only be retrieved by
@@ -297,6 +324,11 @@ module Gitlab
       db_config&.name || 'unknown'
     end
 
+    def self.db_config_database(connection)
+      db_config = db_config_for_connection(connection)
+      db_config&.database || 'unknown'
+    end
+
     # If the `database_tasks: false` is being used,
     # return the expected fallback database for this database configuration
     def self.db_config_share_with(db_config)
@@ -353,10 +385,14 @@ module Gitlab
 
           ::Gitlab::Database::Metrics.subtransactions_increment(self.name) if transaction_type == :sub_transaction
 
-          payload = { connection: connection, transaction_type: transaction_type }
-
-          ActiveSupport::Notifications.instrument('transaction.active_record', payload) do
+          if ::Gitlab.next_rails?
             super(**options, &block)
+          else
+            payload = { connection: connection, transaction_type: transaction_type }
+
+            ActiveSupport::Notifications.instrument('transaction.active_record', payload) do
+              super(**options, &block)
+            end
           end
         end
 
