@@ -6,13 +6,13 @@ module Gitlab
       DEFAULT_INDEXES_PER_INVOCATION = 2
 
       def self.create_pending_indexes!(how_many: DEFAULT_INDEXES_PER_INVOCATION)
-        PostgresAsyncIndex.to_create.order(:id).limit(how_many).each do |async_index|
+        PostgresAsyncIndex.to_create.ordered.limit(how_many).each do |async_index|
           IndexCreator.new(async_index).perform
         end
       end
 
       def self.drop_pending_indexes!(how_many: DEFAULT_INDEXES_PER_INVOCATION)
-        PostgresAsyncIndex.to_drop.order(:id).limit(how_many).each do |async_index|
+        PostgresAsyncIndex.to_drop.ordered.limit(how_many).each do |async_index|
           IndexDestructor.new(async_index).perform
         end
       end
