@@ -27,6 +27,15 @@ module Gitlab
           SQL
         end
 
+        def copy_relation(relation)
+          connection.execute(<<~SQL)
+            INSERT INTO #{destination_table} (#{column_listing})
+            #{relation.select(column_listing).to_sql}
+            FOR UPDATE
+            ON CONFLICT (#{conflict_targets}) DO NOTHING
+          SQL
+        end
+
         private
 
         def column_listing
