@@ -13,6 +13,7 @@ module Gitlab
             ci_builds_metadata
             ci_job_artifacts
             ci_pipeline_variables
+            ci_pipelines
             ci_stages
           ].freeze
 
@@ -23,6 +24,9 @@ module Gitlab
             end
 
             def analyze(parsed)
+              # This analyzer requires the PgQuery parsed query to be present
+              return unless parsed.pg
+
               analyze_legacy_tables_usage(parsed)
             end
 
