@@ -17,7 +17,13 @@ module Gitlab
         end
 
         def versions_to_create
-          versions_from_database = @connection.schema_migration.all_versions
+          versions_from_database =
+            if ::Gitlab.next_rails?
+              @connection.schema_migration.versions
+            else
+              @connection.schema_migration.all_versions
+            end
+
           versions_from_migration_files = @connection.migration_context.migrations.map { |m| m.version.to_s }
 
           versions_from_database & versions_from_migration_files
