@@ -29,7 +29,8 @@ module Gitlab
           time_tracking: 'Time tracking',
           designs: 'Designs',
           development: 'Development',
-          crm_contacts: 'CRM contacts'
+          crm_contacts: 'CRM contacts',
+          email_participants: 'Email participants'
         }.freeze
 
         WIDGETS_FOR_TYPE = {
@@ -41,6 +42,7 @@ module Gitlab
             :description,
             :designs,
             :development,
+            :email_participants,
             :health_status,
             :hierarchy,
             :iteration,
@@ -61,6 +63,7 @@ module Gitlab
             :current_user_todos,
             :description,
             :development,
+            :email_participants,
             :hierarchy,
             :linked_items,
             :notes,
@@ -166,6 +169,7 @@ module Gitlab
             :crm_contacts,
             :current_user_todos,
             :description,
+            :email_participants,
             :health_status,
             :hierarchy,
             :iteration,
@@ -185,13 +189,15 @@ module Gitlab
           current_time = Time.current
 
           base_types = ::WorkItems::Type::BASE_TYPES.map do |type, attributes|
-            attributes.slice(:name, :icon_name)
-                      .merge(created_at: current_time, updated_at: current_time, base_type: type)
+            attributes
+              .slice(:name, :icon_name, :id)
+              .merge(created_at: current_time, updated_at: current_time, base_type: type, correct_id: attributes[:id])
           end
 
           ::WorkItems::Type.upsert_all(
             base_types,
-            unique_by: :idx_work_item_types_on_namespace_id_and_name_null_namespace
+            unique_by: :index_work_item_types_on_name_unique,
+            update_only: %i[name icon_name base_type]
           )
 
           upsert_widgets
@@ -217,7 +223,7 @@ module Gitlab
 
           ::WorkItems::WidgetDefinition.upsert_all(
             widgets,
-            unique_by: :index_work_item_widget_definitions_on_default_witype_and_name
+            unique_by: :index_work_item_widget_definitions_on_type_id_and_name
           )
         end
       end
