@@ -5,11 +5,12 @@ module Gitlab
     class ServiceDeskReceiver < Receiver
       private
 
-      def find_handler
+      def handler
         return unless mail_key
 
         Gitlab::Email::Handler::ServiceDeskHandler.new(mail, nil, service_desk_key: mail_key)
       end
+      strong_memoize_attr :handler
 
       def email_class
         ::Gitlab::Email::ServiceDeskEmail
