@@ -3,15 +3,16 @@
 module Gitlab
   module Git
     class ChangedPath
-      attr_reader :status, :path, :old_mode, :new_mode, :new_blob_id, :old_blob_id
+      attr_reader :status, :path, :old_mode, :new_mode, :new_blob_id, :old_blob_id, :old_path
 
-      def initialize(status:, path:, old_mode:, new_mode:, new_blob_id: nil, old_blob_id: nil)
+      def initialize(status:, path:, old_mode:, new_mode:, new_blob_id: nil, old_blob_id: nil, old_path: nil)
         @status = status
         @path = path
         @old_mode = old_mode
         @new_mode = new_mode
         @old_blob_id = old_blob_id
         @new_blob_id = new_blob_id
+        @old_path = old_path.presence || @path
       end
 
       def new_file?
