@@ -105,7 +105,6 @@ module Gitlab
         #   Commit.last_for_path(repo, 'master', 'Gemfile')
         #
         def last_for_path(repo, ref, path = nil, literal_pathspec: false)
-          # rubocop: disable Rails/FindBy
           # This is not where..first from ActiveRecord
           where(
             repo: repo,
@@ -114,7 +113,6 @@ module Gitlab
             limit: 1,
             literal_pathspec: literal_pathspec
           ).first
-          # rubocop: enable Rails/FindBy
         end
 
         # Get commits between two revspecs
@@ -144,6 +142,8 @@ module Gitlab
           end
         end
 
+        # Prefer `list_all` since it deprecates this RPC and `FindCommits`.
+        #
         # Returns commits collection
         #
         # Ex.
@@ -168,6 +168,15 @@ module Gitlab
           end
         end
 
+        # ListCommits lists all commits reachable via a set of references by doing a graph walk.
+        # This deprecates FindAllCommits and FindCommits (except Follow is not yet supported).
+        # Any unknown revisions will cause the RPC to fail.
+        def list_all(repo, options = {})
+          wrapped_gitaly_errors do
+            Gitlab::GitalyClient::CommitService.new(repo).list_commits(options[:revisions], options.except(:revisions))
+          end
+        end
+
         def decorate(repository, commit, ref = nil)
           Gitlab::Git::Commit.new(repository, commit, ref)
         end
