@@ -5,8 +5,9 @@ module Gitlab
     class BlobsStitcher
       include Enumerable
 
-      def initialize(rpc_response)
+      def initialize(rpc_response, filter_function: nil)
         @rpc_response = rpc_response
+        @filter_function = filter_function
       end
 
       def each
@@ -15,6 +16,10 @@ module Gitlab
         @rpc_response.each do |msg|
           if msg.oid.blank? && msg.data.blank?
             next
+          # rubocop: disable Lint/DuplicateBranch -- No duplication, filter can be supplied
+          elsif removed_by_filter(msg)
+            # rubocop: enable Lint/DuplicateBranch
+            next
           elsif msg.oid.present?
             yield new_blob(current_blob_data) if current_blob_data
 
@@ -30,6 +35,12 @@ module Gitlab
 
       private
 
+      def removed_by_filter(msg)
+        return unless @filter_function
+
+        !@filter_function.call(msg)
+      end
+
       def new_blob(blob_data)
         data = blob_data[:data_parts].join
 
