@@ -251,8 +251,8 @@ module Gitlab
       # else # defaults to :include_merges behavior
       #   ['foo_bar.rb', 'bar_baz.rb'],
       #
-      def find_changed_paths(objects, merge_commit_diff_mode: nil)
-        request = find_changed_paths_request(objects, merge_commit_diff_mode)
+      def find_changed_paths(objects, merge_commit_diff_mode: nil, find_renames: false)
+        request = find_changed_paths_request(objects, merge_commit_diff_mode, find_renames)
 
         return [] if request.nil?
 
@@ -262,6 +262,7 @@ module Gitlab
             Gitlab::Git::ChangedPath.new(
               status: path.status,
               path: EncodingHelper.encode!(path.path),
+              old_path: EncodingHelper.encode!(path.old_path),
               old_mode: path.old_mode.to_s(8),
               new_mode: path.new_mode.to_s(8),
               old_blob_id: path.old_blob_id,
@@ -285,14 +286,20 @@ module Gitlab
       end
 
       def list_commits(revisions, params = {})
+        # We want to include the commit ref in the revisions if present.
+        revisions = Array.wrap(params[:ref].presence || []) + Array.wrap(revisions)
+
         request = Gitaly::ListCommitsRequest.new(
           repository: @gitaly_repo,
-          revisions: Array.wrap(revisions),
+          revisions: revisions,
           reverse: !!params[:reverse],
           ignore_case: params[:ignore_case],
           pagination_params: params[:pagination_params]
         )
 
+        request.order = params[:order].upcase if params[:order].present?
+        request.skip = params[:skip].to_i if params[:skip].present?
+
         if params[:commit_message_patterns]
           request.commit_message_patterns += Array.wrap(params[:commit_message_patterns])
         end
@@ -301,7 +308,14 @@ module Gitlab
         request.before = GitalyClient.timestamp(params[:before]) if params[:before]
         request.after = GitalyClient.timestamp(params[:after]) if params[:after]
 
-        response = gitaly_client_call(@repository.storage, :commit_service, :list_commits, request, timeout: GitalyClient.medium_timeout)
+        response = gitaly_client_call(
+          @repository.storage,
+          :commit_service,
+          :list_commits,
+          request,
+          timeout: GitalyClient.medium_timeout
+        )
+
         consume_commits_response(response)
       end
 
@@ -527,7 +541,8 @@ module Gitlab
           h[k] = {
             signature: +''.b,
             signed_text: +''.b,
-            signer: :SIGNER_UNSPECIFIED
+            signer: :SIGNER_UNSPECIFIED,
+            author_email: +''.b
           }
         end
 
@@ -538,6 +553,7 @@ module Gitlab
 
           signatures[current_commit_id][:signature] << message.signature
           signatures[current_commit_id][:signed_text] << message.signed_text
+          signatures[current_commit_id][:author_email] << message.author.email if message.author.present?
 
           # The actual value is send once. All the other chunks send SIGNER_UNSPECIFIED
           signatures[current_commit_id][:signer] = message.signer unless message.signer == :SIGNER_UNSPECIFIED
@@ -647,7 +663,7 @@ module Gitlab
         response.commit
       end
 
-      def find_changed_paths_request(objects, merge_commit_diff_mode)
+      def find_changed_paths_request(objects, merge_commit_diff_mode, find_renames)
         diff_mode = MERGE_COMMIT_DIFF_MODES[merge_commit_diff_mode] if Feature.enabled?(:merge_commit_diff_modes)
 
         requests = objects.filter_map do |object|
@@ -667,7 +683,7 @@ module Gitlab
 
         return if requests.blank?
 
-        Gitaly::FindChangedPathsRequest.new(repository: @gitaly_repo, requests: requests, merge_commit_diff_mode: diff_mode)
+        Gitaly::FindChangedPathsRequest.new(repository: @gitaly_repo, requests: requests, merge_commit_diff_mode: diff_mode, find_renames: find_renames)
       end
 
       def path_error_message(path_error)
