@@ -6,12 +6,15 @@ module Gitlab
       module Events
         class ChangedAssignee < BaseImporter
           def execute(issue_event)
-            assignee_id = author_id(issue_event, author_key: :assignee)
             author_id = author_id(issue_event, author_key: :actor)
 
-            note_body = parse_body(issue_event, assignee_id)
+            note_body = parse_body(issue_event)
 
-            create_note(issue_event, note_body, author_id)
+            created_note = create_note(issue_event, note_body, author_id)
+
+            return unless mapper.user_mapping_enabled?
+
+            push_with_record(created_note, :author_id, issue_event[:actor].id, mapper.user_mapper)
           end
 
           private
@@ -38,13 +41,11 @@ module Gitlab
             )
           end
 
-          def parse_body(issue_event, assignee_id)
-            assignee = User.find(assignee_id).to_reference
-
+          def parse_body(issue_event)
             if issue_event.event == 'unassigned'
-              "#{SystemNotes::IssuablesService.issuable_events[:unassigned]} #{assignee}"
+              "#{SystemNotes::IssuablesService.issuable_events[:unassigned]} `@#{issue_event[:assignee].login}`"
             else
-              "#{SystemNotes::IssuablesService.issuable_events[:assigned]} #{assignee}"
+              "#{SystemNotes::IssuablesService.issuable_events[:assigned]} `@#{issue_event[:assignee].login}`"
             end
           end
         end
