@@ -30,7 +30,11 @@ module Gitlab
               imported_from: imported_from
             }.merge(resource_event_belongs_to(issue_event))
 
-            ResourceMilestoneEvent.create!(attrs)
+            created_event = ResourceMilestoneEvent.create!(attrs)
+
+            return unless mapper.user_mapping_enabled?
+
+            push_with_record(created_event, :user_id, issue_event[:actor].id, mapper.user_mapper)
           end
 
           def action(event_type)
