@@ -4,7 +4,10 @@ module Gitlab
   module GithubImport
     module Importer
       class NoteImporter
-        attr_reader :note, :project, :client, :user_finder
+        include Gitlab::Import::UsernameMentionRewriter
+        include Gitlab::GithubImport::PushPlaceholderReferences
+
+        attr_reader :note, :project, :client, :user_finder, :mapper
 
         # note - An instance of `Gitlab::GithubImport::Representation::Note`.
         # project - An instance of `Project`.
@@ -14,6 +17,7 @@ module Gitlab
           @project = project
           @client = client
           @user_finder = GithubImport::UserFinder.new(project, client)
+          @mapper = Gitlab::GithubImport::ContributionsMapper.new(project)
         end
 
         def execute
@@ -45,7 +49,9 @@ module Gitlab
           # Note: if you're going to replace `legacy_bulk_insert` with something that trigger callback
           # to generate HTML version - you also need to regenerate it in
           # Gitlab::GithubImport::Importer::NoteAttachmentsImporter.
-          ApplicationRecord.legacy_bulk_insert(Note.table_name, [attributes]) # rubocop:disable Gitlab/BulkInsert
+          ids = ApplicationRecord.legacy_bulk_insert(Note.table_name, [attributes], return_ids: true) # rubocop:disable Gitlab/BulkInsert
+
+          push_refs_with_ids(ids, Note, mapper.user_mapper) if mapper.user_mapping_enabled?
         end
 
         # Returns the ID of the issue or merge request to create the note for.
@@ -57,6 +63,7 @@ module Gitlab
 
         def note_body(author_found)
           text = MarkdownText.convert_ref_links(note.note, project)
+          text = wrap_mentions_in_backticks(text)
           MarkdownText.format(text, note.author, author_found)
         end
       end
