@@ -5,6 +5,8 @@ module Gitlab
     module Importer
       module PullRequests
         class MergedByImporter
+          include Gitlab::GithubImport::PushPlaceholderReferences
+
           # pull_request - An instance of
           #                `Gitlab::GithubImport::Representation::PullRequest`
           # project - An instance of `Project`
@@ -13,21 +15,27 @@ module Gitlab
             @pull_request = pull_request
             @project = project
             @client = client
+            @merged_by = pull_request.merged_by
+            @mapper = Gitlab::GithubImport::ContributionsMapper.new(project)
           end
 
           def execute
             user_finder = GithubImport::UserFinder.new(project, client)
 
-            gitlab_user_id = user_finder.user_id_for(pull_request.merged_by)
+            gitlab_user_id = user_finder.user_id_for(merged_by)
 
             metrics_upsert(gitlab_user_id)
 
-            add_note!
+            if mapper.user_mapping_enabled?
+              push_with_record(merge_request.metrics, :merged_by_id, merged_by[:id], mapper.user_mapper)
+            else
+              add_legacy_note!
+            end
           end
 
           private
 
-          attr_reader :project, :pull_request, :client
+          attr_reader :project, :pull_request, :client, :mapper, :merged_by
 
           def metrics_upsert(gitlab_user_id)
             MergeRequest::Metrics.upsert({
@@ -40,7 +48,7 @@ module Gitlab
             }, unique_by: :merge_request_id)
           end
 
-          def add_note!
+          def add_legacy_note!
             merge_request.notes.create!(
               importing: true,
               note: missing_author_note,
@@ -61,7 +69,7 @@ module Gitlab
 
           def missing_author_note
             format(s_("GitHubImporter|*Merged by: %{author} at %{timestamp}*"),
-              author: pull_request.merged_by&.login || 'ghost',
+              author: merged_by&.login || 'ghost',
               timestamp: pull_request.merged_at
             )
           end
