@@ -25,14 +25,14 @@ module Gitlab
         return if @size_gauge
 
         @size_gauge ||= ::Gitlab::Metrics.gauge(:gitlab_connection_pool_size, 'Size of connection pool', {}, :all)
-        @size_gauge.set({ pool_name: @name, pool_key: @key, connection_class: connection_class }, @size)
+        @size_gauge.set({ pool_name: @name, connection_class: connection_class }, @size)
       end
 
       def track_available_connections(connection_class)
         @available_gauge ||= ::Gitlab::Metrics.gauge(:gitlab_connection_pool_available_count,
           'Number of available connections in the pool', {}, :all)
 
-        @available_gauge.set({ pool_name: @name, pool_key: @key, connection_class: connection_class }, available)
+        @available_gauge.set({ pool_name: @name, connection_class: connection_class }, available)
       end
     end
     # rubocop:enable Gitlab/ModuleWithInstanceVariables
