@@ -68,11 +68,8 @@ module Gitlab
           if server
             # we close sockets if thread is not longer running
             # this happens, when the process forks
-            if thread.alive?
-              server.shutdown
-            else
-              server.listeners.each(&:close)
-            end
+            server.listeners.each(&:close) unless thread.alive?
+            server.shutdown
           end
 
           @server = nil
@@ -87,7 +84,7 @@ module Gitlab
             use Gitlab::Metrics::Exporter::MetricsMiddleware, pid
             use Gitlab::Metrics::Exporter::GcRequestMiddleware if gc_requests
             use ::Prometheus::Client::Rack::Exporter if ::Gitlab::Metrics.metrics_folder_present?
-            run -> (env) { [404, {}, ['']] }
+            run ->(env) { [404, {}, ['']] }
           end
         end
 
