@@ -13,6 +13,7 @@ module Gitlab
           :merge_when_pipeline_succeeds,
           :milestone,
           :remove_source_branch,
+          :squash,
           :target,
           :target_project,
           :title,
@@ -28,6 +29,9 @@ module Gitlab
       },
       secret_detection: {
         keys: [:skip_all]
+      },
+      secret_push_protection: {
+        keys: [:skip_all]
       }
     }).freeze
 
