@@ -141,9 +141,9 @@ module Gitlab
           run_label_command(labels: find_labels(labels_param), command: :relabel, updates_key: :label_ids)
         end
 
-        desc { _('Add a to do') }
-        explanation { _('Adds a to do.') }
-        execution_message { _('Added a to do.') }
+        desc { _('Add a to-do item') }
+        explanation { _('Adds a to-do item.') }
+        execution_message { _('Added a to-do item.') }
         types ::Issuable
         condition do
           quick_action_target.persisted? &&
@@ -153,9 +153,9 @@ module Gitlab
           @updates[:todo_event] = 'add'
         end
 
-        desc { _('Mark to do as done') }
-        explanation { _('Marks to do as done.') }
-        execution_message { _('Marked to do as done.') }
+        desc { _('Mark to-do item as done') }
+        explanation { _('Marks to-do item as done.') }
+        execution_message { _('Marked to-do item as done.') }
         types ::Issuable
         condition do
           quick_action_target.persisted? &&
