@@ -3,7 +3,7 @@
 module Gitlab
   module RelativePositioning
     STEPS = 10
-    IDEAL_DISTANCE = 2**(STEPS - 1) + 1
+    IDEAL_DISTANCE = (2**(STEPS - 1)) + 1
 
     MIN_POSITION = Gitlab::Database::MIN_INT_VALUE
     START_POSITION = 0
