@@ -12,21 +12,24 @@ module Gitlab
             @data[worker] = max_jobs
           end
 
+          # Returns an integer value where:
+          # - positive value is returned to enforce a valid concurrency limit
+          # - 0 value is returned for workers without concurrency limits
+          # - negative value is returned for paused workers
           def limit_for(worker:)
-            return unless data
-            return if Feature.disabled?(:sidekiq_concurrency_limit_middleware, Feature.current_request, type: :ops)
+            return 0 unless data
+            return 0 if Feature.disabled?(:sidekiq_concurrency_limit_middleware, Feature.current_request, type: :ops)
 
             worker_class = worker.is_a?(Class) ? worker : worker.class
-            data[worker_class]
+            data[worker_class]&.call.to_i
           end
 
           def over_the_limit?(worker:)
-            limit_proc = limit_for(worker: worker)
+            limit = limit_for(worker: worker)
+            return false if limit == 0
+            return true if limit < 0
 
-            limit = limit_proc&.call
-            return false if limit.to_i <= 0
-
-            current = ::Gitlab::SidekiqMiddleware::ConcurrencyLimit::WorkersConcurrency.current_for(worker: worker)
+            current = current_count(worker)
 
             current >= limit
           end
@@ -39,6 +42,12 @@ module Gitlab
 
           private
 
+          def current_count(worker)
+            worker_class = worker.is_a?(Class) ? worker : worker.class
+            worker_name = worker_class.name
+            ::Gitlab::SidekiqMiddleware::ConcurrencyLimit::ConcurrencyLimitService.concurrent_worker_count(worker_name)
+          end
+
           attr_reader :data
         end
       end
