@@ -16,11 +16,12 @@ module Gitlab
 
             yield
 
-            should_reschedule = duplicate_job.should_reschedule?
-            # Deleting before rescheduling to make sure we don't deduplicate again.
+            # early return since not reschedulable. ensure block to handle cleanup.
+            return unless duplicate_job.reschedulable?
+
             duplicate_job.delete!
             job_deleted = true
-            duplicate_job.reschedule if should_reschedule
+            duplicate_job.reschedule if duplicate_job.check_and_del_reschedule_signal
           ensure
             duplicate_job.delete! unless job_deleted
           end
