@@ -12,7 +12,11 @@ module Gitlab
       rescue Gitlab::SidekiqDaemon::Monitor::CancelledError
         # push job to DeadSet
         payload = ::Sidekiq.dump_json(job)
-        ::Sidekiq::DeadSet.new.kill(payload, notify_failure: false)
+        Gitlab::SidekiqSharding::Validator.allow_unrouted_sidekiq_calls do
+          # DeadSet is shard-local. It is correct to directly use Sidekiq.redis rather than to
+          # route to another shard's DeadSet.
+          ::Sidekiq::DeadSet.new.kill(payload, notify_failure: false)
+        end
 
         # ignore retries
         raise ::Sidekiq::JobRetry::Skip
