@@ -2,10 +2,10 @@
 
 module Gitlab
   module TemplateHelper
-    def prepare_template_environment(file)
+    def prepare_template_environment(file, user)
       return unless file
 
-      params[:import_export_upload] = ImportExportUpload.new(import_file: file)
+      params[:import_export_upload] = ImportExportUpload.new(import_file: file, user: user)
     end
 
     def tmp_filename
