@@ -57,7 +57,6 @@ module Gitlab
         {
           counts: {
             assignee_lists: count(List.assignee),
-            ci_builds: count(::Ci::Build),
             ci_external_pipelines: count(::Ci::Pipeline.external),
             ci_pipeline_config_auto_devops: count(::Ci::Pipeline.auto_devops_source),
             ci_pipeline_config_repository: count(::Ci::Pipeline.repository_source),
@@ -66,9 +65,7 @@ module Gitlab
             auto_devops_enabled: count(::ProjectAutoDevops.enabled),
             auto_devops_disabled: count(::ProjectAutoDevops.disabled),
             deploy_keys: count(DeployKey),
-            # rubocop: disable UsageData/LargeTable:
             feature_flags: count(Operations::FeatureFlag),
-            # rubocop: enable UsageData/LargeTable:
             environments: count(::Environment),
             clusters: count(::Clusters::Cluster),
             clusters_enabled: count(::Clusters::Cluster.enabled),
@@ -87,13 +84,11 @@ module Gitlab
             kubernetes_agents: count(::Clusters::Agent),
             kubernetes_agents_with_token: distinct_count(::Clusters::AgentToken, :agent_id),
             in_review_folder: count(::Environment.in_review_folder),
-            grafana_integrated_projects: count(GrafanaIntegration.enabled),
             groups: count(Group),
             issues: add_metric('CountIssuesMetric', time_frame: 'all'),
             issues_created_from_gitlab_error_tracking_ui: count(SentryIssue),
             issues_with_associated_zoom_link: count(ZoomMeeting.added_to_issue),
             issues_using_zoom_quick_actions: distinct_count(ZoomMeeting, :issue_id),
-            issues_with_embedded_grafana_charts_approx: grafana_embed_usage_data,
             incident_issues: count(::Issue.with_issue_type(:incident), start: minimum_id(Issue), finish: maximum_id(Issue)),
             alert_bot_incident_issues: count(::Issue.authored(::Users::Internal.alert_bot), start: minimum_id(Issue), finish: maximum_id(Issue)),
             keys: count(Key),
@@ -148,14 +143,6 @@ module Gitlab
         }
       end
 
-      # rubocop:disable CodeReuse/ActiveRecord
-      def grafana_embed_usage_data
-        count(Issue.joins('JOIN grafana_integrations USING (project_id)')
-          .where("issues.description LIKE '%' || grafana_integrations.grafana_url || '%'")
-          .where(grafana_integrations: { enabled: true }))
-      end
-      # rubocop: enable CodeReuse/ActiveRecord
-
       def features_usage_data = {}
 
       def components_usage_data
@@ -450,7 +437,6 @@ module Gitlab
           Gitlab::Utils::UsageData::FALLBACK
         else
           # rubocop: disable CodeReuse/ActiveRecord
-          # rubocop: disable UsageData/LargeTable
           start = ::Event.where(time_period).select(:id).order(created_at: :asc).first&.id
           finish = ::Event.where(time_period).select(:id).order(created_at: :desc).first&.id
           estimate_batch_distinct_count(::Event.where(time_period), :author_id, start: start, finish: finish)
