@@ -3,12 +3,7 @@
 module Gitlab
   module UsageDataCounters
     COUNTERS = [
-      PackageEventCounter,
-      MergeRequestCounter,
-      DesignsCounter,
       DiffsCounter,
-      KubernetesAgentCounter,
-      NoteCounter,
       WebIdeCounter,
       MergeRequestWidgetExtensionCounter
     ].freeze
