@@ -27,18 +27,33 @@ module MicrosoftTeams
 
     private
 
-    def body(activity:, title: nil, summary: nil, attachments: nil)
-      result = { 'sections' => [] }
+    def body(activity:, title: nil, attachments: nil)
+      body = [
+        {
+          type: "TextBlock",
+          text: title,
+          weight: "bolder",
+          size: "medium"
+        }
+      ]
 
-      result['title'] = title
-      result['summary'] = summary
-      result['sections'] << ::MicrosoftTeams::Activity.new(**activity).prepare
+      body << ::MicrosoftTeams::Activity.new(**activity).prepare
 
       unless attachments.blank?
-        result['sections'] << { text: attachments }
+        body << {
+          type: "TextBlock",
+          text: attachments,
+          wrap: true
+        }
       end
 
-      result.to_json
+      {
+        type: "message",
+        'attachments' => [
+          contentType: "application/vnd.microsoft.card.adaptive",
+          content: { type: "AdaptiveCard", msteams: { width: "Full" }, version: "1.0", body: body }
+        ]
+      }.to_json
     end
   end
 end
