@@ -33,6 +33,8 @@ module Sidebars
 
         override :pill_count
         def pill_count
+          return if Feature.enabled?(:async_sidebar_counts, context.group.root_ancestor)
+
           strong_memoize(:pill_count) do
             count_service = ::Groups::MergeRequestsCountService
             count = count_service.new(context.group, context.current_user).count
@@ -41,6 +43,11 @@ module Sidebars
           end
         end
 
+        override :pill_count_field
+        def pill_count_field
+          'openMergeRequestsCount' if Feature.enabled?(:async_sidebar_counts, context.group.root_ancestor)
+        end
+
         override :pill_html_options
         def pill_html_options
           {
@@ -57,6 +64,7 @@ module Sidebars
         def serialize_as_menu_item_args
           super.merge({
             pill_count: pill_count,
+            pill_count_field: pill_count_field,
             has_pill: has_pill?,
             super_sidebar_parent: ::Sidebars::Groups::SuperSidebarMenus::CodeMenu,
             item_id: :group_merge_request_list
