@@ -39,10 +39,17 @@ module Sidebars
 
         override :pill_count
         def pill_count
+          return if Feature.enabled?(:async_sidebar_counts, context.project.root_ancestor)
+
           count = @pill_count ||= context.project.open_merge_requests_count
           format_cached_count(1000, count)
         end
 
+        override :pill_count_field
+        def pill_count_field
+          'openMergeRequestsCount' if Feature.enabled?(:async_sidebar_counts, context.project.root_ancestor)
+        end
+
         override :pill_html_options
         def pill_html_options
           {
@@ -63,6 +70,7 @@ module Sidebars
         def serialize_as_menu_item_args
           super.merge({
             pill_count: pill_count,
+            pill_count_field: pill_count_field,
             has_pill: has_pill?,
             super_sidebar_parent: ::Sidebars::Projects::SuperSidebarMenus::CodeMenu,
             item_id: :project_merge_request_list
