@@ -46,7 +46,6 @@ module Users
           u.bio = 'System bot that monitors detected vulnerabilities for solutions ' \
                   'and creates merge requests with the fixes.'
           u.name = 'GitLab Security Bot'
-          u.website_url = Gitlab::Routing.url_helpers.help_page_url('user/application_security/security_bot/index.md')
           u.avatar = bot_avatar(image: 'security-bot.png')
           u.confirmed_at = Time.zone.now
           u.private_profile = true
@@ -95,7 +94,7 @@ module Users
         unique_internal(User.where(user_type: :duo_code_review_bot), 'GitLab-Duo-Code-Reviewer', email_pattern) do |u|
           u.bio = 'The reviewer bot for GitLab Duo Code Review'
           u.name = 'Duo Code Reviewer'
-          u.avatar = bot_avatar(image: 'support-bot.png') # todo: add an avatar for duo_code_review_bot
+          u.avatar = bot_avatar(image: 'duo-bot.png') # todo: add an avatar for duo_code_review_bot
           u.confirmed_at = Time.zone.now
           u.private_profile = true
         end
