@@ -9,14 +9,6 @@ module QA
         def self.included(base)
           super
 
-          base.view 'app/assets/javascripts/groups/components/overview_tabs.vue' do
-            element 'groups-filter-field'
-          end
-
-          base.view 'app/views/shared/groups/_search_form.html.haml' do
-            element 'groups-filter-field'
-          end
-
           base.view 'app/assets/javascripts/groups/components/groups.vue' do
             element 'groups-list-tree-container'
           end
@@ -37,7 +29,10 @@ module QA
         # @param name [String] group name
         # @return [Boolean] whether the filter returned any group
         def filter_group(name)
-          fill_element('groups-filter-field', name).send_keys(:return)
+          filter_input = find_element('filtered-search-term-input')
+          filter_input.click
+          filter_input.set(name)
+          click_element 'search-button'
           # Loading starts a moment after `return` is sent. We mustn't jump ahead
           wait_for_requests if spinner_exists?
           has_element?('groups-list-tree-container', wait: 1)
