@@ -76,7 +76,6 @@ module QA
 
           base.view 'app/views/layouts/nav/breadcrumbs/_breadcrumbs.html.haml' do
             element 'breadcrumb-links'
-            element 'breadcrumb-current-link'
           end
         end
 
@@ -281,7 +280,7 @@ module QA
 
         def snippet_id
           within_element('breadcrumb-links') do
-            find_element('breadcrumb-current-link').text.delete_prefix('$')
+            find('li:last-of-type').text.delete_prefix('$')
           end
         end
       end
