@@ -42,7 +42,7 @@ module QA
         end
 
         def set_content(content)
-          fill_element('markdown-editor-form-field', content)
+          fill_editor_element('markdown-editor-form-field', content)
         end
 
         def set_message(message)
@@ -67,11 +67,16 @@ module QA
         end
 
         def use_new_editor
+          return if has_element?('content-editor')
+
           click_element('editing-mode-switcher')
 
           wait_until(reload: false) do
             has_element?('content-editor')
           end
+
+          # Remove once tabindex error is fixed: https://gitlab.com/gitlab-org/gitlab/-/issues/493891
+          sleep 2
         end
       end
     end
