@@ -5,12 +5,12 @@ module QA
     module Layout
       class Banner < Page::Base
         view 'app/views/layouts/header/_read_only_banner.html.haml' do
-          element :flash_notice, ".flash-notice" # rubocop:disable QA/ElementWithPattern
+          element 'read-only-banner'
         end
 
         def has_notice?(message)
-          page.within('.flash-notice') do
-            !!find('span', text: message)
+          page.within('.gl-alert') do
+            !!find('.gl-alert-body', text: message)
           end
         end
       end
