@@ -4,7 +4,7 @@ module QA
   module Page
     module MergeRequest
       class Index < Page::Base
-        view 'app/views/shared/empty_states/_merge_requests_without_filters.html.haml' do
+        view 'app/views/shared/empty_states/_merge_requests.html.haml' do
           element 'new-merge-request-button'
         end
 
