@@ -90,6 +90,10 @@ module QA
           element 'squash-checkbox'
         end
 
+        view 'app/assets/javascripts/vue_merge_request_widget/components/states/ready_to_merge.vue' do
+          element 'widget_edit_commit_message'
+        end
+
         view 'app/assets/javascripts/vue_merge_request_widget/mr_widget_options.vue' do
           element 'mr-widget-content'
           element 'pipeline-container'
@@ -99,6 +103,10 @@ module QA
           element 'artifacts-dropdown'
         end
 
+        view 'app/assets/javascripts/content_editor/components/formatting_toolbar.vue' do
+          element 'code-suggestion'
+        end
+
         view 'app/assets/javascripts/vue_shared/components/markdown/apply_suggestion.vue' do
           element 'apply-suggestion-dropdown'
           element 'commit-message-field'
@@ -145,6 +153,7 @@ module QA
         end
 
         def start_review
+          has_active_element?('start-review-button', wait: 0.5)
           click_element('start-review-button')
 
           # After clicking the button, wait for it to disappear
@@ -194,7 +203,7 @@ module QA
           click_element('dismiss-suggestion-popover-button') if has_element?('dismiss-suggestion-popover-button',
             wait: 1)
 
-          fill_element('reply-field', text)
+          fill_editor_element('reply-field', text)
         end
 
         def click_discussions_tab
@@ -208,8 +217,7 @@ module QA
         end
 
         def click_diffs_tab
-          # Do not wait for spinner due to https://gitlab.com/gitlab-org/gitlab/-/issues/398584
-          click_element('diffs-tab', skip_finished_loading_check: true)
+          click_element('diffs-tab')
         end
 
         def click_pipeline_link
@@ -296,6 +304,10 @@ module QA
           check_element('squash-checkbox', true)
         end
 
+        def edit_commit_message
+          check_element('widget_edit_commit_message', true)
+        end
+
         def merge!
           try_to_merge!
           finished_loading?
@@ -309,6 +321,10 @@ module QA
           click_element('merge-button', text: 'Set to auto-merge')
         end
 
+        def auto_mergeable?
+          has_element?('merge-button', text: 'Set to auto-merge', wait: 10)
+        end
+
         def merged?
           # Reloads the page at this point to avoid the problem of the merge status failing to update
           # That's the transient UX issue this test is checking for, so if the MR is merged but the UI still shows the
@@ -342,8 +358,7 @@ module QA
         # then check again if it's ready to merge. For example, it will refresh if a new change was pushed and the page
         # needs to be refreshed to show the change.
         #
-        # @param [Boolean] transient_test true if the current test is a transient test (default: false)
-        def wait_until_ready_to_merge(transient_test: false)
+        def wait_until_ready_to_merge
           wait_until(message: "Waiting for ready to merge", sleep_interval: 1) do
             # changes in mr are rendered async, because of that mr can sometimes show no changes and there will be no
             # merge button, in such case we must retry loop otherwise find_element will raise ElementNotFound error
@@ -354,10 +369,6 @@ module QA
             # If the widget shows "Merge blocked: new changes were just added" we can refresh the page and check again
             next false if has_element?('head-mismatch-content', wait: 1)
 
-            # Stop waiting if we're in a transient test. By this point we're in an unexpected state and should let the
-            # test fail so we can investigate. If we're not in a transient test we keep trying until we reach timeout.
-            next true unless transient_test
-
             QA::Runtime::Logger.debug("MR widget text: #{mr_widget_text}")
 
             false
@@ -391,11 +402,9 @@ module QA
           end
         end
 
-        def try_to_merge!
-          # Revisit after merge page re-architect is done https://gitlab.com/gitlab-org/gitlab/-/issues/300042
-          # To remove page refresh logic if possible
+        def try_to_merge!(wait_for_no_auto_merge: true)
           wait_until_ready_to_merge
-          wait_until { !find_element('merge-button').text.include?('auto-merge') } # rubocop:disable Rails/NegateInclude
+          wait_until { !find_element('merge-button').text.include?('auto-merge') } if wait_for_no_auto_merge # rubocop:disable Rails/NegateInclude -- Wait for text auto-merge to change
 
           click_element('merge-button')
         end
@@ -437,10 +446,20 @@ module QA
         def add_suggestion_to_diff(suggestion, line)
           find("a[data-linenumber='#{line}']").hover
           click_element('left-comment-button')
-          click_element('suggestion-button')
-          initial_content = find_element('reply-field').value
-          fill_element('reply-field', '')
-          fill_element('reply-field', initial_content.gsub(/(```suggestion:-0\+0\n).*(\n```)/, "\\1#{suggestion}\\2"))
+
+          if has_element?('suggestion-button', wait: 0.5)
+            click_element('suggestion-button')
+            initial_content = find_element('reply-field').value
+            fill_editor_element('reply-field', '')
+            fill_editor_element('reply-field',
+              initial_content.gsub(/(```suggestion:-0\+0\n).*(\n```)/, "\\1#{suggestion}\\2"))
+          else
+            click_element('code-suggestion')
+            suggestion_field = find_element('suggestion-field')
+            suggestion_field.set(suggestion)
+            has_active_element?('comment-now-button', wait: 0.5)
+          end
+
           click_element('comment-now-button')
           wait_for_requests
         end
