@@ -227,7 +227,6 @@ module QA
           def create_merge_request
             within_vscode_editor do
               within_element('.notification-toast-container') do
-                has_element?('div[title="GitLab Web IDE Extension (Extension)"]')
                 click_monaco_button('Create MR')
               end
             end
@@ -267,11 +266,10 @@ module QA
             within_vscode_editor do
               within_file_editor do
                 wait_until(reload: false, max_duration: 30, message: 'Waiting for Code Suggestion to start loading') do
-                  has_code_suggestions_status?('loading')
+                  code_suggestion_loading?
                 end
 
-                # Wait for code suggestion to finish loading
-                wait_until_code_suggestions_enabled
+                wait_until_code_suggestion_loaded
               end
             end
           end
@@ -354,6 +352,10 @@ module QA
             page.document.has_css?(code_suggestions_icon_selector(status))
           end
 
+          def code_suggestion_loading?
+            page.document.has_css?('.glyph-margin-widgets .codicon', wait: 0)
+          end
+
           def has_code_suggestions_error?
             !page.document.has_no_css?(code_suggestions_icon_selector('error'))
           end
@@ -374,6 +376,15 @@ module QA
               has_code_suggestions_status_without_error?('enabled')
             end
           end
+
+          def wait_until_code_suggestion_loaded
+            wait_until(reload: false, max_duration: 30, skip_finished_loading_check_on_refresh: true,
+              message: 'Wait for Code Suggestion to finish loading') do
+              raise code_suggestions_error if has_code_suggestions_error?
+
+              !code_suggestion_loading?
+            end
+          end
         end
       end
     end
