@@ -18,10 +18,6 @@ module QA
           click_element('nav-item-link', submenu_item: 'Code')
         end
 
-        def switch_to_projects
-          switch_to_tab(:projects_tab)
-        end
-
         def has_project_in_search_result?(project_name)
           has_element?('result-item-content', text: project_name)
         end
@@ -42,15 +38,6 @@ module QA
         def has_project?(project_name)
           has_element?('project-content', project_name: project_name)
         end
-
-        private
-
-        def switch_to_tab(tab)
-          retry_until do
-            click_element(tab)
-            has_active_element?(tab)
-          end
-        end
       end
     end
   end
