@@ -10,8 +10,7 @@ module QA
           QA::Resource::Clusters::Agent.fabricate_via_api!
         end
 
-        def fabricate!
-        end
+        def fabricate!; end
 
         def resource_web_url(resource)
           super
