@@ -106,11 +106,7 @@ module QA
         Page::Project::New.perform(&:click_blank_project_link)
 
         Page::Project::New.perform do |new_page|
-          if @personal_namespace
-            new_page.choose_namespace(@personal_namespace)
-          else
-            new_page.choose_test_namespace
-          end
+          new_page.choose_namespace(@personal_namespace || group.path)
 
           new_page.choose_name(@name)
           new_page.add_description(@description) if @description
@@ -412,7 +408,28 @@ module QA
       end
 
       def latest_pipeline
-        parse_body(api_get_from(api_latest_pipeline_path))
+        # Observing in https://gitlab.com/gitlab-org/gitlab/-/issues/481642#note_2081214771
+        # Sometimes in either canary or staging-canary,
+        # GET latest pipeline immediately after 1st pipeline was created seems to cause 500 or 502
+        # Adding a retry block with `retry_on_exception: true` to reduce flakiness
+        #
+        retry_until do
+          response = get(request_url(api_latest_pipeline_path))
+          response.code == HTTP_STATUS_OK
+        rescue ResourceQueryError
+          raise(
+            "Could not GET project's latest pipeline. Request returned (#{response.code}): `#{response}`."
+          )
+        end
+
+        parse_body(get(request_url(api_latest_pipeline_path)))
+      end
+
+      def visit_latest_pipeline
+        url = latest_pipeline[:web_url]
+        Runtime::Logger.info("Visiting #{Rainbow(self.class.name).black.bg(:white)}'s latest pipeline at #{url}")
+        visit(url)
+        Support::WaitForRequests.wait_for_requests
       end
 
       # Waits for a pipeline to be available with the attributes as specified.
@@ -437,6 +454,13 @@ module QA
         jobs.find { |job| job[:name] == job_name }
       end
 
+      def visit_job(job_name)
+        url = job_by_name(job_name)[:web_url]
+        Runtime::Logger.info("Visiting #{Rainbow(self.class.name).black.bg(:white)}'s job #{job_name} at #{url}")
+        visit(url)
+        Support::WaitForRequests.wait_for_requests
+      end
+
       def issues(auto_paginate: false, attempts: 0)
         return parse_body(api_get_from(api_issues_path)) unless auto_paginate
 
@@ -493,7 +517,7 @@ module QA
       # Uses the API to wait until a pull mirroring update is successful (pull mirroring is treated as an import)
       def wait_for_pull_mirroring
         mirror_succeeded = Support::Retrier.retry_until(
-          max_duration: 180,
+          max_duration: 360,
           raise_on_failure: false,
           sleep_interval: 1
         ) do
@@ -501,7 +525,10 @@ module QA
           api_resource[:import_status] == "finished"
         end
 
-        raise "Mirroring failed with error: #{api_resource[:import_error]}" unless mirror_succeeded
+        return if mirror_succeeded
+
+        mirror_error = api_resource[:import_error] || 'Did not complete within 360 seconds'
+        raise "Mirroring was not successful: #{mirror_error}}"
       end
 
       def remove_via_api!
