@@ -21,26 +21,11 @@ module QA
         true
       end
 
-      ##
-      # Visit a page that belongs to a GitLab instance under given address.
-      #
-      # Example:
-      #
-      # visit(:gitlab, Page::Main::Login)
-      # visit('http://gitlab.example/users/sign_in')
-      #
-      # In case of an address that is a symbol we will try to guess address
-      # based on `Runtime::Scenario#something_address`.
-      #
-      def visit(address, page_class, &block)
-        Browser::Session.new(address, page_class).perform(&block)
+      def self.visit(address, page_class, &)
+        new.visit(address, page_class, &)
       end
 
-      def self.visit(address, page_class, &block)
-        new.visit(address, page_class, &block)
-      end
-
-      def self.configure! # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity
+      def self.configure! # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity -- TODO: Break up this method
         return if QA::Runtime::Env.dry_run
         return if @configured
 
@@ -72,6 +57,8 @@ module QA
             # Disable /dev/shm use in CI. See https://gitlab.com/gitlab-org/gitlab/issues/4252
             chrome_options[:args] << 'disable-dev-shm-usage' if QA::Runtime::Env.disable_dev_shm?
 
+            chrome_options[:args] << 'disable-search-engine-choice-screen'
+
             # Allows chrome to consider all actions as secure when no ssl is used
             Runtime::Scenario.attributes[:gitlab_address].tap do |address|
               next unless address.start_with?('http://')
@@ -203,10 +190,7 @@ module QA
         end
 
         Capybara::Screenshot.register_filename_prefix_formatter(:rspec) do |example|
-          ::File.join(
-            QA::Runtime::Namespace.name(reset_cache: false),
-            example.full_description.downcase.parameterize(separator: "_")[0..79]
-          )
+          ::File.join("failure_screenshots", example.full_description.downcase.parameterize(separator: "_")[0..79])
         end
 
         Capybara.configure do |config|
@@ -221,12 +205,6 @@ module QA
           config.default_normalize_ws = true
         end
 
-        Chemlab.configure do |config|
-          config.browser = Capybara.current_session.driver.browser # reuse Capybara session
-          config.base_url = Runtime::Scenario.attributes[:gitlab_address] # reuse GitLab address
-          config.hide_banner = true
-        end
-
         @configured = true
       end
 
@@ -240,11 +218,69 @@ module QA
         ::File.expand_path('../../tmp/qa-profile', __dir__)
       end
 
+      ##
+      # Visit a page that belongs to a GitLab instance under given address.
+      #
+      # Example:
+      #
+      # visit(:gitlab, Page::Main::Login)
+      # visit('http://gitlab.example/users/sign_in')
+      #
+      # In case of an address that is a symbol we will try to guess address
+      # based on `Runtime::Scenario#something_address`.
+      #
+      def visit(address, page_class, &)
+        Browser::Session.new(address, page_class).perform(&)
+      end
+
       class Session
         include Capybara::DSL
 
         attr_reader :page_class
 
+        # To redirect the browser to a canary or non-canary web node
+        #   after loading a subject test page
+        # @param [Boolean] Send to canary true or false
+        # @example:
+        #   Runtime::Browser::Session.target_canary(true)
+        def self.target_canary(enable_canary)
+          if QA::Runtime::Env.qa_cookies.to_s.include?("gitlab_canary=true")
+            QA::Runtime::Logger.warn("WARNING: Setting cookie through QA_COOKIES var is incompatible with this method.")
+            return
+          end
+
+          browser = Capybara.current_session.driver.browser
+
+          if enable_canary
+            browser.manage.add_cookie name: "gitlab_canary", value: "true"
+          else
+            browser.manage.delete_cookie("gitlab_canary")
+          end
+
+          browser.navigate.refresh
+        end
+
+        def self.enable_interception
+          script = File.read("#{__dir__}/script_extensions/interceptor.js")
+          command = {
+            cmd: 'Page.addScriptToEvaluateOnNewDocument',
+            params: {
+              source: script
+            }
+          }
+          @interceptor_script_params = Capybara.current_session.driver.browser.send(:bridge).send_command(command)
+        end
+
+        def self.disable_interception
+          return unless @interceptor_script_params
+
+          command = {
+            cmd: 'Page.removeScriptToEvaluateOnNewDocument',
+            params: @interceptor_script_params
+          }
+          Capybara.current_session.driver.browser.send(:bridge).send_command(command)
+        end
+
         def initialize(instance, page_class)
           @session_address = Runtime::Address.new(instance, page_class)
           @page_class = page_class
@@ -278,28 +314,6 @@ module QA
           yield.tap { clear! } if block
         end
 
-        # To redirect the browser to a canary or non-canary web node
-        #   after loading a subject test page
-        # @param [Boolean] Send to canary true or false
-        # @example:
-        #   Runtime::Browser::Session.target_canary(true)
-        def self.target_canary(enable_canary)
-          if QA::Runtime::Env.qa_cookies.to_s.include?("gitlab_canary=true")
-            QA::Runtime::Logger.warn("WARNING: Setting cookie through QA_COOKIES var is incompatible with this method.")
-            return
-          end
-
-          browser = Capybara.current_session.driver.browser
-
-          if enable_canary
-            browser.manage.add_cookie name: "gitlab_canary", value: "true"
-          else
-            browser.manage.delete_cookie("gitlab_canary")
-          end
-
-          browser.navigate.refresh
-        end
-
         ##
         # Selenium allows to reset session cookies for current domain only.
         #
@@ -311,27 +325,6 @@ module QA
           @network_conditions_configured = false
         end
 
-        def self.enable_interception
-          script = File.read("#{__dir__}/script_extensions/interceptor.js")
-          command = {
-            cmd: 'Page.addScriptToEvaluateOnNewDocument',
-            params: {
-              source: script
-            }
-          }
-          @interceptor_script_params = Capybara.current_session.driver.browser.send(:bridge).send_command(command)
-        end
-
-        def self.disable_interception
-          return unless @interceptor_script_params
-
-          command = {
-            cmd: 'Page.removeScriptToEvaluateOnNewDocument',
-            params: @interceptor_script_params
-          }
-          Capybara.current_session.driver.browser.send(:bridge).send_command(command)
-        end
-
         private
 
         def simulate_slow_connection
