@@ -2,14 +2,12 @@
 
 module QA
   module Runtime
+    # TODO: remove once all user handling logic is moved to UserStore class
     module User
       extend self
 
       def admin
-        QA::Resource::User.init do |user|
-          user.username = admin_username
-          user.password = admin_password
-        end
+        UserStore.admin_user
       end
 
       def default_username
