@@ -27,7 +27,6 @@ module QA
         def setup
           login_if_not_already_logged_in
           create_cluster
-          install_helm
         end
 
         def teardown
@@ -51,7 +50,6 @@ module QA
             helm upgrade --install gitlab-agent gitlab/gitlab-agent
               --namespace "#{agent_name}"
               --create-namespace
-              --set image.tag=#{Runtime::Env.gitlab_agentk_version}
               --set config.token=#{agent_token}
               --set config.kasAddress=#{kas_address}
               --set config.kasHeaders="{Cookie: gitlab_canary=#{target_canary?}}"
@@ -79,6 +77,16 @@ module QA
           CMD
         end
 
+        def wait_for_pod(namespace)
+          shell <<~CMD.tr("\n", ' ')
+            kubectl wait pod \
+              --all \
+              --for=condition=Ready \
+              --namespace=#{namespace} \
+              --timeout=300s
+          CMD
+        end
+
         def install_gitlab_workspaces_proxy
           cmd_str = <<~CMD.tr("\n", ' ')
             helm repo add gitlab-workspaces-proxy \
@@ -86,7 +94,7 @@ module QA
             helm repo update &&
             helm upgrade --install gitlab-workspaces-proxy \
               gitlab-workspaces-proxy/gitlab-workspaces-proxy \
-              --version 0.1.12 \
+              --version #{Runtime::Env.workspaces_proxy_version} \
               --namespace=gitlab-workspaces \
               --create-namespace \
               --set="auth.client_id=#{Runtime::Env.workspaces_oauth_app_id}" \
@@ -126,14 +134,6 @@ module QA
 
         private
 
-        def install_helm
-          shell <<~CMD.tr("\n", ' ')
-            curl -fsSL -o get_helm.sh https://raw.githubusercontent.com/helm/helm/main/scripts/get-helm-3 &&
-            chmod 700 get_helm.sh &&
-            DESIRED_VERSION=v3.14.0 ./get_helm.sh
-          CMD
-        end
-
         def target_canary?
           Runtime::Env.qa_cookies.to_s.include?("gitlab_canary=true")
         end
