@@ -23,7 +23,7 @@ module QA
       end
 
       it(
-        'can be used to create a file via the project API', :blocking,
+        'can be used to create a file via the project API', :smoke,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/367064'
       ) do
         expect do
@@ -38,7 +38,7 @@ module QA
       end
 
       it(
-        'can be used to commit via the API', :blocking,
+        'can be used to commit via the API', :smoke,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/367067'
       ) do
         expect do
