@@ -31,6 +31,10 @@ module QA
 
         it(
           'successfully imports groups and labels',
+          quarantine: {
+            issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/475036',
+            type: :investigating
+          },
           testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347674'
         ) do
           expect_group_import_finished_successfully
