@@ -25,8 +25,7 @@ module QA
       let!(:source_admin_api_client) do
         Runtime::API::Client.new(
           source_gitlab_address,
-          personal_access_token: ENV["QA_LARGE_IMPORT_GL_TOKEN"] || raise("missing QA_LARGE_IMPORT_GL_TOKEN variable"),
-          is_new_session: false
+          personal_access_token: ENV["QA_LARGE_IMPORT_GL_TOKEN"] || raise("missing QA_LARGE_IMPORT_GL_TOKEN variable")
         )
       end
 
@@ -51,10 +50,13 @@ module QA
       let!(:api_client) do
         Runtime::API::Client.new(
           user: user,
-          is_new_session: false,
           # importing very large project can take multiple days
           # token must not expire while we still poll for import result
-          personal_access_token: create(:personal_access_token, user: user, expires_at: (Time.now.to_date + 6)).token
+          personal_access_token: create(
+            :personal_access_token,
+            user_id: user.id,
+            expires_at: (Time.now.to_date + 6)
+          ).token
         )
       end
 
@@ -303,8 +305,8 @@ module QA
 
           # Print difference in the description
           #
-          expected_body = expected_item[:body]
-          actual_body = actual_item[:body]
+          expected_body = remove_backticks(expected_item[:body])
+          actual_body = remove_backticks(actual_item[:body])
           body_msg = "#{msg} same description. diff:\n#{differ.diff(expected_body, actual_body)}"
           expect(actual_body).to eq(expected_body), body_msg
 
@@ -317,8 +319,8 @@ module QA
 
           # Print amount difference first
           #
-          expected_comments = expected_item[:comments]
-          actual_comments = actual_item[:comments]
+          expected_comments = expected_item[:comments].map { |comment| remove_backticks(comment) }
+          actual_comments = actual_item[:comments].map { |comment| remove_backticks(comment) }
           comment_count_msg = <<~MSG
             #{msg} same amount of comments. Source: #{expected_comments.length}, Target: #{actual_comments.length}
           MSG
@@ -429,6 +431,16 @@ module QA
         @created_by_pattern ||= /\n\n \*By .+ on \S+\*/
       end
 
+      # Remove backticks from string
+      #
+      # @param [String] text
+      # @return [String] modified text
+      def remove_backticks(text)
+        return unless text.present?
+
+        text.delete('`')
+      end
+
       # Source project url
       #
       # @return [String]
