@@ -3,6 +3,11 @@
 module QA
   RSpec.describe 'Create' do
     describe 'Prereceive hook', product_group: :source_code do
+      # NOTE: this test requires a global server hook to be configured in the target test environment.
+      # If running this test against a local GDK installation, please follow the instructions in the
+      # following guide to set up the hook:
+      # https://gitlab.com/gitlab-org/gitlab/-/blob/master/doc/development/testing_guide/end_to_end/running_tests_that_require_special_setup.md#tests-that-require-a-global-server-hook
+
       let(:project) { create(:project, :with_readme) }
 
       context 'when creating a tag for a ref' do
@@ -14,8 +19,7 @@ module QA
             project.change_path("project-reject-prereceive-#{SecureRandom.hex(8)}")
           end
 
-          it 'returns a custom server hook error',
-            :skip_live_env,
+          it 'returns a custom server hook error', :blocking, :skip_live_env,
             except: { job: 'review-qa-*' },
             testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/369053' do
             expect { project.create_repository_tag('v1.2.3') }
