@@ -3,10 +3,8 @@
 module QA
   RSpec.describe 'Verify', :requires_admin, :blocking, product_group: :pipeline_execution do
     describe 'When user is blocked' do
-      let!(:admin_api_client) { Runtime::API::Client.as_admin }
-      let!(:user_api_client) { Runtime::API::Client.new(:gitlab, user: user) }
-
-      let(:user) { create(:user, api_client: admin_api_client) }
+      let(:user) { create(:user).tap(&:create_personal_access_token!) }
+      let(:admin_user) { Runtime::UserStore.admin_user }
 
       let(:project) { create(:project, name: 'project-for-canceled-schedule') }
       let(:ref) { 'master' }
@@ -19,21 +17,18 @@ module QA
         # Long term solution to accessing the status of a project authorization update
         # has been proposed in https://gitlab.com/gitlab-org/gitlab/-/issues/393369
         Support::Retrier.retry_on_exception(max_attempts: 60, sleep_interval: 1) do
-          create(:pipeline_schedule, ref: ref, api_client: user_api_client, project: project)
+          create(:pipeline_schedule, ref: ref, api_client: user.api_client, project: project)
         end
 
         Support::Waiter.wait_until { !pipeline_schedule[:id].nil? && pipeline_schedule[:active] == true }
       end
 
-      after do
-        user.remove_via_api!
-        project.remove_via_api!
-      end
+      it 'pipeline schedule is canceled',
+        testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347999' do
+        admin_user.block!(user.id)
 
-      it 'pipeline schedule is canceled', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347999' do
-        user.block!
-
-        expect(pipeline_schedule[:active]).not_to be_truthy, "Expected schedule active state to be false - active state #{pipeline_schedule[:active]}"
+        expect(pipeline_schedule[:active]).not_to be_truthy,
+          "Expected schedule active state to be false - active state #{pipeline_schedule[:active]}"
       end
 
       private
