@@ -6,7 +6,7 @@ module QA
       let(:group_access_token) { QA::Resource::GroupAccessToken.fabricate_via_browser_ui! }
 
       it(
-        'can be created and revoked via the UI', :blocking,
+        'can be created and revoked via the UI', :smoke,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/367044'
       ) do
         expect(group_access_token.token).not_to be_nil
