@@ -4,7 +4,7 @@ module QA
   RSpec.describe 'Govern', :orchestrated, :instance_saml, product_group: :authentication do
     describe 'Instance wide SAML SSO' do
       it(
-        'user logs in to gitlab with SAML SSO',
+        'user logs in to gitlab with SAML SSO', :blocking,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347895'
       ) do
         Runtime::Browser.visit(:gitlab, Page::Main::Login)
