@@ -20,10 +20,6 @@ module QA
         create(:issue, project: project).visit!
       end
 
-      after do
-        user&.remove_via_api!
-      end
-
       it 'mentions a user in a comment', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347949' do
         Page::Project::Issue::Show.perform do |show|
           show.select_all_activities_filter
