@@ -1,12 +1,7 @@
 # frozen_string_literal: true
 
 module QA
-  RSpec.describe 'Plan', :blocking, product_group: :knowledge,
-    quarantine: {
-      only: { job: 'relative-url' },
-      issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/409541',
-      type: :bug
-    } do
+  RSpec.describe 'Plan', :blocking, product_group: :knowledge do
     describe 'Testing project wiki file upload' do
       let(:initial_wiki) { create(:project_wiki_page) }
       let(:page_title) { 'Content Editor Page' }
@@ -17,10 +12,6 @@ module QA
         Flow::Login.sign_in
       end
 
-      after do
-        initial_wiki.project.remove_via_api!
-      end
-
       it 'by creating a formatted page with an image uploaded',
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347640' do
         initial_wiki.visit!
