@@ -16,10 +16,6 @@ module QA
         commit.visit!
       end
 
-      after do
-        project.remove_via_api!
-      end
-
       it 'creates a merge request', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347716' do
         Page::Project::Commit::Show.perform(&:revert_commit)
         Page::MergeRequest::New.perform(&:create_merge_request)
