@@ -6,7 +6,7 @@ module QA
       it('configures and syncs a (push) mirrored repository',
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347741',
         quarantine: {
-          only: { condition: -> { ENV['QA_RUN_TYPE'] == 'e2e-package-and-test-ce' } },
+          only: { condition: -> { ENV['QA_RUN_TYPE'] == 'e2e-test-on-omnibus-ce' } },
           issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/412611',
           type: :investigating
         }
