@@ -7,14 +7,7 @@ module QA
       # See: https://gitlab.com/gitlab-org/gitlab-qa/blob/master/docs/run_qa_against_gdk.md
 
       let(:project) { create(:project, name: 'ssh-tests') }
-
-      before(:context) do
-        @key = create(:ssh_key, title: "key for ssh tests #{Time.now.to_f}")
-      end
-
-      after(:context) do
-        @key&.remove_via_api!
-      end
+      let(:key) { create(:ssh_key, title: "key for ssh tests #{Time.now.to_f}") }
 
       before do
         Flow::Login.sign_in
@@ -24,11 +17,13 @@ module QA
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347825' do
         Resource::Repository::ProjectPush.fabricate! do |push|
           push.project = project
-          push.ssh_key = @key
+          push.ssh_key = key
           push.file_name = 'README.md'
           push.file_content = '# Test Use SSH Key'
           push.commit_message = 'Add README.md'
-        end.project.visit!
+        end
+
+        project.visit!
 
         Page::Project::Show.perform do |project|
           expect(project).to have_file('README.md')
@@ -42,9 +37,9 @@ module QA
         tags = []
         Git::Repository.perform do |repository|
           repository.uri = project.repository_ssh_location.uri
-          repository.use_ssh_key(@key)
+          repository.use_ssh_key(key)
           repository.clone
-          repository.configure_identity('GitLab QA', 'root@gitlab.com')
+          repository.use_default_identity
           1.upto(3) do |i|
             branches << "branch#{i}"
             tags << "tag#{i}"
