@@ -3,13 +3,9 @@
 module QA
   RSpec.describe 'Create', product_group: :remote_development do
     describe 'Add a directory in Web IDE' do
+      include_context 'Web IDE test prep'
       let(:project) { create(:project, :with_readme, name: 'webide-add-directory-project') }
 
-      before do
-        Flow::Login.sign_in
-        project.visit!
-      end
-
       context 'when a directory with the same name already exists' do
         let(:directory_name) { 'first_directory' }
 
