@@ -3,16 +3,12 @@
 module QA
   RSpec.describe 'Create', product_group: :remote_development do
     describe 'Closing Web IDE' do
+      include_context "Web IDE test prep"
       let(:file_name) { 'file.txt' }
       let(:project) { create(:project, :with_readme, name: 'webide-close-with-unsaved-changes') }
 
       before do
-        Flow::Login.sign_in
-        project.visit!
-        Page::Project::Show.perform(&:open_web_ide!)
-        Page::Project::WebIDE::VSCode.perform do |ide|
-          ide.wait_for_ide_to_load('README.md')
-        end
+        load_web_ide
       end
 
       it 'shows an alert when there are unsaved changes', :blocking,
